@@ -284,7 +284,10 @@ module.exports = {
         'no-redeclare': 2,
 
         // disallow certain object properties
-        'no-restricted-properties': [2/*, { 'object': '', 'property': '' }*/],
+        'no-restricted-properties': [2, {
+            'property': 'DRAWING_INSERT',
+            'message': 'Please use INSERT_DRAWING.'
+        }],
 
         // disallow use of assignment in return statement
         'no-return-assign': [2, 'except-parens'],
