@@ -18,9 +18,9 @@ define('io.ox/office/baseframework/app/applicationlauncher', [
     'io.ox/office/tk/utils',
     'io.ox/office/tk/config',
     'io.ox/office/tk/forms',
-    'io.ox/office/tk/utils/deferredutils',
+    'io.ox/office/tk/utils/scheduler',
     'less!io.ox/office/baseframework/view/basestyle'
-], function (ext, Utils, Config, Forms, DeferredUtils) {
+], function (ext, Utils, Config, Forms, Scheduler) {
 
     'use strict';
 
@@ -54,7 +54,7 @@ define('io.ox/office/baseframework/app/applicationlauncher', [
      *  The state of the stand-alone mode.
      */
     ApplicationLauncher.getStandaloneMode = function () {
-        if (Config.getFlag('standalone')) { return true; }
+        if (Config.getFlag('module/standalone')) { return true; }
         var standalone = (window.self !== window.top) ? _.deserialize(window.self.location.hash.substr(1)).standalone : _.url.hash('standalone');
         return standalone ? (standalone.toLowerCase() === 'true' || standalone === '1') : false;
     };
@@ -137,14 +137,45 @@ define('io.ox/office/baseframework/app/applicationlauncher', [
             logout: function () {
                 var promises = _.map(ox.ui.App.get(moduleName), function (app) {
                     // bug 33152: ignore the result of the quit handlers (rejected promise cancels logout)
-                    var def = DeferredUtils.createDeferred(app, 'ApplicationLauncher: logoutListener');
-                    app.executeQuitHandlers('logout').always(function () { def.resolve(); });
-                    return def.promise();
+                    return app.executeQuitHandlers('logout').then(null, _.constant($.when()));
                 });
                 return $.when.apply($, promises);
             }
         });
 
+        function launchAuthorizer(app, launchOptions, appWindow, shortFileName) {
+            require(['io.ox/guard/auth/authorizer'], function (authorizer) {
+                authorizer.authorize().then(function (auth_code) {
+                    // do function, sending the auth_code with the decode command
+                    launchOptions.auth_code = auth_code;
+                    launchApp(app, launchOptions, appWindow, shortFileName);
+                }).fail(function () {
+                    app.quit();
+                });
+            });
+        }
+
+        function launchApp(app, launchOptions, appWindow, shortFileName) {
+            // show a busy blocker screen to give the user a quick feedback that the app is starting
+            if (launchOptions.hidden !== true) {
+                appWindow.show();
+                appWindow.setTitle(shortFileName);
+                appWindow.busy(null, null, null, { showFileName: true });
+            }
+
+            // load the application mix-in constructor for the current application type
+            require([moduleName + '/app/application']).done(function (ApplicationClass) {
+
+                // the application may have been closed very quickly before RequireJS
+                // provides the application module
+                if (!app.cid) { return; }
+
+                // construct with mix-in application class (with the disadvantage that
+                // the application is not an instance of ApplicationClass)
+                ApplicationClass.call(app, launchOptions);
+            });
+        }
+
         function getFullFileName(file) {
             return (file && (file['com.openexchange.file.sanitizedFilename'] || file.filename)) || '\xa0';
         }
@@ -193,7 +224,7 @@ define('io.ox/office/baseframework/app/applicationlauncher', [
 
             // the name of the edited file, with and without extension
             var fullFileName = getFullFileName(launchOptions.file);
-            var shortFileName = Utils.getFileBaseName(fullFileName);
+            var shortFileName = Utils.getFileBaseName(fullFileName, true);
             var encrypted = Utils.isGuardEncrypted(fullFileName);
 
             // no running application: create and initialize a new application object
@@ -215,16 +246,16 @@ define('io.ox/office/baseframework/app/applicationlauncher', [
             });
             app.setWindow(appWindow);
 
+            // bug 53506: track whether the busy mode is currently active
+            var isBusy = false;
+
             appWindow.isBusy = function () {
-                return !!this.nodes.blocker && this.nodes.blocker.is(':visible');
+                return isBusy;
             };
 
             // override the busy() method of the application window to add Documents specific stuff
             appWindow.busy = _.wrap(appWindow.busy, function (busyMethod, pct, sub, callback, options) {
 
-                // store current busy state
-                var isAlreadyBusy = this.isBusy();
-
                 // invoke core method
                 return busyMethod.call(this, pct, sub, function () {
 
@@ -235,7 +266,8 @@ define('io.ox/office/baseframework/app/applicationlauncher', [
                     var footerNode = blockerNode.find('.footer');
 
                     // initialization when busy mode starts
-                    if (!isAlreadyBusy) {
+                    if (!isBusy) {
+                        isBusy = true;
 
                         // clean header/footer container nodes
                         headerNode.empty();
@@ -255,57 +287,54 @@ define('io.ox/office/baseframework/app/applicationlauncher', [
                         }
                     }
 
-                    // invoke the user-defined callback function
+                    // always invoke the user-defined callback function
                     if (_.isFunction(callback)) {
-                        return callback.call(appWindow, blockerNode, headerNode, footerNode, isAlreadyBusy);
+                        return callback.call(appWindow, blockerNode, headerNode, footerNode);
                     }
                 });
             });
 
+            appWindow.idle = _.wrap(appWindow.idle, function (idleMethod) {
+                if (isBusy) {
+                    idleMethod.call(this);
+                    isBusy = false;
+                }
+                return this;
+            });
+
             // bug 46405: override the launch method of the application instance to be able to fetch
             // the application mix-in class on demand, and to defer invocation of the original launch
             // method until the application has been extended with that mix-in class
             app.setLauncher(function () {
 
-                var launchApp = function () {
-                    // show a busy blocker screen to give the user a quick feedback that the app is starting
-                    if (launchOptions.hidden !== true) {
-                        appWindow.show();
-                        appWindow.setTitle(shortFileName);
-                        appWindow.busy(null, null, null, { showFileName: true });
-                    }
-
-                    // load the application mix-in constructor for the current application type
-                    require([moduleName + '/app/application']).done(function (ApplicationClass) {
-
-                        // the application may have been closed very quickly before RequireJS
-                        // provides the application module
-                        if (!app.cid) { return; }
-
-                        // construct with mix-in application class (with the disadvantage that
-                        // the application is not an instance of ApplicationClass)
-                        ApplicationClass.call(app, launchOptions);
-                    });
-
-                };
+                var appLaunchTime = _.now(); // Setting start time for application
 
                 // check that some launch options have been passed (action must always be part)
                 if (!_.isObject(launchOptions) || !_.isString(launchOptions.action)) {
-                    return DeferredUtils.createDeferred(app, 'ApplicationLauncher: setLauncher');
+                    var windowId = appWindow.nodes.outer.attr('id');
+                    return Scheduler.createDeferred(windowId, 'ApplicationLauncher.setLauncher');
                 }
 
-                if (encrypted) {
-                    require(['io.ox/guard/auth/authorizer'], function (authorizer) {
-                        authorizer.authorize().then(function (auth_code) {
-                            // do function, sending the auth_code with the decode command
-                            launchOptions.auth_code = auth_code;
-                            launchApp();
-                        }).fail(function () {
-                            app.quit();
+                if (Utils.hasProperty(launchOptions, 'file') && !Utils.hasProperty(launchOptions.file, 'filename')) {
+                    // After a browser refresh the filename is not set and if this file is encrypted a error dialog
+                    // pop up, therefore get the complete file from the fileApi to check if it is encrypted
+                    require(['io.ox/files/api'], function (FileAPI) {
+                        FileAPI.get(launchOptions.file).then(function (file) {
+                            fullFileName = getFullFileName(file);
+                            shortFileName = Utils.getFileBaseName(fullFileName, true);
+                            encrypted = Utils.isGuardEncrypted(fullFileName);
+                            if (encrypted) {
+                                launchAuthorizer(app, launchOptions, appWindow, shortFileName);
+                            } else {
+                                launchApp(app, launchOptions, appWindow, shortFileName);
+                            }
                         });
                     });
+                } else if (encrypted && !Utils.hasProperty(launchOptions, 'auth_code')) {
+                    launchAuthorizer(app, launchOptions, appWindow, shortFileName);
                 } else {
-                    launchApp();
+                    if (_.isObject(launchOptions)) { launchOptions.appLaunchTime = appLaunchTime; }
+                    launchApp(app, launchOptions, appWindow, shortFileName);
                 }
 
                 // bug 46405: do not return a pending promise (otherwise it is possible to open
