@@ -13,23 +13,18 @@
  */
 
 define('io.ox/office/baseframework/app/basecontroller', [
-
     'io.ox/office/tk/utils',
     'io.ox/office/tk/keycodes',
     'io.ox/office/tk/dialogs',
-
     'io.ox/office/tk/utils/driveutils',
     'io.ox/office/tk/utils/shareutils',
     'io.ox/office/tk/utils/domconsole',
-
+    'io.ox/office/tk/container/valuemap',
     'io.ox/office/tk/object/baseobject',
     'io.ox/office/tk/object/triggerobject',
-    'io.ox/office/tk/object/timermixin',
-
     'io.ox/office/baseframework/utils/baseconfig',
     'io.ox/office/baseframework/app/appobjectmixin'
-
-], function (Utils, KeyCodes, Dialogs, DriveUtils, ShareUtils, DOMConsole, BaseObject, TriggerObject, TimerMixin, Config, AppObjectMixin) {
+], function (Utils, KeyCodes, Dialogs, DriveUtils, ShareUtils, DOMConsole, ValueMap, BaseObject, TriggerObject, Config, AppObjectMixin) {
 
     'use strict';
 
@@ -80,6 +75,226 @@ define('io.ox/office/baseframework/app/basecontroller', [
 
     } // class ItemState
 
+    // singletons -------------------------------------------------------------
+
+    var DUMMY_STATE = new ItemState('\x00', []);
+
+    // class ControllerItem ===================================================
+
+    var ControllerItem = BaseObject.extend({ constructor: function (controller, key, definition, stateCache) {
+
+        // the controller containing this item
+        this.controller = controller;
+        // the key of this controller item
+        this.key = key;
+        // parent items whose values/states are needed to resolve the own value/state
+        this.parentKeys = Utils.getOption(definition, 'parent');
+        // handler for enabled state (default to function that returns true)
+        this.enableHandler = Utils.getFunctionOption(definition, 'enable', _.constant(true));
+        // handler for value getter (default to identity to forward first parent value)
+        this.getHandler = Utils.getFunctionOption(definition, 'get', _.identity);
+        // handler for value setter
+        this.setHandler = Utils.getFunctionOption(definition, 'set', null);
+        // whether an asynchronous setter is cancelable
+        this.cancelable = Utils.getBooleanOption(definition, 'cancel', false);
+        // whether an asynchronous setter does not block the controller
+        this.nonblocking = Utils.getBooleanOption(definition, 'nonblocking', false);
+        // behavior for returning browser focus to application
+        this.preserveFocus = Utils.getBooleanOption(definition, 'preserveFocus', false);
+        // custom focus target node or callback handler
+        this.focusTarget = Utils.getOption(definition, 'focusTarget');
+        // the shared cache of the controller for the states of all registered items
+        this.stateCache = stateCache;
+
+        // base constructor ---------------------------------------------------
+
+        BaseObject.call(this, controller);
+
+        // initialization -----------------------------------------------------
+
+        // always use an array of parent keys (as strings)
+        this.parentKeys =
+            _.isArray(this.parentKeys) ? this.parentKeys.filter(_.isString) :
+            _.isString(this.parentKeys) ? [this.parentKeys] : [];
+
+    } }); // class ControllerItem
+
+    // private methods  -------------------------------------------------------
+
+    /**
+     * Returns the state descriptor of the specified parent item.
+     */
+    ControllerItem.prototype._getParentState = function (parentKey) {
+
+        // get the specified parent item
+        var parentItem = this.controller._getItem(parentKey);
+        if (!parentItem) {
+            Utils.warn('ControllerItem._getParentState(): item "' + this.key + '" refers to unknown parent "' + parentKey + '"');
+        }
+
+        // resolve the state of the parent item
+        return parentItem ? parentItem.getState() : DUMMY_STATE;
+    };
+
+    // public methods ---------------------------------------------------------
+
+    /**
+     * Returns a descriptor for the current state of this item.
+     *
+     * @returns {ItemState}
+     *  The state descriptor for this controller item.
+     */
+    ControllerItem.prototype.getState = function () {
+
+        // return cached state
+        var itemState = this.stateCache.get(this.key, null);
+        if (itemState) { return itemState; }
+
+        // insert the state descriptor of this item into the cache BEFORE resolving enabled state and value
+        itemState = this.stateCache.insert(this.key, new ItemState(this.key, this.parentKeys.map(this._getParentState, this)));
+
+        // resolve and store the value first (enable callback may want to query the own value)
+        itemState.value = this.getHandler.apply(this, itemState.parentValues);
+
+        // resolve and store the enabled state (pass parent values to the resolver functions)
+        itemState.enabled = itemState.parentsEnabled && (this.enableHandler.apply(this, itemState.parentValues) === true);
+
+        return itemState;
+    };
+
+    /**
+     * Returns whether all parent items are enabled.
+     *
+     * @returns {Boolean}
+     *  False, if at least one parent item is disabled, otherwise true.
+     */
+    ControllerItem.prototype.areParentsEnabled = function () {
+        return this.getState().parentsEnabled;
+    };
+
+    /**
+     * Returns whether this item is effectively enabled.
+     *
+     * @returns {Boolean}
+     *  False, if at least one parent item is disabled, or if the
+     *  enable handler of this item has returned false; otherwise true.
+     */
+    ControllerItem.prototype.isEnabled = function () {
+        return this.getState().enabled;
+    };
+
+    /**
+     * Returns the current value of the specified parent item.
+     *
+     * @param {Number} [index=0]
+     *  The index of the parent item (can be used, if multiple parent items
+     *  have been specified for this item).
+     *
+     * @returns {Any}
+     *  The current value of the specified parent item.
+     */
+    ControllerItem.prototype.getParentValue = function (index) {
+        var parentState = this.getState().parentStates[index || 0];
+        return parentState ? parentState.value : undefined;
+    };
+
+    /**
+     * Returns the current value of this item.
+     *
+     * @returns {Any}
+     *  The current value of this item.
+     */
+    ControllerItem.prototype.getValue = function () {
+        return this.getState().value;
+    };
+
+    /**
+     * Executes the setter function of this item (passing in the new value),
+     * and moves the browser focus back to the application pane.
+     *
+     * @param {Any} value
+     *  The new value of the item.
+     *
+     * @param {Object} [options]
+     *  Optional parameters. See method BaseController.executeItem() for
+     *  details.
+     *
+     * @returns {jQuery.Promise}
+     *  A promise that will be resolved or rejected according to the result of
+     *  the item setter function. If the item is disabled, a rejected promise
+     *  will be returned. If the item setter returns a promise, that promise
+     *  will be returned. Otherwise, the return value of the item setter
+     *  function will be wrapped and returned in a resolved promise.
+     */
+    ControllerItem.prototype.execute = function (value, options) {
+
+        // the controller containing this item
+        var controller = this.controller;
+        // the document view (for busy mode)
+        var docView = controller.getApp().getView();
+        // the current state and value of the item
+        var state = this.getState();
+        // the resulting promise
+        var promise = null;
+        // whether the setter runs asynchronous code
+        var pending = false;
+        // focus options after executing the item
+        var focusOptions = _.extend({}, options);
+
+        // mix item focus options and passed focus options
+        focusOptions.preserveFocus = this.preserveFocus || Utils.getBooleanOption(options, 'preserveFocus', false);
+        focusOptions.focusTarget = Utils.getOption(options, 'focusTarget', this.focusTarget);
+
+        // bind focus target callback function to the item instance
+        if (_.isFunction(focusOptions.focusTarget)) {
+            focusOptions.focusTarget = focusOptions.focusTarget.bind(this);
+        }
+
+        // do nothing if item is disabled
+        if (state.enabled) {
+
+            // execute the set handler, convert result of the setter callback to a promise
+            promise = this.convertToPromise(this.setHandler ? this.setHandler(value, options) : null);
+
+            // show busy screen if setter is running asynchronously
+            // (but not for modal dialogs which have their own blocker overlay)
+            pending = !this.nonblocking && (promise.state() === 'pending');
+            if (pending && !Dialogs.isModalDialogOpen()) {
+                var showCancel = this.cancelable && _.isFunction(promise.abort);
+                docView.enterBusy({ cancelHandler: showCancel ? function () { promise.abort(); } : null });
+            }
+        } else {
+            // item is disabled
+            promise = this.createRejectedPromise();
+        }
+
+        // focus back to application
+        if (!focusOptions.preserveFocus) {
+            this.waitForAny(promise, function () {
+                if (pending) {
+                    // execute in a timeout, needed for dialogs which are closed *after* resolve/reject
+                    controller.executeDelayed(function () { controller.grabFocus(focusOptions); }, 'ControllerItem.execute');
+                } else {
+                    controller.grabFocus(focusOptions);
+                }
+            });
+        }
+
+        // post-processing after the setter is finished
+        Utils.logSelenium(this.key, promise.state());
+        if (pending) {
+            this.waitForAny(promise, function () {
+                docView.leaveBusy();
+                controller.update();
+                Utils.logSelenium(this.key, promise.state());
+            }, this);
+        } else {
+            controller.update();
+        }
+
+        return promise;
+    };
+
     // class BaseController ===================================================
 
     /**
@@ -99,7 +314,6 @@ define('io.ox/office/baseframework/app/basecontroller', [
      * @constructor
      *
      * @extends TriggerObject
-     * @extends TimerMixin
      * @extends AppObjectMixin
      *
      * @param {BaseApplication} app
@@ -123,10 +337,7 @@ define('io.ox/office/baseframework/app/basecontroller', [
         var self = this;
 
         // all registered controller items, mapped by item key
-        var items = {};
-
-        // dummy item, used e.g. for undefined parent items
-        var dummyItem = null;
+        var itemMap = new ValueMap();
 
         // the delay time for the debounced BaseController.update() method
         // Bug 30479: must NOT be 0, to be able give some space for deferred
@@ -135,10 +346,13 @@ define('io.ox/office/baseframework/app/basecontroller', [
         var updateDelay = Utils.getIntegerOption(initOptions, 'updateDelay', 50, 50);
 
         // cached item states, mapped by item keys
-        var stateCache = {};
+        var stateCache = new ValueMap();
 
-        // cached states of all controller items as notified the last time
-        var notifiedStateCache = {};
+        // cached values of all controller items as notified the last time
+        var notifiedStates = new ValueMap();
+
+        // all dirty keys (items that have been executed before the next update), as flag set
+        var dirtyKeys = {};
 
         // number of item setters currently running (recursion counter)
         var runningSetters = 0;
@@ -152,253 +366,9 @@ define('io.ox/office/baseframework/app/basecontroller', [
         // the internal deferred object representing the current update cycle
         var updateDeferred = null;
 
-        // class Item ---------------------------------------------------------
-
-        var Item = BaseObject.extend({ constructor: function (key, definition) {
-
-            // parent items whose values/states are needed to resolve the own value/state
-            var parentKeys = Utils.getOption(definition, 'parent');
-            // handler for enabled state (default to function that returns true)
-            var enableHandler = Utils.getFunctionOption(definition, 'enable', _.constant(true));
-            // handler for value getter (default to identity to forward first parent value)
-            var getHandler = Utils.getFunctionOption(definition, 'get', _.identity);
-            // handler for value setter
-            var setHandler = Utils.getFunctionOption(definition, 'set');
-            // whether an asynchronous setter is cancelable
-            var cancelable = Utils.getBooleanOption(definition, 'cancel', false);
-            // whether an asynchronous setter does not block the controller
-            var nonblocking = Utils.getBooleanOption(definition, 'nonblocking', false);
-            // behavior for returning browser focus to application
-            var itemPreserveFocus = Utils.getBooleanOption(definition, 'preserveFocus', false);
-            // custom focus target node or callback handler
-            var itemFocusTarget = Utils.getOption(definition, 'focusTarget');
-            // alwaysDirty if true, always refresh without checking for changed value
-            var alwaysDirty = Utils.getBooleanOption(definition, 'alwaysDirty');
-
-            BaseObject.call(this);
-
-            // private methods  - - - - - - - - - - - - - - - - - - - - - - - -
-
-            /**
-             * Returns the state descriptor of the specified parent item.
-             */
-            function getParentState(parentKey) {
-                var parentItem = items[parentKey] || dummyItem;
-                if (parentItem === dummyItem) {
-                    Utils.warn('BaseController.Item.getParentState(): item "' + key + '" refers to unknown parent "' + parentKey + '"');
-                }
-                return parentItem.getState();
-            }
-
-            // methods  - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-
-            /**
-             * Returns the unique key of this item.
-             *
-             * @returns {String}
-             *  The unique key this item has been registered with.
-             */
-            this.getKey = function () {
-                return key;
-            };
-
-            /**
-             * Returns a descriptor for the current state of this item.
-             *
-             * @returns {ItemState}
-             *  The state descriptor for this controller item.
-             */
-            this.getState = function () {
-
-                // return cached state
-                if (key in stateCache) { return stateCache[key]; }
-
-                // create the state descriptor of this item
-                var itemState = new ItemState(key, _.map(parentKeys, getParentState));
-
-                // insert the state descriptor into the cache before resolving enabled state and value
-                stateCache[key] = itemState;
-
-                // resolve and store the value first (enable callback may want to query the own value)
-                itemState.value = getHandler.apply(this, itemState.parentValues);
-
-                // resolve and store the enabled state
-                itemState.enabled = itemState.parentsEnabled && (enableHandler.apply(this, itemState.parentValues) === true);
-
-                // return the state descriptor
-                return itemState;
-            };
-
-            /**
-             * Returns whether all parent items are enabled.
-             *
-             * @returns {Boolean}
-             *  False, if at least one parent item is disabled, otherwise true.
-             */
-            this.areParentsEnabled = function () {
-                return this.getState().parentsEnabled;
-            };
-
-            /**
-             * Returns whether this item is effectively enabled.
-             *
-             * @returns {Boolean}
-             *  False, if at least one parent item is disabled, or if the
-             *  enable handler of this item has returned false; otherwise true.
-             */
-            this.isEnabled = function () {
-                return this.getState().enabled;
-            };
-
-            /**
-             * Returns the current value of the specified parent item.
-             *
-             * @param {Number} [index=0]
-             *  The index of the parent item (if multiple parent items have
-             *  been specified for this item).
-             */
-            this.getParentValue = function (index) {
-                var parentState = this.getState().parentStates[_.isNumber(index) ? index : 0];
-                return parentState ? parentState.value : undefined;
-            };
-
-            /**
-             * Returns the current value of this item.
-             */
-            this.getValue = function () {
-                return this.getState().value;
-            };
-
-            /**
-             * Returns true if always refresh without checking for changed value
-             */
-            this.isAlwaysDirty = function () {
-                return alwaysDirty;
-            };
-
-            /**
-             * Executes the setter function of this item (passing in the new
-             * value), and moves the browser focus back to the application
-             * pane.
-             *
-             * @param {Any} value
-             *  The new value of the item.
-             *
-             * @param {Object} [options]
-             *  Optional parameters. See method BaseController.executeItem()
-             *  for details.
-             *
-             * @returns {jQuery.Promise}
-             *  A promise that will be resolved or rejected according to the
-             *  result of the item setter function. If the item is disabled, a
-             *  rejected promise will be returned. If the item setter returns a
-             *  promise, that promise will be returned. Otherwise, the return
-             *  value of the item setter function will be wrapped and returned
-             *  in a resolved promise.
-             */
-            this.execute = function (value, options) {
-
-                // the current state and value of the item
-                var state = this.getState();
-                // the resulting promise
-                var promise = null;
-                // whether the setter runs asynchronous code
-                var pending = false;
-                // focus options after executing the item
-                var focusOptions = _.extend({}, options);
-
-                // final processing after the set handler has finished
-                function finalize() {
-                    // reverted workarounds for Bug 37174, Bug 40673 and Bug 40787
-                    // as fix for Bug 47566
-
-                    // update the controller items
-                    self.update();
-                }
-
-                // mix item focus options and passed focus options
-                focusOptions.preserveFocus = itemPreserveFocus || Utils.getBooleanOption(options, 'preserveFocus', false);
-                focusOptions.focusTarget = Utils.getOption(options, 'focusTarget', itemFocusTarget);
-
-                // bind focus target callback function to the item instance
-                if (_.isFunction(focusOptions.focusTarget)) {
-                    focusOptions.focusTarget = _.bind(focusOptions.focusTarget, this);
-                }
-
-                // do nothing if item is disabled
-                if (state.enabled) {
-
-                    // execute the set handler
-                    runningSetters += 1;
-                    if (_.isFunction(setHandler)) {
-                        promise = setHandler.call(this, value, options);
-                    }
-
-                    // convert result of the setter callback to a promise
-                    promise = $.when(promise);
-                    promise.always(function () {
-                        runningSetters -= 1;
-                    });
-
-                    // show busy screen if setter is running asynchronously
-                    // (but not for modal dialogs which have their own blocker overlay)
-                    pending = !nonblocking && (promise.state() === 'pending');
-                    if (pending && !Dialogs.isModalDialogOpen()) {
-                        var showCancel = cancelable && _.isFunction(promise.abort);
-                        docView.enterBusy({ cancelHandler: showCancel ? function () { promise.abort(); } : null });
-                    }
-                } else {
-                    // item is disabled
-                    promise = $.Deferred().reject();
-                }
-
-                // focus back to application
-                if (!focusOptions.preserveFocus) {
-                    this.waitForAny(promise, function () {
-                        if (pending) {
-                            // execute in a timeout, needed for dialogs which are closed *after* resolve/reject
-                            self.executeDelayed(function () { self.grabFocus(focusOptions); }, { infoString: 'BaseController: grabFocus', app: app });
-                        } else {
-                            self.grabFocus(focusOptions);
-                        }
-                    });
-                }
-
-                // post-processing after the setter is finished
-                Utils.logSelenium(key, promise.state());
-                if (pending) {
-                    this.waitForAny(promise, function () {
-                        docView.leaveBusy();
-                        finalize();
-                        Utils.logSelenium(key, promise.state());
-                    });
-                } else {
-                    finalize();
-                }
-
-                return promise;
-            };
-
-            // initialization - - - - - - - - - - - - - - - - - - - - - - - - -
-
-            // always use an array of parent keys (as strings)
-            parentKeys =
-                _.isArray(parentKeys) ? _.filter(parentKeys, _.isString) :
-                _.isString(parentKeys) ? [parentKeys] :
-                null;
-
-            // destroy all class members on destruction
-            this.registerDestructor(function () {
-                definition = parentKeys = null;
-                enableHandler = getHandler = setHandler = null;
-            });
-
-        } }); // class Item
-
         // base constructor ---------------------------------------------------
 
-        TriggerObject.call(this);
-        TimerMixin.call(this);
+        TriggerObject.call(this, app);
         AppObjectMixin.call(this, app);
 
         // private methods ----------------------------------------------------
@@ -410,7 +380,7 @@ define('io.ox/office/baseframework/app/basecontroller', [
 
             // pending deferred object represents the current controller update cycle
             if (!updateDeferred || (updateDeferred.state() !== 'pending')) {
-                updateDeferred = self.createDeferredObject({ infoString: 'BaseController: createUpdateDeferred', app: app });
+                updateDeferred = self.createDeferred('BaseController.updateDeferred');
             }
         }
 
@@ -425,16 +395,14 @@ define('io.ox/office/baseframework/app/basecontroller', [
          */
         function keyHandler(event) {
 
-            var // whether to stop propagation and prevent the default action
-                stopPropagation = false;
+            // whether to stop propagation and prevent the default action
+            var stopPropagation = false;
 
             // executes the item setter defined in the passed shortcut
             function executeItemForShortcut(shortcut) {
 
-                var // the definition data of the shortcut
-                    definition = shortcut.definition,
-                    // the current value to be passed to the item setter
-                    value = null;
+                // the definition data of the shortcut
+                var definition = shortcut.definition;
 
                 // check whether to actually process the key event according to the event target node
                 if (_.isString(definition.selector) && ($(event.target).closest(definition.selector, app.getRootNode()[0]).length === 0)) {
@@ -444,7 +412,7 @@ define('io.ox/office/baseframework/app/basecontroller', [
                 // bug 30096: do not allow to execute items while a blocking operation is still running
                 if (runningSetters === 0) {
                     // call value resolver function, or take constant value
-                    value = _.isFunction(definition.value) ? definition.value(self.getItemValue(shortcut.key)) : definition.value;
+                    var value = _.isFunction(definition.value) ? definition.value(self.getItemValue(shortcut.key)) : definition.value;
                     self.executeItem(shortcut.key, value, { sourceType: 'keyboard' });
                 }
 
@@ -515,6 +483,45 @@ define('io.ox/office/baseframework/app/basecontroller', [
             });
         }
 
+        // protected methods --------------------------------------------------
+
+        /**
+         * Updates this controller if the event source emits the specified
+         * events.
+         *
+         * @param {Events|jQuery|HTMLElement} source
+         *  The event source object. See method BaseObject.listenTo() for
+         *  details.
+         *
+         * @param {String} [type]
+         *  The type of the event to listen to. Can be a space-separated list
+         *  of event type names. If the event source is an instance the mix-in
+         *  class Events (e.g. a TriggerObject), this parameter can be omitted
+         *  which will cause to update the controller on every event emitted by
+         *  the event source (the controller will listen to the synthetic event
+         *  'triggered' of the event source).
+         *
+         * @returns {BaseController}
+         *  A reference to this instance.
+         */
+        this._updateOnEvent = function (source, type) {
+            return this.listenTo(source, type || 'triggered', function () { self.update(); });
+        };
+
+        /**
+         * Returns the specified controller item instance.
+         *
+         * @param {String} key
+         *  The key of a controller item.
+         *
+         * @returns {ControllerItem|Null}
+         *  The specified controller item instance; or null, if an item with
+         *  the specified key does not exist.
+         */
+        this._getItem = function (key) {
+            return itemMap.get(key, null);
+        };
+
         // public methods -----------------------------------------------------
 
         /**
@@ -681,8 +688,11 @@ define('io.ox/office/baseframework/app/basecontroller', [
          */
         this.registerDefinition = function (key, definition) {
 
+            // destroy an existing item instance
+            itemMap.with(key, function (item) { item.destroy(); });
+
             // create a new item instance
-            items[key] = new Item(key, definition);
+            itemMap.insert(key, new ControllerItem(this, key, definition, stateCache));
 
             // special preparations for global keyboard shortcuts
             if (_.isObject(definition.shortcut)) {
@@ -756,7 +766,7 @@ define('io.ox/office/baseframework/app/basecontroller', [
 
             // clear the entire cache state on every call of the update() method
             function invalidateStates() {
-                stateCache = {};
+                stateCache.clear();
                 createUpdateDeferred();
                 return this.getUpdatePromise();
             }
@@ -770,7 +780,7 @@ define('io.ox/office/baseframework/app/basecontroller', [
                 // but freezing too long can kill RT connection and the browser itself
                 if (_.browser.IE) {
                     var t0 = _.now(), i = 0;
-                    _.any(items, function (item) {
+                    itemMap.some(function (item) {
                         item.getState();
                         i = (i + 1) % 10;
                         if ((i === 0) && (_.now() - t0 > 3000)) {
@@ -779,7 +789,7 @@ define('io.ox/office/baseframework/app/basecontroller', [
                         }
                     });
                 } else {
-                    _.invoke(items, 'getState');
+                    itemMap.forEach(function (item) { item.getState(); });
                 }
 
                 /* test code for performance issues
@@ -794,28 +804,30 @@ define('io.ox/office/baseframework/app/basecontroller', [
                 */
 
                 // reduce to the properties that differ from previous state
-                var changedStates = _.omit(stateCache, function (state, key) {
-                    var prevState = notifiedStateCache[key];
-
-                    return prevState && (prevState.enabled === state.enabled) && !items[key].isAlwaysDirty() && _.isEqual(prevState.value, state.value);
+                var changedStates = stateCache.omit(function (state, key) {
+                    if (key in dirtyKeys) { return false; }
+                    var prevState = notifiedStates.get(key, null);
+                    return prevState && (prevState.enabled === state.enabled) && _.isEqual(prevState.value, state.value);
                 });
 
-                // store the current cache for next update() call
-                // bug 40770: create flat clones of all cache entries, to be able to change stateCache in-place later
-                notifiedStateCache = _.mapObject(stateCache, function (state) { return _.clone(state); });
+                // bug 40770: store the values of the current cache for next update() call
+                notifiedStates = stateCache.clone(function (state) {
+                    return { enabled: state.enabled, value: state.value };
+                });
 
                 // notify all listeners (with locked GUI refresh for performance,
                 // view elements are listening to controller items to change their visibility)
                 if (!_.isEmpty(changedStates)) {
                     docView.lockPaneLayout(function () {
                         self.trigger('change:items', changedStates);
+                        dirtyKeys = {};
                     });
                 }
 
                 updateDeferred.resolve(changedStates);
             }
 
-            return self.createDebouncedMethod(invalidateStates, updateStates, { delay: updateDelay, infoString: 'BaseController: update', app: app });
+            return self.createDebouncedMethod('BaseController.update', invalidateStates, updateStates, { delay: updateDelay });
         }());
 
         /**
@@ -828,7 +840,7 @@ define('io.ox/office/baseframework/app/basecontroller', [
          *  Whether the specified item exists and is enabled.
          */
         this.isItemEnabled = function (key) {
-            return (key in items) && items[key].isEnabled();
+            return itemMap.with(key, function (item) { return item.isEnabled(); }) || false;
         };
 
         /**
@@ -842,7 +854,7 @@ define('io.ox/office/baseframework/app/basecontroller', [
          *  exist.
          */
         this.getItemValue = function (key) {
-            return (key in items) ? items[key].getValue() : undefined;
+            return itemMap.with(key, function (item) { return item.getValue(); });
         };
 
         /**
@@ -898,8 +910,13 @@ define('io.ox/office/baseframework/app/basecontroller', [
         this.executeItem = function (key, value, options) {
 
             // execute setter of existing item
-            if (key in items) {
-                return items[key].execute(value, options);
+            var item = itemMap.get(key, null);
+            if (item) {
+                dirtyKeys[key] = true;
+                runningSetters += 1;
+                return item.execute(value, options).always(function () {
+                    runningSetters -= 1;
+                });
             }
 
             // item does not exist: return focus to application
@@ -920,10 +937,10 @@ define('io.ox/office/baseframework/app/basecontroller', [
          */
         this.grabFocus = function (options) {
 
-            var preserveFocus = Utils.getBooleanOption(options, 'preserveFocus', false),
-                focusTarget = Utils.getOption(options, 'focusTarget'),
-                changeEvent = Utils.getOption(options, 'changeEvent'),
-                sourceNode = Utils.getOption(changeEvent, 'sourceNode');
+            var preserveFocus = Utils.getBooleanOption(options, 'preserveFocus', false);
+            var focusTarget = Utils.getOption(options, 'focusTarget');
+            var changeEvent = Utils.getOption(options, 'changeEvent');
+            var sourceNode = Utils.getOption(changeEvent, 'sourceNode');
 
             // keep current focus, if 'preserveFocus' is set
             // Bug 28214: Focus back to application if source GUI element is hidden
@@ -937,7 +954,7 @@ define('io.ox/office/baseframework/app/basecontroller', [
 
             // resolve callback function to focus target
             if (_.isFunction(focusTarget)) {
-                focusTarget = focusTarget.call(self, Utils.getStringOption(options, 'sourceType', 'custom'));
+                focusTarget = focusTarget.call(this, Utils.getStringOption(options, 'sourceType', 'custom'));
             }
 
             // move focus to specified target, or to the view
@@ -954,9 +971,6 @@ define('io.ox/office/baseframework/app/basecontroller', [
 
         // initialization -----------------------------------------------------
 
-        // dummy item singleton, used e.g. for undefined parent items
-        dummyItem = new Item('\x00');
-
         // create the initial update promise
         createUpdateDeferred();
 
@@ -979,9 +993,14 @@ define('io.ox/office/baseframework/app/basecontroller', [
                 enable: function () { return !app.isStandalone(); }
             },
 
+            // enabled if the document has NOT been stored encrypted
+            'app/unencrypted': {
+                enable: function () { return !app.isDocumentEncrypted(); }
+            },
+
             'app/share': {
-                parent: ['app/imported', 'app/bundled'],
-                enable: function () { return DriveUtils.isShareable(app.getFileDescriptor()) && !app.isDocumentEncrypted(); }
+                parent: ['app/imported', 'app/bundled', 'app/unencrypted'],
+                enable: function () { return DriveUtils.isShareable(app.getFileDescriptor()); }
             },
 
             // all supported operation systems have a file system where user can save in, but not on IOS
@@ -992,22 +1011,21 @@ define('io.ox/office/baseframework/app/basecontroller', [
             // download the document: enabled in read-only mode, disabled during import
             'document/download': {
                 parent: ['app/imported', 'system/filesystem'],
-                enable: function () { return !app.isDocumentEncrypted(); },
                 set: function () { return app.download(); }
             },
 
             // print the document (download as PDF): enabled in read-only mode, disabled during import
             'document/print': {
                 parent: 'app/imported',
-                enable: function () { return !app.isDocumentEncrypted(); },
+                enable: function () { return Config.CONVERTER_AVAILABLE; },
                 set: function () { return app.print(); },
                 shortcut: { keyCode: 'P', ctrlOrMeta: true }
             },
 
             // compose new mail with this document as attachment
             'document/sendmail': {
-                parent: ['app/imported', 'app/bundled'],
-                enable: function () { return Config.MAIL_AVAILABLE && !DriveUtils.isGuest() && !app.isDocumentEncrypted(); },
+                parent: ['app/imported', 'app/bundled', 'app/unencrypted'],
+                enable: function () { return Config.MAIL_AVAILABLE && !DriveUtils.isGuest(); },
                 set: function () { return app.sendMail(); }
             },
 
@@ -1064,17 +1082,17 @@ define('io.ox/office/baseframework/app/basecontroller', [
         // update once after successful import
         this.waitForImportSuccess(function () {
             initializeKeyHandler();
-            this.listenTo(docView, 'refresh:layout', function () { self.update(); });
-            this.listenTo(DOMConsole, 'change:state', function () { self.update(); });
+            this._updateOnEvent(docView, 'refresh:layout');
+            this._updateOnEvent(DOMConsole, 'change:state');
             this.update();
         }, this);
 
         // destroy all class members on destruction
         this.registerDestructor(function () {
-            _.invoke(items, 'destroy');
-            dummyItem.destroy();
+            itemMap.forEach(function (item) { item.destroy(); });
             self = docModel = docView = null;
-            items = dummyItem = stateCache = keyShortcuts = charShortcuts = null;
+            itemMap = stateCache = notifiedStates = null;
+            keyShortcuts = charShortcuts = null;
         });
 
     } }); // class BaseController
