@@ -23,7 +23,7 @@ define('io.ox/office/baseframework/app/extensionregistry', [
     // which file formats are editable (maps format identifier to booleans)
     var EDITABLE_FILE_FORMATS = {
         ooxml: true,
-        odf: Config.getFlag('odfsupport', true)
+        odf: Config.getFlag('module/odfsupport', true)
     };
 
     // the extension suffix for files with an internal error
@@ -87,14 +87,13 @@ define('io.ox/office/baseframework/app/extensionregistry', [
             extensions: {
                 pptx: { format: 'ooxml', template: 'potx' },
                 pptm: { format: 'ooxml', template: 'potm', macros: true },
-                ppsx: {}, // slide show
-                ppsm: { macros: true }, // slide show
+                ppsx: { format: 'ooxml' },
+                ppsm: { format: 'ooxml', macros: true },
                 ppam: { macros: true }, // add-in
-                // disabled for US DOCS-618, no direct odf support, and no doc-converter support
-                // odp:  { format: 'odf', template: 'otp', macros: true },
                 ppt:  { format: 'ooxml', template: 'pot', macros: true, convert: true },
                 pps:  { format: 'ooxml', macros: true, convert: true }, // slide show
-                ppa:  { format: 'ooxml', macros: true, convert: true } // add-in
+                ppa:  { format: 'ooxml', macros: true, convert: true }, // add-in
+                odp:  { format: 'odf', template: 'otp', macros: true, editable: Config.getFlag('module/odpsupport', true) }
             }
         }
     };
@@ -433,7 +432,7 @@ define('io.ox/office/baseframework/app/extensionregistry', [
         // the module name of the edit application
         var module = Utils.getStringOption(moduleConfiguration, 'module', null);
         // whether the edit module is available at all
-        var editAvailable = editable && _.isString(requires) && Capabilities.has(requires) && _.isString(module);
+        var editAvailable = editable && (requires !== null) && Capabilities.has(requires) && (module !== null);
 
         // application configuration entry
         applicationMap[documentType] = { editable: editAvailable };
@@ -454,7 +453,7 @@ define('io.ox/office/baseframework/app/extensionregistry', [
                 type: documentType,
                 format: format,
                 template: false,
-                editable: editAvailable && Utils.getBooleanOption(EDITABLE_FILE_FORMATS, format, false),
+                editable: editAvailable && Utils.getBooleanOption(EDITABLE_FILE_FORMATS, format, false) && Utils.getBooleanOption(extensionSettings, 'editable', true),
                 native: native,
                 macros: Utils.getBooleanOption(extensionSettings, 'macros', false)
             });
