@@ -449,7 +449,7 @@ define('io.ox/office/baseframework/app/guidedtour', [
      * Returns the configuration key used to store the 'shown' flag for a tour.
      */
     function getShownConfigKey(requirePath) {
-        return requirePath + '/shown';
+        return requirePath.replace(/^io.ox\/office\//, '') + '/shown';
     }
 
     /**
