@@ -119,12 +119,15 @@ define('io.ox/office/baseframework/utils/errormessages', [
             LOADDOCUMENT_CANNOT_READ_PASSWORD_PROTECTED_ERROR: gt('The document is protected with a password.'),
             LOADDOCUMENT_TIMEOUT_RETRIEVING_STREAM_ERROR: gt('The document could not be loaded, because the document data could not be read in time. Please try again later.'),
             LOADDOCUMENT_COMPLEXITY_TOO_HIGH_ERROR: gt('This document exceeds the size and complexity limits.'),
+            'LOADDOCUMENT_COMPLEXITY_TOO_HIGH_ERROR.TEXT': gt('This document exceeds the text document size and complexity limits.'),           // fulfilling task DOCS-733
+            'LOADDOCUMENT_COMPLEXITY_TOO_HIGH_ERROR.PRESENTATION': gt('This document exceeds the presentation size and complexity limits.'),    // "Improve OOM Error Message in Client"
+            'LOADDOCUMENT_COMPLEXITY_TOO_HIGH_ERROR.SPREADSHEET': gt('This document exceeds the spreadsheet size and complexity limits.'),      // [https://jira.open-xchange.com/browse/DOCS-733]
             'LOADDOCUMENT_COMPLEXITY_TOO_HIGH_SHEET_COUNT_ERROR.SPREADSHEET': gt('This document exceeds the number of sheets limit.'),
-            'LOADDOCUMENT_COMPLEXITY_TOO_HIGH_ERROR.SPREADSHEET': gt('This document exceeds the spreadsheet size and complexity limits.'),
             LOADDOCUMENT_CALCENGINE_NOT_WORKING_ERROR: gt('The engine used for calculating formulas is not available.'),
             LOADDOCUMENT_STRICT_OOXML_NOT_SUPPORTED_ERROR: gt('This document could not be loaded, because it was created with a version of Microsoft Office prior to Office 2007.'),
             LOADDOCUMENT_FEATURE_NOT_SUPPORTED_ERROR: gt('The document could not be loaded, because it contains an unsupported feature.'),
             LOADDOCUMENT_FEATURE_NOT_SUPPORTED_FRAME_ATTACHED_TO_FRAME_ERROR: gt('The document could not be loaded, because it contains grouped text frames.'),
+            LOADDOCUMENT_NO_FILTER_FOR_DOCUMENT_ERROR: gt('The document could not be loaded, because the document format is unknown'),
             'GENERAL_PERMISSION_READ_MISSING_ERROR.LOAD': gt('The document could not be read, because you do not have read permissions.'),
             'GENERAL_FILE_NOT_FOUND_ERROR.LOAD': gt('The document cannot be found. Please check, if the document has been removed.'),
             'GENERAL_MEMORY_TOO_LOW_ERROR.LOAD': gt('The document could not be loaded. The server is currently too busy. Please try again later.'),
@@ -365,7 +368,8 @@ define('io.ox/office/baseframework/utils/errormessages', [
                 case 'LOADDOCUMENT_FEATURE_NOT_SUPPORTED_ERROR':
                 case 'LOADDOCUMENT_FEATURE_NOT_SUPPORTED_FRAME_ATTACHED_TO_FRAME_ERROR':
                 case 'GENERAL_FILE_CORRUPT_ERROR':
-                case 'GENERAL_FILE_NOT_FOUND_ERROR': delete messageData.action; break;
+                case 'GENERAL_FILE_NOT_FOUND_ERROR':
+                case 'LOADDOCUMENT_NO_FILTER_FOR_DOCUMENT_ERROR': delete messageData.action; break;
                 case 'LOADDOCUMENT_FAILED_ERROR':
                     if (errorContext === ErrorContext.CLOSE) {
                         // special behavior for close - don't provide reload in this case
@@ -379,7 +383,8 @@ define('io.ox/office/baseframework/utils/errormessages', [
             //use the cause error for extented message with errorcode & fileid
             var causeError = Utils.getOption(options, 'causeError', errorCode);
             if (_.isObject(causeError)) {
-                messageData.extendedMessage = 'Error\xa0code:\xa0' + causeError.getCodeAsConstant() + '. ';
+                messageData.errorCode = causeError.getCodeAsConstant();
+                messageData.extendedMessage = 'Error\xa0code:\xa0' + messageData.errorCode + '. ';
                 var originalFileId = String(Utils.getOption(options, ErrorContextData.ORIGINAL_FILEID, ''));
                 if (originalFileId) {
                     if (originalFileId.length > 30) {
