@@ -17,15 +17,14 @@ define('io.ox/office/baseframework/view/baseview', [
     'io.ox/office/tk/utils',
     'io.ox/office/tk/keycodes',
     'io.ox/office/tk/forms',
-    'io.ox/office/tk/object/triggerobject',
-    'io.ox/office/tk/object/timermixin',
     'io.ox/office/tk/dialogs',
+    'io.ox/office/tk/object/triggerobject',
     'io.ox/office/baseframework/utils/errormessages',
     'io.ox/office/baseframework/app/appobjectmixin',
     'io.ox/office/baseframework/view/viewobjectmixin',
     'gettext!io.ox/office/baseframework/main',
     'less!io.ox/office/baseframework/view/basestyle'
-], function (Notifications, Utils, KeyCodes, Forms, TriggerObject, TimerMixin, Dialogs, ErrorMessages, AppObjectMixin, ViewObjectMixin, gt) {
+], function (Notifications, Utils, KeyCodes, Forms, Dialogs, TriggerObject, ErrorMessages, AppObjectMixin, ViewObjectMixin, gt) {
 
     'use strict';
 
@@ -73,7 +72,6 @@ define('io.ox/office/baseframework/view/baseview', [
      * @constructor
      *
      * @extends TriggerObject
-     * @extends TimerMixin
      * @extends AppObjectMixin
      * @extends ViewObjectMixin
      *
@@ -122,74 +120,78 @@ define('io.ox/office/baseframework/view/baseview', [
      */
     function BaseView(app, docModel, initOptions) {
 
-        var // self reference
-            self = this,
+        // self reference
+        var self = this;
 
-            // moves the browser focus into a node of the application pane
-            grabFocusHandler = Utils.getFunctionOption(initOptions, 'grabFocusHandler'),
+        // moves the browser focus into a node of the application pane
+        var grabFocusHandler = Utils.getFunctionOption(initOptions, 'grabFocusHandler');
 
-            // the application window instance (ox.ui.Window)
-            appWindow = null,
+        // the application window instance (ox.ui.Window)
+        var appWindow = app.getWindow();
 
-            // the DOM node of the application window body
-            winBodyNode = null,
+        // the DOM node of the application window body
+        var winBodyNode = app.getWindowNode();
 
-            // root node of the application pane (remaining space for document contents)
-            appPaneNode = null,
+        // root node of the application pane (remaining space for document contents)
+        var appPaneNode = null;
 
-            // root container node for invisible document contents
-            hiddenRootNode = $('<div class="abs app-hidden-root">'),
+        // root container node for invisible document contents
+        var hiddenRootNode = $('<div class="app-hidden-root">');
 
-            // root container node for visible document contents (may be scrollable)
-            contentRootNode = $('<div class="abs app-content-root">'),
+        // root container node for visible document contents (may be scrollable)
+        var contentRootNode = $('<div class="app-content-root">');
 
-            // container node for application contents
-            appContentNode = $('<div class="app-content">').appendTo(contentRootNode),
+        // container node for application contents
+        var appContentNode = $('<div class="app-content">').appendTo(contentRootNode);
 
-            // the temporary container for all nodes while application is hidden
-            tempNode = $('<div>'),
+        // the temporary container for all nodes while application is hidden
+        var tempNode = $('<div>');
 
-            // all registered view panes, in insertion order
-            viewPanes = [],
+        // all registered view panes, in insertion order
+        var viewPanes = [];
 
-            // whether refreshing the pane layout is currently locked
-            layoutLocks = 0,
+        // whether refreshing the pane layout is currently locked
+        var layoutLocks = 0;
 
-            // whether refreshing the pane layout is currently running
-            layoutRunning = false,
+        // whether refreshing the pane layout is currently running
+        var layoutRunning = false;
 
-            // whether refreshing the pane layout was requested while it was locked
-            layoutPending = false,
+        // whether refreshing the pane layout was requested while it was locked
+        var layoutPending = false;
 
-            // whether the content root node is focusable by itself
-            contentFocusable = Utils.getBooleanOption(initOptions, 'contentFocusable', false),
+        // whether the content root node is focusable by itself
+        var contentFocusable = Utils.getBooleanOption(initOptions, 'contentFocusable', false);
 
-            // whether the application is hidden explicitly
-            viewHidden = false,
+        // whether the application is hidden explicitly
+        var viewHidden = false;
 
-            // cached yell options, shown when application becomes visible
-            pendingYellOptions = null,
+        // cached yell options, shown when application becomes visible
+        var pendingYellOptions = null;
 
-            // the timer waiting to fade in the blocker element in busy mode
-            blockerFadeTimer = null,
+        // the timer waiting to fade in the blocker element in busy mode
+        var blockerFadeTimer = null;
 
-            // the timer waiting to show a warning message during busy mode
-            blockerWarningTimer = null;
+        // the timer waiting to show a warning message during busy mode
+        var blockerWarningTimer = null;
 
         // base constructors --------------------------------------------------
 
-        TriggerObject.call(this);
-        TimerMixin.call(this);
+        TriggerObject.call(this, app);
         AppObjectMixin.call(this, app);
 
         // private methods ----------------------------------------------------
 
         function silentRefreshPaneLayout() {
 
-            var // current offsets representing available space in the application window
-                offsets = { top: 0, bottom: 0, left: 0, right: 0 };
+            // prevent recursive processing
+            if (layoutRunning) { return; }
+            layoutRunning = true;
 
-            function updatePane(pane) {
+            // current offsets representing available space in the application window
+            var offsets = { top: 0, bottom: 0, left: 0, right: 0 };
+
+            // update all registered view panes
+            viewPanes.forEach(function (pane) {
 
                 var paneNode = pane.getNode(),
                     visible = pane.isVisible(),
@@ -209,14 +211,7 @@ define('io.ox/office/baseframework/view/baseview', [
                     pane.layout();
                     offsets[position] += sizeFunc();
                 }
-            }
-
-            // prevent recursive processing
-            if (layoutRunning) { return; }
-            layoutRunning = true;
-
-            // update all registered view panes
-            _.each(viewPanes, updatePane);
+            });
 
             // update the application pane node (remaining space without panes)
             appPaneNode.css(offsets);
@@ -231,7 +226,7 @@ define('io.ox/office/baseframework/view/baseview', [
         function refreshPaneLayout() {
 
             // do nothing if the window is hidden (but refresh if import runs (fast loading))
-            if (!self.isVisible() || app.isInQuit()) {
+            if (!app || app.isInQuit() || !self || !self.isVisible()) {
                 return;
             }
 
@@ -251,8 +246,8 @@ define('io.ox/office/baseframework/view/baseview', [
          */
         var paneResizeHandler = (function () {
 
-            var // whether to really refresh the layout in the deferred callback
-                refreshLayout = false;
+            // whether to really refresh the layout in the deferred callback
+            var refreshLayout = false;
 
             function registerRefresh() {
                 // do nothing when view panes are changing during layout updates
@@ -266,7 +261,7 @@ define('io.ox/office/baseframework/view/baseview', [
                 }
             }
 
-            return self.createDebouncedMethod(registerRefresh, executeRefresh, { infoString: 'BaseView paneResizeHandler()', app: app });
+            return self.createDebouncedMethod('BaseView.paneResizeHandler', registerRefresh, executeRefresh);
         }());
 
         /**
@@ -317,6 +312,45 @@ define('io.ox/office/baseframework/view/baseview', [
                     messageNode.append($('<div class="small-text"><span>' + Utils.escapeHTML(extendedMessage) + '</span></div>'));
                 }
 
+                var
+                    closeActionOptions = Utils.getObjectOption(yellOptions, 'closeAction'),
+                    isQuitAppOnClose = Utils.getBooleanOption(closeActionOptions, 'isQuitApp', false),
+                    closeHandler = Utils.getFunctionOption(closeActionOptions, 'handler', null);
+
+                if (isQuitAppOnClose) {
+                    if (closeHandler !== null) {
+
+                        closeHandler = (function (app, docModel, callback) {
+                            return function () {
+
+                                callback(app, docModel);
+                                app.quit();
+                            };
+                        }(app, docModel, closeHandler));
+
+                    } else {
+
+                        closeHandler = (function (app) {
+                            return function () {
+
+                                app.quit();
+                            };
+                        }(app));
+                    }
+                } else if (closeHandler !== null) {
+
+                    closeHandler = (function (app, docModel, callback) {
+                        return function () {
+
+                            callback(app, docModel);
+                        };
+                    }(app, docModel, closeHandler));
+                }
+                if (closeHandler !== null) {
+
+                    self.listenTo(yellNode, 'notification:removed', closeHandler);
+                }
+
                 // options for an action link shown below the message text
                 var actionOptions = Utils.getObjectOption(yellOptions, 'action');
                 // the key of the controller item for an action link
@@ -350,7 +384,7 @@ define('io.ox/office/baseframework/view/baseview', [
             self.listenTo(yellNode, 'notification:removed', function (event) {
                 // bug 33735: only if focus is inside the alert box (e.g. after mouse click)
                 if (Forms.containsFocus(event.currentTarget)) {
-                    self.executeDelayed(function () { self.grabFocus(); }, { infoString: 'BaseView.showNotification', app: app });
+                    self.executeDelayed(function () { self.grabFocus(); }, 'BaseView.showNotification');
                 }
             });
         }
@@ -401,7 +435,7 @@ define('io.ox/office/baseframework/view/baseview', [
                     refreshPaneLayout();
                     app.getController().update();
                     self.grabFocus({ afterImport: true });
-                }, { infoString: 'BaseView: windowShowHandler', app: app });
+                }, 'BaseView.windowShowHandler');
             }
         }
 
@@ -429,8 +463,8 @@ define('io.ox/office/baseframework/view/baseview', [
          *  from external code.
          *
          * @returns {jQuery.Promise}
-         *  The promise of a Deferred object that will be resolved when the
-         *  initialization handler has finished.
+         *  A promise that will be resolved when the initialization handler has
+         *  finished.
          */
         this.hideBeforeImport = _.once(function () {
 
@@ -439,10 +473,11 @@ define('io.ox/office/baseframework/view/baseview', [
             self.hide();
 
             // invoke the initialization handler passed to the constructor
-            var result = Utils.getFunctionOption(initOptions, 'initHandler', $.noop).call(self);
+            var initHandler = Utils.getFunctionOption(initOptions, 'initHandler', null);
+            var result = initHandler ? initHandler.call(self) : null;
 
             // return a promise
-            return $.when(result);
+            return self.convertToPromise(result);
         });
 
         /**
@@ -459,8 +494,8 @@ define('io.ox/office/baseframework/view/baseview', [
          *  the view will not be initialized further.
          *
          * @returns {jQuery.Promise}
-         *  The promise of a Deferred object that will be resolved when the GUI
-         *  initialization handler has finished.
+         *  A promise that will be resolved when the GUI initialization handler
+         *  has finished.
          */
         this.showAfterImport = _.once(function (globalFailure) {
 
@@ -468,10 +503,11 @@ define('io.ox/office/baseframework/view/baseview', [
             self.show();
 
             // invoke the GUI initialization handler passed to the constructor
-            var result = globalFailure ? null : Utils.getFunctionOption(initOptions, 'initGuiHandler', $.noop).call(self);
+            var initGuiHandler = globalFailure ? null : Utils.getFunctionOption(initOptions, 'initGuiHandler', null);
+            var result = initGuiHandler ? initGuiHandler.call(self) : null;
 
             // wait for the callback, immediately refresh all view panes to reduce flicker effects
-            return $.when(result).always(function () {
+            return self.convertToPromise(result).always(function () {
                 silentRefreshPaneLayout();
                 self.leaveBusy();
             });
@@ -500,10 +536,11 @@ define('io.ox/office/baseframework/view/baseview', [
         };
 
         /**
-         * Returns whether the browser is located inside the application pane.
+         * Returns whether the browser focus is located inside the application
+         * pane.
          *
          * @returns {Boolean}
-         *  Whether the browser is located inside the application pane.
+         *  Whether the browser focus is located inside the application pane.
          */
         this.hasAppFocus = function () {
             return Forms.hasOrContainsFocus(this.getAppPaneNode());
@@ -702,7 +739,7 @@ define('io.ox/office/baseframework/view/baseview', [
                     blockerNode.css('opacity', 0);
                     blockerFadeTimer = self.repeatDelayed(function (index) {
                         blockerNode.css('opacity', (index + 1) / 10);
-                    }, { delay: delay, repeatDelay: 50, cycles: 10, infoString: 'BaseApp: blockerFadeTimer', app: app });
+                    }, 'BaseView.blockerFadeTimer', { delay: delay, repeatDelay: 50, cycles: 10 });
                     // defer showing the warning box until blocker is visible
                     warningDelay += delay + 500;
                 }
@@ -731,7 +768,7 @@ define('io.ox/office/baseframework/view/baseview', [
                             Utils.setFocus(cancelButton);
                             blockerNode.removeAttr('tabindex');
                         }
-                    }, { delay: warningDelay, infoString: 'BaseView: blockerWarningTimer', app: app });
+                    }, 'BaseView.blockerWarningTimer', warningDelay);
                 }
             }, options);
 
@@ -759,8 +796,8 @@ define('io.ox/office/baseframework/view/baseview', [
          */
         this.updateBusyProgress = (function () {
 
-            var // the current progress value to be shown at the progress bar
-                currProgress = 0;
+            // the current progress value to be shown at the progress bar
+            var currProgress = 0;
 
             function registerProgress(progress) {
                 currProgress = progress;
@@ -773,7 +810,7 @@ define('io.ox/office/baseframework/view/baseview', [
                 }
             }
 
-            return self.createDebouncedMethod(registerProgress, showProgress, { delay: 500, maxDelay: 500, infoString: 'BaseView updateBusyProgress()', app: app });
+            return self.createDebouncedMethod('BaseView.updateBusyProgress', registerProgress, showProgress, { delay: 500, maxDelay: 500 });
         }());
 
         /**
@@ -844,6 +881,15 @@ define('io.ox/office/baseframework/view/baseview', [
          *          icons are NOT supported.
          *      @param {String} yellOptions.action.label
          *          A label text for the link.
+         *  @param {Object} [yellOptions.closeAction]
+         *      A descriptor for how to handle an actively triggered close event of any notification popup.
+         *      If specified, it should be an object with the following properties:
+         *      @param {Boolean} yellOptions.closeAction.isQuitApp
+         *          An optional boolean flag pointing to whether the current application should be quit to or not.
+         *      @param {Function} yellOptions.closeAction.handler
+         *          An optionally provided method, handled as callback. It has to provide behavior that will be
+         *          executed in addition to closing the notification popup. Following arguments will be passed
+         *          into such a closing action handler ... [{app}, {docModel}, {BaseView}].
          *
          * @returns {BaseView}
          *  A reference to this instance.
@@ -939,7 +985,6 @@ define('io.ox/office/baseframework/view/baseview', [
          *  A reference to this instance.
          */
         this.addPane = function (pane) {
-
             // insert the new view pane
             viewPanes.push(pane);
             (viewHidden ? tempNode : winBodyNode).append(pane.getNode());
@@ -1152,17 +1197,13 @@ define('io.ox/office/baseframework/view/baseview', [
         // mix-in classes expecting complete view
         ViewObjectMixin.call(this, this);
 
-        // initialize class members
-        appWindow = app.getWindow();
-        winBodyNode = app.getWindowNode();
-
         // add CSS classes to the window root node, and the temporary container node
         (function () {
 
-            var // all CSS classes (always add the application name)
-                windowNodeClasses = 'io-ox-office-main ' + app.getName().replace(/[./]/g, '-') + '-main',
-                // additional CSS classes from options
-                classes = Utils.getStringOption(initOptions, 'classes');
+            // all CSS classes (always add the application name)
+            var windowNodeClasses = 'io-ox-office-main ' + app.getName().replace(/[./]/g, '-') + '-main';
+            // additional CSS classes from options
+            var classes = Utils.getStringOption(initOptions, 'classes');
 
             // add the classes passed through options
             if (classes) { windowNodeClasses += ' ' + classes; }
