@@ -15,13 +15,30 @@
 define('io.ox/office/baseframework/view/component', [
     'io.ox/office/tk/utils',
     'io.ox/office/tk/forms',
-    'io.ox/office/tk/object/timermixin',
+    'io.ox/office/tk/container/valueset',
+    'io.ox/office/tk/container/valuemap',
     'io.ox/office/baseframework/model/modelobject',
     'io.ox/office/baseframework/view/viewobjectmixin'
-], function (Utils, Forms, TimerMixin, ModelObject, ViewObjectMixin) {
+], function (Utils, Forms, ValueSet, ValueMap, ModelObject, ViewObjectMixin) {
 
     'use strict';
 
+    // private global functions ===============================================
+
+    /**
+     * Inserts the passed group into the map under a specific controller key.
+     */
+    function addGroupToKeyMap(keyMap, key, group) {
+        keyMap.getOrConstruct(key, ValueSet, 'getUid()').insert(group);
+    }
+
+    /**
+     * Removes the passed group from the key map.
+     */
+    function removeGroupFromKeyMap(keyMap, group) {
+        keyMap.forEach(function (groupSet) { groupSet.remove(group); });
+    }
+
     // class Component ========================================================
 
     /**
@@ -56,7 +73,6 @@ define('io.ox/office/baseframework/view/component', [
      * @constructor
      *
      * @extends ModelObject
-     * @extends TimerMixin
      * @extends ViewObjectMixin
      *
      * @param {BaseView} docView
@@ -78,66 +94,49 @@ define('io.ox/office/baseframework/view/component', [
      */
     function Component(docView, initOptions) {
 
-        var // self reference
-            self = this,
+        // self reference
+        var self = this;
 
-            // the application instance
-            app = docView.getApp(),
+        // the application instance
+        var app = docView.getApp();
 
-            // the container element representing the pane
-            rootNode = $('<div class="view-component">').addClass(Utils.getStringOption(initOptions, 'classes', '')),
+        // the container element representing the pane
+        var rootNode = $('<div class="view-component">').addClass(Utils.getStringOption(initOptions, 'classes', ''));
 
-            // the last cached size of the root node, used to detect layout changes
-            nodeSize = null,
+        // the last cached size of the root node, used to detect layout changes
+        var nodeSize = null;
 
-            // all control groups, as descriptor objects with key and other data, mapped by group UID
-            groupRegistry = {},
+        // all control groups, as descriptor objects with key and other data, mapped by group UID
+        var groupRegistry = new ValueMap();
 
-            // all control groups, as sub-maps mapped by controller key, then by group UID
-            groupsByKey = {},
+        // all control groups, as sets mapped by controller key
+        var groupsByKey = new ValueMap();
 
-            // all control groups with bound visibility, as sub-maps mapped by visibility key, then by group UID
-            groupsByVisibleKey = {},
+        // all control groups with bound visibility, as sets mapped by visibility key
+        var groupsByVisibleKey = new ValueMap();
 
-            // handler called to insert a new group into this view component
-            groupInserters = [],
+        // handler called to insert a new group into this view component
+        var groupInserters = [];
 
-            // whether to hide all disabled control groups automatically
-            autoHideGroups = Utils.getBooleanOption(initOptions, 'autoHideGroups', false),
+        // whether to hide all disabled control groups automatically
+        var autoHideGroups = Utils.getBooleanOption(initOptions, 'autoHideGroups', false);
 
-            // whether the view component is set to visible (regardless of effective visibility)
-            visible = true,
+        // whether the view component is set to visible (regardless of effective visibility)
+        var visible = true;
 
-            // whether a 'component:resize' event is currently triggering (prevent recursion)
-            isResizeTriggering = false,
+        // whether a 'component:resize' event is currently triggering (prevent recursion)
+        var isResizeTriggering = false;
 
-            // whether a 'component:layout' event is currently triggering (prevent recursion)
-            isLayoutTriggering = false;
+        // whether a 'component:layout' event is currently triggering (prevent recursion)
+        var isLayoutTriggering = false;
 
         // base constructors --------------------------------------------------
 
         ModelObject.call(this, docView.getDocModel());
-        TimerMixin.call(this);
         ViewObjectMixin.call(this, docView);
 
         // private methods ----------------------------------------------------
 
-        /**
-         * Inserts the passed group into the map under a specific group key.
-         */
-        function addGroupToKeyMap(keyMap, key, group) {
-            var subMap = keyMap[key] || (keyMap[key] = {});
-            subMap[group.getUid()] = group;
-        }
-
-        /**
-         * Removes the passed group from the key map.
-         */
-        function removeGroupFromKeyMap(keyMap, group) {
-            var groupUid = group.getUid();
-            _.each(keyMap, function (subMap) { delete subMap[groupUid]; });
-        }
-
         /**
          * Updates the effective visibility of the root node, according to the
          * own visible state, and the visibility of all control groups.
@@ -148,7 +147,7 @@ define('io.ox/office/baseframework/view/component', [
         function updateNodeVisibility() {
 
             // whether the component is visible and contains at least one visible group
-            var makeVisible = visible && _.some(groupRegistry, function (data) { return data.group.isVisible(); });
+            var makeVisible = visible && self.hasVisibleGroups();
 
             // update node visibility and notify listeners, if really changed
             if (self.isVisible() !== makeVisible) {
@@ -180,13 +179,13 @@ define('io.ox/office/baseframework/view/component', [
             // do nothing if the component is hidden, or is inside a hidden container node
             if (!self.isVisible() || !Forms.isDeeplyVisibleNode(rootNode)) { return; }
 
-            var // whether to update the view components
-                updateLayout = Utils.getBooleanOption(options, 'updateLayout', false),
-                // whether to trigger a 'pane:layout' event
-                triggerLayout = updateLayout || Utils.getBooleanOption(options, 'triggerLayout', false);
+            // whether to update the view components
+            var updateLayout = Utils.getBooleanOption(options, 'updateLayout', false);
+            // whether to trigger a 'pane:layout' event
+            var triggerLayout = updateLayout || Utils.getBooleanOption(options, 'triggerLayout', false);
 
             // update layout of all control groups if specified
-            if (updateLayout) { _.each(groupRegistry, function (data) { data.group.layout(); }); }
+            if (updateLayout) { groupRegistry.forEach(function (data) { data.group.layout(); }); }
 
             // current size of the DOM root node
             var newSize = { width: rootNode.outerWidth(), height: rootNode.outerHeight() };
@@ -232,14 +231,14 @@ define('io.ox/office/baseframework/view/component', [
          */
         var groupResizeHandler = (function () {
             var triggerLayout = false;
-            return self.createDebouncedMethod(function (event) {
+            return self.createDebouncedMethod('Component.groupResizeHandler', function (event) {
                 if (!isLayoutTriggering) { triggerLayout = true; }
                 if (event.type !== 'group:resize') { updateNodeVisibility(); }
             }, function () {
                 var options = { triggerLayout: triggerLayout };
                 triggerLayout = false;
                 updateNodeSize(options);
-            }, { infoString: 'Component groupResizeHandler()', app: app });
+            });
         }());
 
         /**
@@ -249,8 +248,8 @@ define('io.ox/office/baseframework/view/component', [
          */
         function groupFocusHandler(event) {
 
-            var focused = event.type === 'group:focus',
-                type = focused ? 'component:focus' : 'component:blur';
+            var focused = event.type === 'group:focus';
+            var type = focused ? 'component:focus' : 'component:blur';
 
             rootNode.toggleClass(Forms.FOCUSED_CLASS, focused);
             self.trigger(type);
@@ -272,7 +271,7 @@ define('io.ox/office/baseframework/view/component', [
 
             // if the group is initially enabled, ask its registered callback handler
             if (enabled) {
-                var groupData = groupRegistry[group.getUid()];
+                var groupData = groupRegistry.get(group.getUid());
                 if (groupData.enableHandler) {
                     enabled = groupData.enableHandler.call(self, group) === true;
                 }
@@ -302,31 +301,35 @@ define('io.ox/office/baseframework/view/component', [
 
             // show/hide the passed control group
             function updateGroupVisibility(group) {
-                var visibleKey = groupRegistry[group.getUid()].visibleKey;
+                var visibleKey = groupRegistry.get(group.getUid()).visibleKey;
                 if (autoHideGroups || visibleKey) {
                     group.toggle((!autoHideGroups || enabled) && (!visibleKey || controller.isItemEnabled(visibleKey)));
                 }
             }
 
             // update all control groups with the passed key (may be more than one)
-            _.each(groupsByKey[key], function (group) {
+            groupsByKey.with(key, function (groupSet) {
+                groupSet.forEach(function (group) {
 
-                // update enabled state and value of the controls
-                updateGroupEnabledState(group, enabled);
-                group.setValue(value);
+                    // update enabled state and value of the controls
+                    updateGroupEnabledState(group, enabled);
+                    group.setValue(value);
 
-                // show/hide all groups with bound visibility
-                updateGroupVisibility(group);
+                    // show/hide all groups with bound visibility
+                    updateGroupVisibility(group);
+                });
             });
 
             // show/hide all controls whose visibility is bound to the passed key (regardless of their own key)
-            _.each(groupsByVisibleKey[key], updateGroupVisibility);
+            groupsByVisibleKey.with(key, function (groupSet) {
+                groupSet.forEach(updateGroupVisibility);
+            });
         }
 
         /**
          * Debounced version of the method updateAllGroups().
          */
-        var updateAllGroupsDebounced = this.createDebouncedMethod(_.noop, function () { self.updateAllGroups(); }, { delay: 50, infoString: 'Component updateAllGroupsDebounced()', app: app });
+        var updateAllGroupsDebounced = this.createDebouncedMethod('Component.updateAllGroupsDebounced', null, function () { self.updateAllGroups(); }, { delay: 50 });
 
         /**
          * Handler for changed controller items. Updates the state and value of
@@ -517,16 +520,16 @@ define('io.ox/office/baseframework/view/component', [
          */
         this.addGroup = function (key, group, options) {
 
-            var // the unique identifier of the group
-                groupUid = group.getUid(),
-                // the registry entry for the group
-                groupData = {
-                    group: group,
-                    key: key,
-                    visibleKey: Utils.getStringOption(options, 'visibleKey', null),
-                    enableHandler: Utils.getFunctionOption(options, 'enableHandler', null),
-                    focusTarget: Utils.getOption(options, 'focusTarget')
-                };
+            // the unique identifier of the group
+            var groupUid = group.getUid();
+            // the registry entry for the group
+            var groupData = {
+                group: group,
+                key: key,
+                visibleKey: Utils.getStringOption(options, 'visibleKey', null),
+                enableHandler: Utils.getFunctionOption(options, 'enableHandler', null),
+                focusTarget: Utils.getOption(options, 'focusTarget')
+            };
 
             // builds a focus options object to be passed to the controller
             function getFocusOptions(event) {
@@ -542,10 +545,10 @@ define('io.ox/office/baseframework/view/component', [
             }
 
             // remember the group object
-            groupRegistry[groupUid] = groupData;
+            groupRegistry.insert(groupUid, groupData);
 
             // insert the group into this view component
-            if (_.all(groupInserters, function (inserter) { return inserter.call(self, group, options) === false; })) {
+            if (groupInserters.every(function (inserter) { return inserter.call(self, group, options) === false; })) {
                 rootNode.append(group.getNode());
             }
 
@@ -621,7 +624,7 @@ define('io.ox/office/baseframework/view/component', [
             this.stopListeningTo(group);
 
             // remove group from internal containers
-            delete groupRegistry[groupUid];
+            groupRegistry.remove(groupUid);
             removeGroupFromKeyMap(groupsByKey, group);
             removeGroupFromKeyMap(groupsByVisibleKey, group);
 
@@ -652,7 +655,7 @@ define('io.ox/office/baseframework/view/component', [
          *  Utils.BREAK to stop the iteration process, otherwise undefined.
          */
         this.iterateGroups = function (iterator, context) {
-            return _.some(groupRegistry, function (data) {
+            return groupRegistry.some(function (data) {
                 return iterator.call(context, data.group) === Utils.BREAK;
             }) ? Utils.BREAK : undefined;
         };
@@ -664,7 +667,7 @@ define('io.ox/office/baseframework/view/component', [
          *  Whether this view component contains visible groups.
          */
         this.hasVisibleGroups = function () {
-            return _.some(groupRegistry, function (data) { return data.group.isVisible(); });
+            return groupRegistry.some(function (data) { return data.group.isVisible(); });
         };
 
         /**
@@ -681,20 +684,21 @@ define('io.ox/office/baseframework/view/component', [
 
             // use the 'groupsByKey' map for iteration, to resolve each controller item
             // once, even if multiple groups have been registered for that item
-            _.each(groupsByKey, function (map, key) {
+            groupsByKey.forEachKey(function (key) {
                 updateGroupState(key, controller.isItemEnabled(key), controller.getItemValue(key));
             });
 
             // update enabled state of all groups not bound to a controller item
-            _.each(groupRegistry, function (data) {
+            groupRegistry.forEach(function (data) {
                 if (!data.key) { updateGroupEnabledState(data.group, true); }
             });
 
             // update all groups not bound to a controller item, but with a 'visibleKey'
-            _.each(groupsByVisibleKey, function (map, key) {
+            groupsByVisibleKey.forEach(function (groupSet, key) {
                 var visible = controller.isItemEnabled(key);
-                _.each(map, function (group, groupUid) {
-                    if (!groupRegistry[groupUid].key) {
+                groupSet.forEach(function (group, groupUid) {
+                    var groupData = groupRegistry.get(groupUid);
+                    if (!groupData.key) {
                         group.toggle(visible);
                     }
                 });
@@ -713,12 +717,12 @@ define('io.ox/office/baseframework/view/component', [
         this.destroyAllGroups = function () {
 
             // destroy all group instances (remove themselves from the DOM)
-            _.each(groupRegistry, function (data) { data.group.destroy(); });
+            groupRegistry.forEach(function (data) { data.group.destroy(); });
 
             // clean the group containers (arrays/maps)
-            groupRegistry = {};
-            groupsByKey = {};
-            groupsByVisibleKey = {};
+            groupRegistry.clear();
+            groupsByKey.clear();
+            groupsByVisibleKey.clear();
 
             // remove all remaining DOM nodes (separators etc.)
             this.getNode().empty();
@@ -741,7 +745,7 @@ define('io.ox/office/baseframework/view/component', [
          *  browser focus.
          */
         this.hasFocus = function () {
-            return _.some(groupRegistry, function (data) { return data.group.hasFocus(); });
+            return groupRegistry.some(function (data) { return data.group.hasFocus(); });
         };
 
         /**
@@ -778,7 +782,7 @@ define('io.ox/office/baseframework/view/component', [
 
         // destroy all class members on destruction
         this.registerDestructor(function () {
-            _.each(groupRegistry, function (data) { data.group.destroy(); });
+            groupRegistry.forEach(function (data) { data.group.destroy(); });
             rootNode.remove();
             self = app = docView = initOptions = rootNode = null;
             groupRegistry = groupsByKey = groupsByVisibleKey = groupInserters = null;
