@@ -42,17 +42,17 @@ define('io.ox/office/baseframework/view/control/compoundcheckbox', [
      */
     function CompoundCheckBox(docView, initOptions) {
 
-        var // the drop-down button
-            menuButton = $(Forms.createButtonMarkup());
+        // the drop-down button
+        var menuButton = $(Forms.createButtonMarkup());
 
         // base constructors --------------------------------------------------
 
-        CheckBox.call(this, initOptions);
+        CheckBox.call(this, docView, initOptions);
         CompoundMenuMixin.call(this, docView, Utils.extendOptions(initOptions, { button: menuButton }));
 
         // initialization -----------------------------------------------------
 
-        Forms.setToolTip(menuButton, { tooltip: Utils.getOption(initOptions, 'tooltip', '') });
+        Forms.setToolTip(menuButton, Utils.getStringOption(initOptions, 'tooltip', ''));
 
         // add the drop-down button to the group
         this.addChildNodes(menuButton);
