@@ -17,11 +17,11 @@ define('io.ox/office/baseframework/view/pane', [
     'io.ox/office/tk/keycodes',
     'io.ox/office/tk/forms',
     'io.ox/office/tk/utils/tracking',
+    'io.ox/office/tk/container/valueset',
     'io.ox/office/tk/object/triggerobject',
-    'io.ox/office/tk/object/timermixin',
     'io.ox/office/baseframework/app/appobjectmixin',
     'io.ox/office/baseframework/view/viewobjectmixin'
-], function (Utils, KeyCodes, Forms, Tracking, TriggerObject, TimerMixin, AppObjectMixin, ViewObjectMixin) {
+], function (Utils, KeyCodes, Forms, Tracking, ValueSet, TriggerObject, AppObjectMixin, ViewObjectMixin) {
 
     'use strict';
 
@@ -57,7 +57,6 @@ define('io.ox/office/baseframework/view/pane', [
      * @constructor
      *
      * @extends TriggerObject
-     * @extends TimerMixin
      * @extends AppObjectMixin
      * @extends ViewObjectMixin
      *
@@ -72,17 +71,17 @@ define('io.ox/office/baseframework/view/pane', [
      *  @param {String} [initOptions.position='top']
      *      The border of the application window to attach the view pane to.
      *      Supported values are 'top', 'bottom', 'left', and 'right'.
-     *  @param {String} [initOptions.size]
+     *  @param {Number} [initOptions.size]
      *      The size of the pane, between window border and application pane.
      *      If omitted, the size will be determined by the DOM contents of the
      *      pane root node.
-     *  @param {String} [initOptions.resizable=false]
+     *  @param {Boolean} [initOptions.resizable=false]
      *      If set to true, the pane will be resizable at its inner border. Has
      *      no effect for transparent overlay panes.
-     *  @param {String} [initOptions.minSize=1]
+     *  @param {Number} [initOptions.minSize=1]
      *      The minimum size of resizable panes (when the option 'resizable' is
      *      set to true).
-     *  @param {String} [initOptions.maxSize=0x7FFFFFFF]
+     *  @param {Number} [initOptions.maxSize=0x7FFFFFFF]
      *      The maximum size of resizable panes (when the option 'resizable' is
      *      set to true).
      *  @param {Boolean} [initOptions.cursorNavigate=false]
@@ -91,45 +90,45 @@ define('io.ox/office/baseframework/view/pane', [
      */
     function Pane(docView, initOptions) {
 
-        var // self reference
-            self = this,
+        // self reference
+        var self = this;
 
-            // the container element representing the pane
-            rootNode = $('<div class="view-pane">').addClass(Utils.getStringOption(initOptions, 'classes', '')),
+        // the application instance
+        var app = docView.getApp();
 
-            // position of the pane in the application window
-            position = Utils.getStringOption(initOptions, 'position', 'top'),
+        // the container element representing the pane
+        var rootNode = $('<div class="view-pane">').addClass(Utils.getStringOption(initOptions, 'classes', ''));
 
-            // minimum size of the view pane (for resizable panes)
-            minSize = Utils.getIntegerOption(initOptions, 'minSize', 1, 1),
+        // position of the pane in the application window
+        var position = Utils.getStringOption(initOptions, 'position', 'top');
 
-            // maximum size of the view pane (for resizable panes)
-            maxSize = Utils.getIntegerOption(initOptions, 'maxSize', 0x7FFFFFFF, minSize),
+        // minimum size of the view pane (for resizable panes)
+        var minSize = Utils.getIntegerOption(initOptions, 'minSize', 1, 1);
 
-            // the last cached size of the root node, used to detect layout changes
-            nodeSize = null,
+        // maximum size of the view pane (for resizable panes)
+        var maxSize = Utils.getIntegerOption(initOptions, 'maxSize', 0x7FFFFFFF, minSize);
 
-            // view components contained in this pane
-            components = [],
+        // the last cached size of the root node, used to detect layout changes
+        var nodeSize = null;
 
-            // callback handlers for inserting components into this view pane
-            componentInserters = [],
+        // view components contained in this pane
+        var components = new ValueSet('getUid()');
 
-            // whether the view pane is set to visible (regardless of effective visibility)
-            visible = true,
+        // callback handlers for inserting components into this view pane
+        var componentInserters = [];
 
-            // whether a 'pane:resize' event is currently triggering (prevent recursion)
-            isResizeTriggering = false,
+        // whether the view pane is set to visible (regardless of effective visibility)
+        var visible = true;
 
-            // whether a 'pane:layout' event is currently triggering (prevent recursion)
-            isLayoutTriggering = false,
+        // whether a 'pane:resize' event is currently triggering (prevent recursion)
+        var isResizeTriggering = false;
 
-            app = docView.getApp();
+        // whether a 'pane:layout' event is currently triggering (prevent recursion)
+        var isLayoutTriggering = false;
 
         // base constructors --------------------------------------------------
 
-        TriggerObject.call(this);
-        TimerMixin.call(this);
+        TriggerObject.call(this, app);
         AppObjectMixin.call(this, app);
         ViewObjectMixin.call(this, docView);
 
@@ -173,16 +172,18 @@ define('io.ox/office/baseframework/view/pane', [
             // do nothing if the pane is hidden, or is inside a hidden container node
             if (!self.isVisible() || !Forms.isDeeplyVisibleNode(rootNode)) { return; }
 
-            var // whether to update the view components
-                updateLayout = Utils.getBooleanOption(options, 'updateLayout', false),
-                // whether to trigger a 'pane:layout' event
-                triggerLayout = updateLayout || Utils.getBooleanOption(options, 'triggerLayout', false);
+            // whether to update the view components
+            var updateLayout = Utils.getBooleanOption(options, 'updateLayout', false);
+            // whether to trigger a 'pane:layout' event
+            var triggerLayout = updateLayout || Utils.getBooleanOption(options, 'triggerLayout', false);
 
             // update layout of all components if specified
-            if (updateLayout) { _.invoke(components, 'layout'); }
+            if (updateLayout) {
+                components.forEach('layout');
+            }
 
-            var // current size of the DOM root node
-                newSize = { width: rootNode.outerWidth(), height: rootNode.outerHeight() };
+            // current size of the DOM root node
+            var newSize = { width: rootNode.outerWidth(), height: rootNode.outerHeight() };
 
             // notify listeners if size has changed
             if (!_.isEqual(nodeSize, newSize)) {
@@ -226,13 +227,13 @@ define('io.ox/office/baseframework/view/pane', [
          */
         var componentResizeHandler = (function () {
             var triggerLayout = false;
-            return self.createDebouncedMethod(function () {
+            return self.createDebouncedMethod('Pane.componentResizeHandler', function () {
                 if (!isLayoutTriggering) { triggerLayout = true; }
             }, function () {
                 var options = { triggerLayout: triggerLayout };
                 triggerLayout = false;
                 updateNodeSize(options);
-            }, { infoString: 'Pane componentResizeHandler()', app: app });
+            });
         }());
 
         /**
@@ -242,8 +243,8 @@ define('io.ox/office/baseframework/view/pane', [
          */
         function componentFocusHandler(event) {
 
-            var focused = event.type === 'component:focus',
-                type = focused ? 'pane:focus' : 'pane:blur';
+            var focused = event.type === 'component:focus';
+            var type = focused ? 'pane:focus' : 'pane:blur';
 
             rootNode.toggleClass(Forms.FOCUSED_CLASS, focused);
             self.trigger(type);
@@ -254,8 +255,8 @@ define('io.ox/office/baseframework/view/pane', [
          */
         var trackingHandler = (function () {
 
-            var // the original size of the view pane when tracking has been started
-                origSize = 0;
+            // the original size of the view pane when tracking has been started
+            var origSize = 0;
 
             function trackingHandler(event) {
                 switch (event.type) {
@@ -291,8 +292,8 @@ define('io.ox/office/baseframework/view/pane', [
             }
 
             // shortcut in panes to open drop-down menus with simple UP/DOWN cursor key
-            var menuGroupNode = $(event.target).closest('.group.dropdown-group', rootNode[0]),
-                menuButtonNode = menuGroupNode.find(Forms.BUTTON_SELECTOR + '.caret-button');
+            var menuGroupNode = $(event.target).closest('.group.dropdown-group', rootNode[0]);
+            var menuButtonNode = menuGroupNode.find(Forms.BUTTON_SELECTOR + '.caret-button');
             if ((menuButtonNode.length === 1) && Forms.isVisibleNode(menuButtonNode) && !KeyCodes.hasModifierKeys(event)) {
                 if ((event.keyCode === KeyCodes.UP_ARROW) || (event.keyCode === KeyCodes.DOWN_ARROW)) {
                     event.target = menuButtonNode[0];
@@ -494,10 +495,10 @@ define('io.ox/office/baseframework/view/pane', [
         this.addViewComponent = function (component, options) {
 
             // store component
-            components.push(component);
+            components.insert(component);
 
             // insert the root node of the component into this view pane
-            if (_.all(componentInserters, function (inserter) { return inserter.call(self, component, options) === false; })) {
+            if (componentInserters.every(function (inserter) { return inserter.call(self, component, options) === false; })) {
                 rootNode.append(component.getNode());
             }
 
@@ -524,40 +525,32 @@ define('io.ox/office/baseframework/view/pane', [
          */
         this.removeViewComponent = function (component) {
 
-            var // the number of view components
-                count = components.length;
-
-            // remove the component from the internal array
-            components = _.without(components, component);
-
             // unregister listeners and remove DOM node if the component was part of this pane
-            if (components.length !== count) {
-
+            if (components.remove(component)) {
                 // stop listening to the view component
                 this.stopListeningTo(component);
-
                 // remove the root node of the component from this pane
                 component.getNode().detach();
-
                 // update internal layout (pane visibility and size)
                 updateNode();
             }
+
             return this;
         };
 
         /**
-         * Checks whether the component already exists
+         * Returns whether the passed view component has already been inserted
+         * into this view pane.
          *
          * @param {Component} component
-         *  The view component to be removed from this pane. Nothing will
-         *  happen, if the component has not been added to this view pane
-         *  before using the method Pane.addViewComponent().
+         *  The view component to be checked.
          *
          * @returns {Boolean}
-         *  Whether the component exists.
+         *  Whether the view component has already been inserted into this view
+         *  pane.
          */
         this.hasViewComponent = function (component) {
-            return _.contains(components, component);
+            return components.has(component);
         };
 
         /**
@@ -572,7 +565,7 @@ define('io.ox/office/baseframework/view/pane', [
          *  browser focus.
          */
         this.hasFocus = function () {
-            return _.any(components, function (component) { return component.hasFocus(); });
+            return components.some('hasFocus');
         };
 
         /**
@@ -625,9 +618,9 @@ define('io.ox/office/baseframework/view/pane', [
 
         // destroy all class members on destruction
         this.registerDestructor(function () {
-            _.invoke(components, 'destroy');
+            components.forEach('destroy').clear();
             rootNode.remove();
-            self = docView = initOptions = rootNode = components = componentInserters = null;
+            self = app = docView = initOptions = rootNode = components = componentInserters = null;
         });
 
     } // class Pane
