@@ -16,19 +16,18 @@ define('io.ox/office/baseframework/view/popup/compoundmenu', [
     'io.ox/office/tk/utils',
     'io.ox/office/tk/forms',
     'io.ox/office/tk/popup/basemenu',
-    'io.ox/office/tk/control/button',
     'io.ox/office/baseframework/view/component',
     'io.ox/office/baseframework/view/viewobjectmixin',
     'gettext!io.ox/office/baseframework/main'
-], function (Utils, Forms, BaseMenu, Button, Component, ViewObjectMixin, gt) {
+], function (Utils, Forms, BaseMenu, Component, ViewObjectMixin, gt) {
 
     'use strict';
 
-    var // CSS class name for separator lines
-        SEPARATOR_LINE_CLASS = 'separator-line',
+    // CSS class name for separator lines
+    var SEPARATOR_LINE_CLASS = 'separator-line';
 
-        // CSS class name for header labels
-        HEADER_LABEL_CLASS = 'header-label';
+    // CSS class name for header labels
+    var HEADER_LABEL_CLASS = 'header-label';
 
     // class CompoundMenu =====================================================
 
@@ -84,36 +83,36 @@ define('io.ox/office/baseframework/view/popup/compoundmenu', [
      */
     function CompoundMenu(docView, initOptions) {
 
-        var // self reference
-            self = this,
+        // self reference
+        var self = this;
 
-            // lazy initialization callback function
-            lazyInitHandler = Utils.getFunctionOption(initOptions, 'lazyInitHandler'),
+        // lazy initialization callback function
+        var lazyInitHandler = Utils.getFunctionOption(initOptions, 'lazyInitHandler');
 
-            // callback predicate returning whether the OK button in the footer is currently enabled
-            enableActionHandler = Utils.getFunctionOption(initOptions, 'enableActionHandler'),
+        // callback predicate returning whether the OK button in the footer is currently enabled
+        var enableActionHandler = Utils.getFunctionOption(initOptions, 'enableActionHandler');
 
-            // whether to hide all disabled control groups automatically
-            autoHideGroups = Utils.getBooleanOption(initOptions, 'autoHideGroups', false),
+        // whether to hide all disabled control groups automatically
+        var autoHideGroups = Utils.getBooleanOption(initOptions, 'autoHideGroups', false);
 
-            // the view component in the drop-down menu for dynamic contents
-            innerComponent = null,
+        // the view component in the drop-down menu for dynamic contents
+        var innerComponent = null;
 
-            // the root node of the menu footer
-            footerNode = null,
+        // the root node of the menu footer
+        var footerNode = null;
 
-            // the OK button shown in the footer
-            actionButton = null,
+        // the OK button shown in the footer
+        var actionButton = null;
 
-            // the Cancel button shown in the footer
-            cancelButton = null,
+        // the Cancel button shown in the footer
+        var cancelButton = null;
 
-            // saved scroll position of inner component during 2-step layouting
-            scrollTop = 0;
+        // saved scroll position of inner component during 2-step layouting
+        var scrollTop = 0;
 
         // base constructors --------------------------------------------------
 
-        BaseMenu.call(this, Utils.extendOptions(initOptions, {
+        BaseMenu.call(this, docView, Utils.extendOptions(initOptions, {
             suppressScrollBars: true,
             prepareLayoutHandler: prepareLayoutHandler,
             updateLayoutHandler: updateLayoutHandler
@@ -127,16 +126,16 @@ define('io.ox/office/baseframework/view/popup/compoundmenu', [
          */
         function groupInserter(group, options) {
 
-            var // the root node of the passed group
-                groupNode = group.getNode(),
-                // the target node for the passed group
-                targetNode = innerComponent.getNode(),
-                // the last child in the view component
-                lastNode = targetNode.children().last(),
-                // insert given group before this specific element
-                insertBefore = Utils.getOption(options, 'insertBefore', null),
-                // save the separator, if existing, before the element given in "insertBefore"
-                saveSeparator = Utils.getBooleanOption(options, 'saveSeparator', false);
+            // the root node of the passed group
+            var groupNode = group.getNode();
+            // the target node for the passed group
+            var targetNode = innerComponent.getNode();
+            // the last child in the view component
+            var lastNode = targetNode.children().last();
+            // insert given group before this specific element
+            var insertBefore = Utils.getOption(options, 'insertBefore', null);
+            // save the separator, if existing, before the element given in "insertBefore"
+            var saveSeparator = Utils.getBooleanOption(options, 'saveSeparator', false);
 
             if (Utils.getBooleanOption(options, 'inline', false)) {
                 if (lastNode.is('.inline-container')) {
@@ -196,24 +195,30 @@ define('io.ox/office/baseframework/view/popup/compoundmenu', [
                 } else if (childNode.is('.group')) {
                     if (!currData) { newSectionData(null); }
                     currData.groups.push(childNode);
+                } else if (childNode.is('.inline-container')) {
+                    if (!currData) { newSectionData(null); }
+                    currData.groups = currData.groups.concat(childNode.children('.group').get());
                 }
             });
 
             // update visibility of the separator lines and header labels according to visible groups
-            allSectionData.forEach(function (sectionData, index) {
+            var anyVisible = false;
+            allSectionData.forEach(function (sectionData) {
 
                 // detect sections with visible groups
-                sectionData.visible = sectionData.groups.some(Forms.isVisibleNode);
+                var visible = sectionData.groups.some(Forms.isVisibleNode);
 
-                // separator line needs a visible group before and one after
+                // separator line needs another visible group before
                 if (sectionData.separator) {
-                    Forms.showNodes(sectionData.separator, (index > 0) && sectionData.visible && allSectionData[index - 1].visible);
+                    Forms.showNodes(sectionData.separator, anyVisible && visible);
                 }
 
                 // header label needs a visible group after
                 if (sectionData.header) {
-                    Forms.showNodes(sectionData.header, sectionData.visible);
+                    Forms.showNodes(sectionData.header, visible);
                 }
+
+                anyVisible = anyVisible || visible;
             });
         }
 
@@ -222,14 +227,14 @@ define('io.ox/office/baseframework/view/popup/compoundmenu', [
          */
         function updateLayoutHandler(contentSize, availableSize) {
 
-            var // DOM node of the inner component
-                innerCompNode = innerComponent ? innerComponent.getNode() : null,
-                // all child nodes (set to inline-block to be able to measure their required width)
-                childNodes = self.getContentNode().children().css('display', 'inline-block'),
-                // the maximum required width of all children
-                childWidth = _.max(_.map(childNodes.get(), function (node) { return Utils.getCeilNodeSize(node).width; })),
-                // height reduction for the inner component
-                heightDiff = contentSize.height - availableSize.height;
+            // DOM node of the inner component
+            var innerCompNode = innerComponent ? innerComponent.getNode() : null;
+            // all child nodes (set to inline-block to be able to measure their required width)
+            var childNodes = self.getContentNode().children().css('display', 'inline-block');
+            // the maximum required width of all children
+            var childWidth = _.max(_.map(childNodes.get(), function (node) { return Utils.getCeilNodeSize(node).width; }));
+            // height reduction for the inner component
+            var heightDiff = contentSize.height - availableSize.height;
 
             // if the menu is larger than the available height, make the inner view component
             // scrollable, and add space for vertical scroll bar to required width of the children
@@ -337,8 +342,8 @@ define('io.ox/office/baseframework/view/popup/compoundmenu', [
          */
         this.addSectionLabel = function (label, options) {
 
-            var // whether to add a separator line
-                separator = Utils.getBooleanOption(options, 'separator', true);
+            // whether to add a separator line
+            var separator = Utils.getBooleanOption(options, 'separator', true);
 
             if (separator && innerComponent.getNode()[0].hasChildNodes()) {
                 this.addSeparator();
