@@ -14,9 +14,9 @@
 
 define('io.ox/office/baseframework/view/popup/contextmenu', [
     'io.ox/office/tk/utils',
-    'io.ox/office/tk/object/timermixin',
+    'io.ox/office/tk/popup/tooltip',
     'io.ox/office/baseframework/view/popup/compoundmenu'
-], function (Utils, TimerMixin, CompoundMenu) {
+], function (Utils, ToolTip, CompoundMenu) {
 
     'use strict';
 
@@ -41,7 +41,6 @@ define('io.ox/office/baseframework/view/popup/contextmenu', [
      * @constructor
      *
      * @extends CompoundMenu
-     * @extends TimerMixin
      *
      * @param {BaseView} docView
      *  The document view instance containing this context menu.
@@ -70,32 +69,41 @@ define('io.ox/office/baseframework/view/popup/contextmenu', [
      *      false, the context menu will be opened after the 'mouseup' and its
      *      related 'contextmenu' event.
      */
-    function ContextMenu(docView, sourceNode, initOptions) {
+    var ContextMenu = CompoundMenu.extend({ constructor: function (docView, sourceNode, initOptions) {
 
-        var // self reference
-            self = this,
+        // self reference
+        var self = this;
 
-            // jQuery selector for descendant nodes this context menu is restricted to
-            selector = Utils.getStringOption(initOptions, 'selector'),
+        // jQuery selector for descendant nodes this context menu is restricted to
+        var selector = Utils.getStringOption(initOptions, 'selector');
 
-            // controller keys specifying whether the context menu is enabled
-            enableKeys = Utils.getOption(initOptions, 'enableKey'),
+        // controller keys specifying whether the context menu is enabled
+        var enableKeys = _.getArray(Utils.getOption(initOptions, 'enableKey')).filter(_.isString);
 
-            // delay to open the context menu
-            delay = Utils.getNumberOption(initOptions, 'delay'),
+        // delay to open the context menu
+        var delay = Utils.getNumberOption(initOptions, 'delay');
 
-            // special handler to invoke
-            contextMenuHandlers = [],
-            detectHandlers = [],
-            resetHandlers = [];
+        // a permanent tool tip shown for the context menu#
+        var toolTip = null;
+
+        // the events of the source node to be handled by this instance
+        var EVENT_MAP = {
+            mousedown: mouseDownHandler,
+            mouseup: mouseUpHandler,
+            keydown: keyDownHandler,
+            keyup: keyUpHandler,
+            'documents:contextmenu': contextMenuHandler
+        };
+
+        // special handler to invoke
+        var contextMenuHandlers = [];
+        var detectHandlers = [];
+        var resetHandlers = [];
 
         // base constructor ---------------------------------------------------
 
         CompoundMenu.call(this, docView, _.extend({ anchorPadding: 0, autoHideGroups: true }, initOptions));
 
-        // add timer methods (needs the registerDestructor() method)
-        TimerMixin.call(this);
-
         // private methods ----------------------------------------------------
 
         /**
@@ -103,9 +111,9 @@ define('io.ox/office/baseframework/view/popup/contextmenu', [
          * the context menu at the correct position.
          */
         function showContextMenu(event) {
-            var // the (cancelable) jQuery prepare event
-                prepareEvent = new $.Event('contextmenu:prepare', { sourceEvent: event.sourceEvent }),
-                xy = self.getXY(event);
+
+            // the (cancelable) jQuery prepare event
+            var prepareEvent = new $.Event('contextmenu:prepare', { sourceEvent: event.sourceEvent });
 
             // notify listeners (also if the context menu is disabled, e.g. to select
             // an element on click, although the context menu will not occur)
@@ -120,8 +128,9 @@ define('io.ox/office/baseframework/view/popup/contextmenu', [
                 self.hide().setAnchor({ left: xy.pageX, top: xy.pageY, width: 1, height: 1 }).show();
             }
 
+            var xy = self.getXY(event);
             if (delay) {
-                self.executeDelayed(executeShow, { delay: delay, infoString: 'showContextMenu', app: docView.getApp() });
+                self.executeDelayed(executeShow, 'ContextMenu.showContextMenu', delay);
             } else {
                 executeShow();
             }
@@ -134,8 +143,8 @@ define('io.ox/office/baseframework/view/popup/contextmenu', [
          *  The type which triggers the event (mouse, keyboard or touch)
          */
         function detectState() {
-            detectHandlers.forEach(function (func) {
-                func.call(this);
+            detectHandlers.forEach(function (handler) {
+                handler.call(this);
             }, this);
         }
 
@@ -146,12 +155,26 @@ define('io.ox/office/baseframework/view/popup/contextmenu', [
          *  Optional parameters. Used in some resetHandlers.
          */
         function resetState(options) {
-            resetHandlers.forEach(function (func) {
-                func.call(this, options);
+            resetHandlers.forEach(function (handler) {
+                handler.call(this, options);
             }, this);
         }
 
-        // EVENT-Handler ------------------------------------------------------
+        /**
+         * Callback for the 'popup:show' event of this context menu.
+         */
+        function popupShowHandler() {
+            if (toolTip.hasContents()) { toolTip.show(); }
+        }
+
+        /**
+         * Callback for the 'popup:hide' event of this context menu.
+         */
+        function popupHideHandler() {
+            toolTip.hide();
+            // fix for bug 46769
+            docView.grabFocus();
+        }
 
         /**
          * Handles 'keydown' events of the source node.
@@ -190,7 +213,7 @@ define('io.ox/office/baseframework/view/popup/contextmenu', [
             // if x/y-coordinate not set, calculate them both by last known
             // touch position
             if (!event.pageX || !event.pageY) {
-                if (!_.isNull(sourceEvent)) {
+                if (sourceEvent) {
                     event.pageX = sourceEvent.pageX;
                     event.pageY = sourceEvent.pageY;
 
@@ -200,13 +223,13 @@ define('io.ox/office/baseframework/view/popup/contextmenu', [
                         width = clickedElement.width(),
                         height = clickedElement.height();
 
-                    event.pageX = (offset.left + (width / 2));
-                    event.pageY = (offset.top + (height / 2));
+                    event.pageX = offset.left + Math.ceil(width / 2);
+                    event.pageY = offset.top + Math.ceil(height / 2);
                 }
             }
 
-            contextMenuHandlers.forEach(function (func) {
-                func.call(self, event);
+            contextMenuHandlers.forEach(function (handler) {
+                handler.call(self, event);
             });
 
             showContextMenu(event);
@@ -233,10 +256,10 @@ define('io.ox/office/baseframework/view/popup/contextmenu', [
             // nothing to do, if the context menu is not visible
             if (!self.isVisible()) { return; }
 
-            var // whether to hide the context menu due to changed controller item states
-                hideMenu = enableKeys.some(function (enableKey) {
-                    return (enableKey in changedItems) && (changedItems[enableKey].enabled === false);
-                });
+            // whether to hide the context menu due to changed controller item states
+            var hideMenu = enableKeys.some(function (enableKey) {
+                return (enableKey in changedItems) && (changedItems[enableKey].enabled === false);
+            });
 
             if (hideMenu) {
                 self.hide();
@@ -305,50 +328,64 @@ define('io.ox/office/baseframework/view/popup/contextmenu', [
             };
         };
 
+        /**
+         * Sets a tool tip that will be shown permanently while this context
+         * menu is visible.
+         *
+         * @param {String} label
+         *  The text for the tooltip text to be shown. If set to an empty
+         *  string, the context menu will not show a tooltip anymore.
+         *
+         * @param {Object} [options]
+         *  Optional parameters:
+         *  @param {String} [options.anchorBorder='bottom top']
+         *      The preferred position of the tool tip relative to this context
+         *      menu. Must be a space-separated list of border name tokens. See
+         *      description of the constructor option 'anchorBorder' of the
+         *      class BasePopup for details.
+         *
+         * @returns {ContextMenu}
+         *  A reference to this instance.
+         */
+        this.setToolTip = function (label, options) {
+            toolTip.setText(label);
+            toolTip.setAnchorBorder(Utils.getStringOption(options, 'anchorBorder', 'bottom top'));
+            if (this.isVisible()) { toolTip.toggle(label.length > 0); }
+            return this;
+        };
+
         // initialization -----------------------------------------------------
 
         this.getNode().addClass('context-menu');
 
+        // create the tool tip shown permenently
+        toolTip = new ToolTip(docView, { anchor: this.getNode(), anchorAlign: 'center' });
+
         // listen to relevant context events on the source node
-        sourceNode.on({
-            mousedown: mouseDownHandler,
-            mouseup: mouseUpHandler,
-            keydown: keyDownHandler,
-            keyup: keyUpHandler,
-            'documents:contextmenu': contextMenuHandler
-        }, selector);
+        sourceNode.on(EVENT_MAP, selector);
 
         // always use an array of parent keys (as strings)
-        enableKeys =
-            _.isArray(enableKeys) ? _.filter(enableKeys, _.isString) :
-            _.isString(enableKeys) ? [enableKeys] : [];
+        enableKeys = _.getArray(enableKeys).filter(_.isString);
 
         // hide displayed context menu, if controller item changes to disabled state
         if (enableKeys.length > 0) {
             this.handleChangedControllerItems(controllerChangeHandler);
         }
 
-        // fix for Bug 46769
-        self.on('popup:hide', function () { docView.grabFocus(); });
+        // additional processing when showing/hiding the context menu
+        this.on({ 'popup:show': popupShowHandler, 'popup:hide': popupHideHandler });
 
         // destroy all class members on destruction
         this.registerDestructor(function () {
-            sourceNode.off({
-                mousedown: mouseDownHandler,
-                mouseup: mouseUpHandler,
-                keydown: keyDownHandler,
-                keyup: keyUpHandler,
-                'documents:contextmenu': contextMenuHandler
-            }, selector);
-
-            docView = sourceNode = initOptions = self = null;
+            toolTip.destroy();
+            sourceNode.off(EVENT_MAP, selector);
+            docView = sourceNode = initOptions = self = toolTip = EVENT_MAP = null;
         });
 
-    } // class ContextMenu
+    } }); // class ContextMenu
 
     // exports ================================================================
 
-    // derive this class from class CompoundMenu
-    return CompoundMenu.extend({ constructor: ContextMenu });
+    return ContextMenu;
 
 });
