@@ -14,14 +14,10 @@
  */
 
 define('io.ox/office/drawinglayer/model/drawingstylecollection', [
-
     'io.ox/office/tk/utils',
-
     'io.ox/office/editframework/utils/color',
     'io.ox/office/editframework/utils/gradient',
-
     'io.ox/office/editframework/model/stylecollection'
-
 ], function (Utils, Color, Gradient, StyleCollection) {
 
     'use strict';
@@ -66,6 +62,11 @@ define('io.ox/office/drawinglayer/model/drawingstylecollection', [
          */
         description: { def: '' },
 
+        /**
+         * Rotation of the drawing.
+         */
+        rotation: { def: 0 },
+
         /**
          * Flip the drawing horizontally (swap left and right side).
          */
@@ -81,6 +82,36 @@ define('io.ox/office/drawinglayer/model/drawingstylecollection', [
          */
         hidden: { def: false },
 
+        /**
+         * Whether the aspect ratio of the drawing object is locked and cannot
+         * be changed when the drawing object will be resized.
+         */
+        aspectLocked: { def: false },
+
+        /**
+         * Left border of the rectangle used to set the position of embedded
+         * child objects.
+         */
+        childLeft: { def: 0 },
+
+        /**
+         * Top border of the rectangle used to set the position of embedded
+         * child objects.
+         */
+        childTop: { def: 0 },
+
+        /**
+         * Width of the rectangle used to set the position of embedded child
+         * objects.
+         */
+        childWidth: { def: 0 },
+
+        /**
+         * Height of the rectangle used to set the position of embedded child
+         * objects.
+         */
+        childHeight: { def: 0 },
+
         /**
          * Replacement image for unsupported drawing objects. The string
          * contains either BASE64 encoded bitmap data, or SVG mark-up.
@@ -93,25 +124,35 @@ define('io.ox/office/drawinglayer/model/drawingstylecollection', [
     var FILL_ATTRIBUTE_DEFINITIONS = {
 
         /**
-         *  Type of the fill. Supported values are:
+         * Type of the fill. Supported values are:
          *  - 'none': not filled (transparent).
          *  - 'auto': specific default fill, dependent on context.
          *  - 'solid': single fill color ('color' attribute).
          *  - 'gradient': color gradient.
          *  - 'pattern': monochrome pattern.
          *  - 'bitmap': background image.
+         *
+         * The property 'undo' contains the names of all attributes that need
+         * to be inserted into the undo operation that will be generated when
+         * changing this attribute (e.g. when a document operation changes the
+         * value of this attribute from 'bitmap' to 'none', the undo operation
+         * has to contain the value of the 'bitmap' attribute, although it has
+         * not been reset by the document operation).
          */
-        type: { def: 'none' },
+        type: { def: 'none', undo: '*' },
 
         /**
-         * Fill color (used for fill type 'solid', 'gradient', and 'pattern').
+         * Primary fill color. Used for fill type 'solid' (solid fill color),
+         * 'gradient' (start color of a simple color gradient), and 'pattern'
+         * (pattern foreground color).
          */
         color: { def: Color.AUTO },
 
         /**
-         * Second fill color (used for fill type 'gradient' or 'pattern').
+         * Secondary fill color. Used for fill type 'gradient' (end color of a
+         * simple color gradient), or 'pattern' (pattern background color).
          */
-        backgroundColor: { def: Color.AUTO },
+        color2: { def: Color.AUTO },
 
         /**
          * Gradient descriptor object (used for fill type 'gradient').
@@ -349,7 +390,7 @@ define('io.ox/office/drawinglayer/model/drawingstylecollection', [
          * a pathList whose points are determined by a combination of constant,
          * guide and absolute values
          */
-        presetShape: { def: 'rect' },
+        presetShape: { def: '' },
 
         avList: { def: {} },
 
@@ -357,7 +398,9 @@ define('io.ox/office/drawinglayer/model/drawingstylecollection', [
 
         pathList: { def: [] },
 
-        textRect: { def: {} }
+        textRect: { def: {} },
+
+        hostData: { def: '' }
     };
 
     // definitions for connector attributes --------------------------------
@@ -380,12 +423,6 @@ define('io.ox/office/drawinglayer/model/drawingstylecollection', [
 
     var CHART_ATTRIBUTE_DEFINITIONS = {
 
-        /**
-         * The type of the chart. Specifies how the data series will be
-         * rendered.
-         */
-        type: { def: 'column2d', scope: 'element' },
-
         /**
          * standard, clustered, stacked, percent, the way how multi series lay
          * to each other (bar, column and area)
@@ -402,14 +439,12 @@ define('io.ox/office/drawinglayer/model/drawingstylecollection', [
          */
         chartStyleId: { def: 0, scope: 'element' },
 
-        rotation: { def: 0, scope: 'element' }, //TODO: only for pie & donut, should be moved
+        rotation: { def: 0, scope: 'element' },
 
         /**
          * defines if the points of the first series are same color or not
          */
-        varyColors: { def: false, scope: 'element' },
-
-        dataLabel: { def: false, scope: 'element' }
+        varyColors: { def: false, scope: 'element' }
     };
 
     // definitions for chart data series attributes ---------------------------
@@ -443,7 +478,29 @@ define('io.ox/office/drawinglayer/model/drawingstylecollection', [
          * charts. May be an array of constant values, or a string with an
          * application-dependent dynamic data source definition.
          */
-        bubbles: { def: [] }
+        bubbles: { def: [] },
+
+        /**
+         * The type of the chart. Specifies how the data series will be
+         * rendered.
+         */
+        type: { def: 'column' },
+
+        /**
+         * holder for fill & line attributes for colors
+         */
+        dataPoints: { def: [] },
+
+        /**
+         * optional number format code
+         */
+        format: { def: '' },
+
+        dataLabel: { def: '' },
+
+        axisXIndex: { def: 0 },
+
+        axisYIndex: { def: 0 }
     };
 
     // definitions for chart axis attributes ----------------------------------
@@ -487,38 +544,41 @@ define('io.ox/office/drawinglayer/model/drawingstylecollection', [
      * @param {Object} [initOptions]
      *  Optional parameters passed to the base class StyleCollection.
      */
-    function DrawingStyleCollection(docModel, initOptions) {
+    var DrawingStyleCollection = StyleCollection.extend({ constructor: function (docModel, initOptions) {
 
         // base constructor ---------------------------------------------------
 
-        StyleCollection.call(this, docModel, 'drawing', initOptions);
+        StyleCollection.call(this, docModel, 'drawing', (function () {
+            var families = Utils.getStringOption(initOptions, 'families', '');
+            if (families) { families += ' '; }
+            families += 'line fill image shape geometry connector paragraph character';
+            return Utils.extendOptions(initOptions, { families: families });
+        }()));
 
         // initialization -----------------------------------------------------
 
-        docModel
-            .registerAttributeDefinitions('drawing', DRAWING_ATTRIBUTE_DEFINITIONS)
-            .registerAttributeDefinitions('fill', FILL_ATTRIBUTE_DEFINITIONS)
-            .registerAttributeDefinitions('line', LINE_ATTRIBUTE_DEFINITIONS)
-            .registerAttributeDefinitions('text', TEXT_ATTRIBUTE_DEFINITIONS)
-            .registerAttributeDefinitions('image', IMAGE_ATTRIBUTE_DEFINITIONS)
-            .registerAttributeDefinitions('connector', CONNECTOR_ATTRIBUTE_DEFINITIONS)
-            .registerAttributeDefinitions('shape', SHAPE_ATTRIBUTE_DEFINITIONS)
-            .registerAttributeDefinitions('chart', CHART_ATTRIBUTE_DEFINITIONS)
-            .registerAttributeDefinitions('series', CHART_SERIES_ATTRIBUTE_DEFINITIONS)
-            .registerAttributeDefinitions('axis', CHART_AXIS_ATTRIBUTE_DEFINITIONS)
-            .registerAttributeDefinitions('geometry', GEOMETRY_ATTRIBUTE_DEFINITIONS)
-            .registerAttributeDefinitions('legend', CHART_LEGEND_ATTRIBUTE_DEFINITIONS);
+        docModel.registerAttributes('drawing', DRAWING_ATTRIBUTE_DEFINITIONS);
+        docModel.registerAttributes('fill', FILL_ATTRIBUTE_DEFINITIONS);
+        docModel.registerAttributes('line', LINE_ATTRIBUTE_DEFINITIONS);
+        docModel.registerAttributes('text', TEXT_ATTRIBUTE_DEFINITIONS);
+        docModel.registerAttributes('image', IMAGE_ATTRIBUTE_DEFINITIONS);
+        docModel.registerAttributes('connector', CONNECTOR_ATTRIBUTE_DEFINITIONS);
+        docModel.registerAttributes('shape', SHAPE_ATTRIBUTE_DEFINITIONS);
+        docModel.registerAttributes('geometry', GEOMETRY_ATTRIBUTE_DEFINITIONS);
+        docModel.registerAttributes('chart', CHART_ATTRIBUTE_DEFINITIONS);
+        docModel.registerAttributes('series', CHART_SERIES_ATTRIBUTE_DEFINITIONS);
+        docModel.registerAttributes('axis', CHART_AXIS_ATTRIBUTE_DEFINITIONS);
+        docModel.registerAttributes('legend', CHART_LEGEND_ATTRIBUTE_DEFINITIONS);
 
         // destroy class members on destruction
         this.registerDestructor(function () {
             docModel = initOptions = null;
         });
 
-    } // class DrawingStyleCollection
+    } }); // class DrawingStyleCollection
 
     // exports ================================================================
 
-    // derive this class from class StyleCollection
-    return StyleCollection.extend({ constructor: DrawingStyleCollection });
+    return DrawingStyleCollection;
 
 });
