@@ -45,7 +45,30 @@ define('io.ox/office/drawinglayer/utils/operations', function () {
          *
          * @constant
          */
-        SET_DRAWING_ATTRIBUTES: 'setDrawingAttributes',
+        CHANGE_DRAWING: 'setDrawingAttributes',
+
+        /**
+         * Name of the operation that moves an existing drawing object to a new
+         * position.
+         *
+         * @constant
+         */
+        MOVE_DRAWING: 'moveDrawing',
+
+        /**
+         * Creates a group object from several drawing objects.
+         *
+         * @constant
+         */
+        GROUP: 'group',
+
+        /**
+         * Removes a group object and moves the contained drawing objects to
+         * its parent container.
+         *
+         * @constant
+         */
+        UNGROUP: 'ungroup',
 
         /**
          * Name of the operation that inserts a new data series into a chart
