@@ -32,11 +32,11 @@ define('io.ox/office/drawinglayer/view/control/chartlegendpicker', [
      * @param {Object} [initOptions]
      *  Optional parameters. Supports all options of the base class RadioList.
      */
-    function ChartLegendPicker(initOptions) {
+    function ChartLegendPicker(docView, initOptions) {
 
         // base constructor ---------------------------------------------------
 
-        RadioList.call(this, Utils.extendOptions({
+        RadioList.call(this, docView, Utils.extendOptions({
             label: /*#. menu title: positions for the legend in a chart object */ gt.pgettext('chart-legend', 'Legend position'),
             tooltip: /*#. menu tooltip: positions for the legend in a chart object */ gt.pgettext('chart-legend', 'Visibility and position of the chart legend')
         }, initOptions, {
