@@ -17,13 +17,13 @@ define('io.ox/office/drawinglayer/view/imageutil', [
     'io.ox/office/tk/io',
     'io.ox/office/tk/dialogs',
     'io.ox/office/tk/utils/driveutils',
-    'settings!io.ox/office',
-    'io.ox/office/tk/utils/deferredutils',
     'gettext!io.ox/office/drawinglayer/main'
-], function (Utils, IO, Dialogs, DriveUtils, Settings, DeferredUtils, gt) {
+], function (Utils, IO, Dialogs, DriveUtils, gt) {
 
     'use strict';
 
+    var RECENT_IMAGE_FOLDER_KEY = 'recentImageFolder';
+
     var CRC32_TABLE = [
         0x00000000, 0x77073096, 0xEE0E612C, 0x990951BA, 0x076DC419, 0x706AF48F, 0xE963A535, 0x9E6495A3,
         0x0EDB8832, 0x79DCB8A4, 0xE0D5E91E, 0x97D2D988, 0x09B64C2B, 0x7EB17CBD, 0xE7B82D07, 0x90BF1D91,
@@ -176,7 +176,7 @@ define('io.ox/office/drawinglayer/view/imageutil', [
 
     function insertFile(app, file) {
 
-        return IO.readClientFileAsDataUrl(file).then(function (dataUrl) {
+        return app.readClientFile(file).then(function (dataUrl) {
             return insertDataUrl(app, dataUrl, file.name);
         });
     }
@@ -423,20 +423,17 @@ define('io.ox/office/drawinglayer/view/imageutil', [
     /**
      * Inserts the image specified by a URL into a document.
      *
-     * @param {ox.ui.App} app
-     *  The application object representing the edited document.
-     *
      * @param {String} url
      *  The full URL of the image to be inserted.
      */
-    Image.insertURL = function (app, url) {
-        var def = DeferredUtils.createDeferred(app, 'ImageUtil: insertURL');
+    Image.insertURL = function (url) {
+        var def = new $.Deferred();
         if (_.isString(url) && RE_IMAGE_URL.test(url)) {
             def.resolve({ url: url, name: Image.getFileNameWithoutExt(url) });
         } else {
             def.reject();
         }
-        return def;
+        return def.promise();
     };
 
      /**
@@ -478,11 +475,11 @@ define('io.ox/office/drawinglayer/view/imageutil', [
      *  been canceled.
      */
     Image.showInsertImageDriveFileDialog = function (app) {
-        var deferred = DeferredUtils.createDeferred(app, 'ImageUtil: showInsertImageFileDialog');
-        require(['io.ox/files/filepicker']).done(function (FilePicker) {
 
-            var recentImageFolderKey = 'recentImageFolder' + app.getDocumentType();
-            var recentImageFolder = Settings.get(recentImageFolderKey) || DriveUtils.getStandardPicturesFolderId();
+        return require(['io.ox/files/filepicker']).then(function (FilePicker) {
+
+            var deferred = app.createDeferred('ImageUtil.showInsertImageDriveFileDialog');
+            var recentImageFolder = app.getUserSettingsValue(RECENT_IMAGE_FOLDER_KEY) || DriveUtils.getStandardPicturesFolderId();
 
             var dialogPromise = new FilePicker({
                 // filter files of disabled applications (capabilities)
@@ -497,41 +494,41 @@ define('io.ox/office/drawinglayer/view/imageutil', [
                 folder: recentImageFolder,
                 uploadButton: true,
                 multiselect: false,
-                width: Dialogs.getBestDialogWidth(800),
                 //uploadFolder: DriveUtils.getStandardDocumentsFolderId(),
                 hideTrashfolder: true,
                 acceptLocalFileType: 'image/*',
+                createFolderButton: false,
                 cancel: function () {
                     deferred.reject();
                 },
                 initialize: function (dialog) {
-                    app.getView().closeDialogOnReadOnlyMode(dialog, function () {
-                        deferred.reject();
-                    });
+                    app.getView().closeDialogOnReadOnlyMode(dialog);
                 }
             });
 
             dialogPromise.done(function (selectedFiles) {
-                if (app.getModel().getEditMode()) {
+                if (app.isEditable()) {
                     var selectedFile = selectedFiles[0];
                     if (selectedFile) {
                         Image.insertDriveImage(app, selectedFile).done(function (imageFragment) {
                             deferred.resolve(imageFragment);
                         });
 
-                        Settings.set(recentImageFolderKey, selectedFile.folder_id).save();
+                        app.setUserSettingsValue(RECENT_IMAGE_FOLDER_KEY, selectedFile.folder_id);
                     } else {
                         deferred.reject();
                     }
                 } else {
                     deferred.reject();
                 }
-
             });
 
-        });
+            dialogPromise.fail(function () {
+                deferred.reject();
+            });
 
-        return deferred.promise();
+            return deferred;
+        });
     };
 
     /**
@@ -547,19 +544,18 @@ define('io.ox/office/drawinglayer/view/imageutil', [
      */
     Image.showInsertImageUrlDialog = function (app) {
 
-        var
         // the dialog instance, and the tab panel nodes
-            dialog = null,
+        var dialog = null;
 
         // the 'Enter URL' widgets
-            urlInput = $('<input>', {
-                tabindex: 0,
-                role: 'textbox',
-                'aria-label': gt('enter image URL')
-            }).addClass('form-control'),
+        var urlInput = $('<input>', {
+            tabindex: 0,
+            role: 'textbox',
+            'aria-label': gt('enter image URL')
+        }).addClass('form-control');
 
         // the resulting promise
-            promise = null;
+        var promise = null;
 
         // Bug 43868: ios auto correction should be of for input fields
         // TODO: use Forms.createInputMarkup() to create inputs here, it already has this fix
@@ -568,7 +564,7 @@ define('io.ox/office/drawinglayer/view/imageutil', [
         }
 
         // create the dialog
-        dialog = new Dialogs.ModalDialog({ title: gt('Insert Image URL'), async: true, width: Dialogs.getBestDialogWidth(800) });
+        dialog = new Dialogs.ModalDialog(app, { title: gt('Insert Image URL'), async: true, width: Dialogs.getBestDialogWidth(800) });
 
         app.getView().closeDialogOnReadOnlyMode(dialog);
 
@@ -576,7 +572,7 @@ define('io.ox/office/drawinglayer/view/imageutil', [
 
         // register a handler at the url input field
         urlInput.on('input',  function () {
-            dialog.enableOkButton(app.getModel().getEditMode() && (urlInput.val().length > 0));
+            dialog.enableOkButton(app.isEditable() && (urlInput.val().length > 0));
         });
 
         // show the dialog
@@ -594,26 +590,9 @@ define('io.ox/office/drawinglayer/view/imageutil', [
 
         // process the result after the OK button has been pressed
         promise = promise.then(function () {
-
-            var file = null,
-                def = DeferredUtils.createDeferred(app, 'ImageUtil: showInsertImageDialog');
-
             // show progress indicator
             dialog.getHeader().find('h4').first().busy();
-
-            file = urlInput.val();
-
-            if (_.isObject(file) || _.isString(file)) {
-                def.resolve(file);
-            } else {
-                def.reject();
-            }
-
-            return def.promise();
-        });
-
-        promise = promise.then(function (file) {
-            return Image.insertURL(app, file.trim());
+            return Image.insertURL(urlInput.val().trim());
         });
 
         return promise.always(function () {
@@ -696,13 +675,20 @@ define('io.ox/office/drawinglayer/view/imageutil', [
             inputFile.on('change', function (event) {
                 var name = (event.target && event.target.files && event.target.files[0] && event.target.files[0].name) || (fileInput[0].value && fileInput[0].value.substring(fileInput[0].value.lastIndexOf('\\') + 1)) || '';
                 inputText.val(name);
+
+                // BUG #53214:
+                //  Safari is not able to remove the placeholder by itselfs, so we have to do it.
+                //  Because it's not critical, we remove this attribute for all (not only for safari)
+                if (name !== '') {
+                    inputText.attr('placeholder', '');
+                }
             });
 
             return node;
         }
 
         // create the dialog
-        dialog = new Dialogs.ModalDialog({ title: gt('Insert Image'), async: true, width: Dialogs.getBestDialogWidth(800) });
+        dialog = new Dialogs.ModalDialog(app, { title: gt('Insert Image'), async: true, width: Dialogs.getBestDialogWidth(800) });
         dialog.enableOkButton(false);
 
         // close dialog automatically after losing edit rights
@@ -730,7 +716,7 @@ define('io.ox/office/drawinglayer/view/imageutil', [
             dialog.enableOkButton(false);
             if (uploadFile) {
                 if (Image.hasFileImageExtension(uploadFile.name)) {
-                    dialog.enableOkButton(app.getModel().getEditMode());
+                    dialog.enableOkButton(app.isEditable());
                 } else {
                     app.rejectEditAttempt('image');
                     uploadFile = null;
@@ -740,29 +726,10 @@ define('io.ox/office/drawinglayer/view/imageutil', [
 
         // process the result after the OK button has been pressed
         promise = promise.then(function () {
-
-            var file = null,
-                form = null,
-                def = DeferredUtils.createDeferred(app, 'ImageUtil: showInsertImageLocalFileDialog');
-
             // show progress indicator
             dialog.getHeader().find('h4').first().busy();
-
-            if (uploadFile) {
-                file = uploadFile;
-            }
-
-            if (_.isObject(file) || _.isString(file) || _.isObject(form)) {
-                def.resolve(file, form);
-            } else {
-                def.reject();
-            }
-
-            return def.promise();
-        });
-
-        promise = promise.then(function (file, form) {
-            return Image.insertFile(app, file, form);
+            var hasFile = _.isObject(uploadFile) || _.isString(uploadFile);
+            return hasFile ? Image.insertFile(app, uploadFile) : new $.Deferred().reject();
         });
 
         return promise.always(function () {
