@@ -15,8 +15,9 @@
 define('io.ox/office/editframework/app/editcontroller', [
     'io.ox/office/tk/utils',
     'io.ox/office/baseframework/app/basecontroller',
-    'io.ox/office/editframework/utils/editconfig'
-], function (Utils, BaseController, Config) {
+    'io.ox/office/editframework/utils/editconfig',
+    'io.ox/core/capabilities'
+], function (Utils, BaseController, Config, Capabilities) {
 
     'use strict';
 
@@ -96,10 +97,10 @@ define('io.ox/office/editframework/app/editcontroller', [
      *  Optional parameters. Supports all options supported by the base class
      *  BaseController.
      */
-    function EditController(app, docModel, docView, searchHandler, initOptions) {
+    var EditController = BaseController.extend({ constructor: function (app, docModel, docView, searchHandler, initOptions) {
 
-        // self reference
-        var self = this;
+        // the undo manager of the document model
+        var undoManager = null;
 
         // the current search configuration
         var searchSettings = _.clone(DEFAULT_SEARCH_SETTINGS);
@@ -143,6 +144,43 @@ define('io.ox/office/editframework/app/editcontroller', [
             return promise;
         }
 
+        // public methods -----------------------------------------------------
+
+        /**
+         * Registers an undo manager that will be used for undo/redo controller
+         * items, instead of the undo manager provided by the document model.
+         *
+         * @param {UndoManager} newUndoManager
+         *  The undo manager to be used by this controller. Instead of a real
+         *  instance of the class UndoManager, this may be any object that
+         *  provides the methods getUndoCount(), undo(), getRedoCount(), and
+         *  redo(), and has event support.
+         *
+         * @returns {EditController}
+         *  A reference to this instance.
+         */
+        this.registerUndoManager = function (newUndoManager) {
+            if (undoManager !== newUndoManager) {
+                this.stopListeningTo(undoManager);
+                undoManager = newUndoManager;
+                this._updateOnEvent(undoManager);
+                this.update();
+            }
+            return this;
+        };
+
+        /**
+         * Reactivates the undo manager of the document model to be used for
+         * undo/redo controller itens, instead of the undo manager that has
+         * been registered with the method EditController.registerUndoManager().
+         *
+         * @returns {EditController}
+         *  A reference to this instance.
+         */
+        this.restoreUndoManager = function () {
+            return this.registerUndoManager(docModel.getUndoManager());
+        };
+
         // initialization -----------------------------------------------------
 
         // register all controller items
@@ -177,11 +215,11 @@ define('io.ox/office/editframework/app/editcontroller', [
             // dummy item for the 'Save in Drive' drop-down menu
             'view/saveas/menu': {
                 parent: 'app/valid',
-                enable: function () { return (!app.getLaunchOption('disableSaveAs')) && (!app.isDocumentEncrypted()); }
+                enable: function () { return (!app.getLaunchOption('disableSaveAs')); }
             },
 
             'view/searchgroup': {
-                enable: 'app/valid',
+                parent: 'app/valid',
                 get: function () { return docView.getSearchGroup().isVisible(); },
                 set: function (state) { docView.getSearchGroup().toggle(state); },
                 focusTarget: function () { return docView.getSearchGroup(); },
@@ -196,6 +234,11 @@ define('io.ox/office/editframework/app/editcontroller', [
                 enable: function () { return app.isOOXML(); }
             },
 
+            // parent iten that is enabled if the edited document is based on ODF file format
+            'document/odf': {
+                enable: function () { return app.isODF(); }
+            },
+
             'document/acquireedit': {
                 parent: 'app/valid',
                 enable: function () { return app.isAcquireEditRightsEnabled(); }
@@ -216,12 +259,12 @@ define('io.ox/office/editframework/app/editcontroller', [
             // to be used as parent item for all items that require edit mode
             'document/editable': {
                 parent: 'app/valid',
-                enable: function () { return docModel.getEditMode(); }
+                enable: function () { return app.isEditable(); }
             },
 
             'document/readonly': {
                 parent: 'app/valid',
-                enable: function () { return !docModel.getEditMode(); }
+                enable: function () { return !app.isEditable(); }
             },
 
             'document/fullname': {
@@ -240,22 +283,26 @@ define('io.ox/office/editframework/app/editcontroller', [
                 set: function () { return docView.showRenameDialog(); }
             },
 
+            // getter returns the number of available undo actions, setter applies the next undo action
             'document/undo': {
                 parent: 'document/editable',
-                enable: function () { return docView.isUndoAvailable(); },
-                set: function () { return docView.undo(); },
+                enable: function () { return this.getValue() > 0; },
+                get: function () { return undoManager.getUndoCount(); },
+                set: function () { return undoManager.undo(); },
                 shortcut: [
-                   // bug 33077: restrict to application pane, to not interfere with text field's
-                   // native undo/redo and automatic item execution after losing focus
+                    // bug 33077: restrict to application pane, to not interfere with text field's
+                    // native undo/redo and automatic item execution after losing focus
                     { keyCode: 'Z', ctrlOrMeta: true, selector: '.app-pane' },
                     { keyCode: 'BACKSPACE', alt: true, selector: '.app-pane' }
                 ]
             },
 
+            // getter returns the number of available redo actions, setter applies the next redo action
             'document/redo': {
                 parent: 'document/editable',
-                enable: function () { return docView.isRedoAvailable(); },
-                set: function () { return docView.redo(); },
+                enable: function () { return this.getValue() > 0; },
+                get: function () { return undoManager.getRedoCount(); },
+                set: function () { return undoManager.redo(); },
                 shortcut: [
                     // bug 33077: restrict to application pane, to not interfere with text field's
                     // native undo/redo and automatic item execution after losing focus
@@ -265,23 +312,26 @@ define('io.ox/office/editframework/app/editcontroller', [
             },
 
             'document/saveas/dialog': {
+                parent: ['app/valid', 'app/unencrypted'],
+                set: function (type) { return docView.showSaveAsDialog(type); }
+            },
+
+            'document/saveasencrypted/dialog': {
                 parent: 'app/valid',
+                enable: function () { return Capabilities.has('guard-docs'); },
                 set: function (type) { return docView.showSaveAsDialog(type); }
             },
 
             'document/exportaspdf/dialog': {
-              //parent: 'document/saveas/dialog',
-                parent: 'app/valid',
+                parent: ['app/valid', 'app/unencrypted'],
                 enable: function () { return Config.CONVERTER_AVAILABLE; },
                 set: function (type) { return docView.showSaveAsDialog(type); }
             },
 
             'document/autosave': {
-                parent: ['document/editable'],
+                parent: 'document/editable',
                 get: function () { return app.isAutoSaveEnabled(); },
-                set: function (state) { return app.toggleAutoSave(state); },
-                // auto save button must be always fresh
-                alwaysDirty: true
+                set: function (state) { return app.toggleAutoSave(state); }
             },
 
             'document/users': {
@@ -365,23 +415,26 @@ define('io.ox/office/editframework/app/editcontroller', [
             }
         });
 
+        // initially register the undo manager of the document model
+        app.onInit(function () {
+            undoManager = docModel.getUndoManager();
+            this._updateOnEvent(undoManager);
+        }, this);
+
         // update controller after operations, or changed state of edit mode
         this.waitForImport(function () {
-            this.listenTo(app, 'docs:state:error docs:users', function () { self.update(); });
-            this.listenTo(docModel, 'operations:after change:editmode', function () { self.update(); });
-            this.listenTo(docModel.getUndoManager(), 'change:count', function () { self.update(); });
+            this._updateOnEvent(app, 'docs:state:error docs:users docs:editmode');
         }, this);
 
         // destroy all class members on destruction
         this.registerDestructor(function () {
-            app = initOptions = self = docModel = docView = null;
+            app = initOptions = docModel = docView = null;
         });
 
-    } // class EditController
+    } }); // class EditController
 
     // exports ================================================================
 
-    // derive this class from class BaseController
-    return BaseController.extend({ constructor: EditController });
+    return EditController;
 
 });
