@@ -22,9 +22,9 @@ define('io.ox/office/editframework/app/fileactions', [
     'io.ox/office/tk/io',
     'io.ox/office/baseframework/app/extensionregistry',
     'io.ox/office/baseframework/app/applicationlauncher',
-    'io.ox/office/tk/utils/deferredutils',
+    'io.ox/core/capabilities',
     'gettext!io.ox/office/editframework/actions'
-], function (ext, links, DriveUtils, Utils, IO, ExtensionRegistry, ApplicationLauncher, DeferredUtils, gt) {
+], function (ext, links, DriveUtils, Utils, IO, ExtensionRegistry, ApplicationLauncher, Capabilities, gt) {
 
     'use strict';
 
@@ -305,7 +305,7 @@ define('io.ox/office/editframework/app/fileactions', [
 
             ////////////////////////////////////////////////////////////////////////
 
-            var editAsNew = function (ref, requires) {
+            var editAsNew = function (ref, requires, encrypted) {
                 new links.Action(ACTION_POINT + ref, {
                     requires: requires,
                     filter: function (obj) {
@@ -313,8 +313,28 @@ define('io.ox/office/editframework/app/fileactions', [
                     },
                     action: function (baton) {
                         var filename = baton.data.filename;
-                        var convert = filename && ExtensionRegistry.isConvertible(filename);
-                        launchApplication({ action: convert ? 'convert' : 'new', target_folder_id: baton.data.folder_id, templateFile: baton.data, preserveFileName: convert });
+                        var promise = encrypted || ExtensionRegistry.isGuardEncrypted(filename) ? require(['io.ox/guard/auth/authorizer']).then(function (authorizer) {
+                            return authorizer.authorize();
+                        }) : $.when();
+
+                        // set authorization data to the model
+                        return promise.then(function (auth_code) {
+
+                            var convert = filename && ExtensionRegistry.isConvertible(filename);
+                            var action = convert ? 'convert' : 'new';
+
+                            var launchOptions = { action: action, target_folder_id: baton.data.folder_id, templateFile: baton.data, preserveFileName: convert };
+
+                            if (encrypted) {
+                                launchOptions.cryptoAction = 'Encrypt';
+                                launchOptions.auth_code = auth_code;
+                            }
+                            launchOptions.encryted_file = ExtensionRegistry.isGuardEncrypted(filename);
+                            if (launchOptions.encryted_file) {
+                                launchOptions.encryted_file_auth_code = auth_code;
+                            }
+                            launchApplication(launchOptions);
+                        });
                     }
                 });
             };
@@ -324,26 +344,48 @@ define('io.ox/office/editframework/app/fileactions', [
                 // guest -> no my files -> no edit-as-new button!
                 var filename = e.context.filename;
                 if (!filename || DriveUtils.isGuest()) { return false; }
-                return e.collection.has('one', 'read') && !ExtensionRegistry.isError(filename) && !ExtensionRegistry.isGuardEncrypted(filename) && !ExtensionRegistry.isTemplate(filename, MODULE_NAME) && ExtensionRegistry.isEditable(filename, MODULE_NAME);
+                return e.collection.has('one', 'read') && !ExtensionRegistry.isError(filename) && !ExtensionRegistry.isTemplate(filename, MODULE_NAME) && ExtensionRegistry.isEditable(filename, MODULE_NAME);
             };
 
             var isNormalEditAsNew = function (e) {
                 var filename = e.context.filename;
-                return !!filename && !ExtensionRegistry.isGuardEncrypted(filename) && hasWritePermissions(e) && ExtensionRegistry.isNative(filename, MODULE_NAME);
+                return !!filename && hasWritePermissions(e) && ExtensionRegistry.isNative(filename, MODULE_NAME);
+            };
+
+            var isNormalEditAsNewEncrypted = function (e) {
+                var filename = e.context.filename;
+                return !!filename && Capabilities.has('guard-docs');
+            };
+
+            var isEncrypted = function (e) {
+                var filename = e.context.filename;
+                return !!filename && ExtensionRegistry.isGuardEncrypted(filename);
             };
 
             editAsNew('-edit-asnew', function (e) {
-                if (isExtraEditAsNew(e) && isNormalEditAsNew(e)) {
+                if (isExtraEditAsNew(e) && (isNormalEditAsNew(e) || (!isNormalEditAsNew(e) && isEncrypted(e)))) {
                     return isEditableFolderAndCurrentVersion(e.baton);
                 }
             });
 
             editAsNew('-edit-asnew-hi', function (e) {
-                if (isExtraEditAsNew(e) && !isNormalEditAsNew(e)) {
+                if (isExtraEditAsNew(e) && !isNormalEditAsNew(e) && !isEncrypted(e)) {
                     return isEditableFolderAndCurrentVersion(e.baton);
                 }
             });
 
+            editAsNew('-edit-asnew-hi-encrypted', function (e) {
+                if (isExtraEditAsNew(e) && isNormalEditAsNewEncrypted(e) && !isNormalEditAsNew(e) && isEncrypted(e)) {
+                    return isEditableFolderAndCurrentVersion(e.baton);
+                }
+            }, true);
+
+            editAsNew('-edit-asnew-encrypted', function (e) {
+                if (isExtraEditAsNew(e) && isNormalEditAsNewEncrypted(e) && !(!isNormalEditAsNew(e) && isEncrypted(e))) {
+                    return isEditableFolderAndCurrentVersion(e.baton);
+                }
+            }, true);
+
             ////////////////////////////////////////////////////////////////////////
 
             new links.Action(ACTION_POINT + '-edit-template', {
@@ -417,6 +459,9 @@ define('io.ox/office/editframework/app/fileactions', [
         extend('-editasnew',       gt('Edit as new'),          'lo',   'lo',          160,      '-edit-asnew',      'edit');
         extend('-editasnewhi',     gt('Edit as new'),          'hi',   'lo',          150,      '-edit-asnew-hi',   'edit');
 
+        extend('-editasnewencrypted', gt('Edit as new (encrypted)'), 'lo',   'lo',    170,      '-edit-asnew-encrypted', 'edit');
+        extend('-editasnewhiencrypted', gt('Edit as new (encrypted)'), 'hi', 'lo', 160,      '-edit-asnew-hi-encrypted',   'edit');
+
         if (!Utils.IOS) {
             overwriteExtPointForRunningApp('io.ox/files/actions/download', MODULE_NAME, '/download', 50, function (app) {
                 app.download();
