@@ -21,11 +21,10 @@ define('io.ox/office/editframework/app/rtconnection', [
     'io.ox/realtime/groups',
     'io.ox/office/tk/utils',
     'io.ox/office/tk/utils/logger',
+    'io.ox/office/tk/utils/scheduler',
     'io.ox/office/tk/object/triggerobject',
-    'io.ox/office/tk/object/timermixin',
-    'io.ox/office/editframework/utils/editconfig',
-    'io.ox/office/tk/utils/deferredutils'
-], function (Events, UUID, SessionRestore, RTGroups, Utils, Logger, TriggerObject, TimerMixin, Config, DeferredUtils) {
+    'io.ox/office/editframework/utils/editconfig'
+], function (Events, UUID, SessionRestore, RTGroups, Utils, Logger, Scheduler, TriggerObject, Config) {
 
     'use strict';
 
@@ -74,7 +73,6 @@ define('io.ox/office/editframework/app/rtconnection', [
      *  identifier of the current editor, etc.).
      *
      * @extends TriggerObject
-     * @extends TimerMixin
      *
      * @param {EditApplication} app
      *  The application containing this operations queue.
@@ -127,8 +125,7 @@ define('io.ox/office/editframework/app/rtconnection', [
 
         // base constructor ---------------------------------------------------
 
-        TriggerObject.call(this);
-        TimerMixin.call(this);
+        TriggerObject.call(this, app);
 
         // private methods ----------------------------------------------------
 
@@ -166,12 +163,8 @@ define('io.ox/office/editframework/app/rtconnection', [
             Utils.log(output);
 
             // check that all array elements are objects
-            if (_.all(actions, _.isObject)) {
-                try {
-                    Utils.log('Last remote action received by RT-Update: ' + JSON.stringify(actions[actions.length - 1]));
-                } catch (ex) {
-                    // do nothing
-                }
+            if (actions.every(_.isObject)) {
+                Utils.log('Last remote action received by RT-Update: ' + JSON.stringify(_.last(actions)));
             }
         }
 
@@ -362,8 +355,8 @@ define('io.ox/office/editframework/app/rtconnection', [
          */
         function handleResponse(promise, timeout) {
 
-            var // the Deferred object to be returned
-                def = DeferredUtils.createDeferred(app, 'RTConnection: handleResponse');
+            // the Deferred object to be returned
+            var def = Scheduler.createDeferred(app, 'RTConnection.handleResponse');
 
             promise.then(function (response) {
                 handleResolvedResponse(def, response);
@@ -378,7 +371,7 @@ define('io.ox/office/editframework/app/rtconnection', [
                         RTConnection.log('Timeout reached for RT request, timeout=' + timeout + 'ms.');
                         def.reject({ cause: 'timeout' });
                     }
-                }, { delay: timeout, infoString: 'RTConnection: handleResponse', app: app });
+                }, 'RTConnection.handleResponse', timeout);
                 def.always(function () { timer.abort(); timer = null; });
             }
 
@@ -402,14 +395,14 @@ define('io.ox/office/editframework/app/rtconnection', [
          */
         function handleGenericResponse(promise, timeout) {
 
-            var // the Deferred object to be returned
-                def = DeferredUtils.createDeferred(app, 'RTConnection: handleGenericResponse');
+            // the Deferred object to be returned
+            var def = Scheduler.createDeferred(app, 'RTConnection.handleGenericResponse');
 
             promise.then(function (data) { def.resolve(data); }, function (data) { def.reject(data); });
 
             // prevent endless waiting
             if (_.isNumber(timeout) && (timeout > 0)) {
-                self.executeDelayed(function () { def.reject({ cause: 'timeout' }); }, { delay: timeout, infoString: 'RTConnection: handleGenericResponse', app: app });
+                self.executeDelayed(function () { def.reject({ cause: 'timeout' }); }, 'RTConnection.handleGenericResponse', timeout);
             }
 
             return def.promise();
@@ -568,7 +561,7 @@ define('io.ox/office/editframework/app/rtconnection', [
                     handleJoinResponse(def, response);
                     joining = false;
                 }
-            }, { delay: 1000, infoString: 'RTConnection: joinGroup', app: app });
+            }, 'RTConnection.handleRejoin', 1000);
         }
 
         /**
@@ -631,7 +624,7 @@ define('io.ox/office/editframework/app/rtconnection', [
          */
         this.connect = function (connectData) {
 
-            var connectDeferred = DeferredUtils.createDeferred(app, 'RTConnection: connect'),
+            var connectDeferred = Scheduler.createDeferred(app, 'RTConnection.connect'),
                 // optional connect data
                 connectOptions = { expectWelcomeMessage: true },
                 // connect data
@@ -871,7 +864,7 @@ define('io.ox/office/editframework/app/rtconnection', [
         // initialization -----------------------------------------------------
 
         RTConnection.log('RTConnection initialization');
-        this.repeatDelayed(checkPendingAcks, { delay: CHECK_PENDING_INTERVAL, infoString: 'RTConnection: checkPendingAcks', app: app, priority: 'background-proc' });
+        this.repeatDelayed(checkPendingAcks, 'RTConnection.checkPendingAcks', { delay: CHECK_PENDING_INTERVAL, background: true });
 
         // read traceable actions from page URL
         if (_.url.hash('office:trace')) {
@@ -892,7 +885,7 @@ define('io.ox/office/editframework/app/rtconnection', [
             if (event.type === 'reset') {
                 if (joining) {
                     // If we are joining, reset is an indicator that a re-enroll
-                    // has been done. In that case we have to try to join again.
+                    // has to be done. In that case we have to try to join again.
                     // This must be limited to error code 1007 which means that
                     // we have to re-enroll. A reset after we received a reset with
                     // data.code 1007 is also normal, ignore that, too.
@@ -954,7 +947,7 @@ define('io.ox/office/editframework/app/rtconnection', [
     // global initialization ==================================================
 
     // whether to show console output of this RTConnection class
-    RTConnection.debug = Config.DEBUG && Config.getDebugState('realtimedebugging', 'office:log-realtime');
+    RTConnection.debug = Config.DEBUG && Config.getDebugState('module/realtimedebugging', 'office:log-realtime');
 
     // extend statically with logging methods
     Logger.extend(RTConnection, { enable: RTConnection.debug, prefix: 'RT' });
