@@ -14,8 +14,8 @@
 
 define('io.ox/office/editframework/app/seleniumwrapper', [
     'io.ox/office/tk/utils',
-    'io.ox/office/tk/utils/debugutils'
-], function (Utils, DebugUtils) {
+    'io.ox/office/tk/utils/scheduler'
+], function (Utils, Scheduler) {
 
     'use strict';
 
@@ -106,7 +106,7 @@ define('io.ox/office/editframework/app/seleniumwrapper', [
             var path = options.path.split('/');
             recursiv(DriveUtils.getRootId(), path).then(function (id) {
                 if (!id) {
-                    innerMap[transactionID] = { state: false, result: 'not found!!' };
+                    innerMap[transactionID] = { state: false, result: 'File not found!!' };
                 } else {
                     innerMap[transactionID] = { state: true, result: id };
                 }
@@ -183,6 +183,12 @@ define('io.ox/office/editframework/app/seleniumwrapper', [
         innerMap[transactionID] = { state: true, result: res };
     };
 
+    SeleniumWrapper.getTableAttributes = function (app, transactionID) {
+        var table = app.getView().getTableCollection().findTable(app.getView().getActiveCell()).getMergedAttributeSet();
+
+        innerMap[transactionID] = { state: true, result: table };
+    };
+
     SeleniumWrapper.scrollToCell = function (app, transactionID, options) {
         var SheetUtils = app.getSheetUtils();
         app.getView().getActiveGridPane().scrollToCell(SheetUtils.Address.parse(options.cellAddress));
@@ -196,7 +202,7 @@ define('io.ox/office/editframework/app/seleniumwrapper', [
     };
 
     SeleniumWrapper.getSheetName = function (app, transactionID) {
-        innerMap[transactionID] = { state: true, result: app.getView().getSheetName() };
+        innerMap[transactionID] = { state: true, result: app.getModel().getSheetName(app.getModel().getActiveSheet()) };
     };
 
     SeleniumWrapper.shiftSeleniumLog = function (app, transactionID) {
@@ -204,7 +210,10 @@ define('io.ox/office/editframework/app/seleniumwrapper', [
     };
 
     SeleniumWrapper.getRunningJobs = function (app, transactionID) {
-        innerMap[transactionID] = { state: true, result: DebugUtils.getRunningJobs() };
+        innerMap[transactionID] = { state: true, result: {
+            timer: Scheduler.getPendingTimers(),
+            deferred: Scheduler.getPendingDeferreds()
+        } };
     };
 
     SeleniumWrapper.getControllerUpdate = function (app, transactionID) {
@@ -255,7 +264,8 @@ define('io.ox/office/editframework/app/seleniumwrapper', [
     };
 
     SeleniumWrapper.getCanvasJSData = function (app, transactionID, options) {
-        innerMap[transactionID] = { state: true, result: app.getView().getDrawingCollection().findModel(options.position, { type: 'chart' }).getCanvasJSData() };
+        var chartModel = app.getView().getDrawingCollection().getModel(options.position, { type: 'chart' });
+        innerMap[transactionID] = { state: true, result: chartModel.getCanvasJSData() };
     };
 
     // exports ================================================================
