@@ -62,16 +62,23 @@ define('io.ox/office/editframework/model/attributedmodel', [
      *      style sheets will also be supported by this model object.
      *  @param {String} [initOptions.families]
      *      The attribute families of explicit attributes supported by this
-     *      attributed model object (space-separated). The style family
-     *      specified in the 'styleFamily' option, and all additional attribute
-     *      families supported by the style sheet container (as specified in
-     *      the constructor of the respective container) do not need to be
-     *      repeated here.
+     *      attributed model object (space-separated).
+     *  @param {Boolean} [initOptions.addStyleFamilies=true]
+     *      Whether to add the attribute families supported by the style sheet
+     *      container (as specified in the constructor of the respective
+     *      container) to the own supported attribute families automatically.
      *  @param {Boolean} [initOptions.listenToStyles=true]
      *      If set to false, this instance will not listen to change events of
      *      the style sheet collection specified with the option 'styleFamily'.
      *      This may be desired for performance reasons to reduce the number of
      *      event listeners in collections with many instances of this class.
+     *  @param {String} [initOptions.poolId]
+     *      The identifier of an attribute pool to be used. This option will be
+     *      ignored, if this model instance uses style sheets (see option
+     *      'styleFamily'. In this case, the attribute pool of the style sheet
+     *      collection will be used instead. If omitted and no style family has
+     *      been specified, the default attribute pool of the document will be
+     *      used.
      *  @param {AttributedModel} [initOptions.parentModel]
      *      A parent model object (instance of AttributedModel) that supports
      *      all or a few of the attribute families supported by this instance.
@@ -111,7 +118,11 @@ define('io.ox/office/editframework/model/attributedmodel', [
         var autoClear = !styleFamily && !parentModel && Utils.getBooleanOption(initOptions, 'autoClear', false);
 
         // the collection of style sheets for the style family
-        var styleCollection = null;
+        var styleCollection = styleFamily ? docModel.getStyleCollection(styleFamily) : null;
+
+        // the attribute pool to be used for the formatting attributes
+        var attributePool = styleCollection ? styleCollection.getAttributePool() :
+            docModel.getAttributePool(Utils.getStringOption(initOptions, 'poolId', null));
 
         // the names of all supported attribute families, as flag set
         var supportedFamilySet = null;
@@ -137,27 +148,27 @@ define('io.ox/office/editframework/model/attributedmodel', [
             var oldMergedAttributeSet = mergedAttributeSet;
 
             // start with default attribute values of all supported families
-            mergedAttributeSet = docModel.getDefaultAttributeSet(supportedFamilySet);
+            mergedAttributeSet = attributePool.getDefaultValueSet(supportedFamilySet);
 
             // add merged attributes of parent model object
             if (parentModel) {
-                docModel.extendAttributes(mergedAttributeSet, parentModel.getMergedAttributeSet(true));
+                attributePool.extendAttributeSet(mergedAttributeSet, parentModel.getMergedAttributeSet(true));
             }
 
             // add the style sheet attributes to resulting merged attribute set
             var styleId = null;
             if (styleCollection) {
                 styleId = explicitAttributeSet.styleId || '';
-                docModel.extendAttributes(mergedAttributeSet, styleCollection.getStyleAttributeSet(styleId));
+                attributePool.extendAttributeSet(mergedAttributeSet, styleCollection.getStyleAttributeSet(styleId));
                 styleId = mergedAttributeSet.styleId;
             }
 
             // add the explicit attributes of this instance
-            docModel.extendAttributes(mergedAttributeSet, explicitAttributeSet);
+            attributePool.extendAttributeSet(mergedAttributeSet, explicitAttributeSet);
 
             // delete all unsupported attribute families
             _.each(mergedAttributeSet, function (attributes, family) {
-                if (!(family in supportedFamilySet)) {
+                if (!self.supportsFamily(family)) {
                     delete mergedAttributeSet[family];
                 }
             });
@@ -202,6 +213,31 @@ define('io.ox/office/editframework/model/attributedmodel', [
 
         // public methods -----------------------------------------------------
 
+        /**
+         * Returns whether this instances supports attributes of the specified
+         * attribute family.
+         *
+         * @param {String} family
+         *  The name of an attribute family.
+         *
+         * @returns {Boolean}
+         *  Whether this instances supports the specified attribute family.
+         */
+        this.supportsFamily = function (family) {
+            return family in supportedFamilySet;
+        };
+
+        /**
+         * Returns the identifier of the style sheet used to format this model.
+         *
+         * @returns {String|Null}
+         *  The identifier of the style sheet used to format this model; or the
+         *  value null, if this model does not support style sheets.
+         */
+        this.getStyleId = function () {
+            return styleCollection ? mergedAttributeSet.styleId : null;
+        };
+
         /**
          * Returns whether this model object contains any explicit attributes,
          * or a reference to a style sheet.
@@ -278,7 +314,7 @@ define('io.ox/office/editframework/model/attributedmodel', [
             _.each(attributeSet, function (newAttrs, family) {
 
                 // skip unsupported attribute families
-                if (!(family in supportedFamilySet)) { return; }
+                if (!self.supportsFamily(family)) { return; }
 
                 // the explicit attributes of the current family
                 var oldExplicitAttrs = explicitAttributeSet[family];
@@ -319,6 +355,17 @@ define('io.ox/office/editframework/model/attributedmodel', [
 
             var undoAttributeSet = {};
 
+            // handle the style sheet identifier
+            if (styleCollection) {
+                var oldStyleId = explicitAttributeSet.styleId;
+                var newStyleId = attributeSet.styleId;
+                if ((typeof newStyleId === 'string') && (newStyleId !== oldStyleId)) {
+                    undoAttributeSet.styleId = (typeof oldStyleId === 'string') ? oldStyleId : null;
+                } else if ((newStyleId === null) && (typeof oldStyleId === 'string')) {
+                    undoAttributeSet.styleId = oldStyleId;
+                }
+            }
+
             // restore all old attributes that will be changed or cleared
             _.each(explicitAttributeSet, function (oldAttrs, family) {
 
@@ -326,6 +373,7 @@ define('io.ox/office/editframework/model/attributedmodel', [
                 var newAttrs = attributeSet[family];
                 if (!_.isObject(newAttrs)) { return; }
 
+                // copy the old attribute values to the undo attribute set, if it will change
                 _.each(oldAttrs, function (value, name) {
                     if ((name in newAttrs) && !_.isEqual(value, newAttrs[name])) {
                         AttributeUtils.insertAttribute(undoAttributeSet, family, name, value);
@@ -337,16 +385,45 @@ define('io.ox/office/editframework/model/attributedmodel', [
             _.each(attributeSet, function (newAttrs, family) {
 
                 // skip unsupported attribute families
-                if (!(family in supportedFamilySet)) { return; }
+                if (!self.supportsFamily(family)) { return; }
 
                 // the explicit attributes of the current family
                 var oldAttrs = explicitAttributeSet[family];
+                // the definitions of the current family
+                var definitionMap = attributePool.getRegisteredAttributes(family);
+                // all attributes to be restored in undo even if they will not be changed
+                var restoreAttrs = null;
 
-                _.each(newAttrs, function (value, name) {
+                // process all new attributes
+                definitionMap.forEachSupported(newAttrs, function (value, name, definition) {
+
+                    // if the attribute does not exist, reset it in undo (with a null value)
                     if (!oldAttrs || !(name in oldAttrs)) {
                         AttributeUtils.insertAttribute(undoAttributeSet, family, name, null);
                     }
+
+                    // if the attribute has been changed, and the definition contains additional
+                    // attributes to always be restored, add them to the undo attribute set
+                    var undoAttrs = undoAttributeSet[family];
+                    if (oldAttrs && undoAttrs && (name in undoAttrs)) {
+                        if (definition.undo === true) {
+                            restoreAttrs = oldAttrs;
+                        } else if (_.isArray(definition.undo) && (restoreAttrs !== oldAttrs)) {
+                            restoreAttrs = restoreAttrs || {};
+                            definition.undo.forEach(function (attrName) {
+                                if (attrName in oldAttrs) {
+                                    restoreAttrs[attrName] = oldAttrs[attrName];
+                                }
+                            });
+                        }
+                    }
                 });
+
+                // add all attributes to the undo attribute set that need to be updated
+                // according to the attribte definition
+                if (restoreAttrs) {
+                    undoAttributeSet[family] = _.extend({}, restoreAttrs, undoAttributeSet[family]);
+                }
             });
 
             return undoAttributeSet;
@@ -434,22 +511,21 @@ define('io.ox/office/editframework/model/attributedmodel', [
             // update the remaining explicit attributes of all supported attribute families
             _.each(supportedFamilySet, function (flag, family) {
 
-                // check if new attributes exist in the passed attribute set
-                if (!_.isObject(attributeSet[family])) { return; }
-
                 // attribute definitions of the current family
-                var definitions = docModel.getAttributeDefinitions(family);
+                var definitionMap = attributePool.getRegisteredAttributes(family);
+
+                // check if new attributes exist in the passed attribute set
+                if (!definitionMap || !_.isObject(attributeSet[family])) { return; }
+
                 // target attribute map for the current family
                 var explicitAttributes = explicitAttributeSet[family] || (explicitAttributeSet[family] = {});
 
                 // update the attribute map with the new attribute values
-                _.each(attributeSet[family], function (value, name) {
-                    if (AttributeUtils.isRegisteredAttribute(definitions, name, options)) {
-                        if (AttributeUtils.updateAttribute(explicitAttributes, name, value, autoClear ? definitions[name] : null)) {
-                            changed = true;
-                        }
+                definitionMap.forEachSupported(attributeSet[family], function (value, name, definition) {
+                    if (AttributeUtils.updateAttribute(explicitAttributes, name, value, autoClear ? definition : null)) {
+                        changed = true;
                     }
-                });
+                }, options);
 
                 // remove empty attribute value maps completely
                 if (_.isEmpty(explicitAttributes)) {
@@ -480,12 +556,11 @@ define('io.ox/office/editframework/model/attributedmodel', [
 
         // initialization -----------------------------------------------------
 
-        // initialize class members
-        styleCollection = styleFamily ? docModel.getStyleCollection(styleFamily) : null;
-
         // get all supported attribute families
         supportedFamilySet = Utils.makeSet(Utils.getTokenListOption(initOptions, 'families', []));
-        if (styleCollection) { _.extend(supportedFamilySet, styleCollection.getSupportedFamilies()); }
+        if (styleCollection && Utils.getBooleanOption(initOptions, 'addStyleFamilies', true)) {
+            _.extend(supportedFamilySet, styleCollection.getSupportedFamilies());
+        }
 
         // set the attributes passed to the constructor (filters by supported attributes)
         this.setAttributes(_.isObject(initAttributes) ? initAttributes : {}, { notify: 'never' });
@@ -512,7 +587,7 @@ define('io.ox/office/editframework/model/attributedmodel', [
 
         // destroy all class members on destruction
         this.registerDestructor(function () {
-            self = docModel = parentModel = styleCollection = null;
+            self = docModel = parentModel = styleCollection = attributePool = null;
             explicitAttributeSet = mergedAttributeSet = null;
         });
 
