@@ -14,13 +14,12 @@
 
 define('io.ox/office/editframework/model/autostylecollection', [
     'io.ox/office/tk/utils',
-    'io.ox/office/tk/container/simplemap',
-    'io.ox/office/tk/object/timermixin',
+    'io.ox/office/tk/container/valuemap',
     'io.ox/office/baseframework/model/modelobject',
     'io.ox/office/editframework/utils/operations',
     'io.ox/office/editframework/utils/attributeutils',
     'io.ox/office/editframework/model/attributedmodel'
-], function (Utils, SimpleMap, TimerMixin, ModelObject, Operations, AttributeUtils, AttributedModel) {
+], function (Utils, ValueMap, ModelObject, Operations, AttributeUtils, AttributedModel) {
 
     'use strict';
 
@@ -66,7 +65,6 @@ define('io.ox/office/editframework/model/autostylecollection', [
      * @constructor
      *
      * @extends ModelObject
-     * @extends TimerMixin
      *
      * @param {EditModel} docModel
      *  The document model containing this instance.
@@ -127,17 +125,20 @@ define('io.ox/office/editframework/model/autostylecollection', [
         // the style sheet collection for the passed style family
         var styleSheets = docModel.getStyleCollection(styleFamily);
 
+        // the attribute pool to be used for the formatting attributes
+        var attributePool = styleSheets.getAttributePool();
+
         // the names of all supported attribute families, as flag set
         var supportedFamilySet = styleSheets.getSupportedFamilies();
 
         // all registered auto-styles, mapped by unique identifier
-        var autoStyleMap = new SimpleMap();
+        var autoStyleMap = new ValueMap();
 
         // the serialized attribute keys of all auto-styles, mapped by identifier
-        var attrKeysByStyleId = new SimpleMap();
+        var attrKeysByStyleId = new ValueMap();
 
         // all auto-style identifiers, mapped by serialized attribute key
-        var styleIdsByAttrKey = new SimpleMap();
+        var styleIdsByAttrKey = new ValueMap();
 
         // identifier of the default auto style
         var defaultStyleId = '';
@@ -161,10 +162,9 @@ define('io.ox/office/editframework/model/autostylecollection', [
         // expected index for the next inserted auto-style identifier
         var nextStyleIndex = 0;
 
-        // base constructors --------------------------------------------------
+        // base constructor ---------------------------------------------------
 
         ModelObject.call(this, docModel);
-        TimerMixin.call(this);
 
         // private methods ----------------------------------------------------
 
@@ -248,7 +248,7 @@ define('io.ox/office/editframework/model/autostylecollection', [
             // return a complete merged attribute set in 'complete mode'
             if (keepComplete) {
                 var defAttributeSet = styleSheets.getDefaultStyleAttributeSet();
-                return attributeSet ? docModel.extendAttributes(defAttributeSet, attributeSet, { clone: true }) : defAttributeSet;
+                return attributeSet ? attributePool.extendAttributeSet(defAttributeSet, attributeSet, { clone: true }) : defAttributeSet;
             }
 
             // default to null, if parameter is missing
@@ -563,7 +563,7 @@ define('io.ox/office/editframework/model/autostylecollection', [
 
             // in non-strict mode, allow to use the identifiers of real style sheets,
             // otherwise return an empty object
-            return strictMode ? {} : styleSheets.getStyleSheetAttributeMap(styleId);
+            return strictMode ? {} : styleSheets.getStyleSheetAttributeMap(styleId, true);
         };
 
         /**
@@ -587,7 +587,7 @@ define('io.ox/office/editframework/model/autostylecollection', [
          * created, and the appropriate remote operations will be inserted into
          * the passed generators.
          *
-         * @param {SheetOperationsGenerator} generator
+         * @param {OperationGenerator} generator
          *  The operations generator to be filled with the operation.
          *
          * @param {String|Null} styleId
@@ -611,20 +611,20 @@ define('io.ox/office/editframework/model/autostylecollection', [
             var resultAttributeSet = autoStyle ? autoStyle.getExplicitAttributeSet() : {};
             _.each(supportedFamilySet, function (flag, family) {
 
-                // check if new attributes exist in the passed attribute set
-                var sourceAttributes = attributeSet[family];
-                if (!_.isObject(sourceAttributes)) { return; }
-
                 // attribute definitions of the current family
-                var definitions = docModel.getAttributeDefinitions(family);
+                var definitionMap = attributePool.getRegisteredAttributes(family);
+                // the attribute values of the current family
+                var sourceAttributes = attributeSet[family];
+
+                // check if new attributes exist in the passed attribute set
+                if (!definitionMap || !_.isObject(sourceAttributes)) { return; }
+
                 // target attribute map for the current family
                 var resultAttributes = resultAttributeSet[family] || (resultAttributeSet[family] = {});
 
                 // update the attribute map with the new attribute values
-                _.each(sourceAttributes, function (value, name) {
-                    if (AttributeUtils.isRegisteredAttribute(definitions, name)) {
-                        AttributeUtils.updateAttribute(resultAttributes, name, value);
-                    }
+                definitionMap.forEachSupported(sourceAttributes, function (value, name) {
+                    AttributeUtils.updateAttribute(resultAttributes, name, value);
                 });
 
                 // remove empty attribute value maps completely
@@ -678,7 +678,7 @@ define('io.ox/office/editframework/model/autostylecollection', [
         // destroy class members on destruction
         this.registerDestructor(function () {
             autoStyleMap.forEach(function (autoStyle) { autoStyle.destroy(); });
-            docModel = styleSheets = supportedFamilySet = null;
+            docModel = styleSheets = attributePool = supportedFamilySet = null;
             autoStyleMap = attrKeysByStyleId = styleIdsByAttrKey = null;
         });
 
