@@ -15,15 +15,16 @@
 define('io.ox/office/editframework/model/editmodel', [
     'io.ox/office/tk/utils',
     'io.ox/office/tk/utils/logger',
+    'io.ox/office/tk/utils/scheduler',
+    'io.ox/office/tk/container/valuemap',
     'io.ox/office/baseframework/model/basemodel',
     'io.ox/office/editframework/utils/operations',
     'io.ox/office/editframework/utils/operationutils',
-    'io.ox/office/editframework/utils/operationcontext',
-    'io.ox/office/editframework/model/undomanager',
-    'io.ox/office/editframework/model/operationsgenerator',
+    'io.ox/office/editframework/model/operationcontext',
+    'io.ox/office/editframework/model/operationgenerator',
     'io.ox/office/editframework/model/modelattributesmixin',
-    'io.ox/office/tk/utils/deferredutils'
-], function (Utils, Logger, BaseModel, Operations, OperationUtils, OperationContext, UndoManager, OperationsGenerator, ModelAttributesMixin, DeferredUtils) {
+    'io.ox/office/editframework/model/undomanager'
+], function (Utils, Logger, Scheduler, ValueMap, BaseModel, Operations, OperationUtils, OperationContext, OperationGenerator, ModelAttributesMixin, UndoManager) {
 
     'use strict';
 
@@ -77,12 +78,10 @@ define('io.ox/office/editframework/model/editmodel', [
      *      Directly after the event 'operations:after', if applying the
      *      operations has failed. The event handler receives the external
      *      state passed to the method EditModel.applyOperations().
-     * - 'change:editmode'
-     *      When the edit mode of the document model has been changed. Event
-     *      handlers receive the new state of the edit mode.
-     * - 'change:attributes': After the document attributes have been changed
-     *      via the method 'EditModel.setDocumentAttributes()'. Event handlers
-     *      receive the following parameters:
+     * - 'change:attributes':
+     *      After the document attributes have been changed by a
+     *      'setDocumentAttributes' document operation. Event handlers receive
+     *      the following parameters:
      *      (1) {jQuery.Event} event
      *          The jQuery event object.
      *      (2) {Object} newAttributes
@@ -91,8 +90,10 @@ define('io.ox/office/editframework/model/editmodel', [
      *          The old (complete) map of document attributes.
      *      (4) {Object} changedAttributes
      *          A map with the document attributes that have really changed.
-     * - 'change:defaults': After the default values of formatting attributes
-     *      have been changed. Event handlers receive the following parameters:
+     * - 'change:defaults':
+     *      After the default values of formatting attributes have been changed
+     *      by a 'setDocumentAttributes' document operation. Event handlers
+     *      receive the following parameters:
      *      (1) {jQuery.Event} event
      *          The jQuery event object.
      *      (2) {Object} newAttributeSet
@@ -111,17 +112,13 @@ define('io.ox/office/editframework/model/editmodel', [
      * @param {EditApplication} app
      *  The application containing this document model instance.
      *
-     * @param {UndoManager} undoManager
-     *  The undo manager used by the document model to store undo and redo
-     *  actions.
-     *
      * @param {Object} [initOptions]
      *  Optional parameters that will be passed to the constructor of the undo
      *  manager (see class UndoManager for details). Additionally, the
      *  following options are supported:
-     *  @param {Function} [initOptions.generatorClass=OperationsGenerator]
+     *  @param {Function} [initOptions.generatorClass=OperationGenerator]
      *      The constructor function of the operations generator used by this
-     *      document model. MUST be a sub class of class OperationsGenerator.
+     *      document model. MUST be a sub class of class OperationGenerator.
      *  @param {Function} [initOptions.contextClass=OperationContext]
      *      The constructor function of the operation context class used to
      *      wrap JSON operation objects, passed to operation handler callback
@@ -142,45 +139,46 @@ define('io.ox/office/editframework/model/editmodel', [
      *      objects, and MUST return an array of processed operations (the
      *      return value may be the same array modified in-place). Will be
      *      called in the context of this document model.
+     *  @param {Function} [initOptions.themeTargetsResolver]
+     *      A callback function that returns the theme target chain for a
+     *      specific DOM element or the active theme target chain, e.g.
+     *      according to the current selection of this document model. Receives
+     *      the following parameters:
+     *      (1) {HTMLElement|jQuery} [elementNode]
+     *          The DOM element node to resolve the theme target for. If
+     *          omitted, the active theme target must be returned.
+     *      Will be called in the context of this document model instance. May
+     *      return null, a single string, or an array of strings.
      *  @param {Boolean} [initOptions.slideMode=false]
      *      Whether the model supports the slide mode (used in the Presentation
      *      application).
      */
     function EditModel(app, initOptions) {
 
-        // the constructor of the operations generator class used by this document
-        var GeneratorClass = Utils.getFunctionOption(initOptions, 'generatorClass', OperationsGenerator);
+        // the constructor of the operation generator class used by this document
+        var GeneratorClass = Utils.getFunctionOption(initOptions, 'generatorClass', OperationGenerator);
 
-        // the constructor of the operations generator class used by this document
+        // the constructor of the operation context class used by this document
         var ContextClass = Utils.getFunctionOption(initOptions, 'contextClass', OperationContext);
 
         // self reference for local functions
         var self = this;
 
-        // flag to enable slide specific behavior
-        var slideMode = Utils.getBooleanOption(initOptions, 'slideMode', false);
-
-        // flag to enable slide specific behavior in iOS and Android
-        var slideTouchMode = slideMode && (Utils.IOS || Utils.CHROME_ON_ANDROID);
-
-        // edit mode, received dynamically from server (one editing user at a time)
-        var editMode = null;
-
         // the undo manager of this document
         var undoManager = null;
 
         // callback handler to receive or restore the document selection state
-        var selectionStateHandler = Utils.getFunctionOption(initOptions, 'selectionStateHandler');
+        var selectionStateHandler = Utils.getFunctionOption(initOptions, 'selectionStateHandler', null);
 
         // callback to preprocess operations before applying them
-        var operationsFinalizer = Utils.getFunctionOption(initOptions, 'operationsFinalizer');
+        var operationsFinalizer = Utils.getFunctionOption(initOptions, 'operationsFinalizer', null);
 
         // Deferred object for current asynchronous actions, will remain in
         // resolved/rejected state as long as no new actions will be applied
         var actionsDef = $.when();
 
         // maps all operation names to operation handler functions
-        var operationHandlers = {};
+        var operationHandlerMap = new ValueMap();
 
         // whether operations are currently applied (prevent recursive calls)
         var processingOperations = false;
@@ -196,10 +194,16 @@ define('io.ox/office/editframework/model/editmodel', [
         // collecting the last two operations in cache
         var operationsCache = { previous: null, current: null };
 
+        // flag to enable slide specific behavior
+        var slideMode = Utils.getBooleanOption(initOptions, 'slideMode', false);
+
+        // flag to enable slide specific behavior in iOS and Android
+        var slideTouchMode = slideMode && (Utils.IOS || Utils.CHROME_ON_ANDROID);
+
         // base constructors --------------------------------------------------
 
         BaseModel.call(this, app);
-        ModelAttributesMixin.call(this);
+        ModelAttributesMixin.call(this, initOptions);
 
         // private methods ----------------------------------------------------
 
@@ -244,7 +248,7 @@ define('io.ox/office/editframework/model/editmodel', [
 
             // create a new deferred object which remains in pending state as long
             // as the callback function runs (and the promise it returns is pending)
-            actionsDef = DeferredUtils.createDeferred(app, 'EditModel.enterProcessActionsMode()').always(function () {
+            actionsDef = Scheduler.createDeferred(app, 'EditModel.enterProcessActionsMode').always(function () {
                 var state = actionsDef ? actionsDef.state().replace(/ed$/, 'ing') : 'destructed';
                 logger.log('EditModel.enterProcessActionsMode(): ' + state + ' promise...');
             });
@@ -317,12 +321,7 @@ define('io.ox/office/editframework/model/editmodel', [
         function endProcessOperations(success, operations, external) {
             processingOperations = false;
             self.trigger('operations:after', operations, external);
-            if (success) {
-                self.trigger('operations:success', operations, external);
-            } else {
-                self.setEditMode(false);
-                self.trigger('operations:error', operations, external);
-            }
+            self.trigger(success ? 'operations:success' : 'operations:error', operations, external);
         }
 
         /**
@@ -367,7 +366,7 @@ define('io.ox/office/editframework/model/editmodel', [
                 // the context passed to the operation handler
                 var context = new ContextClass(self, operation, external, importing);
                 // the callback handler for the operation
-                var handler = operationHandlers[context.getStr('name')];
+                var handler = operationHandlerMap.get(context.getStr('name'), null);
 
                 // check existence of operation handler (always, also if operation will be filtered below)
                 context.ensure(handler, 'unknown operation');
@@ -383,7 +382,7 @@ define('io.ox/office/editframework/model/editmodel', [
                     // During loading the document, the initial OSN is sent by the server.
                     // If we don't have a valid value use that OSN.
                     if (operationStateNumber === -1) {
-                        operationStateNumber = opOSN;
+                        self.setOperationStateNumber(opOSN);
                     }
 
                     // the current OSN must be equal to the OSN contained in the external operation
@@ -400,7 +399,7 @@ define('io.ox/office/editframework/model/editmodel', [
 
                 // update the current OSN of the document
                 if (operationStateNumber >= 0) {
-                    operationStateNumber += context.getOptInt(OperationUtils.OPL, 1);
+                    self.setOperationStateNumber(operationStateNumber + context.getOptInt(OperationUtils.OPL, 1));
                 }
 
                 // cache the last two operations
@@ -408,7 +407,7 @@ define('io.ox/office/editframework/model/editmodel', [
                 operationsCache.current = operation;
 
                 // do not apply operations scoped to the export filter
-                var scope = context.getOptEnum('scope', /^filter$/);
+                var scope = context.getOptStr('scope');
 
                 // invoke the operation handler (unless the operation scope is 'filter' for operations intended
                 // to be executed in the filter component only, or the filter callback function returns false)
@@ -429,7 +428,7 @@ define('io.ox/office/editframework/model/editmodel', [
          * undo manager is active, all applied operations will be embedded into
          * a single undo group action.
          *
-         * @param {Object|Array|OperationsGenerator} operations
+         * @param {Object|Array|OperationGenerator} operations
          *  A single JSON operation, or an array of JSON operations, or an
          *  operations generator instance with operations to be applied at this
          *  document model. Note that an operations generator passed to this
@@ -450,7 +449,7 @@ define('io.ox/office/editframework/model/editmodel', [
          *      disable applying all operations.
          *  @param {Boolean} [options.undo=false]
          *      If set to true, and the parameter 'operations' is an instance
-         *      of the class OperationsGenerator, its undo operations will be
+         *      of the class OperationGenerator, its undo operations will be
          *      applied.
          *
          * @returns {Boolean}
@@ -466,11 +465,11 @@ define('io.ox/office/editframework/model/editmodel', [
             var success = false;
 
             // convert input parameter to an array of JSON operations
-            operations = OperationsGenerator.getArray(operations, options);
+            operations = OperationGenerator.getArray(operations, options);
 
             // if the operation's origin is not an external client and
             // we don't have edit rights then we skip the operations silently.
-            if ((!external && !editMode) || (operations.length === 0)) {
+            if ((!external && !app.isEditable()) || (operations.length === 0)) {
                 return true;
             }
 
@@ -500,7 +499,7 @@ define('io.ox/office/editframework/model/editmodel', [
          * asynchronous background loop. If the undo manager is active, all
          * applied operations will be embedded into a single undo group action.
          *
-         * @param {Object|Array|OperationsGenerator} operations
+         * @param {Object|Array|OperationGenerator} operations
          *  A single JSON operation, or an array of JSON operations, or an
          *  operations generator instance with operations to be applied at this
          *  document model. Note that an operations generator passed to this
@@ -521,7 +520,7 @@ define('io.ox/office/editframework/model/editmodel', [
          *      disable applying all operations.
          *  @param {Boolean} [options.undo=false]
          *      If set to true, and the parameter 'operations' is an instance
-         *      of the class OperationsGenerator, its undo operations will be
+         *      of the class OperationGenerator, its undo operations will be
          *      applied.
          *
          * @returns {jQuery.Promise}
@@ -542,7 +541,7 @@ define('io.ox/office/editframework/model/editmodel', [
             var startIndex = totalOperations;
 
             // convert input parameter to an array of JSON operations
-            operations = OperationsGenerator.getArray(operations, options);
+            operations = OperationGenerator.getArray(operations, options);
 
             // immediate success on empty operations array
             if (operations.length === 0) { return self.createResolvedPromise(null); }
@@ -558,7 +557,7 @@ define('io.ox/office/editframework/model/editmodel', [
 
                         // if the operation's origin is not an external client and
                         // we don't have edit rights then we skip the operations silently
-                        if (!external && !editMode) {
+                        if (!external && !app.isEditable()) {
                             return Utils.BREAK;
                         }
 
@@ -566,7 +565,7 @@ define('io.ox/office/editframework/model/editmodel', [
                         if (!applyOperation(operation, external, filter, importing)) {
                             return self.createRejectedPromise({ cause: 'operation' });
                         }
-                    }, { delay: 'immediate', infoString: 'EditModel: applyOperationsAsync 2', app: app });
+                    }, 'EditModel.applyOperationsAsync');
                 });
 
             } else {
@@ -622,7 +621,7 @@ define('io.ox/office/editframework/model/editmodel', [
          *  A reference to this instance.
          */
         this.registerContextOperationHandler = function (name, handler) {
-            operationHandlers[name] = handler;
+            operationHandlerMap.insert(name, handler);
             return this;
         };
 
@@ -742,7 +741,7 @@ define('io.ox/office/editframework/model/editmodel', [
          * operations manually before they will be sent to the server. In this
          * case, the registered operation handlers must not be called.
          *
-         * @param {Object|Array|OperationsGenerator} operations
+         * @param {Object|Array|OperationGenerator} operations
          *  A single JSON operation, or an array of JSON operations, or an
          *  operations generator instance with operations to be sent to the
          *  server. Note that an operations generator passed to this method
@@ -752,7 +751,7 @@ define('io.ox/office/editframework/model/editmodel', [
          *  Optional parameters:
          *  @param {Boolean} [options.undo=false]
          *      If set to true, and the parameter 'operations' is an instance
-         *      of the class OperationsGenerator, its undo operations will be
+         *      of the class OperationGenerator, its undo operations will be
          *      sent to the server.
          *
          * @returns {Boolean}
@@ -765,7 +764,7 @@ define('io.ox/office/editframework/model/editmodel', [
         /**
          * Executes the handler functions for all passed operations.
          *
-         * @param {Object|Array|OperationsGenerator} operations
+         * @param {Object|Array|OperationGenerator} operations
          *  A single JSON operation, or an array of JSON operations, or an
          *  operations generator instance with operations to be applied at this
          *  document model. Note that an operations generator passed to this
@@ -788,7 +787,7 @@ define('io.ox/office/editframework/model/editmodel', [
          *      will be notified about the progress of the operation.
          *  @param {Boolean} [options.undo=false]
          *      If set to true, and the parameter 'operations' is an instance
-         *      of the class OperationsGenerator, its undo operations will be
+         *      of the class OperationGenerator, its undo operations will be
          *      applied.
          *
          * @returns {Boolean|jQuery.Promise}
@@ -885,7 +884,7 @@ define('io.ox/office/editframework/model/editmodel', [
                 // whether the actions have been received from the server
                 var external = Utils.getBooleanOption(options, 'external', false);
                 // resulting deferred object returned by this method
-                var resultDef = DeferredUtils.createDeferred(app, 'EditModel: applyActions');
+                var resultDef = Scheduler.createDeferred(app, 'EditModel.applyActions');
                 // start index of first operations in the current action (for progress)
                 var startIndex = 0;
                 // the promise of the inner loop processing operations of an action
@@ -909,7 +908,7 @@ define('io.ox/office/editframework/model/editmodel', [
                     // clean up after finishing the loop
                     return innerPromise.always(function () { innerPromise = null; });
 
-                }, { delay: 'immediate', infoString: 'EditModel: applyActions', app: app });
+                }, 'EditModel.applyActions');
 
                 // forward the result of the timer to the own deferred object
                 timer.done(function () { resultDef.notify(1).resolve(); });
@@ -945,12 +944,16 @@ define('io.ox/office/editframework/model/editmodel', [
 
                 // the operation context passed to the callback
                 var context = new ContextClass(this, operation, false);
-                // the callback handler for the operation
-                var handler = operationHandlers[context.getStr('name')];
 
-                // check existence of callback function , and invoke it
+                // the callback handler for the operation
+                var handler = operationHandlerMap.get(context.getStr('name'), null);
                 context.ensure(handler, 'unknown operation');
-                handler.call(this, context);
+
+                // suppress implicit undo operations generated e.g. in text framework
+                undoManager.disableUndo(function () {
+                    handler.call(this, context);
+                }, this);
+
                 return true;
 
             } catch (ex) {
@@ -962,16 +965,16 @@ define('io.ox/office/editframework/model/editmodel', [
         /**
          * Creates and returns an initialized operations generator instance (an
          * instance of the class specified in the constructor parameter
-         * OperationsGeneratorClass).
+         * 'generatorClass').
          *
          * @param {Object} [options]
          *  Optional parameters that will be passed to the constructor of the
          *  operations generator.
          *
-         * @returns {OperationsGenerator}
+         * @returns {OperationGenerator}
          *  A new operations generator instance.
          */
-        this.createOperationsGenerator = function (options) {
+        this.createOperationGenerator = function (options) {
             return new GeneratorClass(this, options);
         };
 
@@ -984,7 +987,7 @@ define('io.ox/office/editframework/model/editmodel', [
          *
          * @param {Function} callback
          *  The callback function. Receives the following parameters:
-         *  (1) {OperationsGenerator} generator
+         *  (1) {OperationGenerator} generator
          *      The operations generator to be filled with the document
          *      operations, and undo operations.
          *  May return a promise to defer applying and sending the operations
@@ -1018,6 +1021,16 @@ define('io.ox/office/editframework/model/editmodel', [
          *      - 'clear': No undo action will be generated, regardless of the
          *          contents of the operations generator, AND the undo manager
          *          will be cleared completely.
+         *  @param {Function} [options.generatorClass]
+         *      The constructor function of the operations generator used by
+         *      this invocation. Can be used to override the default operations
+         *      generator passed to the constructor of this docuemnt model.
+         *      MUST be a sub class of class OperationGenerator.
+         *  @param {Object} [options.undoOptions]
+         *      Additional optional parameters that will be passed to the
+         *      method UndoManager.enterUndoGroup(). These options will be
+         *      stored in the undo/redo action group, and will be passed to all
+         *      listeners of undo/redo events triggered by the undo manager.
          *
          * @returns {jQuery.Promise}
          *  A promise that will be resolved after the operations have been
@@ -1028,12 +1041,14 @@ define('io.ox/office/editframework/model/editmodel', [
          */
         this.createAndApplyOperations = logger.profileAsyncMethod('EditModel.createAndApplyOperations()', function (callback, options) {
 
-            // create default operations generator if none has been passed to this method
-            var generator = this.createOperationsGenerator(options);
+            // create a custom operations generator type if requested
+            var CurrentGeneratorClass = Utils.getFunctionOption(options, 'generatorClass', GeneratorClass);
+            // create the operation generator instance to be used during this method call
+            var generator = new CurrentGeneratorClass(this, options);
 
             // whether to store the old and new selection state in the undo action
             var storeSelection = Utils.getBooleanOption(options, 'storeSelection', false);
-            var storeSelectionHandler = storeSelection ? _.noop : Utils.getFunctionOption(options, 'storeSelection');
+            var storeSelectionHandler = storeSelection ? _.noop : Utils.getFunctionOption(options, 'storeSelection', null);
 
             // whether the generator applies all generated operations immediately
             var immediateMode = generator.isImmediateApplyMode();
@@ -1044,7 +1059,9 @@ define('io.ox/office/editframework/model/editmodel', [
                 // get the current selection state of the document
                 var oldSelectionState = storeSelectionHandler ? self.getSelectionState() : null;
                 // invoke the callback function
-                var promise = $.when(callback.call(self, generator));
+                var result = callback.call(self, generator);
+                // start with a promise
+                var promise = self.convertToPromise(result);
 
                 // clean-up if the callback function fails
                 promise = promise.then(null, function (result) {
@@ -1058,7 +1075,7 @@ define('io.ox/office/editframework/model/editmodel', [
                         if (!self.invokeOperationHandler(operation)) {
                             return $.Deferred().reject({ cause: 'operation' });
                         }
-                    }, { infoString: 'EditModel: createAndApplyOperations', app: app });
+                    }, 'EditModel.createAndApplyOperations');
 
                     // restore the rejected state of the outer promise (unless reverting the operations fails too)
                     return promise2.then(_.constant($.Deferred().reject(result)));
@@ -1080,18 +1097,26 @@ define('io.ox/office/editframework/model/editmodel', [
                 promise = promise.then(function (result) {
 
                     // invoke the callback function to allow to change the document selection after applying the operations
-                    if (storeSelectionHandler) { storeSelectionHandler.call(self); }
-                    var newSelectionState = storeSelectionHandler ? self.getSelectionState() : null;
+                    var newSelectionState = null;
+                    if (storeSelectionHandler) {
+                        storeSelectionHandler.call(self);
+                        newSelectionState = self.getSelectionState();
+                    }
 
                     // create the undo action with the collected operations and selection states
                     switch (Utils.getStringOption(options, 'undoMode', 'generate')) {
+                        case 'generate':
+                            undoManager.enterUndoGroup(function () {
+                                undoManager.addUndo(generator.getOperations({ undo: true }), generator.getOperations(), oldSelectionState, newSelectionState);
+                            }, self, Utils.getObjectOption(options, 'undoOptions', null));
+                            break;
                         case 'clear':
                             undoManager.clearUndoActions();
                             break;
                         case 'skip':
                             break;
                         default:
-                            undoManager.addUndo(generator.getOperations({ undo: true }), generator.getOperations(), oldSelectionState, newSelectionState);
+                            Utils.error('EditModel.createAndApplyOperations(): unknown undo mode');
                     }
 
                     // return the original result of the generator callback function
@@ -1117,12 +1142,18 @@ define('io.ox/office/editframework/model/editmodel', [
         };
 
         /**
-         * Sets the operation state number of the document. Used when empty doc is fast displayed
-         * @param {Number} osn - new osn number
+         * Sets the operation state number of the document. Used when empty doc
+         * is fast displayed.
+         *
+         * @param {Number} osn
+         *  new osn number
          */
         this.setOperationStateNumber = function (osn) {
-            operationStateNumber = osn;
-            this.trigger('change:osn', osn); // update osn value in operations pane
+            if (operationStateNumber !== osn) {
+                operationStateNumber = osn;
+                this.trigger('change:osn', osn);
+            }
+            return this;
         };
 
         /**
@@ -1148,36 +1179,6 @@ define('io.ox/office/editframework/model/editmodel', [
             return operationsCache.previous;
         };
 
-        /**
-         * Returns whether the document can be modified by the current user.
-         *
-         * @returns {Boolean}
-         *  Whether the document can be modified.
-         */
-        this.getEditMode = function () {
-            return editMode;
-        };
-
-        /**
-         * Enables or disables the edit mode of this document model.
-         *
-         * @param {Boolean} state
-         *  The new edit mode state. If set to true, the user can modify the
-         *  document, otherwise the user can view the document contents, but
-         *  cannot edit them.
-         *
-         * @returns {EditModel}
-         *  A reference to this instance.
-         */
-        this.setEditMode = function (state) {
-            if (editMode !== state) {
-                editMode = state;
-                // notify state change to listeners
-                this.trigger('change:editmode', editMode);
-            }
-            return this;
-        };
-
         /**
          * Returns the undo manager of this document containing the undo action
          * stack and the redo action stack.
@@ -1210,61 +1211,13 @@ define('io.ox/office/editframework/model/editmodel', [
             return slideTouchMode;
         };
 
-        /**
-         * Create a busy Screen with a cancel Button and a listener which is listening if the
-         * edit rights are withdrawn. The function returns a Deferred which must resolved if the
-         * job is done to remove the 'change:editmode' listener.
-         *
-         * @param {Object} [options]
-         *  Optional parameters.
-         *
-         *  @param {String} [options.dialogText='']
-         *      The text which is displayed on the busy screen e.g. 'Please wait while paste the text'
-         *
-         *  @param {Function} [abortHandler=null]
-         *      The callback function to listen if the cancel button is pressed or the edit rights are withdrawn.
-         *
-         * @returns {jQuery.Deferred}
-         *  The new deferred object.
-         */
-        this.createAbortableBusyScreen = function (options) {
-            var dialogText = Utils.getStringOption(options, 'dialogText', '');
-            var abortHandler = Utils.getFunctionOption(options, 'abortHandler', null);
-
-            function abort() {
-                if (abortHandler) {
-                    abortHandler();
-                }
-            }
-
-            app.getView().enterBusy({
-                cancelHandler: function () {
-                    abort();
-                },
-                warningLabel: dialogText
-            });
-
-            var editModeHandler = function (event, editMode) {
-                if (!editMode) {
-                    abort();
-                }
-            };
-
-            self.listenTo(self, 'change:editmode', editModeHandler);
-
-            return DeferredUtils.createDeferred(app, 'EditModel.createAbortablePromiseCancelDialog()')
-                .always(function () {
-                    self.stopListeningTo(self, 'change:editmode', editModeHandler);
-                });
-        };
-
         // operation generators -----------------------------------------------
 
         /**
          * Generates an 'insertStyleSheet' operation, if the specified style
          * sheet exists in the style sheet collection, and is marked dirty.
          *
-         * @param {SheetOperationsGenerator} generator
+         * @param {SheetOperationGenerator} generator
          *  The operations generator to be filled with the operations.
          *
          * @param {String} styleFamily
@@ -1286,16 +1239,15 @@ define('io.ox/office/editframework/model/editmodel', [
         // operation handlers -------------------------------------------------
 
         this.registerContextOperationHandler(Operations.SET_DOCUMENT_ATTRIBUTES, function (context) {
-            // setting document/default attributes is not undoable
-            this.setDocumentAttributes(context.getObj('attrs'));
+            this.applySetDocumentAttributesOperation(context);
         });
 
         this.registerContextOperationHandler(Operations.INSERT_THEME, function (context) {
-            this.getThemeCollection().insertTheme(context.getStr('themeName'), context.getObj('attrs'), context.getOptStr('target', '', true));
+            this.getThemeCollection().applyInsertThemeOperation(context);
         });
 
         this.registerContextOperationHandler(Operations.INSERT_FONT_DESCRIPTION, function (context) {
-            this.getFontCollection().insertFont(context.getStr('fontName'), context.getObj('attrs'));
+            this.getFontCollection().applyInsertFontOperation(context);
         });
 
         this.registerContextOperationHandler(Operations.INSERT_STYLESHEET, function (context) {
@@ -1328,7 +1280,7 @@ define('io.ox/office/editframework/model/editmodel', [
             var undoOp = { name: Operations.INSERT_STYLESHEET, type: styleFamily, styleId: styleId };
             undoOp.styleName = styleCollection.getName(styleId);
             undoOp.parentId = styleCollection.getParentId(styleId);
-            undoOp.attrs = styleCollection.getStyleSheetAttributeMap(styleId);
+            undoOp.attrs = styleCollection.getStyleSheetAttributeMap(styleId, true);
             undoOp.hidden = styleCollection.isHidden(styleId);
             undoOp.uiPriority = styleCollection.getUIPriority(styleId);
             undoOp.custom = styleCollection.isCustom(styleId);
@@ -1349,7 +1301,7 @@ define('io.ox/office/editframework/model/editmodel', [
             var styleId = context.getStr('styleId');
             var undoOp = { name: Operations.CHANGE_STYLESHEET, type: styleFamily, styleId: styleId };
             if (context.has('styleName')) { undoOp.styleName = styleCollection.getName(styleId); }
-            if (context.has('attrs')) { undoOp.attrs = styleCollection.getStyleSheetAttributeMap(styleId); }
+            if (context.has('attrs')) { undoOp.attrs = styleCollection.getStyleSheetAttributeMap(styleId, true); }
             undoManager.addUndo(undoOp, context.operation);
 
             // apply the operation (throws on error)
@@ -1401,8 +1353,8 @@ define('io.ox/office/editframework/model/editmodel', [
         this.registerDestructor(function () {
             undoManager.destroy();
             self = initOptions = actionsDef = null;
-            operationsFinalizer = operationHandlers = null;
-            undoManager = GeneratorClass = null;
+            operationsFinalizer = operationHandlerMap = null;
+            undoManager = GeneratorClass = ContextClass = null;
         });
 
     } // class EditModel
