@@ -15,52 +15,54 @@
 define('io.ox/office/editframework/model/fontcollection', [
     'io.ox/office/tk/config',
     'io.ox/office/tk/utils',
-    'io.ox/office/tk/utils/deferredutils',
-    'io.ox/office/tk/container/simplemap',
-    'io.ox/office/tk/render/font',
+    'io.ox/office/tk/utils/scheduler',
+    'io.ox/office/tk/container/valuemap',
     'io.ox/office/baseframework/model/modelobject'
-], function (Config, Utils, DeferredUtils, SimpleMap, Font, ModelObject) {
+], function (Config, Utils, Scheduler, ValueMap, ModelObject) {
 
     'use strict';
 
     // all known fonts, mapped by font name
     var PREDEFINED_FONTS = {
 
-        Helvetica:              { cssDefault: 'sans-serif', fontProps: { pitch: 'variable', altNames: ['Arial'] } },
-        Arial:                  { cssDefault: 'sans-serif', fontProps: { pitch: 'variable', altNames: ['Helvetica'] } },
-        'Arial Black':          { cssDefault: 'sans-serif', fontProps: { pitch: 'variable', altNames: ['sans serif', 'Arial'] }, hidden: true },
-        // Arial Narrow is overwritten in themecollection.js
-        Verdana:                { cssDefault: 'sans-serif', fontProps: { pitch: 'variable', altNames: ['Arial'] } },
-        Tahoma:                 { cssDefault: 'sans-serif', fontProps: { pitch: 'variable', altNames: ['Arial'] } },
-        Calibri:                { cssDefault: 'sans-serif', fontProps: { pitch: 'variable', altNames: ['Carlito', 'Arial'] } },
-        'Calibri Light':        { cssDefault: 'sans-serif', fontProps: { pitch: 'variable', altNames: ['Carlito', 'Arial'] } },
-        Carlito:                { cssDefault: 'sans-serif', fontProps: { pitch: 'variable', altNames: ['Calibri', 'Arial'] }, hidden: true },
-        Albany:                 { cssDefault: 'sans-serif', fontProps: { pitch: 'variable', altNames: ['Arial'] }, hidden: true },
-        Impact:                 { cssDefault: 'sans-serif', fontProps: { pitch: 'variable', altNames: ['sans serif', 'Arial'] } },
-        // Bug 49056 in Linux is "sans serif" not the same as "sans-serif"
+        Helvetica:              { cssDefault: 'sans-serif', fontProps: { pitch: 'variable', altNames: ['Arial'] }, display: true },
+        Arial:                  { cssDefault: 'sans-serif', fontProps: { pitch: 'variable', altNames: ['Helvetica'] }, display: true },
+        'Arial Black':          { cssDefault: 'sans-serif', fontProps: { pitch: 'variable', altNames: ['sans serif', 'Arial'] } },
+        'Arial Narrow':         { cssDefault: 'sans-serif', fontProps: { pitch: 'variable', altNames: ['Calibri Light'] } },
+        Verdana:                { cssDefault: 'sans-serif', fontProps: { pitch: 'variable', altNames: ['Arial'] }, display: true },
+        Tahoma:                 { cssDefault: 'sans-serif', fontProps: { pitch: 'variable', altNames: ['Arial'] }, display: true },
+        Calibri:                { cssDefault: 'sans-serif', fontProps: { pitch: 'variable', altNames: ['Carlito', 'Arial'] }, display: true },
+        'Calibri Light':        { cssDefault: 'sans-serif', fontProps: { pitch: 'variable', altNames: ['Carlito', 'Arial'] }, display: true },
+        Carlito:                { cssDefault: 'sans-serif', fontProps: { pitch: 'variable', altNames: ['Calibri', 'Arial'] } },
+        Albany:                 { cssDefault: 'sans-serif', fontProps: { pitch: 'variable', altNames: ['Liberation Sans', 'Arial'] } }, // old OOo default for sans-serif
+        'Liberation Sans':      { cssDefault: 'sans-serif', fontProps: { pitch: 'variable', altNames: ['Albany', 'Arial'] }, display: 'odf' }, // LO default for sans-serif
+        // bug 49056: in Linux, "sans serif" is not the same as "sans-serif"
+        Impact:                 { cssDefault: 'sans-serif', fontProps: { pitch: 'variable', altNames: ['sans serif', 'Arial'] }, display: true },
+        'Helvetica Neue':       { cssDefault: 'sans-serif', fontProps: { pitch: 'variable', altNames: ['Helvetica'] } },
+        'Helvetica Light':      { cssDefault: 'sans-serif', fontProps: { pitch: 'variable', altNames: ['Helvetica'] } },
+        'Open Sans':            { cssDefault: 'sans-serif', fontProps: { pitch: 'variable', altNames: ['Helvetica Neue'] } },
+        'Open Sans Light':      { cssDefault: 'sans-serif', fontProps: { pitch: 'variable', altNames: ['Open Sans'] } },
+        'Open Sans Semibold':   { cssDefault: 'sans-serif', fontProps: { pitch: 'variable', altNames: ['Open Sans'] } },
+        'Open Sans Extrabold':  { cssDefault: 'sans-serif', fontProps: { pitch: 'variable', altNames: ['Open Sans Semibold'] } },
+        Euphemia:               { cssDefault: 'sans-serif', fontProps: { pitch: 'variable', altNames: ['Calibri', 'Arial'] } },
 
-        'Helvetica Neue':       { cssDefault: 'sans-serif', fontProps: { pitch: 'variable', altNames: ['Helvetica'] }, hidden: true },
-        'Helvetica Light':      { cssDefault: 'sans-serif', fontProps: { pitch: 'variable', altNames: ['Helvetica'] }, hidden: true },
-        'Open Sans':            { cssDefault: 'sans-serif', fontProps: { pitch: 'variable', altNames: ['Helvetica Neue'] }, hidden: true },
-        'Open Sans Light':      { cssDefault: 'sans-serif', fontProps: { pitch: 'variable', altNames: ['Open Sans'] }, hidden: true },
-        'Open Sans Semibold':   { cssDefault: 'sans-serif', fontProps: { pitch: 'variable', altNames: ['Open Sans'] }, hidden: true },
-        'Open Sans Extrabold':  { cssDefault: 'sans-serif', fontProps: { pitch: 'variable', altNames: ['Open Sans Semibold'] }, hidden: true },
+        Times:                  { cssDefault: 'serif', fontProps: { pitch: 'variable', altNames: ['Times New Roman'] } },
+        'Times New Roman':      { cssDefault: 'serif', fontProps: { pitch: 'variable', altNames: ['Times'] }, display: true },
+        Georgia:                { cssDefault: 'serif', fontProps: { pitch: 'variable', altNames: ['Times New Roman'] }, display: true },
+        Palatino:               { cssDefault: 'serif', fontProps: { pitch: 'variable', altNames: ['Times New Roman'] }, display: true },
+        'Book Antiqua':         { cssDefault: 'serif', fontProps: { pitch: 'variable', altNames: ['Palatino'] }, display: true },
+        Cambria:                { cssDefault: 'serif', fontProps: { pitch: 'variable', altNames: ['Caladea', 'Times New Roman'] }, display: true },
+        Caladea:                { cssDefault: 'serif', fontProps: { pitch: 'variable', altNames: ['Cambria', 'Times New Roman'] } },
+        Thorndale:              { cssDefault: 'serif', fontProps: { pitch: 'variable', altNames: ['Liberation Serif', 'Times New Roman'] } }, // old OOo default for serif
+        'Liberation Serif':     { cssDefault: 'serif', fontProps: { pitch: 'variable', altNames: ['Thorndale', 'Times New Roman'] }, display: 'odf' }, // LO default for serif
+        'Calisto MT':           { cssDefault: 'serif', fontProps: { pitch: 'variable', altNames: ['Book Antiqua'] } },
 
-        Times:                  { cssDefault: 'serif', fontProps: { pitch: 'variable', altNames: ['Times New Roman'] }, hidden: true },
-        'Times New Roman':      { cssDefault: 'serif', fontProps: { pitch: 'variable', altNames: ['Times'] } },
-        Georgia:                { cssDefault: 'serif', fontProps: { pitch: 'variable', altNames: ['Times New Roman'] } },
-        Palatino:               { cssDefault: 'serif', fontProps: { pitch: 'variable', altNames: ['Times New Roman'] } },
-        Cambria:                { cssDefault: 'serif', fontProps: { pitch: 'variable', altNames: ['Caladea', 'Times New Roman'] } },
-        Caladea:                { cssDefault: 'serif', fontProps: { pitch: 'variable', altNames: ['Cambria', 'Times New Roman'] }, hidden: true },
-        Thorndale:              { cssDefault: 'serif', fontProps: { pitch: 'variable', altNames: ['Times New Roman'] }, hidden: true },
-        'Book Antiqua':         { cssDefault: 'serif', fontProps: { pitch: 'variable', altNames: ['Palatino'] } },
-        'Calisto MT':           { cssDefault: 'serif', fontProps: { pitch: 'variable', altNames: ['Book Antiqua'] }, hidden: true },
-
-        Courier:                { cssDefault: 'monospace', fontProps: { pitch: 'fixed', altNames: ['Courier New'] }, hidden: true },
-        'Courier New':          { cssDefault: 'monospace', fontProps: { pitch: 'fixed', altNames: ['Courier'] } },
-        'Andale Mono':          { cssDefault: 'monospace', fontProps: { pitch: 'fixed', altNames: ['Courier New'] } },
-        Consolas:               { cssDefault: 'monospace', fontProps: { pitch: 'fixed', altNames: ['Courier New'] } },
-        Cumberland:             { cssDefault: 'monospace', fontProps: { pitch: 'fixed', altNames: ['Courier New'] }, hidden: true }
+        Courier:                { cssDefault: 'monospace', fontProps: { pitch: 'fixed', altNames: ['Courier New'] } },
+        'Courier New':          { cssDefault: 'monospace', fontProps: { pitch: 'fixed', altNames: ['Courier'] },     display: true },
+        'Andale Mono':          { cssDefault: 'monospace', fontProps: { pitch: 'fixed', altNames: ['Courier New'] }, display: true },
+        Consolas:               { cssDefault: 'monospace', fontProps: { pitch: 'fixed', altNames: ['Courier New'] }, display: true },
+        Cumberland:             { cssDefault: 'monospace', fontProps: { pitch: 'fixed', altNames: ['Liberation Mono', 'Courier New'] } }, // old OOo default for monospace
+        'Liberation Mono':      { cssDefault: 'monospace', fontProps: { pitch: 'fixed', altNames: ['Cumberland', 'Courier New'] }, display: 'odf' } // LO default for monospace
     };
 
     // a regular expression that matches valid font names
@@ -72,6 +74,59 @@ define('io.ox/office/editframework/model/fontcollection', [
     // key in localStorage were blockDownloadToken token is saved
     var LOCAL_STORAGE_BLOCK_FONT_DOWNLOAD_KEY = LOCAL_STORAGE_FONT_KEY + '-do-not-download-again';
 
+    // web font name that is used in debug mode
+    var DEBUG_FONT_NAME = 'oxdebugwebfontox';
+
+    // private global functions ===============================================
+
+    // Calculates and returns the container width for the given font.
+    // When this font is not available, it uses the fallback font and
+    // therefore returns the container width for the fallback font.
+    function calcFontMetric(font) {
+
+        // container for calculation, with the font and the fallback font attached, it's moved offscreen
+        var hiddenCalcContainer = $('<div style="position:absolute; width:auto; font-size: 100px; left:-9000px; font-family:' + font + ';">');
+        // the span with a string for measurements
+        var textToMeasure = $('<span>abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234</span>');
+
+        $('body').append(hiddenCalcContainer.append(textToMeasure));
+        var fontWidth = hiddenCalcContainer.outerWidth();
+        hiddenCalcContainer.remove();
+        return fontWidth;
+    }
+
+    /**
+     * Check if the the given font is available in the browser. It's available
+     * when it is installed at the client or when it is already in the DOM as a web font.
+     * It was created to work with Calibri', 'Carlito', 'Cambria' and 'Caladea', so in other
+     * cases see the restriction below.
+     *
+     * Important restriction: This does only work 100% reliable for the fonts 'Calibri', 'Carlito',
+     * 'Cambria' and 'Caladea' at the moment. That said, it should work for all fonts that have a
+     * different metric to 'monospace'. So just check if the detection for the font that should
+     * be checked works when installed and when not installed.
+     *
+     * But to be reliable for every font without checking it before, this function needs to be enhanced
+     * with at least a second check in addition to the monospace font.
+     */
+    function isFontAvailableInBrowser(font) {
+
+        // width from the container with the test font
+        var testFontWidth = calcFontMetric(font + ',monospace');
+        // width from the container with the fallback font
+        var monoFontWidth = calcFontMetric('monospace');
+
+        // When the testFontWidth is equal to the fallbackFontWidth it means that the testFont was not used by the browser.
+        // Therefore the font is available when both width values are different.
+        return testFontWidth !== monoFontWidth;
+    }
+
+    // When used with 'office:testautomation=true', the importReplacementFonts is tested with a own, unique font (see 'debugFontName') that doesn't exists on Windows and Linux.
+    // Since Calibri and Cambria are system fonts in Windows, it would not work otherwise. In Linux 'Fontconfig' may generate Calibri replacement fonts on OS level that are not possible to detect.
+    function debugReplacementFonts() {
+        return !Config.AUTOTEST || isFontAvailableInBrowser(DEBUG_FONT_NAME);
+    }
+
     // class FontCollection ===================================================
 
     /**
@@ -90,10 +145,13 @@ define('io.ox/office/editframework/model/fontcollection', [
      * @param {EditModel} docModel
      *  The document model containing this instance.
      */
-    function FontCollection(docModel) {
+    var FontCollection = ModelObject.extend({ constructor: function (docModel) {
 
         // all registered fonts, mapped by capitalized font name
-        var fontMap = new SimpleMap();
+        var fontMap = new ValueMap();
+
+        // special handling for different file formats
+        var fileFormat = docModel.getApp().getFileFormat();
 
         var debugStateImportReplacementFonts = {
             fontLoadedWithAjax: false,
@@ -178,83 +236,32 @@ define('io.ox/office/editframework/model/fontcollection', [
             return cssFontNames.join(',');
         }
 
-        /**
-         * Check if the the given font is available in the browser. It's available
-         * when it is installed at the client or when it is already in the DOM as a web font.
-         * It was created to work with Calibri', 'Carlito', 'Cambria' and 'Caladea', so in other
-         * cases see the restriction below.
-         *
-         * Important restriction: This does only work 100% reliable for the fonts 'Calibri', 'Carlito',
-         * 'Cambria' and 'Caladea' at the moment. That said, it should work for all fonts that have a
-         * different metric to 'monospace'. So just check if the detection for the font that should
-         * be checked works when installed and when not installed.
-         *
-         * But to be reliable for every font without checking it before, this function needs to be enhanced
-         * with at least a second check in addition to the monospace font.
-         */
-        function isFontAvailableInBrowser(font) {
-            var // width from the container with the test font
-                testFontWidth,
-                // width from the container with the fallback font
-                fallbackFontWidth,
-                // name from the fallback font that is compared against the test font
-                fallBackFont = 'monospace';
-
-            // Calculates and returns the container width for the given font.
-            // When this font is not available, it uses the fallback font and
-            // therefore returns the container width for the fallback font.
-            function calcFontMetric(font, fontFallback) {
-                var
-                    // were the hiddenCalcContainer is appended
-                    rootNode = $('body'),
-                    // container for calculation, with the font and the fallback font attached, it's moved offscreen
-                    hiddenCalcContainer = $('<div style="position:absolute; width:auto; font-size: 100px; left:-9000px; font-family:' + font + ',' + fontFallback + ';"</div>'),
-                    // the span with a string for measurements
-                    textToMeasure = $('<span>abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234</span>'),
-                    // width from the container with the current font
-                    fontWidth;
-
-                rootNode.append(hiddenCalcContainer.append(textToMeasure));
-                fontWidth = hiddenCalcContainer.outerWidth();
-                hiddenCalcContainer.remove();
-                return fontWidth;
-            }
-
-            testFontWidth = calcFontMetric(font, fallBackFont);
-            fallbackFontWidth = calcFontMetric(fallBackFont, fallBackFont);
-
-            // When the testFontWidth is equal to the fallbackFontWidth it means that the testFont was not used by the browser.
-            // Therefore the font is available when both width values are different.
-            return testFontWidth !== fallbackFontWidth;
-        }
-
-        // public methods -----------------------------------------------------
+        // protected methods --------------------------------------------------
 
         /**
-         * Inserts a new font definition into this container. An existing font
-         * definition with the specified name will be replaced.
+         * Callback handler for the document operation 'insertFontDescription'.
+         * Inserts a new font entry into this collection.
          *
-         * @param {String} fontName
-         *  The name of of the new font.
+         * @param {OperationContext} context
+         *  A wrapper representing the 'insertFontDescription' document
+         *  operation.
          *
-         * @param {Object} fontProps
-         *  The definition properties of the font.
-         *
-         * @returns {FontCollection}
-         *  A reference to this instance.
+         * @throws {OperationError}
+         *  If applying the operation fails, e.g. if a required property is
+         *  missing in the operation.
          */
-        this.insertFont = function (fontName, fontProps) {
+        this.applyInsertFontOperation = function (context) {
 
             // fonts are keyed by capitalized names
-            fontName = Utils.capitalizeWords(fontName);
+            var fontName = Utils.capitalizeWords(context.getStr('fontName'));
 
             // store passed font attributes
-            fontProps = _.copy(fontProps, true);
-            var fontDesc = fontMap.insert(fontName, { fontProps: fontProps, hidden: false });
+            var fontProps = _.copy(context.getObj('attrs'), true);
+            var fontDesc = fontMap.insert(fontName, { fontProps: fontProps, display: true });
 
             // validate alternative names
             if (_.isArray(fontProps.altNames)) {
-                fontProps.altNames = _.chain(fontProps.altNames).without('').map(Utils.capitalizeWords).value();
+                fontProps.altNames = fontProps.altNames.filter(_.identity).map(Utils.capitalizeWords);
             } else {
                 fontProps.altNames = [];
             }
@@ -274,10 +281,10 @@ define('io.ox/office/editframework/model/fontcollection', [
             // remove calculated CSS font families of all fonts, notify listeners
             deleteAllCssFontFamilies();
             this.trigger('insert:font', fontName);
-
-            return this;
         };
 
+        // public methods -----------------------------------------------------
+
         /**
          * Returns the names of all predefined and registered fonts. Predefined
          * fonts with the hidden flag that have not been registered will not be
@@ -288,7 +295,9 @@ define('io.ox/office/editframework/model/fontcollection', [
          */
         this.getFontNames = function () {
             return fontMap.reduce([], function (fontNames, fontDesc, fontName) {
-                if (!fontDesc.hidden) { fontNames.push(fontName); }
+                if ((fontDesc.display === true) || (fontDesc.display === fileFormat)) {
+                    fontNames.push(fontName);
+                }
                 return fontNames;
             });
         };
@@ -300,17 +309,11 @@ define('io.ox/office/editframework/model/fontcollection', [
          * @param {String} fontName
          *  The name of of the font (case-insensitive).
          *
-         * @param {Theme} [theme]
-         *  The document theme used to resolve abstract font names.
-         *
          * @returns {String}
          *  The value of the CSS 'font-family' attribute containing the
          *  specified font name and all alternative font names.
          */
-        this.getCssFontFamily = function (fontName, theme) {
-
-            // resolve abstract font names from the passed document theme
-            if (theme) { fontName = theme.getFontName(fontName); }
+        this.getCssFontFamily = function (fontName) {
 
             // fonts are keyed by capitalized names
             fontName = Utils.capitalizeWords(fontName);
@@ -327,183 +330,6 @@ define('io.ox/office/editframework/model/fontcollection', [
             return fontDesc.cssFontFamily;
         };
 
-        /**
-         * Calculates the scaled font size for the passed font size and zoom
-         * factor.
-         *
-         * @param {Number} fontSize
-         *  The original font size, in points.
-         *
-         * @param {Number} [zoom=1]
-         *  The zoom factor. The value 1 represents the normal zoom (of 100%).
-         *
-         * @returns {Number}
-         *  The scaled font size, in points, rounded to 1/10 of points.
-         */
-        this.getScaledFontSize = function (fontSize, zoom) {
-            if (typeof zoom === 'number') { fontSize *= zoom; }
-            return Utils.round(fontSize, 0.1);
-        };
-
-        /**
-         * Converts the passed character formatting attributes to a font
-         * descriptor, according to the font registered in this collection, and
-         * the passed zoom factor.
-         *
-         * @param {Object} charAttributes
-         *  The character formatting attributes, as used in operations, to be
-         *  converted to the CSS font style, with the following properties:
-         *  @param {String} charAttributes.fontName
-         *      The original font name (case-insensitive).
-         *  @param {Number} charAttributes.fontSize
-         *      The original font size, in points.
-         *  @param {Boolean} [charAttributes.bold=false]
-         *      Whether the text will be rendered in bold characters.
-         *  @param {Boolean} [charAttributes.italic=false]
-         *      Whether the text will be rendered in italic characters.
-         *
-         * @param {Object} [options]
-         *  Optional parameters:
-         *  @param {Theme} [options.theme]
-         *      The document theme used to resolve abstract font names.
-         *  @param {Number} [options.zoom=1]
-         *      The zoom factor used to scale the font size. The value 1 (the
-         *      default of this option) represents the normal zoom (of 100%).
-         *
-         * @returns {Font}
-         *  The resulting font. The property 'family' includes all known
-         *  fall-back fonts for the font. The property 'size' contains the font
-         *  size as number (scaled according to the zoom factor if specified).
-         */
-        this.getFont = function (charAttributes, options) {
-            return new Font(
-                this.getCssFontFamily(charAttributes.fontName, Utils.getOption(options, 'theme', null)),
-                this.getScaledFontSize(charAttributes.fontSize, Utils.getNumberOption(options, 'zoom', 1)),
-                charAttributes.bold,
-                charAttributes.italic
-            );
-        };
-
-        /**
-         * Calculates the normal line height for the passed character
-         * attributes, as reported by the current browser. Note that this value
-         * may vary for the same font settings in different browsers.
-         *
-         * @param {Object} charAttributes
-         *  The character formatting attributes, as used in operations. See
-         *  method FontCollection.getFont() for details.
-         *
-         * @param {Object} [options]
-         *  Optional parameters. See method FontCollection.getFont() for
-         *  details.
-         *
-         * @returns {Number}
-         * The normal line height for the specified font, in pixels (with a
-         * precision of 1/100 pixel for browsers using fractional line heights
-         * internally).
-         */
-        this.getNormalLineHeight = function (charAttributes, options) {
-            return this.getFont(charAttributes, options).getNormalLineHeight();
-        };
-
-        /**
-         * Calculates the position of the font base line for the passed
-         * character attributes and line height, as reported by the current
-         * browser. Note that this value may vary for the same font settings in
-         * different browsers.
-         *
-         * @param {Object} charAttributes
-         *  The character formatting attributes, as used in operations. See
-         *  method FontCollection.getFont() for details.
-         *
-         * @param {Number} [lineHeight]
-         *  The line height to be used to determine the position of the font
-         *  base line. If omitted, the normal line height, as reported by the
-         *  method FontCollection.getNormalLineHeight(), will be used.
-         *
-         * @param {Object} [options]
-         *  Optional parameters. See method FontCollection.getFont() for
-         *  details.
-         *
-         * @returns {Number}
-         *  The position of the font base line for the passed character
-         *  attributes and line height, in pixels, relative to the top border
-         *  of the text line.
-         */
-        this.getBaseLineOffset = function (charAttributes, lineHeight, options) {
-            return this.getFont(charAttributes, options).getBaseLineOffset(lineHeight);
-        };
-
-        /**
-         * Returns the effective width of the passed text, in pixels.
-         *
-         * @param {Object} charAttributes
-         *  The character formatting attributes, as used in operations. See
-         *  method FontCollection.getFont() for details.
-         *
-         * @param {String} text
-         *  The text whose width will be calculated. If the text consists of
-         *  one character only, the calculated text width will be cached
-         *  internally for subsequent invocations with the same text and
-         *  character attributes.
-         *
-         * @param {Object} [options]
-         *  Optional parameters. See method FontCollection.getFont() for
-         *  details.
-         *
-         * @returns {Number}
-         *  The effective width of the passed text, in pixels.
-         */
-        this.getTextWidth = function (charAttributes, text, options) {
-            // empty string: always zero (do not create a font)
-            return (text.length === 0) ? 0 : this.getFont(charAttributes, options).getTextWidth(text);
-        };
-
-        /**
-         * Returns measures for the digits '0' to '9'.
-         *
-         * @param {Object} charAttributes
-         *  The character formatting attributes, as used in operations. See
-         *  method FontCollection.getFont() for details.
-         *
-         * @param {Object} [options]
-         *  Optional parameters. See method FontCollection.getFont() for
-         *  details.
-         *
-         * @returns {Array<Number>}
-         *  An array with the widths of the digits '0' to '9', in pixels, and
-         *  additional properties. See method Font.getDigitWidths() for more
-         *  details.
-         */
-        this.getDigitWidths = function (charAttributes, options) {
-            return this.getFont(charAttributes, options).getDigitWidths();
-        };
-
-        /**
-         * Splits the passed string to text lines that all fit into the passed
-         * width, using the specified font settings.
-         *
-         * @param {Object} charAttributes
-         *  The character formatting attributes, as used in operations. See
-         *  method FontCollection.getFont() for details.
-         *
-         * @param {String} text
-         *  The text that will be split into single text lines.
-         *
-         * @param {Number} width
-         *  The maximum width of the text lines, in pixels.
-         *
-         * @param {Object} [options]
-         *  Optional parameters. See method FontCollection.getFont() for
-         *  details.
-         *
-         * @returns {Array}
-         *  An array of strings containing the single text lines.
-         */
-        this.getTextLines = function (charAttributes, text, width, options) {
-            return this.getFont(charAttributes, options).getTextLines(text, width);
-        };
-
         /**
          * Make replacement fonts for 'Calibri' and 'Cambria' available in the browser,
          * when neither these two nor the replacement fonts exists on the client.
@@ -513,8 +339,8 @@ define('io.ox/office/editframework/model/fontcollection', [
          * stored in localStorage and added to the DOM to be useable.
          *
          * font data:
-         * The replacement fonts (tk/fonts/fonts.css) are base64 encoded woff files that are
-         * attached directly to the <head> in the DOM.
+         * The replacement fonts (io.ox/office/tk/render/fonts.css) are base64 encoded woff
+         * files that are attached directly to the <head> in the DOM.
          *
          * Already stored:
          * When the replacement fonts are already in localStorage, they don't need to be loaded
@@ -547,25 +373,13 @@ define('io.ox/office/editframework/model/fontcollection', [
         this.importReplacementFonts = function () {
 
             var
-                loadDeferred = DeferredUtils.createDeferred(docModel.getApp(), 'FontCollection.importReplacementFonts()'),
+                loadDeferred = Scheduler.createDeferred(docModel, 'FontCollection.importReplacementFonts'),
                 // whether 'Calibri' or the metric compatible replacement 'Carlito' is available at the device
                 calibriOrReplacementAvailible = isFontAvailableInBrowser('Calibri') || isFontAvailableInBrowser('Carlito'),
                 // whether 'Cambria' or the metric compatible replacement 'Caladea' is available at the device
                 cambriaOrReplacementAvailible = isFontAvailableInBrowser('Cambria') || isFontAvailableInBrowser('Caladea'),
-                // data from the localStorage
-                localStorageData,
                 // whether a possible font download should be allowed
-                blockDownloadToken = false,
-                // needed as an exit condition/timeout
-                pollingStartTime,
-                // web font name that is used in debug mode
-                debugFontName = 'oxdebugwebfontox';
-
-            // When used with 'office:testautomation=true', the importReplacementFonts is tested with a own, unique font (see 'debugFontName') that doesn't exists on Windows and Linux.
-            // Since Calibri and Cambria are system fonts in Windows, it would not work otherwise. In Linux 'Fontconfig' may generate Calibri replacement fonts on OS level that are not possible to detect.
-            function debugReplacementFonts() {
-                return !Config.AUTOTEST || isFontAvailableInBrowser(debugFontName);
-            }
+                blockDownloadToken = false;
 
             // Attach the CSS content which contains the web font to DOM
             function addFontToDOM(cssFontData) {
@@ -575,23 +389,22 @@ define('io.ox/office/editframework/model/fontcollection', [
                     $('head').append('<style type="text/css">' + cssFontData + '</style>');
 
                     // insert a hidden node to reference the replacement fonts in the DOM. This starts using the font-face rule (note: 'A' is a used glyph in 'debugFontName' font )
-                    Utils.insertHiddenNodes($('<div class="font-preloading-helper"><div style="font-family: Carlito;">g</div><div style="font-family: Caladea;">g</div><div style="font-family: ' +  debugFontName + ';">A</div></div>'));
+                    Utils.insertHiddenNodes($('<div class="font-preloading-helper"><div style="font-family:Carlito;">g</div><div style="font-family:Caladea;">g</div><div style="font-family:' +  DEBUG_FONT_NAME + ';">A</div></div>'));
 
                     // trigger a reflow in the browser, at least Chrome needs this to make
                     // the font really available for rendering in the browser
                     Utils.findHiddenNodes('.font-preloading-helper').outerWidth();
 
-                    pollingStartTime = Date.now();
-
                     // Check and resolve the Promise if the font is available in the browser. This must
                     // be checked async, because when the code runs synchronous e.g. Chrome is not able to make
                     // the font available for rendering in the browser. This check should normally resolve with
                     // true in the first round, but browser can behave differently here. So better be save and
                     // check until the font is finally available or the interval is timed out.
+                    var pollingStartTime = Date.now();
                     var isFontLoadedInBrowserPolling = window.setInterval(function () {
 
                         // exit condition: break when the font is still not ready in the browser after 2000ms
-                        if ((2000 < (Date.now() - pollingStartTime))) {
+                        if (2000 < (Date.now() - pollingStartTime)) {
                             //console.log(Date.now() - pollingStartTime);
                             window.clearInterval(isFontLoadedInBrowserPolling);
                             loadDeferred.resolve();
@@ -614,7 +427,7 @@ define('io.ox/office/editframework/model/fontcollection', [
 
             // only for debug
             Utils.withLogging(function () {
-                Utils.log('ImportReplacementFonts - Calibri:', isFontAvailableInBrowser('Calibri'), ' - Carlito:', isFontAvailableInBrowser('Carlito'), ' - Cambria:', isFontAvailableInBrowser('Cambria'), ' - Caladea:', isFontAvailableInBrowser('Caladea'), '| FontDebugMode:', Config.AUTOTEST, '- ' + debugFontName + ':', isFontAvailableInBrowser(debugFontName));
+                Utils.log('ImportReplacementFonts - Calibri:', isFontAvailableInBrowser('Calibri'), ' - Carlito:', isFontAvailableInBrowser('Carlito'), ' - Cambria:', isFontAvailableInBrowser('Cambria'), ' - Caladea:', isFontAvailableInBrowser('Caladea'), '| FontDebugMode:', Config.AUTOTEST, '- ' + DEBUG_FONT_NAME + ':', isFontAvailableInBrowser(DEBUG_FONT_NAME));
             });
 
             // check if font or replacement is installed locally, or already available in the browser
@@ -627,7 +440,7 @@ define('io.ox/office/editframework/model/fontcollection', [
             // when font is not available in the browser
             } else {
                 // get the data from local storage
-                localStorageData = localStorage.getItem(LOCAL_STORAGE_FONT_KEY);
+                var localStorageData = localStorage.getItem(LOCAL_STORAGE_FONT_KEY);
 
                 // add font when it's cached in localStorage
                 if (localStorageData !== null && localStorageData !== undefined) {
@@ -653,7 +466,7 @@ define('io.ox/office/editframework/model/fontcollection', [
 
                         // get the css file which contains the base64 encoded fonts
                         $.ajax({
-                            url: ox.root + '/apps/io.ox/office/tk/render/font.css',
+                            url: ox.root + '/apps/io.ox/office/tk/render/fonts.css',
                             dataType: 'text',
                             timeout: 40000 // with 3G 512 kbit/s the 1.7mb font.css needs about 27s to download, add some safety buffer
                         }).done(function (data) {
@@ -697,7 +510,9 @@ define('io.ox/office/editframework/model/fontcollection', [
                 }
             }
 
-            return docModel.createAbortablePromise(loadDeferred, function () { Utils.warn('ImportReplacementFonts -  Promise aborted'); });
+            return docModel.createAbortablePromise(loadDeferred, function () {
+                Utils.warn('ImportReplacementFonts -  Promise aborted');
+            });
         };
 
         /**
@@ -724,7 +539,7 @@ define('io.ox/office/editframework/model/fontcollection', [
             docModel = fontMap = null;
         });
 
-    } // class FontCollection
+    } }); // class FontCollection
 
     // static methods ---------------------------------------------------------
 
@@ -753,7 +568,6 @@ define('io.ox/office/editframework/model/fontcollection', [
 
     // exports ================================================================
 
-    // derive this class from class ModelObject
-    return ModelObject.extend({ constructor: FontCollection });
+    return FontCollection;
 
 });
