@@ -130,8 +130,8 @@ define('io.ox/office/editframework/utils/border', [
      * @param {Object} border
      *  The border object as used in operations.
      *
-     * @param {Theme} theme
-     *  The theme object used to map scheme color names to color values.
+     * @param {ThemeModel} themeModel
+     *  The model of the theme used to map scheme color names to color values.
      *
      * @param {Object} [options]
      *  Optional parameters:
@@ -153,13 +153,13 @@ define('io.ox/office/editframework/utils/border', [
      *  and the property 'color' with the effective CSS color (as string with
      *  leading hash sign).
      */
-    Border.getCssBorderAttributes = function (border, theme, options) {
+    Border.getCssBorderAttributes = function (border, themeModel, options) {
 
-        var style = Utils.getStringOption(border, 'style', 'none'),
-            width = Utils.getIntegerOption(border, 'width', 0),
-            color = Utils.getObjectOption(border, 'color', Color.AUTO),
-            preview = Utils.getBooleanOption(options, 'preview', false),
-            autoColor = Utils.getObjectOption(options, 'autoColor');
+        var style = Utils.getStringOption(border, 'style', 'none');
+        var width = Utils.getIntegerOption(border, 'width', 0);
+        var color = Utils.getObjectOption(border, 'color', Color.AUTO);
+        var preview = Utils.getBooleanOption(options, 'preview', false);
+        var autoColor = Utils.getObjectOption(options, 'autoColor');
 
         // convert operation line styles to CSS styles
         style = Border.getCssBorderStyle(style);
@@ -187,7 +187,7 @@ define('io.ox/office/editframework/utils/border', [
         width = (width > 0) ? Math.max(Math.round(width), 1) : 0;
 
         // resolve color object to CSS color value
-        return { style: style, width: width, color: color.resolve(autoColor || 'line', theme).css };
+        return { style: style, width: width, color: color.resolve(autoColor || 'line', themeModel).css };
     };
 
     /**
@@ -196,8 +196,8 @@ define('io.ox/office/editframework/utils/border', [
      * @param {Object} border
      *  The border object as used in operations.
      *
-     * @param {Theme} theme
-     *  The theme object used to map scheme color names to color values.
+     * @param {ThemeModel} themeModel
+     *  The model of the theme used to map scheme color names to color values.
      *
      * @param {Object} [options]
      *  Optional parameters. Supports all options supported by the method
@@ -210,9 +210,11 @@ define('io.ox/office/editframework/utils/border', [
      * @returns {String}
      *  The CSS border value converted from the passed border object.
      */
-    Border.getCssBorder = function (border, theme, options) {
-        var visible = Border.isVisibleBorder(border),
-            attributes = visible ? Border.getCssBorderAttributes(border, theme, options) : null;
+    Border.getCssBorder = function (border, themeModel, options) {
+
+        var visible = Border.isVisibleBorder(border);
+        var attributes = visible ? Border.getCssBorderAttributes(border, themeModel, options) : null;
+
         return visible ? (attributes.style + ' ' + attributes.width + 'px ' + attributes.color) :
             Utils.getBooleanOption(options, 'clearNone', false) ? '' : 'none';
     };
