@@ -21,10 +21,18 @@ define('io.ox/office/editframework/utils/color', [
     'use strict';
 
     // convenience shortcuts
+    var round = Math.round;
+    var max = Math.max;
+    var minMax = Utils.minMax;
+
+    // helper classes
     var RGBModel = ColorUtils.RGBModel;
     var HSLModel = ColorUtils.HSLModel;
     var ColorDescriptor = ColorUtils.ColorDescriptor;
 
+    // hue channel conversion factor (units per degree)
+    var HUE_PER_DEG = 60000;
+
     // the gamma correction factors (intended to be similar to MSO)
     var INV_GAMMA = 2.27;
     var GAMMA = 1 / INV_GAMMA;
@@ -57,7 +65,7 @@ define('io.ox/office/editframework/utils/color', [
         lightGrey: 'd3d3d3',        lightPink: 'ffb6c1',            lightSalmon: 'ffa07a',      lightSeaGreen: '20b2aa',
         lightSkyBlue: '87cefa',     lightSlateGray: '778899',       lightSlateGrey: '778899',   lightSteelBlue: 'b0c4de',
         lightYellow: 'ffffe0',      lime: '00ff00',                 limeGreen: '32cd32',        linen: 'faf0e6',
-        ltBlue: 'add8e6',           ltCoral: 'f08080',              ltCyan: 'e0ffff',           ltGoldenrodYellow: 'fafa78',
+        ltBlue: 'add8e6',           ltCoral: 'f08080',              ltCyan: 'e0ffff',           ltGoldenrodYellow: 'fafad2',
         ltGray: 'd3d3d3',           ltGreen: '90ee90',              ltGrey: 'd3d3d3',           ltPink: 'ffb6c1',
         ltSalmon: 'ffa07a',         ltSeaGreen: '20b2aa',           ltSkyBlue: '87cefa',        ltSlateGray: '778899',
         ltSlateGrey: '778899',      ltSteelBlue: 'b0c4de',          ltYellow: 'ffffe0',         magenta: 'ff00ff',
@@ -97,6 +105,28 @@ define('io.ox/office/editframework/utils/color', [
 
     // private static functions ===============================================
 
+    /**
+     * Returns the specified integer property from a JSON object, normalizes
+     * the number by the specified scaling factor, but does not restrict it any
+     * further.
+     *
+     * @param {Object} json
+     *  An arbitrary JSON object.
+     *
+     * @param {String} prop
+     *  The name of an integer property to be extracted from the JSON object.
+     *  If the property does not exist, this function returns zero.
+     *
+     * @param {Number} scale
+     *  The scaling factor the number will be divided by. MUST be positive.
+     *
+     * @returns {Number}
+     *  The normalized value of the specified property.
+     */
+    function getScaledNum(json, prop, scale) {
+        return Utils.getIntegerOption(json, prop, 0) / scale;
+    }
+
     /**
      * Returns the specified integer property from a JSON object, normalizes
      * the number, but does not restrict it any further.
@@ -112,7 +142,7 @@ define('io.ox/office/editframework/utils/color', [
      *  The normalized value of the specified property.
      */
     function getNum(json, prop) {
-        return Utils.getIntegerOption(json, prop, 0) / 100000;
+        return getScaledNum(json, prop, 100000);
     }
 
     /**
@@ -131,7 +161,7 @@ define('io.ox/office/editframework/utils/color', [
      *  non-negative numbers.
      */
     function getPosNum(json, prop) {
-        return Utils.getIntegerOption(json, prop, 0, 0) / 100000;
+        return max(getScaledNum(json, prop, 100000), 0);
     }
 
     /**
@@ -150,7 +180,7 @@ define('io.ox/office/editframework/utils/color', [
      *  interval [0;1].
      */
     function getLimNum(json, prop) {
-        return Utils.getIntegerOption(json, prop, 0, 0, 100000) / 100000;
+        return minMax(getScaledNum(json, prop, 100000), 0, 1);
     }
 
     // color transformations ==================================================
@@ -162,21 +192,21 @@ define('io.ox/office/editframework/utils/color', [
         alphaMod: function (model, transform) { return model.modulate('a', getPosNum(transform, 'value')); },
         alphaOff: function (model, transform) { return model.offset('a', getNum(transform, 'value')); },
 
-        red:      function (model, transform) { return model.toRGB().set('r', getNum(transform, 'value')); },
-        redMod:   function (model, transform) { return model.toRGB().modulate('r', getPosNum(transform, 'value')); },
-        redOff:   function (model, transform) { return model.toRGB().offset('r', getNum(transform, 'value')); },
+        red:      function (model, transform) { return model.toRGB().setGamma('r', getNum(transform, 'value'), GAMMA); },
+        redMod:   function (model, transform) { return model.toRGB().modulateGamma('r', getPosNum(transform, 'value'), GAMMA); },
+        redOff:   function (model, transform) { return model.toRGB().offsetGamma('r', getNum(transform, 'value'), GAMMA); },
 
-        green:    function (model, transform) { return model.toRGB().set('g', getNum(transform, 'value')); },
-        greenMod: function (model, transform) { return model.toRGB().modulate('g', getPosNum(transform, 'value')); },
-        greenOff: function (model, transform) { return model.toRGB().offset('g', getNum(transform, 'value')); },
+        green:    function (model, transform) { return model.toRGB().setGamma('g', getNum(transform, 'value'), GAMMA); },
+        greenMod: function (model, transform) { return model.toRGB().modulateGamma('g', getPosNum(transform, 'value'), GAMMA); },
+        greenOff: function (model, transform) { return model.toRGB().offsetGamma('g', getNum(transform, 'value'), GAMMA); },
 
-        blue:     function (model, transform) { return model.toRGB().set('b', getNum(transform, 'value')); },
-        blueMod:  function (model, transform) { return model.toRGB().modulate('b', getPosNum(transform, 'value')); },
-        blueOff:  function (model, transform) { return model.toRGB().offset('b', getNum(transform, 'value')); },
+        blue:     function (model, transform) { return model.toRGB().setGamma('b', getNum(transform, 'value'), GAMMA); },
+        blueMod:  function (model, transform) { return model.toRGB().modulateGamma('b', getPosNum(transform, 'value'), GAMMA); },
+        blueOff:  function (model, transform) { return model.toRGB().offsetGamma('b', getNum(transform, 'value'), GAMMA); },
 
-        hue:      function (model, transform) { return model.toHSL().set('h', Utils.getIntegerOption(transform, 'value', 0) / 1000, 360); },
-        hueMod:   function (model, transform) { return model.toHSL().modulate('h', getPosNum(transform, 'value'), 360); },
-        hueOff:   function (model, transform) { return model.toHSL().offset('h', Utils.getIntegerOption(transform, 'value', 0) / 1000, 360); },
+        hue:      function (model, transform) { return model.toHSL().setH(getScaledNum(transform, 'value', HUE_PER_DEG)); },
+        hueMod:   function (model, transform) { return model.toHSL().modulateH(getPosNum(transform, 'value')); },
+        hueOff:   function (model, transform) { return model.toHSL().offsetH(getScaledNum(transform, 'value', HUE_PER_DEG)); },
 
         sat:      function (model, transform) { return model.toHSL().set('s', getNum(transform, 'value')); },
         satMod:   function (model, transform) { return model.toHSL().modulate('s', getPosNum(transform, 'value')); },
@@ -186,14 +216,14 @@ define('io.ox/office/editframework/utils/color', [
         lumMod:   function (model, transform) { return model.toHSL().modulate('l', getPosNum(transform, 'value')); },
         lumOff:   function (model, transform) { return model.toHSL().offset('l', getNum(transform, 'value')); },
 
-        shade:    function (model, transform) { return model.toHSL().darken(1 - getLimNum(transform, 'value')); },
-        tint:     function (model, transform) { return model.toHSL().lighten(1 - getLimNum(transform, 'value')); },
+        shade:    function (model, transform) { return model.toRGB().darkenGamma(1 - getPosNum(transform, 'value'), GAMMA); },
+        tint:     function (model, transform) { return model.toRGB().lightenGamma(1 - getPosNum(transform, 'value'), GAMMA); },
 
         gamma:    function (model) { return model.toRGB().gamma(GAMMA); },
         invGamma: function (model) { return model.toRGB().gamma(INV_GAMMA); },
 
         comp:     function (model) { return model.toHSL().comp(); },
-        inv:      function (model) { return model.toRGB().inv(); },
+        inv:      function (model) { return model.toRGB().invGamma(GAMMA); },
         gray:     function (model) { return model.toRGB().gray(); }
     };
 
@@ -224,8 +254,8 @@ define('io.ox/office/editframework/utils/color', [
      *      of them in the interval [0;100000] (representing 0% to 100%).
      *  - 'rgb': A string with a 6-digit hexadecimal character (RRGGBB).
      *  - 'hsl': An object with the integer properties 'h', 's', and 'l'. The
-     *      property 'h' is expected to be in the interval [0;359999]
-     *      (representing 1/1000 of degrees), the other properties have to be
+     *      property 'h' is expected to be in the interval [0;21599999]
+     *      (representing 1/60000 of degrees), the other properties have to be
      *      in the interval [0;100000] (representing 0% to 100%).
      *
      * @param {Array<Object>} [transforms]
@@ -242,340 +272,342 @@ define('io.ox/office/editframework/utils/color', [
      */
     function Color(type, value, transforms, defRGB) {
 
-        // public methods -----------------------------------------------------
-
-        /**
-         * Returns the type of this color.
-         *
-         * @returns {String}
-         *  The type of this color. See constructor parameter 'type' for
-         *  details.
-         */
-        this.getType = function () {
-            return type;
-        };
-
-        /**
-         * Returns whether this color is the automatic color.
-         *
-         * @returns {Boolean}
-         *  Whether this color is the automatic color.
-         */
-        this.isAuto = function () {
-            return type === 'auto';
-        };
-
-        /**
-         * Returns whether this color is equal to the passed color.
-         *
-         * @param {Color} color
-         *  The color to be compared with this color.
-         *
-         * @returns {Boolean}
-         *  Whether this color is equal to the passed color.
-         */
-        this.equals = function (color) {
-            var jsonColor1 = this.toJSON(), jsonColor2 = color.toJSON();
-            // ignore unused properties, e.g. 'fallbackValue'
-            return (jsonColor1.type === jsonColor2.type) &&
-                _.isEqual(jsonColor1.value, jsonColor2.value) &&
-                _.isEqual(jsonColor1.transformations, jsonColor2.transformations);
-        };
-
-        /**
-         * Returns a deep clone of this color.
-         *
-         * @returns {Color}
-         *  A deep clone of this color.
-         */
-        this.clone = function () {
-            return new Color(type, value, transforms, defRGB);
-        };
-
-        /**
-         * Appends one or more color transformations to this color.
-         *
-         * @param {String|Object|Array} tType
-         *  The name of a color transformation, a complete color transformation
-         *  object, or an array of transformation objects (see constructor
-         *  parameter 'transforms' for details).
-         *
-         * @param {Number} [tValue]
-         *  The value for the color transformation. Can be omitted, if the
-         *  specified transformations does not need a value (e.g. 'gray'). Will
-         *  be ignored, if the first parameter is not a string.
-         *
-         * @returns {Color}
-         *  A reference to this instance.
-         */
-        this.transform = function (tType, tValue) {
-            if (_.isString(tType)) {
-                var transform = { type: tType };
-                if (_.isNumber(tValue)) { transform.value = tValue; }
-                (transforms || (transforms = [])).push(transform);
-            } else if (_.isArray(tType)) {
-                transforms = transforms ? transforms.concat(tType) : tType.slice();
-            } else if (_.isObject(tType)) {
-                (transforms || (transforms = [])).push(tType);
-            }
-            return this;
-        };
-
-        /**
-         * Returns a color descriptor with details about the color represented
-         * by this instance.
-         *
-         * @param {String|Color} auto
-         *  Additional information needed to resolve the automatic color. Can
-         *  be a string for predefined automatic color types, or an instance of
-         *  the class Color with a type other than the automatic color.
-         *  The following color types are supported:
-         *  - 'text': for text colors (mapped to black),
-         *  - 'line': for line colors (mapped to black),
-         *  - 'fill': for fill colors (mapped to full transparency).
-         *
-         * @param {Theme} [theme]
-         *  A document theme object used to map scheme color names to color
-         *  values. If missing, theme colors will not be resolved correctly.
-         *
-         * @returns {ColorDescriptor}
-         *  A descriptor for the resulting color.
-         */
-        this.resolve = function (auto, theme) {
-
-            // the color model containing the resolved color
-            var colorModel = null;
-            // the original color type to be passed to the color descriptor
-            var descType = 'rgb';
-            // whether to apply the color transformations
-            var applyTransforms = true;
-
-            function createHexModel(hex) {
-                var rgbModel = _.isString(hex) ? RGBModel.parseHex(hex) : null;
-                return rgbModel || new RGBModel(0, 0, 0, 1);
-            }
-
-            function createDefaultModel() {
-                applyTransforms = false;
-                return createHexModel(defRGB);
-            }
-
-            // resolve automatic color with explicit color passed in 'auto' parameter
-            if ((type === 'auto') && (auto instanceof Color)) {
-                if (transforms) { auto = auto.clone().transform(transforms); }
-                return auto.resolve('fill', theme);
-            }
-
-            // create a color model for all supported color types
-            switch (type) {
-
-                // predefined colors with fixed RGB values
-                case 'preset':
-                    var presetColor = _.isString(value) ? PRESET_COLOR_MAP[value] : null;
-                    colorModel = createHexModel(presetColor);
-                    descType = presetColor ? 'preset' : 'rgb';
-                    break;
-
-                // predefined system UI colors without fixed RGB values
-                case 'system':
-                    var systemColor = _.isString(value) ? SYSTEM_COLOR_MAP[value] : null;
-                    colorModel = createHexModel(systemColor ? ColorUtils.getSystemColor(systemColor) : null);
-                    descType = systemColor ? 'system' : 'rgb';
-                    break;
-
-                // CRGB color model: each channel in the interval [0;100000]
-                case 'crgb':
-                    colorModel = new RGBModel(getLimNum(value, 'r'), getLimNum(value, 'g'), getLimNum(value, 'b'), 1);
-                    colorModel.gamma(GAMMA);
-                    break;
-
-                // HSL color model (hue, saturation, luminance)
-                case 'hsl':
-                    var h = Utils.mod(Utils.getIntegerOption(value, 'h', 0) / 1000, 360);
-                    colorModel = new HSLModel(h, getLimNum(value, 's'), getLimNum(value, 'l'), 1);
-                    descType = 'hsl';
-                    break;
-
-                // simple hexadecimal RGB
-                case 'rgb':
-                    colorModel = createHexModel(value);
-                    break;
-
-                // scheme color
-                case 'scheme':
-                    if (theme && _.isString(value)) {
-                        if (value === 'style') {
-                            Utils.warn('Color.resolve(): scheme color type "style" not implemented');
-                            colorModel = createDefaultModel();
-                        } else {
-                            colorModel = createHexModel(theme.getSchemeColor(value, '000000'));
-                            descType = 'scheme';
-                        }
-                    } else {
-                        colorModel = createDefaultModel();
-                    }
-                    break;
-
-                // automatic color, effective color depends on passed 'auto' parameter
-                case 'auto':
-                    // resolve automatic color by color type name
-                    switch (auto) {
-                        case 'text':
-                        case 'line':
-                            colorModel = new RGBModel(0, 0, 0, 1); // black
-                            break;
-                        case 'fill':
-                            colorModel = new RGBModel(0, 0, 0, 0); // full transparency
-                            descType = 'transparent';
-                            applyTransforms = false;
-                            break;
-                        default:
-                            Utils.error('Color.resolve(): unknown color type "' + auto + '" for auto color');
-                            colorModel = createDefaultModel();
-                    }
-                    break;
-
-                default:
-                    Utils.error('Color.resolve(): unknown color type "' + type + '"');
-                    colorModel = createDefaultModel();
-            }
-
-            // apply all transformations
-            if (applyTransforms && transforms) {
-                transforms.forEach(function (transform) {
-                    var tType = Utils.getStringOption(transform, 'type', '');
-                    var handler = TRANSFORMATIONS[tType];
-                    if (handler) {
-                        colorModel = handler(colorModel, transform);
-                    } else {
-                        Utils.warn('Color.resolve(): unknown color transformation "' + tType + '"');
-                    }
-                });
-            }
-
-            // create the color descriptor for the resulting color model
-            return new ColorDescriptor(colorModel, descType);
-        };
-
-        /**
-         * Returns a color descriptor with details about the color represented
-         * by this instance, assuming it to be a text color on a specific
-         * background style. The automatic color will be resolved to the color
-         * black or white, depending on the lightness of the passed background
-         * colors. All other colors will be resolved according to the method
-         * Color.resolve().
-         *
-         * @param {Array<Color>} fillColors
-         *  The source fill colors, from outermost to innermost level. The last
-         *  explicit (non-automatic) fill color in the array will be used as
-         *  effective fill color.
-         *
-         * @param {Theme} [theme]
-         *  A document theme object used to map scheme color names to color
-         *  values. If missing, theme colors will not be resolved correctly.
-         *
-         * @returns {ColorDescriptor}
-         *  A descriptor for the resulting color.
-         */
-        this.resolveText = function (fillColors, theme) {
-
-            // the resulting text color
-            var textColor = this;
-            // the effective fill color
-            var fillColor = null;
-
-            // resolve explicit colors directly
-            if (this.isAuto()) {
-
-                // find last non-transparent fill color in the passed array
-                // TODO: merge semi-transparent colors?
-                fillColors.forEach(function (currFillColor) {
-                    if (!currFillColor.isAuto()) { fillColor = currFillColor; }
-                });
-
-                // resolve to black or white according to lightness of fill color (assume white for missing fill color)
-                textColor = new Color('preset', (fillColor && fillColor.resolve('fill', theme).dark) ? 'white' : 'black');
-            }
-
-            return textColor.resolve('text', theme);
-        };
-
-        /**
-         * Returns a color descriptor with details for a color that is a mix of
-         * this color instance, and the passed color instance.
-         *
-         * @param {Color} color
-         *  The other color to be mixed with this color.
-         *
-         * @param {Number} weighting
-         *  Specifies how much of the other color will be mixed into this
-         *  color. Values equal to or less than zero will result in an exact
-         *  copy of THIS color. Values equal to or greater than one will result
-         *  in an exact copy of the OTHER color. Values between zero and one
-         *  result in a mixed color between this and the other color, where
-         *  values close to zero result in colors similar to THIS color, and
-         *  values close to one result in colors similar to the OTHER color.
-         *
-         * @param {String|Color} auto
-         *  Additional information needed to resolve the automatic color. See
-         *  method Color.resolve() for details.
-         *
-         * @param {Theme} [theme]
-         *  A document theme object used to map scheme color names to color
-         *  values. If missing, theme colors will not be resolved correctly.
-         *
-         * @returns {ColorDescriptor}
-         *  A descriptor for the resulting color.
-         */
-        this.resolveMixed = function (color, weighting, auto, theme) {
-
-            // resolve this color and the other color
-            var desc1 = this.resolve(auto, theme);
-            var desc2 = color.resolve(auto, theme);
-
-            // early exit if passed weithing is out of the open interval (0,1)
-            if (weighting <= 0) { return desc1; }
-            if (weighting >= 1) { return desc2; }
-
-            // use the RGBA color model to calculate a mixed color
-            var r = desc1.rgb.r + (desc2.rgb.r - desc1.rgb.r) * weighting;
-            var g = desc1.rgb.g + (desc2.rgb.g - desc1.rgb.g) * weighting;
-            var b = desc1.rgb.b + (desc2.rgb.b - desc1.rgb.b) * weighting;
-            var a = desc1.rgb.a + (desc2.rgb.a - desc1.rgb.a) * weighting;
-
-            return new ColorDescriptor(new RGBModel(r, g, b, a), 'rgb');
-        };
-
-        /**
-         * Returns the JSON representation of this color, as used in document
-         * operations.
-         *
-         * @returns {Object}
-         *  The JSON representation of this color.
-         */
-        this.toJSON = function () {
-            var json = { type: type };
-            if (type !== 'auto') { json.value = value; }
-            if (transforms && (transforms.length > 0)) { json.transformations = transforms.slice(); }
-            if (_.isString(defRGB)) { json.fallbackValue = defRGB; }
-            return json;
-        };
-
-        // initialization -----------------------------------------------------
+        this._type = type;
 
         // create copies of input values to prevent modification from outside
         if (_.isString(value)) {
-            // scheme color string must stay stable, other colors get unified
-            if (type !== 'scheme') { value = value.toLowerCase(); }
+            this._value = (type === 'rgb') ? value.toLowerCase() : value;
         } else if (_.isObject(value)) {
-            value = _.clone(value);
+            this._value = _.clone(value);
         } else {
-            value = null;
+            this._value = null;
         }
-        transforms = _.isArray(transforms) ? transforms.slice() : null;
+
+        this._transforms = _.isArray(transforms) ? transforms.slice() : null;
+        this._defRGB = defRGB;
 
     } // class Color
 
+    // public methods ---------------------------------------------------------
+
+    /**
+     * Returns the type of this color.
+     *
+     * @returns {String}
+     *  The type of this color. See constructor parameter 'type' for details.
+     */
+    Color.prototype.getType = function () {
+        return this._type;
+    };
+
+    /**
+     * Returns whether this color is the automatic color.
+     *
+     * @returns {Boolean}
+     *  Whether this color is the automatic color.
+     */
+    Color.prototype.isAuto = function () {
+        return this._type === 'auto';
+    };
+
+    /**
+     * Returns whether this color is equal to the passed color.
+     *
+     * @param {Color} color
+     *  The color to be compared with this color.
+     *
+     * @returns {Boolean}
+     *  Whether this color is equal to the passed color.
+     */
+    Color.prototype.equals = function (color) {
+        var jsonColor1 = this.toJSON(), jsonColor2 = color.toJSON();
+        // ignore unused properties, e.g. 'fallbackValue'
+        return (jsonColor1.type === jsonColor2.type) &&
+            _.isEqual(jsonColor1.value, jsonColor2.value) &&
+            _.isEqual(jsonColor1.transformations, jsonColor2.transformations);
+    };
+
+    /**
+     * Returns a deep clone of this color.
+     *
+     * @returns {Color}
+     *  A deep clone of this color.
+     */
+    Color.prototype.clone = function () {
+        return new Color(this._type, this._value, this._transforms, this._defRGB);
+    };
+
+    /**
+     * Appends one or more color transformations to this color.
+     *
+     * @param {String|Object|Array} tType
+     *  The name of a color transformation, a complete color transformation
+     *  object, or an array of transformation objects (see constructor
+     *  parameter 'transforms' for details).
+     *
+     * @param {Number} [tValue]
+     *  The value for the color transformation. Can be omitted, if the
+     *  specified transformations does not need a value (e.g. 'gray'). Will be
+     *  ignored, if the first parameter is not a string.
+     *
+     * @returns {Color}
+     *  A reference to this instance.
+     */
+    Color.prototype.transform = function (tType, tValue) {
+        if (_.isString(tType)) {
+            var transform = { type: tType };
+            if (_.isNumber(tValue)) { transform.value = tValue; }
+            (this._transforms || (this._transforms = [])).push(transform);
+        } else if (_.isArray(tType)) {
+            this._transforms = this._transforms ? this._transforms.concat(tType) : tType.slice();
+        } else if (_.isObject(tType)) {
+            (this._transforms || (this._transforms = [])).push(tType);
+        }
+        return this;
+    };
+
+    /**
+     * Returns a color descriptor with details about the color represented by
+     * this instance.
+     *
+     * @param {String|Color} auto
+     *  Additional information needed to resolve the automatic color. Can be a
+     *  string for predefined automatic color types, or an instance of the
+     *  class Color with a type other than the automatic color. The following
+     *  color types are supported:
+     *  - 'text': for text colors (mapped to black),
+     *  - 'line': for line colors (mapped to black),
+     *  - 'fill': for fill colors (mapped to full transparency).
+     *
+     * @param {ThemeModel} [themeModel]
+     *  The model of a document theme used to map scheme color names to color
+     *  values. If missing, theme colors will not be resolved correctly.
+     *
+     * @returns {ColorDescriptor}
+     *  A descriptor for the resulting color.
+     */
+    Color.prototype.resolve = function (auto, themeModel) {
+
+        // shortcut to the current value
+        var value = this._value;
+        // shortcut to the default RGB value
+        var defRGB = this._defRGB;
+        // the color model containing the resolved color
+        var colorModel = null;
+        // the original color type to be passed to the color descriptor
+        var descType = 'rgb';
+        // whether to apply the color transformations
+        var applyTransforms = true;
+
+        function createHexModel(hex) {
+            var rgbModel = _.isString(hex) ? RGBModel.parseHex(hex) : null;
+            return rgbModel || new RGBModel(0, 0, 0, 1);
+        }
+
+        function createDefaultModel() {
+            applyTransforms = false;
+            return createHexModel(defRGB);
+        }
+
+        // resolve automatic color with explicit color passed in 'auto' parameter
+        if ((this._type === 'auto') && (auto instanceof Color)) {
+            if (this._transforms) { auto = auto.clone().transform(this._transforms); }
+            return auto.resolve('fill', themeModel);
+        }
+
+        // create a color model for all supported color types
+        switch (this._type) {
+
+            // predefined colors with fixed RGB values
+            case 'preset':
+                var presetColor = _.isString(value) ? PRESET_COLOR_MAP[value] : null;
+                colorModel = createHexModel(presetColor);
+                descType = presetColor ? 'preset' : 'rgb';
+                break;
+
+            // predefined system UI colors without fixed RGB values
+            case 'system':
+                var systemColor = _.isString(value) ? SYSTEM_COLOR_MAP[value] : null;
+                colorModel = createHexModel(systemColor ? ColorUtils.getSystemColor(systemColor) : null);
+                descType = systemColor ? 'system' : 'rgb';
+                break;
+
+            // CRGB color model: each channel in the interval [0;100000]
+            case 'crgb':
+                colorModel = new RGBModel(getLimNum(value, 'r'), getLimNum(value, 'g'), getLimNum(value, 'b'), 1);
+                colorModel.gamma(GAMMA);
+                break;
+
+            // HSL color model (hue, saturation, luminance)
+            case 'hsl':
+                colorModel = new HSLModel(getScaledNum(value, 'h', HUE_PER_DEG), getLimNum(value, 's'), getLimNum(value, 'l'), 1);
+                descType = 'hsl';
+                break;
+
+            // simple hexadecimal RGB
+            case 'rgb':
+                colorModel = createHexModel(value);
+                break;
+
+            // scheme color
+            case 'scheme':
+                if (themeModel && _.isString(value)) {
+                    if (value === 'style') {
+                        Utils.warn('Color.resolve(): scheme color type "style" not implemented');
+                        colorModel = createDefaultModel();
+                    } else {
+                        colorModel = createHexModel(themeModel.getSchemeColor(value, '000000'));
+                        descType = 'scheme';
+                    }
+                } else {
+                    colorModel = createDefaultModel();
+                }
+                break;
+
+            // automatic color, effective color depends on passed 'auto' parameter
+            case 'auto':
+                // resolve automatic color by color type name
+                switch (auto) {
+                    case 'text':
+                    case 'line':
+                        colorModel = new RGBModel(0, 0, 0, 1); // black
+                        break;
+                    case 'fill':
+                        colorModel = new RGBModel(0, 0, 0, 0); // full transparency
+                        descType = 'transparent';
+                        applyTransforms = false;
+                        break;
+                    default:
+                        Utils.error('Color.resolve(): unknown color type "' + auto + '" for auto color');
+                        colorModel = createDefaultModel();
+                }
+                break;
+
+            default:
+                Utils.error('Color.resolve(): unknown color type "' + this._type + '"');
+                colorModel = createDefaultModel();
+        }
+
+        // apply all transformations
+        if (applyTransforms && this._transforms) {
+            this._transforms.forEach(function (transform) {
+                var tType = Utils.getStringOption(transform, 'type', '');
+                var handler = TRANSFORMATIONS[tType];
+                if (handler) {
+                    colorModel = handler(colorModel, transform);
+                } else {
+                    Utils.warn('Color.resolve(): unknown color transformation "' + tType + '"');
+                }
+            });
+        }
+
+        // create the color descriptor for the resulting color model
+        return new ColorDescriptor(colorModel, descType);
+    };
+
+    /**
+     * Returns a color descriptor with details about the color represented by
+     * this instance, assuming it to be a text color on a specific background
+     * style. The automatic color will be resolved to the color black or white,
+     * depending on the lightness of the passed background colors. All other
+     * colors will be resolved according to the method Color.resolve().
+     *
+     * @param {Array<Color>} fillColors
+     *  The source fill colors, from outermost to innermost level. The last
+     *  explicit (non-automatic) fill color in the array will be used as
+     *  effective fill color.
+     *
+     * @param {ThemeModel} [themeModel]
+     *  The model of a document theme used to map scheme color names to color
+     *  values. If missing, theme colors will not be resolved correctly.
+     *
+     * @returns {ColorDescriptor}
+     *  A descriptor for the resulting color.
+     */
+    Color.prototype.resolveText = function (fillColors, themeModel) {
+
+        // the resulting text color
+        var textColor = this;
+        // the effective fill color
+        var fillColor = null;
+
+        // resolve explicit colors directly
+        if (this.isAuto()) {
+
+            // find last non-transparent fill color in the passed array
+            // TODO: merge semi-transparent colors?
+            fillColors.forEach(function (currFillColor) {
+                if (!currFillColor.isAuto()) { fillColor = currFillColor; }
+            });
+
+            // resolve to black or white according to lightness of fill color (assume white for missing fill color)
+            textColor = new Color('preset', (fillColor && fillColor.resolve('fill', themeModel).dark) ? 'white' : 'black');
+        }
+
+        return textColor.resolve('text', themeModel);
+    };
+
+    /**
+     * Returns a color descriptor with details for a color that is a mix of
+     * this color instance, and the passed color instance.
+     *
+     * @param {Color} color
+     *  The other color to be mixed with this color.
+     *
+     * @param {Number} weighting
+     *  Specifies how much of the other color will be mixed into this color.
+     *  Values equal to or less than zero will result in an exact copy of THIS
+     *  color. Values equal to or greater than one will result in an exact copy
+     *  of the OTHER color. Values between zero and one result in a mixed color
+     *  between this and the other color, where values close to zero result in
+     *  colors similar to THIS color, and values close to one result in colors
+     *  similar to the OTHER color.
+     *
+     * @param {String|Color} auto
+     *  Additional information needed to resolve the automatic color. See
+     *  method Color.resolve() for details.
+     *
+     * @param {ThemeModel} [themeModel]
+     *  The model of a document theme used to map scheme color names to color
+     *  values. If missing, theme colors will not be resolved correctly.
+     *
+     * @returns {ColorDescriptor}
+     *  A descriptor for the resulting color.
+     */
+    Color.prototype.resolveMixed = function (color, weighting, auto, themeModel) {
+
+        // resolve this color and the other color
+        var desc1 = this.resolve(auto, themeModel);
+        var desc2 = color.resolve(auto, themeModel);
+
+        // early exit if passed weithing is out of the open interval (0,1)
+        if (weighting <= 0) { return desc1; }
+        if (weighting >= 1) { return desc2; }
+
+        // use the RGBA color model to calculate a mixed color
+        var r = desc1.rgb.r + (desc2.rgb.r - desc1.rgb.r) * weighting;
+        var g = desc1.rgb.g + (desc2.rgb.g - desc1.rgb.g) * weighting;
+        var b = desc1.rgb.b + (desc2.rgb.b - desc1.rgb.b) * weighting;
+        var a = desc1.rgb.a + (desc2.rgb.a - desc1.rgb.a) * weighting;
+
+        return new ColorDescriptor(new RGBModel(r, g, b, a), 'rgb');
+    };
+
+    /**
+     * Returns the JSON representation of this color, as used in document
+     * operations.
+     *
+     * @returns {Object}
+     *  The JSON representation of this color.
+     */
+    Color.prototype.toJSON = function () {
+        var json = { type: this._type };
+        if (this._type !== 'auto') { json.value = this._value; }
+        if (this._transforms && (this._transforms.length > 0)) { json.transformations = this._transforms.slice(); }
+        if (_.isString(this._defRGB)) { json.fallbackValue = this._defRGB; }
+        return json;
+    };
+
     // static methods ---------------------------------------------------------
 
     /**
@@ -625,7 +657,7 @@ define('io.ox/office/editframework/utils/color', [
         if (!colorDesc) { return null; }
 
         // value of the alpha channel, in the interval [0;100000]
-        var alpha = Math.round(colorDesc.a * 100000);
+        var alpha = round(colorDesc.a * 100000);
 
         // return auto color for fill mode will full transparency
         if (fill && (alpha === 0)) {
@@ -641,7 +673,7 @@ define('io.ox/office/editframework/utils/color', [
                     return new Color('system', value);
                 case 'hsl':
                     var hsl = colorDesc.hsl;
-                    return new Color('hsl', { h: Math.round(hsl.h * 1000), s: Math.round(hsl.s * 100000), l: Math.round(hsl.l * 100000) });
+                    return new Color('hsl', { h: round(hsl.h * HUE_PER_DEG), s: round(hsl.s * 100000), l: round(hsl.l * 100000) });
             }
             return new Color('rgb', colorDesc.hex);
         }());
@@ -689,11 +721,27 @@ define('io.ox/office/editframework/utils/color', [
      */
     Color.HYPERLINK = { type: 'scheme', value: 'hyperlink' };
 
+    /**
+     * The JSON representation of the placeholder color.
+     *
+     * @constant
+     */
+    Color.PLACEHOLDER = { type: 'scheme', value: 'phClr' };
+
     /**
      * The JSON representation of the color 'black'.
+     *
+     * @constant
      */
     Color.BLACK = { type: 'rgb', value: PRESET_COLOR_MAP.black };
 
+    /**
+     * The JSON representation of the color 'white'.
+     *
+     * @constant
+     */
+    Color.WHITE = { type: 'rgb', value: PRESET_COLOR_MAP.white };
+
     // exports ================================================================
 
     return Color;
