@@ -81,16 +81,16 @@ define('io.ox/office/editframework/view/control/bordermodepicker', [
      *      list items will be evaluated dynamically every time this control
      *      will be updated, according to the return value.
      */
-    function BorderModePicker(initOptions) {
+    function BorderModePicker(docView, initOptions) {
 
-        var // self reference
-            self = this,
+        // self reference
+        var self = this;
 
-            // whether list entries with inner horizontal borders will be shown
-            showInsideHor = Utils.getFunctionOption(initOptions, 'showInsideHor', Utils.getBooleanOption(initOptions, 'showInsideHor', false)),
+        // whether list entries with inner horizontal borders will be shown
+        var showInsideHor = Utils.getFunctionOption(initOptions, 'showInsideHor', Utils.getBooleanOption(initOptions, 'showInsideHor', false));
 
-            // whether list entries with inner vertical borders will be shown
-            showInsideVert = Utils.getFunctionOption(initOptions, 'showInsideVert', Utils.getBooleanOption(initOptions, 'showInsideVert', false));
+        // whether list entries with inner vertical borders will be shown
+        var showInsideVert = Utils.getFunctionOption(initOptions, 'showInsideVert', Utils.getBooleanOption(initOptions, 'showInsideVert', false));
 
         // base constructor ---------------------------------------------------
 
@@ -98,7 +98,7 @@ define('io.ox/office/editframework/view/control/bordermodepicker', [
             icon: 'docs-border-tblr',
             tooltip: /*#. in paragraphs and tables cells */ gt.pgettext('borders', 'Borders')
         }, initOptions);
-        RadioList.call(this, Utils.extendOptions({
+        RadioList.call(this, docView, Utils.extendOptions({
             dropDownVersion: { label: Utils.getStringOption(initOptions, 'tooltip') }
         }, initOptions, {
             itemMatcher: matchBorder,
@@ -220,7 +220,7 @@ define('io.ox/office/editframework/view/control/bordermodepicker', [
 
         // destroy all members on destruction
         this.registerDestructor(function () {
-            self = showInsideHor = showInsideVert = null;
+            self = docView = showInsideHor = showInsideVert = null;
         });
 
     } // class BorderModePicker
