@@ -54,7 +54,7 @@ define('io.ox/office/editframework/view/control/borderstylepicker', [
     var getBorderStyleBitmapUrl = (function () {
 
         // the canvas element used to generate the bitmaps
-        var canvas = new Canvas();
+        var canvas = new Canvas(Canvas.SINGLETON);
 
         // maps unique bitmap keys values to the data URLs
         var bitmapUrls = {};
@@ -137,7 +137,7 @@ define('io.ox/office/editframework/view/control/borderstylepicker', [
      *  Optional parameters. Supports all options supported by the base class
      *  RadioList.
      */
-    function BorderStylePicker(listEntries, initOptions) {
+    function BorderStylePicker(docView, listEntries, initOptions) {
 
         // maps control values to border style descriptors
         var borderStyles = {};
@@ -150,7 +150,7 @@ define('io.ox/office/editframework/view/control/borderstylepicker', [
             updateCaptionMode: 'none'
         }, initOptions);
 
-        RadioList.call(this, Utils.extendOptions({
+        RadioList.call(this, docView, Utils.extendOptions({
             dropDownVersion: { label: Utils.getStringOption(initOptions, 'tooltip') }
         }, initOptions));
 
@@ -192,7 +192,7 @@ define('io.ox/office/editframework/view/control/borderstylepicker', [
 
         // destroy all class members on destruction
         this.registerDestructor(function () {
-            listEntries = initOptions = null;
+            docView = listEntries = initOptions = null;
         });
 
     } // class BorderStylePicker
