@@ -15,8 +15,9 @@
 define('io.ox/office/editframework/view/control/borderwidthpicker', [
     'io.ox/office/tk/utils',
     'io.ox/office/tk/control/combofield',
+    'io.ox/office/editframework/view/editlabels',
     'gettext!io.ox/office/editframework/main'
-], function (Utils, ComboField, gt) {
+], function (Utils, ComboField, Labels, gt) {
 
     'use strict';
 
@@ -33,19 +34,20 @@ define('io.ox/office/editframework/view/control/borderwidthpicker', [
      *  Optional parameters. Supports all options supported by the base class
      *  ComboField.
      */
-    function BorderWidthPicker(initOptions) {
+    function BorderWidthPicker(docView, initOptions) {
 
         // base constructor ---------------------------------------------------
 
         initOptions = Utils.extendOptions({
             width: 40,
-            tooltip: /*#. line width of borders in paragraphs and tables cells */ gt.pgettext('borders', 'Border width'),
+            tooltip: Labels.BORDER_WIDTH_LABEL,
             style: 'text-align:right;',
             keyboard: 'number',
-            validator: new ComboField.NumberValidator({ min: 0.5, max: 10, precision: 0.1 })
+            validator: new ComboField.NumberValidator({ min: 0.5, max: 10, precision: 0.1 }),
+            dropDownVersion: { label: Labels.BORDER_WIDTH_LABEL }
         }, initOptions);
 
-        ComboField.call(this, Utils.extendOptions({
+        ComboField.call(this, docView, Utils.extendOptions({
             dropDownVersion: { label: Utils.getStringOption(initOptions, 'tooltip') }
         }, initOptions));
 
