@@ -57,16 +57,16 @@ define('io.ox/office/editframework/view/control/userbadge', [
 
         // base constructor ---------------------------------------------------
 
-        UserPicture.call(this, clientData, Utils.extendOptions(initOptions, { size: 32 }));
+        UserPicture.call(this, docView, clientData, Utils.extendOptions(initOptions, { size: 32 }));
 
         // private methods ----------------------------------------------------
 
         function updateHandler(currentData) {
 
-            var // the user name to be inserted into the elements
-                userName = null,
-                // tooltip for edit rights
-                tooltip = null;
+            // the user name to be inserted into the elements
+            var userName = null;
+            // tooltip for edit rights
+            var tooltip = null;
 
             if (!currentData.userName) {
                 userName = gt('Guest');
@@ -83,18 +83,18 @@ define('io.ox/office/editframework/view/control/userbadge', [
             // mark user with editing rights with an appropriate icon (bug 36482: not during offline mode)
             userColorNode.empty();
             // delete tooltip
-            Forms.setToolTip(userColorNode);
+            Forms.setToolTip(userColorNode, '');
             if (currentData.editor && !docView.getApp().isOffline()) {
                 userColorNode.append(Forms.createIconMarkup(Labels.EDIT_ICON));
 
                 if (currentData.remote) {
-                    tooltip =   //#. shown as tooltip in a list of all users working on the same document
-                                gt('This user has edit rights for the document.');
+                    //#. shown as tooltip in a list of all users working on the same document
+                    tooltip = gt('This user has edit rights for the document.');
                 } else {
-                    tooltip =   //#. shown as tooltip in a list of all users working on the same document
-                                gt('You have edit rights for the document.');
+                    //#. shown as tooltip in a list of all users working on the same document
+                    tooltip = gt('You have edit rights for the document.');
                 }
-                Forms.setToolTip(userColorNode, { tooltip: tooltip });
+                Forms.setToolTip(userColorNode, tooltip);
             }
         }
 
