@@ -17,9 +17,8 @@ define('io.ox/office/editframework/view/dialog/hyperlinkdialog', [
     'io.ox/office/tk/dialogs',
     'io.ox/office/editframework/utils/hyperlinkutils',
     'io.ox/office/editframework/view/editlabels',
-    'io.ox/office/tk/object/timermixin',
     'gettext!io.ox/office/editframework/main'
-], function (Utils, Dialogs, HyperlinkUtils, Labels, TimerMixin, gt) {
+], function (Utils, Dialogs, HyperlinkUtils, Labels, gt) {
 
     'use strict';
 
@@ -55,45 +54,54 @@ define('io.ox/office/editframework/view/dialog/hyperlinkdialog', [
      * @param {String} [display]
      *  The initial display string for the URL to be shown in the dialog. If
      *  omitted, the text field for the display string will appear empty.
+     *
+     * @param {Object} [options]
+     *  Additional options for the dialog
+     *  Optional parameters:
+     *  @param {Boolean} [options.showremove=true]
+     *      If set to false, the remove button is not shown, although an initial
+     *      URL is specified for this dialog. This is necessary, if the dialog
+     *      is redrawn after an invalid URL was found (53058).
      */
-    var HyperlinkDialog = Dialogs.ModalDialog.extend({ constructor: function (docView, url, display) {
+    var HyperlinkDialog = Dialogs.ModalDialog.extend({ constructor: function (docView, url, display, options) {
 
-        var // self reference
-            self = this,
+        // self reference
+        var self = this;
 
-            // whether to keep URL and display text in sync
-            syncDisplay = !display || (url === display),
+        // whether to keep URL and display text in sync
+        var syncDisplay = !display || (url === display);
 
-            // the input field for the URL
-            urlInputNode = $('<input>', {
-                value: url || '',
-                tabindex: 0,
-                id: URL_INPUT_ID,
-                role: 'textbox',
-                'aria-labelledby': URL_LABEL_ID,
-                'aria-required': true
-            }).addClass('form-control'),
+        // the input field for the URL
+        var urlInputNode = $('<input>', {
+            value: url || '',
+            tabindex: 0,
+            id: URL_INPUT_ID,
+            role: 'textbox',
+            'aria-labelledby': URL_LABEL_ID,
+            'aria-required': true
+        }).addClass('form-control');
 
-            // the input field for the display text of the URL
-            displayInputNode = $('<input>', {
-                value: display || url,
-                tabindex: 0,
-                id: DISPLAY_INPUT_ID,
-                role: 'textbox',
-                'aria-labelledby': DISPLAY_LABEL_ID,
-                'aria-required': true
-            }).addClass('form-control');
+        // the input field for the display text of the URL
+        var displayInputNode = $('<input>', {
+            value: display || url,
+            tabindex: 0,
+            id: DISPLAY_INPUT_ID,
+            role: 'textbox',
+            'aria-labelledby': DISPLAY_LABEL_ID,
+            'aria-required': true
+        }).addClass('form-control');
+
+        // whether the remove button is visible
+        var removeIsVisible = false;
 
         // base constructor ---------------------------------------------------
 
-        Dialogs.ModalDialog.call(this, {
+        Dialogs.ModalDialog.call(this, docView, {
             width: 400,
             title: url ? Labels.EDIT_HYPERLINK_LABEL : Labels.INSERT_HYPERLINK_LABEL,
             okLabel: gt('Insert')
         });
 
-        TimerMixin.call(this);
-
         // private methods ----------------------------------------------------
 
         /**
@@ -131,10 +139,10 @@ define('io.ox/office/editframework/view/dialog/hyperlinkdialog', [
                         // add http: as default if protocol is missing
                         var newUrl = (currUrl.indexOf(':') < 0) ? ('http://' + currUrl) : currUrl;
 
-                        // show warning and reopen the dialog, if the URL is invalid
+                        // show warning and reopen the dialog, if the URL is invalid (not changing the state of the remove button (53058))
                         if (!HyperlinkUtils.hasSupportedProtocol(newUrl) || !HyperlinkUtils.isValidURL(newUrl)) {
                             docView.yell({ type: 'warning', message: Labels.INVALID_HYPERLINK_LABEL });
-                            return new HyperlinkDialog(docView, currUrl, display).show();
+                            return new HyperlinkDialog(docView, currUrl, display, { showremove: removeIsVisible }).show();
                         }
 
                         // return result object for a valid URL
@@ -175,9 +183,10 @@ define('io.ox/office/editframework/view/dialog/hyperlinkdialog', [
         );
 
         // add a Remove button, if a URL has been passed
-        if (url) {
+        if (url && Utils.getBooleanOption(options, 'showremove', true)) {
             this.addAlternativeButton('remove', gt('Remove'));
             this.getButton('remove').addClass('btn-warning');
+            removeIsVisible = true;
         }
 
         // register a change handlers to toggle the insert button
@@ -191,7 +200,7 @@ define('io.ox/office/editframework/view/dialog/hyperlinkdialog', [
             // otherwise on mouseup the selection is removed again
             if (_.browser.Chrome || _.browser.Safari || _.browser.Edge) {
                 // the workaround: it's also mentioned here https://code.google.com/p/chromium/issues/detail?id=4505
-                docView.executeDelayed(function () { displayInputNode.select(); }, { infoString: 'HyperLinkDialog.displayInputNode.onFocus()', app: docView.getApp() });
+                _.defer(function () { displayInputNode.select(); });
             // this is how it's supposed to work normally
             } else {
                 displayInputNode.select();
@@ -208,7 +217,7 @@ define('io.ox/office/editframework/view/dialog/hyperlinkdialog', [
             // Bug 46886
             // Also for IPad because since IOS 9, body is not scrolled when code triggers focus on input element
             if (Utils.SMALL_DEVICE || Utils.IOS) {
-                Utils.setFocus(self.getOkButton());
+                _.defer(function () { Utils.setFocus(self.getCancelButton()); });
             } else {
                 Utils.setFocus(urlInputNode).select();
             }
