@@ -49,7 +49,7 @@ define('io.ox/office/editframework/view/dialog/saveasfiledialog', [
      *      the assigned DriveUtil from the DriveUtils class
      *      can be: FolderPicker, FlatFolderPicker & FilePicker
      */
-    var SaveAsFileDialog = Dialogs.ModalDriveDialog.extend({ constructor: function (initOptions) {
+    var SaveAsFileDialog = Dialogs.ModalDriveDialog.extend({ constructor: function (docView, initOptions) {
 
         // self reference
         var self = this;
@@ -66,19 +66,15 @@ define('io.ox/office/editframework/view/dialog/saveasfiledialog', [
         // whether to allow empty text
         var allowEmpty = Utils.getBooleanOption(initOptions, 'allowEmpty', false);
 
-        var driveUtil = Utils.getOption(initOptions, 'driveUtil');
-        if (!driveUtil) {
-            driveUtil = new DriveUtils.FolderPicker(initOptions);
-        }
-        driveUtil.getNode().css('height', '250px');
+        var folderPicker = Utils.getOption(initOptions, 'folderPicker') || new DriveUtils.FolderPicker(docView, initOptions);
+        folderPicker.getNode().css('height', '250px');
 
         // base constructor ---------------------------------------------------
 
-        Dialogs.ModalDriveDialog.call(this, Utils.extendOptions({
+        Dialogs.ModalDriveDialog.call(this, docView, folderPicker, Utils.extendOptions({
             ok: gt('Save'),
             addClass: 'save-as-folder-list',
-            height: 350,
-            driveUtil: driveUtil
+            height: 350
         }, initOptions));
 
         // private methods ----------------------------------------------------
