@@ -161,6 +161,20 @@ define('io.ox/office/editframework/view/editlabels', [
         //#. line style of borders in paragraphs and tables cells
         gt.pgettext('borders', 'Border style');
 
+    /**
+     * @constant
+     */
+    EditLabels.BORDER_WIDTH_LABEL =
+        //#. line width of borders in paragraphs and tables cells
+        gt.pgettext('borders', 'Border width');
+
+    /**
+     * @constant
+     */
+    EditLabels.LINE_STYLE_LABEL =
+        //#. line style of borders in paragraphs and tables cells
+        gt.pgettext('lines', 'Line style');
+
     /**
      * @constant
      */
@@ -441,20 +455,6 @@ define('io.ox/office/editframework/view/editlabels', [
      */
     EditLabels.REPLACE_ALL = { label: /*#. in search/replace: replace all occurrences */ gt('Replace all'), tooltip: gt('Replace all search results'), smallerVersion: { css: { maxWidth: 50, textOverflow: 'ellipsis', overflow: 'hidden' } } };
 
-    /**
-     * Standard options for search tab entry
-     *
-     * @constant
-     */
-    EditLabels.TAB_SEARCH = { label: gt('Search'), icon: 'fa-search' };
-
-    /**
-     * Standard options for search & replace tab entry
-     *
-     * @constant
-     */
-    EditLabels.TAB_SEARCH_REPLACE = { label: gt('Replace'), icon: 'fa-search' };
-
     /**
      * @constant
      */
@@ -463,6 +463,27 @@ define('io.ox/office/editframework/view/editlabels', [
         message: gt('No search result found.')
     };
 
+    /**
+     * Standard options for colorpicker of text color
+     *
+     * @constant
+     */
+    EditLabels.TEXT_COLORPICKER_OPTIONS = { icon: 'docs-font-color', tooltip: gt('Text color'), title:  gt('Text color') };
+
+    /**
+     * Standard options for colorpicker of background color
+     *
+     * @constant
+     */
+    EditLabels.FILL_COLORPICKER_OPTIONS = { icon: 'docs-cell-fill-color', tooltip: gt('Fill color'), title: gt('Fill color') };
+
+    /**
+     * Standard options for colorpicker of borderline color
+     *
+     * @constant
+     */
+    EditLabels.BORDER_COLORPICKER_OPTIONS = { icon: 'docs-drawing-line-color', tooltip: gt.pgettext('borders', 'Border color'), title: gt.pgettext('borders', 'Border color') };
+
     // exports ================================================================
 
     return EditLabels;
