@@ -14,9 +14,11 @@
 
 define('io.ox/office/editframework/view/editview', [
     'io.ox/office/tk/utils',
+    'io.ox/office/tk/utils/scheduler',
     'io.ox/office/baseframework/app/extensionregistry',
     'io.ox/office/baseframework/view/baseview',
     'io.ox/office/baseframework/view/baselabels',
+    'io.ox/office/baseframework/view/toolbar',
     'io.ox/office/editframework/utils/editconfig',
     'io.ox/office/editframework/view/toolbartabcollection',
     'io.ox/office/editframework/view/toppane',
@@ -29,19 +31,16 @@ define('io.ox/office/editframework/view/editview', [
     'io.ox/office/editframework/view/editdialogs',
     'io.ox/office/editframework/view/mobilesearchgroup',
     'io.ox/office/editframework/view/popup/userslayermenu',
-    'io.ox/office/tk/utils/deferredutils',
     'gettext!io.ox/office/editframework/main',
     'less!io.ox/office/editframework/view/editstyle'
-], function (Utils, ExtensionRegistry, BaseView, BaseLabels, Config, ToolBarTabCollection, TopPane, EditToolPane, SearchPane, OperationsPane, ClipboardPane, Labels, Controls, Dialogs, MobileSearchGroup, UsersLayerMenu, DeferredUtils, gt) {
+], function (Utils, Scheduler, ExtensionRegistry, BaseView, BaseLabels, ToolBar, Config, ToolBarTabCollection, TopPane, EditToolPane, SearchPane, OperationsPane, ClipboardPane, Labels, Controls, Dialogs, MobileSearchGroup, UsersLayerMenu, gt) {
 
     'use strict';
 
-    // beneath this minimum screen width or height, the tool/tab bars should be combined
-    // Nexus 7 = min resolution 601
-    var PANES_COMBINED_MIN_SIZE = 610;
-
-    // combined panes mode via URL flag in debug mode
-    var DEBUG_PANES_COMBINED = Config.getDebugUrlFlag('office:panes-combined');
+    // convenience shortcuts
+    var Button = Controls.Button;
+    var CheckBox = Controls.CheckBox;
+    var CompoundButton = Controls.CompoundButton;
 
     // class EditView =========================================================
 
@@ -133,9 +132,6 @@ define('io.ox/office/editframework/view/editview', [
             // no filled by this class, but can be filled by addToFileToolbar() & addSeparatorToFileToolbar()
             extraToolbar = null,
 
-            // show combined Panes
-            panesCombined = false,
-
             userLayerShowOwnColor = Utils.getBooleanOption(initOptions, 'userLayerShowOwnColor', false);
 
         var mailToolbar = null;
@@ -163,17 +159,18 @@ define('io.ox/office/editframework/view/editview', [
             // the clipboard pane (debug mode only)
             var clipboardPane = null;
 
-            // determine whether the panes are combined or not
-            panesCombined = DEBUG_PANES_COMBINED || (Utils.TOUCHDEVICE && (Math.min(Utils.getScreenWidth(), Utils.getScreenHeight()) <= PANES_COMBINED_MIN_SIZE));
-
-            // disable internal browser handles on tables and drawings after edit mode has changed
-            self.listenTo(docModel, 'change:editmode', function () { self.disableBrowserEditControls(); });
+            self.listenTo(app, 'docs:editmode', function (editMode) {
+                // indicates the document edit mode
+                app.getWindowNode().toggleClass('doc-editable', editMode);
+                // disable internal browser handles on tables and drawings after edit mode has changed
+                self.disableBrowserEditControls();
+            });
 
             // create the tool bars (initialize themselves internally)
             self.addPane(topPane = new TopPane(self, toolBarTabs, { enablePresenter: Utils.getBooleanOption(initOptions, 'enablePresenter', false) }));
             self.addPane(toolPane = new EditToolPane(self, toolBarTabs, { landmark: false }));
 
-            if (panesCombined) {
+            if (Config.COMBINED_TOOL_PANES) {
                 searchGroup = new MobileSearchGroup(self);
             } else {
                 searchGroup = new SearchPane(self);
@@ -243,13 +240,16 @@ define('io.ox/office/editframework/view/editview', [
                     },
                     'debug/slowsave': {
                         parent: 'debug/enabled',
-                        enable: function () { return Config.getFlag('debugslowsave'); },
-                        get: function () { return Config.getFlag('debugslowsave') && Config.getFlag('debugslowsaveuser'); },
-                        set: function (state) { Config.set('debugslowsaveuser', state); }
+                        enable: function () { return Config.getFlag('module/debugslowsave'); },
+                        get: function () { return Config.getFlag('module/debugslowsave') && Config.getFlag('module/debugslowsaveuser'); },
+                        set: function (state) { Config.set('module/debugslowsaveuser', state); }
                     },
                     'debug/view/busy': {
                         parent: 'debug/enabled',
-                        set: function (cancelable) { return cancelable ? self.createAbortablePromise(DeferredUtils.createDeferred(app, 'EditView: debug/view/busy cancelable')) : DeferredUtils.createDeferred(app, 'EditView: debug/view/busy !cancelable'); },
+                        set: function (cancelable) {
+                            var deferred = Scheduler.createDeferred(app, 'EditView.initHandler@debug/view/busy');
+                            return cancelable ? self.createAbortablePromise(deferred) : deferred.promise();
+                        },
                         cancel: true
                     },
                     'debug/quit': {
@@ -287,16 +287,16 @@ define('io.ox/office/editframework/view/editview', [
                 pageToolbar   = null,
                 actionToolbar = null,
 
-                btnDownload        = new Controls.Button({ icon: Labels.DOWNLOAD_ICON, tooltip: gt('Download'), classes: 'link-style', dropDownVersion: { label: gt('Download') } }),
-                btnPrint           = new Controls.Button({ icon: 'fa-print', tooltip: gt('Print as PDF'), classes: 'link-style', dropDownVersion: { label: gt('Print as PDF') } }),
+                btnDownload        = new Button(self, { icon: Labels.DOWNLOAD_ICON, tooltip: gt('Download'), classes: 'link-style', dropDownVersion: { label: gt('Download') } }),
+                btnPrint           = new Button(self, { icon: 'fa-print', tooltip: gt('Print as PDF'), classes: 'link-style', dropDownVersion: { label: gt('Print as PDF') } }),
 
                 btnSendMail        = null,
                 btnSendMailKey     = 'document/sendmail',
 
-                canConvertToPDFAttachment = app.canConvertTo('pdf-attachment'),
-                canConvertToInlineHTML    = app.canConvertTo('inline-html'),
+                canConvertToPDFAttachment = app.canConvertTo('pdfAttachment'),
+                canConvertToInlineHTML    = app.canConvertTo('inlineHtml'),
 
-                btnReload          = new Controls.Button({ icon: 'fa-repeat', label: gt('Reload'), tooltip: gt('Reload document'), classes: 'link-style' }),
+                btnReload          = new Button(self, { icon: 'fa-repeat', label: gt('Reload'), tooltip: gt('Reload document'), classes: 'link-style' }),
                 btnAcquireEdit     = new Controls.AcquireEditButton(self, { classes: 'link-style' }),
                 enablePageSettings = Utils.getBooleanOption(initOptions, 'enablePageSettings', false),
                 btnShare           = new Controls.ShareButton(self, gt('Share'));
@@ -309,27 +309,26 @@ define('io.ox/office/editframework/view/editview', [
              */
             if (canConvertToPDFAttachment || canConvertToInlineHTML) {
 
-                btnSendMail        = new Controls.CompoundButton(self, {
-                    visibleKey:      'document/sendmail/menu',
+                btnSendMail = new CompoundButton(self, {
                     icon:            'fa-envelope-o',
                     classes:         'link-style',
                     tooltip:         BaseLabels.SEND_AS_MAIL_LABEL,
                     dropDownVersion: { label: BaseLabels.SEND_AS_MAIL_LABEL }
                 })
-                .addGroup('document/sendmail', new Controls.Button({ label: BaseLabels.ATTACH_AS_FILE_TO_MAIL_LABEL }));
+                .addGroup('document/sendmail', new Button(self, { label: BaseLabels.ATTACH_AS_FILE_TO_MAIL_LABEL }));
 
                 if (canConvertToPDFAttachment) {
-                    btnSendMail.addGroup('document/sendmail/pdf-attachment', new Controls.Button({ value: { attachMode: 'pdf-attachment' }, label: BaseLabels.ATTACH_AS_PDF_TO_MAIL_LABEL }));
+                    btnSendMail.addGroup('document/sendmail/pdf-attachment', new Button(self, { value: { attachMode: 'pdfAttachment' }, label: BaseLabels.ATTACH_AS_PDF_TO_MAIL_LABEL }));
                 }
                 if (canConvertToInlineHTML) {
-                    btnSendMail.addGroup('document/sendmail/inline-html',    new Controls.Button({ value: { attachMode: 'inline-html' },    label: BaseLabels.SEND_CONTENT_AS_NEW_MAIL_LABEL }));
+                    btnSendMail.addGroup('document/sendmail/inline-html', new Button(self, { value: { attachMode: 'inlineHtml' },    label: BaseLabels.SEND_CONTENT_AS_NEW_MAIL_LABEL }));
                 }
 
                 btnSendMailKey = 'document/sendmail/menu';
 
             } else { // defaults to the file-attachment build-in.
 
-                btnSendMail        = new Controls.Button({
+                btnSendMail = new Button(self, {
                     icon:            'fa-envelope-o',
                     classes:         'link-style',
                     tooltip:         BaseLabels.SEND_AS_MAIL_LABEL,
@@ -349,39 +348,41 @@ define('io.ox/office/editframework/view/editview', [
             // TOOLBARS
             //      prepare all toolbars (for normal or combined panes)
             // -----------------------------------------------------
-            if (!self.panesCombined()) {
+            if (!Config.COMBINED_TOOL_PANES) {
                 renameToolbar   = self.createToolBar('file');
                 saveToolbar     = self.createToolBar('file', { priority: 2, visibleKey: 'app/bundled' });
             }
 
             if (enablePageSettings) {
-                pageToolbar = self.createToolBar('file', { priority: 3, label: gt('Page'), classes: 'link-style', prepareShrink: true });
+                pageToolbar = self.createToolBar('file', { priority: 3, classes: 'link-style' });
             }
 
-            commonToolbar = self.createToolBar('file', { priority: 3, label: gt('Actions'), classes: 'link-style', prepareShrink: true });
-            printToolbar  = self.createToolBar('file', { priority: 3, label: gt('Actions'), classes: 'link-style', prepareShrink: true, visibleKey: 'document/print' });
-            mailToolbar   = self.createToolBar('file', { priority: 3, label: BaseLabels.SEND_AS_MAIL_LABEL, classes: 'link-style noSeparator', visibleKey: btnSendMailKey });
-            shareToolbar  = self.createToolBar('file', { priority: 3, label: gt('Share'), classes: 'link-style', visibleKey: 'document/share' });
-            extraToolbar  = self.createToolBar('file', { priority: 3, tooltip: gt('Actions'), classes: 'link-style' });
-            actionToolbar = self.createToolBar('file', { priority: 1, tooltip: gt('Actions'), classes: 'link-style' });
+            commonToolbar = self.createToolBar('file', { priority: 3, classes: 'link-style', shrinkToMenu: { label: gt('Actions') } });
+            printToolbar  = self.createToolBar('file', { priority: 3, classes: 'link-style', visibleKey: 'document/print', shrinkToMenu: { label: gt('Actions') } });
+            mailToolbar   = self.createToolBar('file', { priority: 3, classes: 'link-style noSeparator', visibleKey: btnSendMailKey });
+            shareToolbar  = self.createToolBar('file', { priority: 3, classes: 'link-style', visibleKey: 'document/share' });
+            extraToolbar  = self.createToolBar('file', { priority: 3, classes: 'link-style' });
+            actionToolbar = self.createToolBar('file', { priority: 1, classes: 'link-style' });
 
             // -----------------------------------------------------
             // CONTROLS
             //      add all controls
             // -----------------------------------------------------
-            if (!self.panesCombined()) {
+            if (!Config.COMBINED_TOOL_PANES) {
                 var fileNameField       = new Controls.FileNameField(self),
-                    cBoxAutosave        = new Controls.CheckBox({ label: gt('AutoSave') }),
-                    btnSaveAs           = new Controls.Button({ label: gt('Save as'), value: 'file' }),
-                    btnSaveAsTemplate   = new Controls.Button({ label: gt('Save as template'), value: 'template' }),
-                    btnExportAsPdf      = new Controls.Button({ label: gt('Export as PDF'), value: 'pdf' });        // DOCS-122 :: misinterpreted story - [https://jira.open-xchange.com/browse/DOCS-122] :: but hereby saved for good.
+                    cBoxAutosave        = new CheckBox(self, { label: gt('AutoSave') }),
+                    btnSaveAs           = new Button(self, { label: gt('Save as'), value: 'file' }),
+                    btnSaveAsEncrypted  = new Button(self, { label: gt('Save as (encrypted)'), value: 'encrypted' }),
+                    btnSaveAsTemplate   = new Button(self, { label: gt('Save as template'), value: 'template' }),
+                    btnExportAsPdf      = new Button(self, { label: gt('Export as PDF'), value: 'pdf' });        // DOCS-122 :: misinterpreted story - [https://jira.open-xchange.com/browse/DOCS-122] :: but hereby saved for good.
 
                 renameToolbar
                     .addGroup('document/rename', fileNameField);
 
                 saveToolbar
-                    .addGroup('view/saveas/menu', new Controls.CompoundButton(self, { label: gt('Save in Drive'), classes: 'link-style', smallerVersion: { icon: 'fa-save', hideLabel: true } })
+                    .addGroup('view/saveas/menu', new CompoundButton(self, { label: gt('Save in Drive'), classes: 'link-style', smallerVersion: { icon: 'fa-save', hideLabel: true } })
                         .addGroup('document/saveas/dialog', btnSaveAs)
+                        .addGroup('document/saveasencrypted/dialog', btnSaveAsEncrypted)
                         .addGroup('document/saveas/dialog', btnSaveAsTemplate)
                         .addSeparator()
                         .addGroup('document/exportaspdf/dialog', btnExportAsPdf)                                    // DOCS-122 :: misinterpreted story - [https://jira.open-xchange.com/browse/DOCS-122] :: but hereby saved for good.
@@ -403,7 +404,7 @@ define('io.ox/office/editframework/view/editview', [
 
             if (pageToolbar) {
                 if (enablePageSettings) {
-                    pageToolbar.addGroup('document/pagesettings', new Controls.Button({
+                    pageToolbar.addGroup('document/pagesettings', new Button(self, {
                         icon: 'docs-page-layout',
                         tooltip: docModel.useSlideMode() ? gt('Slide settings') : gt('Page settings'),
                         classes: 'link-style',
@@ -412,12 +413,18 @@ define('io.ox/office/editframework/view/editview', [
                 }
             }
 
-            commonToolbar.addGroup('document/download', btnDownload);
+            if (Config.COMBINED_TOOL_PANES) {
+                commonToolbar.addGroup('document/download', btnDownload)
+                             .addGroup('document/print', btnPrint, { visibleKey: 'document/print' })
+                             .addGroup(btnSendMailKey, btnSendMail);
 
-            printToolbar.addGroup('document/print', btnPrint);
+            } else {
+                commonToolbar.addGroup('document/download', btnDownload);
+                printToolbar.addGroup('document/print', btnPrint);
 
-            // provide different appearance of "send mail" button(s) in dependency of an application's ([app]'s) send mail operations/methods.
-            mailToolbar.addGroup(btnSendMailKey, btnSendMail);
+                // provide different appearance of "send mail" button(s) in dependency of an application's ([app]'s) send mail operations/methods.
+                mailToolbar.addGroup(btnSendMailKey, btnSendMail);
+            }
 
             actionToolbar
                 .addGroup('document/acquireeditOrPending', btnAcquireEdit, { visibleKey: 'document/acquireedit' })
@@ -450,35 +457,35 @@ define('io.ox/office/editframework/view/editview', [
             // add view options
             viewMenuGroup
                 .addSectionLabel(_.noI18n('Debug'))
-                .addGroup('debug/operationspane', new Controls.CheckBox({ label: _.noI18n('Show operations panel') }))
-                .addGroup('debug/clipboardpane',  new Controls.CheckBox({ label: _.noI18n('Show clipboard panel') }))
-                .addGroup('debug/console',        new Controls.CheckBox({ label: _.noI18n('Show overlay log console') }))
-                .addGroup('debug/highlight/dom',  new Controls.CheckBox({ label: _.noI18n('Highlight DOM elements') }));
+                .addGroup('debug/operationspane', new CheckBox(self, { label: _.noI18n('Show operations panel') }))
+                .addGroup('debug/clipboardpane',  new CheckBox(self, { label: _.noI18n('Show clipboard panel') }))
+                .addGroup('debug/console',        new CheckBox(self, { label: _.noI18n('Show overlay log console') }))
+                .addGroup('debug/highlight/dom',  new CheckBox(self, { label: _.noI18n('Highlight DOM elements') }));
 
             // create the drop-down list for the debug actions
-            actionMenuGroup = new Controls.CompoundButton(self, { icon: 'fa-wrench', label: Labels.ACTIONS_LABEL, tooltip: _.noI18n('Additional debug actions'), classes: 'link-style' })
+            actionMenuGroup = new CompoundButton(self, { icon: 'fa-wrench', label: Labels.ACTIONS_LABEL, tooltip: _.noI18n('Additional debug actions'), classes: 'link-style' })
                 // register realtime debug actions
                 .addSectionLabel(_.noI18n('Offline mode'))
-                .addGroup('debug/realtime/trigger', new Controls.Button({ label: _.noI18n('Switch to offline mode'),      value: 'offline' }))
-                .addGroup('debug/realtime/trigger', new Controls.Button({ label: _.noI18n('Switch to online mode'),       value: 'online' }))
+                .addGroup('debug/realtime/trigger', new Button(self, { label: _.noI18n('Switch to offline mode'),      value: 'offline' }))
+                .addGroup('debug/realtime/trigger', new Button(self, { label: _.noI18n('Switch to online mode'),       value: 'online' }))
                 .addSectionLabel(_.noI18n('Realtime connection'))
-                .addGroup('debug/realtime/trigger', new Controls.Button({ label: _.noI18n('Simulate connection reset'),   value: 'reset' }))
-                .addGroup('debug/realtime/trigger', new Controls.Button({ label: _.noI18n('Simulate connection timeout'), value: 'timeout' }))
-                .addGroup('debug/realtime/trigger', new Controls.Button({ label: _.noI18n('Simulate connection hangup'),  value: 'hangup' }))
+                .addGroup('debug/realtime/trigger', new Button(self, { label: _.noI18n('Simulate connection reset'),   value: 'reset' }))
+                .addGroup('debug/realtime/trigger', new Button(self, { label: _.noI18n('Simulate connection timeout'), value: 'timeout' }))
+                .addGroup('debug/realtime/trigger', new Button(self, { label: _.noI18n('Simulate connection hangup'),  value: 'hangup' }))
                 // register debug actions for operations
                 .addSectionLabel(_.noI18n('Operations'))
-                .addGroup('debug/operations/apply',              new Controls.Button({ label: _.noI18n('Apply operation with invalid name'), value: { name: '_invalid_operation_' } }))
-                .addGroup('debug/operations/apply',              new Controls.Button({ label: _.noI18n('Apply operation with invalid position'), value: { name: 'insertText', start: [987654321, 0], text: 'test' } }))
-                .addGroup('debug/realtime/sendinvalidoperation', new Controls.Button({ label: _.noI18n('Send operation with invalid OSN'), value: { operation: { name: 'delete', start: [987654321, 0] }, badOsn: true } }))
-                .addGroup('debug/realtime/sendinvalidoperation', new Controls.Button({ label: _.noI18n('Send invalid operation'), value: { operation: { name: 'createError', start: [987654321, 0] } } }))
+                .addGroup('debug/operations/apply',              new Button(self, { label: _.noI18n('Apply operation with invalid name'), value: { name: '_invalid_operation_' } }))
+                .addGroup('debug/operations/apply',              new Button(self, { label: _.noI18n('Apply operation with invalid position'), value: { name: 'insertText', start: [987654321, 0], text: 'test' } }))
+                .addGroup('debug/realtime/sendinvalidoperation', new Button(self, { label: _.noI18n('Send operation with invalid OSN'), value: { operation: { name: 'delete', start: [987654321, 0] }, badOsn: true } }))
+                .addGroup('debug/realtime/sendinvalidoperation', new Button(self, { label: _.noI18n('Send invalid operation'), value: { operation: { name: 'createError', start: [987654321, 0] } } }))
                 // register debug actions for busy screen
                 .addSectionLabel(_.noI18n('Busy blocker'))
-                .addGroup('debug/view/busy', new Controls.Button({ label: _.noI18n('Show permanent busy screen'), value: false }))
-                .addGroup('debug/view/busy', new Controls.Button({ label: _.noI18n('Show busy screen with Cancel button'), value: true }))
+                .addGroup('debug/view/busy', new Button(self, { label: _.noI18n('Show permanent busy screen'), value: false }))
+                .addGroup('debug/view/busy', new Button(self, { label: _.noI18n('Show busy screen with Cancel button'), value: true }))
                 // register debug actions for application quit
                 .addSectionLabel(_.noI18n('Quit'))
-                .addGroup('debug/quit', new Controls.Button({ label: _.noI18n('Close document with unsaved changes'), value: 'unsaved' }))
-                .addGroup('debug/quit', new Controls.Button({ label: _.noI18n('Close document with server error'),    value: 'error' }));
+                .addGroup('debug/quit', new Button(self, { label: _.noI18n('Close document with unsaved changes'), value: 'unsaved' }))
+                .addGroup('debug/quit', new Button(self, { label: _.noI18n('Close document with server error'),    value: 'error' }));
 
             searchGroup.handleTabListButtons();
 
@@ -488,7 +495,7 @@ define('io.ox/office/editframework/view/editview', [
 
             // create a new tool bar for debugging containing debug options
             self.createToolBar('debug')
-                .addGroup('debug/slowsave', new Controls.Button({ icon: 'fa-floppy-o', tooltip: _.noI18n('Slow down save document (' + Config.get('debugslowsavetime', 0) + 's)'), toggle: true }));
+                .addGroup('debug/slowsave', new Button(self, { icon: 'fa-floppy-o', tooltip: _.noI18n('Slow down save document (' + Config.get('module/debugslowsavetime', 0) + 's)'), toggle: true }));
 
             // call initialization handler passed by sub class
             return Utils.getFunctionOption(initOptions, 'initDebugGuiHandler', $.noop).call(self, viewMenuGroup, actionMenuGroup);
@@ -550,6 +557,28 @@ define('io.ox/office/editframework/view/editview', [
             return this;
         };
 
+        /**
+         * Inserts a new tool bar into the tool pane of the application view.
+         *
+         * @param {String} tabId
+         *  The identifier of the tab button the tool bar will be associated
+         *  with.
+         *
+         * @param {ToolBar} toolBar
+         *  The tool bar to be inserted into the tool pane. The edit tool pane
+         *  takes ownership of the tool bar!
+         *
+         * @param {Object} [options]
+         *  Optional parameters. Supports all options that are supported by the
+         *  method EditToolpane.addToolBar().
+         *
+         * @returns {ToolBar}
+         *  The tool bar instance passed to this method, for convenience.
+         */
+        this.addToolBar = function (tabId, toolBar, options) {
+            return toolPane.addToolBar(tabId, toolBar, options);
+        };
+
         /**
          * Creates a new tool bar in the tool pane of the application view.
          *
@@ -558,14 +587,15 @@ define('io.ox/office/editframework/view/editview', [
          *  with.
          *
          * @param {Object} [options]
-         *  Optional parameters. Supports all options supported by the method
-         *  EditToolPane.createToolBar().
+         *  Optional parameters. Supports all options supported by the ToolBar
+         *  class constructor. Additionally, this method supports all options
+         *  that are supported by the method EditToolPane.addToolBar().
          *
          * @returns {ToolBar}
          *  The new tool bar instance.
          */
         this.createToolBar = function (tabId, options) {
-            return toolPane.createToolBar(tabId, options);
+            return toolPane.addToolBar(tabId, new ToolBar(this, options));
         };
 
         /**
@@ -598,6 +628,14 @@ define('io.ox/office/editframework/view/editview', [
             return toolPane;
         };
 
+        /**
+         * adds a group to the extra toolbar
+         * (to be right of the other bars)
+         */
+        this.addToFilebar = function (key, group, options) {
+            extraToolbar.addGroup(key, group, options);
+        };
+
         /**
          * Registers a label text and optional icon for a specific user defined
          * application state.
@@ -656,10 +694,20 @@ define('io.ox/office/editframework/view/editview', [
                     window.document.execCommand('enableInlineTableEditing', false, false);
                 } catch (ex) {
                 }
-            }, { infoString: 'EditFramework: disableBrowserEditControls', app: app });
+            }, 'EditView.disableBrowserEditControls');
             return this;
         };
 
+        /**
+         * Returns whether the document can be modified currently.
+         *
+         * @returns {Boolean}
+         *  Whether the document can be modified.
+         */
+        this.isEditable = function () {
+            return app.isEditable();
+        };
+
         /**
          * Closes the passed dialog automatically, if the document switches to
          * read-only mode.
@@ -667,30 +715,22 @@ define('io.ox/office/editframework/view/editview', [
          * @param {ModalDialog} dialog
          *  The dialog instance that will be closed on read-only mode.
          *
-         * @param {Function} [closeCallback]
-         * A callback handler function called if document switches to read-only mode
-         *
          * @returns {EditView}
          *  A reference to this instance.
          */
-        this.closeDialogOnReadOnlyMode = function (dialog, closeCallback) {
+        this.closeDialogOnReadOnlyMode = function (dialog) {
 
             // close the dialog if document switches to read-only mode
-            function changeEditModeHandler(event, editMode) {
-                if (!editMode) {
-                    dialog.close();
-                    if (_.isFunction(closeCallback)) {
-                        closeCallback();
-                    }
-                }
+            function changeEditModeHandler() {
+                dialog.close();
             }
 
             // listen to read-only mode, close dialog automatically
-            this.listenTo(docModel, 'change:editmode', changeEditModeHandler);
+            this.listenTo(app, 'docs:editmode:leave', changeEditModeHandler);
 
             // unregister listener after closing the dialog
             dialog.on('close', function () {
-                self.stopListeningTo(docModel, 'change:editmode', changeEditModeHandler);
+                self.stopListeningTo(app, 'docs:editmode:leave', changeEditModeHandler);
             });
 
             return this;
@@ -718,7 +758,7 @@ define('io.ox/office/editframework/view/editview', [
         this.showQueryDialog = function (title, message, options) {
 
             // create a query dialog instance
-            var dialog = new Dialogs.ModalQueryDialog(message, _.extend({}, options, { title: title }));
+            var dialog = new Dialogs.ModalQueryDialog(this, message, _.extend({}, options, { title: title }));
 
             // close dialog automatically when losing edit rights
             this.closeDialogOnReadOnlyMode(dialog);
@@ -727,13 +767,53 @@ define('io.ox/office/editframework/view/editview', [
             return dialog.show();
         };
 
+        /**
+         * Overrides the same method of the base class BaseView, and adds
+         * functionality to react on the event that the user loses the edit
+         * rights for the document.
+         *
+         * @param {Object} [options]
+         *  Optional parameters. Supports all options that are also supported
+         *  by the base class method BaseView.enterBusy(), and the following
+         *  additional options:
+         *  @param {Boolean} [options.cancelOnReadOnly=false]
+         *      If set to true, the cancel callback handler passed with the
+         *      option 'cancelHandler' will be invoked automatically.
+         *
+         * @returns {EditView}
+         *  A reference to this instance.
+         */
+        this.enterBusy = _.wrap(this.enterBusy, function (enterBusy, options) {
+
+            // an optional call back function to be called, when edit rights are gone
+            var cancelHandler = Utils.getFunctionOption(options, 'cancelHandler');
+
+            // calling the base class before registering handler
+            enterBusy.call(this, options);
+
+            if (cancelHandler && Utils.getBooleanOption(options, 'cancelOnReadOnly', false)) {
+
+                // invoke cancel handler when leaving edit mode, unregister event handler when leaving busy mode
+                this.listenTo(app, 'docs:editmode:leave', cancelHandler);
+                this.listenOnceTo(app.getWindow(), 'idle', function () {
+                    self.stopListeningTo(app, 'docs:editmode:leave', cancelHandler);
+                });
+            }
+
+            return this;
+        });
+
         /**
          * Toggles the visibility of the collaborator popup
          *
          * @param {Boolean} visibility
+         *
+         * @returns {EditView}
+         *  A reference to this instance.
          */
         this.toggleCollaboratorPopup = function (visibility) {
             collaboratorPopup.toggle(visibility);
+            return this;
         };
 
         /**
@@ -756,13 +836,13 @@ define('io.ox/office/editframework/view/editview', [
          */
         this.showRenameDialog = function () {
 
-            var // the dialog instance
-                dialog = new Dialogs.ModalInputDialog({
-                    title: gt('Rename document'),
-                    okLabel: gt('Rename'),
-                    value: this.getShortFileName(),
-                    placeholder: gt('Document name')
-                });
+            // the dialog instance
+            var dialog = new Dialogs.ModalInputDialog(this, {
+                title: gt('Rename document'),
+                okLabel: gt('Rename'),
+                value: this.getShortFileName(),
+                placeholder: gt('Document name')
+            });
 
             // close dialog automatically after losing edit rights
             this.closeDialogOnReadOnlyMode(dialog);
@@ -782,6 +862,7 @@ define('io.ox/office/editframework/view/editview', [
          *  The target file type. The following file types are supported:
          *  - 'file' (default): Save with the current extension.
          *  - 'template': Save as template file.
+         *  - 'pdf': Convert to PDF and save.
          *
          * @returns {jQuery.Promise}
          *  The Promise of a Deferred object that will be resolved when the
@@ -808,8 +889,8 @@ define('io.ox/office/editframework/view/editview', [
 
                 templateExt = ExtensionRegistry.getTemplateExtension(app.getFullFileName());
 
-                //#. %1$s is the file extension used for the template file
-                //#, c-format
+                    //#. %1$s is the file extension used for the template file
+                    //#, c-format
                 title = gt('Save as template (%1$s)', _.noI18n(templateExt));
 
                 // create the dialog
@@ -823,18 +904,32 @@ define('io.ox/office/editframework/view/editview', [
                 title = gt('Export as PDF');
 
                 // create the dialog
-                dialog = new Dialogs.SaveAsFileDialog({ title: title, value: newFileName, preselect: app.getFileParameters().folder_id });
+                dialog = new Dialogs.SaveAsFileDialog(this, {
+                    title: title,
+                    value: newFileName,
+                    preselect: app.getFileParameters().folder_id
+                });
 
             } else {
 
-                //#. %1$s is the name of the original file used to create a new copy
-                //#, c-format
-                newFileName = gt('Copy of %1$s', _.noI18n(oldFileName));
-
-                title = gt('Save as');
+                if (type === 'encrypted') {
+                    //#. %1$s is the name of the original file used to create a new copy
+                    //#, c-format
+                    newFileName = gt('Copy of %1$s', _.noI18n(Utils.getFileBaseName(oldFileName)));
+                    title = gt('Save as (encrypted)');
+                } else {
+                    //#. %1$s is the name of the original file used to create a new copy
+                    //#, c-format
+                    newFileName = gt('Copy of %1$s', _.noI18n(oldFileName));
+                    title = gt('Save as');
+                }
 
                 // create the dialog
-                dialog = new Dialogs.SaveAsFileDialog({ title: title, value: newFileName, preselect: app.getFileParameters().folder_id });
+                dialog = new Dialogs.SaveAsFileDialog(this, {
+                    title: title,
+                    value: newFileName,
+                    preselect: app.getFileParameters().folder_id
+                });
             }
 
             // show the dialog, and perform the save action
@@ -870,7 +965,11 @@ define('io.ox/office/editframework/view/editview', [
             title = gt('Restore document');
 
             // create the dialog
-            dialog = new Dialogs.SaveAsFileDialog({ title: title, value: newFileName, preselect: app.getFileParameters().folder_id });
+            dialog = new Dialogs.SaveAsFileDialog(this, {
+                title: title,
+                value: newFileName,
+                preselect: app.getFileParameters().folder_id
+            });
 
             // show the dialog, and perform the save action
             return dialog.show().then(function () {
@@ -878,16 +977,6 @@ define('io.ox/office/editframework/view/editview', [
             });
         };
 
-        /**
-         * return whether tool-/tabbars should be combined or not
-         *
-         * @returns {Boolean}
-         *  'true' for combining the bars
-         */
-        this.panesCombined = function () {
-            return panesCombined;
-        };
-
         /**
          * Returns the effective zoom factor of the document. This method MUST
          * be overwritten by the respective applications sub classes.
@@ -904,60 +993,6 @@ define('io.ox/office/editframework/view/editview', [
             throw new Error('abstract method called');
         };
 
-        // undo manager -------------------------------------------------------
-
-        /**
-         * Returns whether at least one undo action is available on the undo
-         * stack.
-         *
-         * @returns {Boolean}
-         *  Whether at least one undo action is available on the stack.
-         */
-        this.isUndoAvailable = function () {
-            return docModel.getUndoManager().getUndoCount() > 0;
-        };
-
-        /**
-         * Applies the topmost undo action on the undo stack.
-         *
-         * @returns {jQuery.Promise}
-         *  A Promise that will be resolved after the undo action has been
-         *  applied.
-         */
-        this.undo = function () {
-            return docModel.getUndoManager().undo();
-        };
-
-        /**
-         * Returns whether at least one redo action is available on the redo
-         * stack.
-         *
-         * @returns {Boolean}
-         *  Whether at least one redo action is available on the stack.
-         */
-        this.isRedoAvailable = function () {
-            return docModel.getUndoManager().getRedoCount() > 0;
-        };
-
-        /**
-         * Applies the topmost redo action on the redo stack.
-         *
-         * @returns {jQuery.Promise}
-         *  A Promise that will be resolved after the redo action has been
-         *  applied.
-         */
-        this.redo = function () {
-            return docModel.getUndoManager().redo();
-        };
-
-        this.addToCommonToolbar = function (key, group, options) {
-            extraToolbar.addGroup(key, group, options);
-        };
-
-        this.addSeparatorToCommonToolbar = function () {
-            // do nothing
-        };
-
         // initialization -----------------------------------------------------
 
         // create class members relying on complete view
