@@ -35,22 +35,22 @@ define('io.ox/office/editframework/view/popup/userslayermenu', [
      */
     function UsersLayerMenu(docView, initOptions) {
 
-        var // self reference
-            self = this,
+        // self reference
+        var self = this;
 
-            // the application instance
-            app = docView.getApp(),
+        // the application instance
+        var app = docView.getApp();
 
-            // all existing user badges, mapped by unique user index
-            bagdeGroups = {},
+        // all existing user badges, mapped by unique user index
+        var bagdeGroups = {};
 
-            // whether this control is visible when the app window is hidden
-            visibleState = false,
+        // whether this control is visible when the app window is hidden
+        var visibleState = false;
 
-            // whether to automatically show the menu for at least two active users
-            autoShow = true,
+        // whether to automatically show the menu for at least two active users
+        var autoShow = true;
 
-            showOwnColor = Utils.getBooleanOption(initOptions, 'showOwnColor', false);
+        var showOwnColor = Utils.getBooleanOption(initOptions, 'showOwnColor', false);
 
         // base constructor ---------------------------------------------------
 
@@ -58,7 +58,7 @@ define('io.ox/office/editframework/view/popup/userslayermenu', [
             tooltip: gt('List of collaborators of this document'),
             autoFocus: false,
             rootContainerNode: app.getWindowNode(),
-            refreshNodeRepeatedDelayed: false
+            backgroundRefresh: false
         });
 
         // private methods ----------------------------------------------------
@@ -98,7 +98,7 @@ define('io.ox/office/editframework/view/popup/userslayermenu', [
         /**
          * Debounced version of the method UsersLayerMenu.fillMenu().
          */
-        var fillMenuDebounced = this.createDebouncedMethod(_.noop, fillMenu, { infoString: 'UsersLayerMenu fillMenuDebounced', app: app });
+        var fillMenuDebounced = this.createDebouncedMethod('UsersLayerMenu.fillMenuDebounced', null, fillMenu);
 
         /**
          * Sets the default position of the collaborators list layer menu
