@@ -17,12 +17,16 @@ define('io.ox/office/editframework/view/searchpane', [
     'io.ox/office/tk/keycodes',
     'io.ox/office/baseframework/view/toolpane',
     'io.ox/office/baseframework/view/toolbar',
-    'io.ox/office/baseframework/view/basecontrols',
-    'io.ox/office/editframework/view/editlabels'
-], function (Utils, KeyCodes, ToolPane, ToolBar, Controls, EditLabels) {
+    'io.ox/office/editframework/view/editlabels',
+    'io.ox/office/editframework/view/editcontrols'
+], function (Utils, KeyCodes, ToolPane, ToolBar, Labels, Controls) {
 
     'use strict';
 
+    // convenience shortcuts
+    var Button = Controls.Button;
+    var TextField = Controls.TextField;
+
     // class SearchPane =======================================================
 
     /**
@@ -37,11 +41,11 @@ define('io.ox/office/editframework/view/searchpane', [
      */
     var SearchPane = ToolPane.extend({ constructor: function (docView) {
 
-        var self = this,
+        var self = this;
 
-            lastLayoutState = null,
+        var lastLayoutState = null;
 
-            searchBar = new ToolBar(docView);
+        var searchBar = new ToolBar(docView);
 
         // base constructor ---------------------------------------------------
 
@@ -101,13 +105,13 @@ define('io.ox/office/editframework/view/searchpane', [
         this.hide();
 
         searchBar
-            .addGroup('document/search/text',  new Controls.TextField(EditLabels.SEARCH_TEXT))
-            .addGroup('document/search/start', new Controls.Button(EditLabels.SEARCH_START))
-            .addGroup('document/search/prev',  new Controls.Button(EditLabels.SEARCH_PREV))
-            .addGroup('document/search/next',  new Controls.Button(EditLabels.SEARCH_NEXT))
-            .addGroup('document/replace/text', new Controls.TextField(EditLabels.REPLACE_TEXT))
-            .addGroup('document/replace/next', new Controls.Button(EditLabels.REPLACE_NEXT))
-            .addGroup('document/replace/all',  new Controls.Button(EditLabels.REPLACE_ALL));
+            .addGroup('document/search/text',  new TextField(docView, Labels.SEARCH_TEXT))
+            .addGroup('document/search/start', new Button(docView, Labels.SEARCH_START))
+            .addGroup('document/search/prev',  new Button(docView, Labels.SEARCH_PREV))
+            .addGroup('document/search/next',  new Button(docView, Labels.SEARCH_NEXT))
+            .addGroup('document/replace/text', new TextField(docView, Labels.REPLACE_TEXT))
+            .addGroup('document/replace/next', new Button(docView, Labels.REPLACE_NEXT))
+            .addGroup('document/replace/all',  new Button(docView, Labels.REPLACE_ALL));
 
         this.addViewComponent(searchBar);
 
