@@ -22,14 +22,13 @@ define('io.ox/office/portal/action/recentsactions', [
     'io.ox/core/extPatterns/links',
     'io.ox/core/extPatterns/actions',
     'io.ox/office/tk/io',
-    'io.ox/office/tk/utils/scheduler',
     'io.ox/office/baseframework/utils/baseconfig',
     'io.ox/office/portal/portalutils',
     'io.ox/office/portal/view/contextmenu',
     'gettext!io.ox/office/portal/main',
     'io.ox/files/toolbar', // important for action links (download in contextmenu)
     'io.ox/mail/detail/links' // this line is important for deep links usage (works with jq delegation)
-], function (Ext, Links, CoreActions, IO, Scheduler, Config, Utils, ContextMenu, gt) {
+], function (Ext, Links, CoreActions, IO, Config, Utils, ContextMenu, gt) {
 
     'use strict';
 
@@ -68,7 +67,7 @@ define('io.ox/office/portal/action/recentsactions', [
 
                     // the path displayed in recent list: The css ellipsis function doesn't
                     // work right with :before, therefore the the divider icon
-                    // (awesomfont - &#xf105; = fa-angle-right) needs to be embedded directly here.
+                    // (awesome font - &#xf105; = fa-angle-right) needs to be embedded directly here.
                     var divider = (baton.data.path.length === (index + 1)) ? '' : '<span class = "divider">' + _.noI18n('&#xf105;') + '</span>'; // Don't insert the divider symbol for the last element.
                     escapedFilePath += _.noI18n(Utils.escapeHTML(folderInfo.filename)) + divider;
 
@@ -78,7 +77,7 @@ define('io.ox/office/portal/action/recentsactions', [
 
                 });
 
-                // build the titel for the tooltip
+                // build the title for the tooltip
                 escapedTitle = _.noI18n(escapedFileName) + '<div class ="tooltip-filepath">' + escapedFilePathinToolTip + '</div>';
                 // iPad title problem: long tap on element -> ios popup appears -> html markup is visible
                 if (Utils.COMPACT_DEVICE) {
@@ -104,12 +103,18 @@ define('io.ox/office/portal/action/recentsactions', [
                     divDate = $('<div class="document-date col-xs-3">').text(_.noI18n(Utils.formatDate(baton.data.last_modified ? baton.data.last_modified : baton.data.last_opened)));
 
                 divName.append(Utils.createDocumentIcon(fullFileName), divFilename, divPath);
+
+                // check if the document is encrypted add add a overlay icon if true
+                if (Utils.isGuardEncrypted(fullFileName)) {
+                    divDate.append($('<i class="encryption-overlay ' + Utils.getAppBaseName(fullFileName) + ' fa fa-lock" aria-hidden="true"></i>'));
+                }
+
                 link.append(divMetadata.append(divName, divDate));
 
                 link.click(function () {
 
                     // only invoke the action when no context menu is open
-                    // use case: the user can click everywere on the screen to close the contextmenu
+                    // use case: the user can click everywhere on the screen to close the contextmenu
                     if (!ContextMenu.isOpen()) {
 
                         // provide feedback to the user which element will be opened
@@ -265,7 +270,7 @@ define('io.ox/office/portal/action/recentsactions', [
                 // After a click event the context menu is closed by the basemenu globalClickHandler().
                 // When a context menu is open, clicking on an element should not invoke it's attached action, but just close the context menu.
                 // As 'closing' and 'invocation' due to a click event happens at the same time, ContextMenu.setOpen(false) must be called delayed.
-                Scheduler.setTimeout(function () { ContextMenu.setOpen(false); }, 300, null, 'RecentsActions contextMenuHandler');
+                window.setTimeout(function () { ContextMenu.setOpen(false); }, 300);
 
                 // destroy the context menu
                 cmenu = null;
