@@ -21,9 +21,9 @@ define('io.ox/office/portal/action/templateactions', [
     'io.ox/office/tk/utils/driveutils',
     'io.ox/office/portal/portalutils',
     'io.ox/office/portal/view/contextmenu',
-    'io.ox/office/tk/utils/scheduler',
+    'io.ox/core/capabilities',
     'gettext!io.ox/office/portal/main'
-], function (Ext, Links, CoreActions, DriveUtils, Utils, ContextMenu, Scheduler, gt) {
+], function (Ext, Links, CoreActions, DriveUtils, Utils, ContextMenu, Capabilities, gt) {
 
     'use strict';
 
@@ -236,7 +236,7 @@ define('io.ox/office/portal/action/templateactions', [
 
             // handle context menu
             templateItem.on('contextmenu', function (e) {
-                contextMenuHandler(e, templateItem, baton, highLightElement);
+                contextMenuHandler(e, baton, highLightElement);
             });
 
             // prevent focus change on click due to mousedown
@@ -270,17 +270,27 @@ define('io.ox/office/portal/action/templateactions', [
          *  The event which triggered the context menu.
          *  The event contains the position were the context menu is opened.
          *
-         * @param {JQuery} link
-         *  The DOM element the context menu is opened for.
-         *
          * @param {Object} baton
          *  The baton for the element the context menu is opened for.
          *
          * @param {jQuery} highLight
          *  The selected element which should be highlighted in the GUI
          *  (note: different for presentation and test/spreadsheet).
+         *
+         * @param {String} blankInvokeId
+         *  The invokeId for a new blank document.
+         *
+         * @param {String} blankTitle
+         *  The context menu entry title for a blank document.
+         *
+         * @param {String} blankInvokeIdEncrypted
+         *  The invokeId for a new blank encrypted document.
+         *
+         * @param {String} blankTitleEncrypted
+         *  The context menu entry title for a blank encrypted document.
+         *
          */
-        function contextMenuHandler(event, link, baton, highLight) {
+        function contextMenuHandler(event, baton, highLight, blankInvokeId, blankTitle, blankInvokeIdEncrypted, blankTitleEncrypted) {
 
             // global flag that a context menu is open
             ContextMenu.setOpen(true);
@@ -294,12 +304,14 @@ define('io.ox/office/portal/action/templateactions', [
             if (baton.data.source === 'global') {
                 cmenu.createSectionNode('heading', { label: gt('System template') }); //heading
                 getNewFromTemplateButton(cmenu, this, baton, 'heading');
+                getNewFromTemplateEncryptedButton(cmenu, this, baton, 'heading');
             }
 
             // init the GUI - case: global template set by the admin
             if (baton.data.source === 'admin') {
                 cmenu.createSectionNode('heading', { label: gt('Global template') }); //heading
                 getNewFromTemplateButton(cmenu, this, baton, 'heading');
+                getNewFromTemplateEncryptedButton(cmenu, this, baton, 'heading');
                 getEditTemplateButton(cmenu, this, baton, 'heading');
                 getshowTemplateInDriveButton(cmenu, baton, 'heading');
             }
@@ -308,11 +320,19 @@ define('io.ox/office/portal/action/templateactions', [
             if (baton.data.source === 'user') {
                 cmenu.createSectionNode('heading', { label: gt('User template') }); //heading
                 getNewFromTemplateButton(cmenu, this, baton, 'heading');
+                getNewFromTemplateEncryptedButton(cmenu, this, baton, 'heading');
                 getEditTemplateButton(cmenu, this, baton, 'heading');
                 getshowTemplateInDriveButton(cmenu, baton, 'heading');
 
             }
 
+            if (blankInvokeId) {
+                getNewBlankButton(cmenu, baton, 'heading', blankInvokeId, blankTitle);
+            }
+            if (blankInvokeIdEncrypted) {
+                getNewBlankEncryptedButton(cmenu, baton, 'heading', blankInvokeIdEncrypted, blankTitleEncrypted);
+            }
+
             // Create the "Edit template" button in the context menu with
             // eventListener and the invoked action on execution.
             function getEditTemplateButton(cmenu, self, baton, section) {
@@ -338,6 +358,46 @@ define('io.ox/office/portal/action/templateactions', [
                 return newFromTemplateButton;
             }
 
+            // Create the "New from template (encrypted)" button in the context menu with
+            // eventListener and the invoked action on execution.
+            function getNewFromTemplateEncryptedButton(cmenu, self, baton, section) {
+                if (Capabilities.has('guard-docs')) {
+                    var newFromTemplateButton = cmenu.createItemNode('newfromtemplateencrypted', { section: section, content: gt('New from template (encrypted)') });
+
+                    newFromTemplateButton.on('click', function () {
+                        cmenu.hide();  //hide the context menu after a button was clicked
+                        CoreActions.invoke(templateExtension + '/action/open-encrypted', self, baton.data);
+                    });
+                    return newFromTemplateButton;
+                }
+            }
+
+            // Create the New document(text, spreadsheet, presentation) button in the context menu with
+            // eventListener and the invoked action on execution.
+            function getNewBlankButton(cmenu, baton, section, invokeId, title) {
+                var newBlankEncryptedButton = cmenu.createItemNode('newblank', { section: section, content: title });
+
+                newBlankEncryptedButton.on('click', function () {
+                    cmenu.hide();  //hide the context menu after a button was clicked
+                    CoreActions.invoke(invokeId, this, baton);
+                });
+                return newBlankEncryptedButton;
+            }
+
+            // Create the New document(text, spreadsheet, presentation) encrypted button in the context menu with
+            // eventListener and the invoked action on execution.
+            function getNewBlankEncryptedButton(cmenu, baton, section, invokeId, title) {
+                if (Capabilities.has('guard-docs')) {
+                    var newBlankEncryptedButton = cmenu.createItemNode('newblankencrypted', { section: section, content: title });
+
+                    newBlankEncryptedButton.on('click', function () {
+                        cmenu.hide();  //hide the context menu after a button was clicked
+                        CoreActions.invoke(invokeId, this, baton);
+                    });
+                    return newBlankEncryptedButton;
+                }
+            }
+
             // Create the "Show in drive' button in the context menu with
             // eventListener and the invoked action on execution.
             function getshowTemplateInDriveButton(cmenu, baton, section) {
@@ -362,7 +422,7 @@ define('io.ox/office/portal/action/templateactions', [
                 // After a click event the context menu is closed by the basemenu globalClickHandler().
                 // When a context menu is open, clicking on an element should not invoke it's attached action, but just close the context menu.
                 // As 'closing' and 'invocation' due to a click event happens at the same time, ContextMenu.setOpen(false) must be called delayed.
-                Scheduler.setTimeout(function () { ContextMenu.setOpen(false); }, 300, null, 'TemplateActions contextMenuHandler');
+                window.setTimeout(function () { ContextMenu.setOpen(false); }, 300);
 
                 // destroy the context menu
                 cmenu = null;
@@ -387,7 +447,7 @@ define('io.ox/office/portal/action/templateactions', [
          * @returns {Function}
          *  The draw function for the blank template extension.
          */
-        var getBlankDrawFunction = function (fileName, invokeId) {
+        var getBlankDrawFunction = function (title, actionTitle, actionTitleEncrypted, invokeId, invokeIdEncrypted) {
 
             return function (baton) {
 
@@ -399,12 +459,12 @@ define('io.ox/office/portal/action/templateactions', [
                     'data-toggle': 'tooltip',
                     'data-animation': 'false',
                     'data-delay': '{ "show": 1400 }',
-                    title: _.noI18n(fileName),
+                    title: _.noI18n(title),
                     tabindex: 0
                 });
 
                 var previewBox = $('<div class="preview-box new-blank">').append($('<i class="fa fa-plus">'));
-                var nameBox = $('<p class="template-name">').text(_.noI18n(fileName));
+                var nameBox = $('<p class="template-name">').text(_.noI18n(title));
 
                 // add new blank template to the template container
                 templateItem.append(previewBox, nameBox);
@@ -425,7 +485,12 @@ define('io.ox/office/portal/action/templateactions', [
                 templateItem.on('keydown', Utils.keydownHandler);
 
                 // prevent native context menu for the getBlank template and the focus change on click due to mousedown
-                templateItem.on('mousedown contextmenu', function (e) {
+                templateItem.on('contextmenu', function (e) {
+                    contextMenuHandler(e, baton, previewBox, invokeId, actionTitle, invokeIdEncrypted, actionTitleEncrypted);
+                });
+
+                // prevent focus change on click due to mousedown
+                templateItem.on('mousedown', function (e) {
                     e.preventDefault();
                 });
 
@@ -496,10 +561,33 @@ define('io.ox/office/portal/action/templateactions', [
             }
         });
 
+        // action to create from an existing template encrypted
+        new Links.Action(templateExtension + '/action/open-encrypted', {
+            action: function (baton) {
+                var loadDeferred = baton.data.loadDeferred;
+
+                if (loadDeferred && loadDeferred.state() === 'pending') {
+                    Utils.warn('cant run convert document, because old call is still pending');
+                    return;
+                }
+
+                loadDeferred = Utils.getNewEncryptedLaunchOptions();
+
+                // set authorization data to the model
+                loadDeferred.then(function (launchOptions) {
+                    var appModuleName = Utils.getModuleNameForFile(baton.data.filename);
+                    loadDeferred = ox.launch(appModuleName + '/main', _.extend(launchOptions, { action: 'convert', template: true, templateFile: baton.data, target_filename: gt('unnamed') }));
+                    Utils.trackEvent({ moduleName: appModuleName, target: 'templates', action: 'newfromtemplate' });
+                    baton.data.loadDeferred = loadDeferred;
+                    return loadDeferred;
+                });
+            }
+        });
+
         // define extension for creating text document with a blank template
         this.text.extend({
             id: 'text_template_blank',
-            draw: getBlankDrawFunction(gt('Blank text document'), templateExtension + '/action/new/text')
+            draw: getBlankDrawFunction(gt('Blank text document'), gt('New text document'), gt('New text document (encrypted)'), templateExtension + '/action/new/text', templateExtension + '/action/newencrypted/text')
         });
 
         // define extension for creating text documents with global templates
@@ -517,7 +605,7 @@ define('io.ox/office/portal/action/templateactions', [
         // define extension for creating spreadsheet with a blank template
         this.spreadsheet.extend({
             id: 'spreadsheet_template_blank',
-            draw: getBlankDrawFunction(gt('Blank spreadsheet'), templateExtension + '/action/new/spreadsheet')
+            draw: getBlankDrawFunction(gt('Blank spreadsheet'), gt('New spreadsheet'), gt('New spreadsheet (encrypted)'), templateExtension + '/action/new/spreadsheet', templateExtension + '/action/newencrypted/spreadsheet')
         });
 
         // define extension for creating spreadsheet with global templates
@@ -535,7 +623,7 @@ define('io.ox/office/portal/action/templateactions', [
         // define extension for creating presentation with a blank template
         this.presentation.extend({
             id: 'presentation_template_blank',
-            draw: getBlankDrawFunction(gt('Blank presentation'), templateExtension + '/action/new/presentation')
+            draw: getBlankDrawFunction(gt('Blank presentation'), gt('New presentation'), gt('New presentation (encrypted)'), templateExtension + '/action/new/presentation', templateExtension + '/action/newencrypted/presentation')
         });
 
         // define extension for creating presentation with global templates
@@ -550,6 +638,47 @@ define('io.ox/office/portal/action/templateactions', [
             draw: drawLocalItem
         });
 
+        if (Capabilities.has('guard-docs')) {
+
+            // action to create a blank text document encrypted
+            new Links.Action(templateExtension + '/action/newencrypted/text', {
+                action: function () {
+                    var promise = Utils.getNewEncryptedLaunchOptions();
+
+                    // set authorization data to the model
+                    return promise.then(function (launchOptions) {
+                        Utils.trackEvent({ moduleName: 'io.ox/office/text', target: 'templates', action: 'newblank' });
+                        return ox.launch('io.ox/office/text/main', launchOptions);
+                    });
+                }
+            });
+
+            // action to create a blank spreadsheet document
+            new Links.Action(templateExtension + '/action/newencrypted/spreadsheet', {
+                action: function () {
+                    var promise = Utils.getNewEncryptedLaunchOptions();
+
+                    // set authorization data to the model
+                    return promise.then(function (launchOptions) {
+                        Utils.trackEvent({ moduleName: 'io.ox/office/spreadsheet', target: 'templates', action: 'newblank' });
+                        return ox.launch('io.ox/office/spreadsheet/main', launchOptions);
+                    });
+                }
+            });
+
+            new Links.Action(templateExtension + '/action/newencrypted/presentation', {
+                action: function () {
+                    var promise = Utils.getNewEncryptedLaunchOptions();
+
+                    // set authorization data to the model
+                    return promise.then(function (launchOptions) {
+                        Utils.trackEvent({ moduleName: 'io.ox/office/presentation', target: 'templates', action: 'newblank' });
+                        return ox.launch('io.ox/office/presentation/main', launchOptions);
+                    });
+                }
+            });
+        }
+
     } // class TemplateExtensions
 
     return new TemplateExtensions();
