@@ -17,13 +17,13 @@
 define('io.ox/office/portal/action/toolbaractionsimpl', [
     'io.ox/core/extensions',
     'io.ox/core/extPatterns/links',
+    'io.ox/office/tk/config',
     'io.ox/office/tk/utils',
-    'io.ox/office/tk/dialogs',
     'io.ox/office/tk/utils/driveutils',
     'io.ox/office/portal/portalutils',
-    'settings!io.ox/office',
+    'io.ox/core/capabilities',
     'gettext!io.ox/office/portal/main'
-], function (Ext, Links, Utils, Dialogs, DriveUtils, PortalUtils, Settings, gt) {
+], function (Ext, Links, Config, Utils, DriveUtils, PortalUtils, Capabilities, gt) {
 
     'use strict';
 
@@ -43,6 +43,8 @@ define('io.ox/office/portal/action/toolbaractionsimpl', [
             appBaseName =  Utils.getStringOption(options, 'appBaseName'),
             // identifier for the appBaseName toolbar
             toolbarPointId = 'io.ox/office/portal/toolbar' + appBaseName,
+            // configuration key to store the path to the recently opened documents
+            preselectKey = appBaseName + '/recentOpenDocPath',
             // deferred is set when "newdoc" & "loaddoc" is called, so we can allow only one new call at once
             newDeferred = null, loadDeferred = null;
 
@@ -67,6 +69,26 @@ define('io.ox/office/portal/action/toolbaractionsimpl', [
             }
         });
 
+        if (Capabilities.has('guard-docs') && !PortalUtils.SMALL_DEVICE) {
+            // create extension point for the 'new appBaseName' link
+            Ext.point(toolbarPointId + '-newblank-encrypted').extend(new Links.Link({
+                id: 'new_' + appBaseName + '_encrypted',
+                index: 150,
+                prio: 'hi',
+                label: Utils.getStringOption(options, 'newDocTextEncrypted'),
+                cssClasses: 'new-document',
+                ref: toolbarPointId + '/actions/newencrypted/' + appBaseName
+            }));
+
+            // add link to the toolbar point
+            this.toolbarPoint.extend({
+                id: 'new-' + appBaseName + 'document-encrypted',
+                index: 150,
+                draw: function (baton) {
+                    Ext.point(toolbarPointId + '-newblank-encrypted').invoke('draw', this, baton);
+                }
+            });
+        }
         //add open document link to  the toolbar point
         this.toolbarPoint.extend(new Links.Link({
             id: 'open-' + appBaseName + 'document',
@@ -90,12 +112,32 @@ define('io.ox/office/portal/action/toolbaractionsimpl', [
                 newDeferred = ox.launch(moduleName + '/main', PortalUtils.getNewLaunchOptions());
             }
         });
+        if (Capabilities.has('guard-docs')) {
+            // define action that will be fired on the 'new appBaseName', 'new text' and 'open document' link encrypted
+            new Links.Action(toolbarPointId + '/actions/newencrypted/' + appBaseName, {
+                capabilities: appBaseName,
+                action: function () {
 
+                    if (newDeferred && newDeferred.state() === 'pending') {
+                        Utils.warn('cant run new document, because old call is still pending');
+                        return;
+                    }
+
+                    var promise = PortalUtils.getNewEncryptedLaunchOptions();
+
+                    // set authorization data to the model
+                    promise.then(function (launch_options) {
+                        var moduleName = PortalUtils.getEditorModuleName(appBaseName);
+                        PortalUtils.trackEvent({ moduleName: moduleName, target: 'toolbar', action: 'newblank' });
+                        newDeferred = ox.launch(moduleName + '/main', launch_options);
+                    });
+                }
+            });
+        }
         new Links.Action('io.ox/office/portal/open' + appBaseName, {
             action: function () {
                 require(['io.ox/files/filepicker', 'io.ox/office/baseframework/app/extensionregistry']).done(function (FilePicker, ExtensionRegistry) {
-                    var preselectKey = 'recentOpenDocPath' + appBaseName;
-                    var preselect = Settings.get(preselectKey) || DriveUtils.getStandardDocumentsFolderId();
+                    var preselect = Config.get(preselectKey) || DriveUtils.getStandardDocumentsFolderId();
                     var extensions = ExtensionRegistry.getEditableExtensions();
                     var filter = extensions.map(function (ext) { return '.' + ext; }).join(',');
 
@@ -117,10 +159,10 @@ define('io.ox/office/portal/action/toolbaractionsimpl', [
                         folder: preselect,
                         uploadButton: true,
                         multiselect: false,
-                        width: Dialogs.getBestDialogWidth(800),
                         //uploadFolder: DriveUtils.getStandardDocumentsFolderId(),
                         hideTrashfolder: true,
-                        acceptLocalFileType: filter
+                        acceptLocalFileType: filter,
+                        createFolderButton: false
                     });
                     dialog.done(function (selectedFiles) {
                         var selectedFile = selectedFiles[0];
@@ -148,7 +190,7 @@ define('io.ox/office/portal/action/toolbaractionsimpl', [
                                 { action: 'load', file: selectedFile } :
                                 { action: 'convert', target_folder_id: selectedFile.folder_id, templateFile: selectedFile, preserveFileName: true };
                             loadDeferred = ox.launch(actionModuleName + '/main', launchOptions);
-                            Settings.set(preselectKey, selectedFile.folder_id).save();
+                            Config.set(preselectKey, selectedFile.folder_id);
                         }
                     });
                 });
