@@ -27,7 +27,8 @@ define('io.ox/office/portal/action/toolbaractionspresentation', [
      */
     return new ToolbarActionsImpl({
         appBaseName: 'presentation',
-        newDocText: gt('New Presentation')
+        newDocText: gt('New presentation'),
+        newDocTextEncrypted: gt('New presentation (encrypted)')
     });
 
 });
