@@ -37,7 +37,7 @@ define('io.ox/office/portal/mainhelper', [
     'use strict';
 
     // bug 51700: do not show welcome tours if the standard tour package is not installed
-    var TOURS_PACKAGE_INSTALLED = require.defined('io.ox/tours/main');
+    var TOURS_PACKAGE_INSTALLED = Config.getDebugUrlFlag('office:show-tours') || require.defined('io.ox/tours/main');
 
     // static class MainHelper ================================================
 
