@@ -23,7 +23,7 @@ define('io.ox/office/portal/portaltour', [
     'use strict';
 
     // the 'shown' configuration key for any of the portal tours
-    var ANY_PORTAL_TOUR_SHOWN_KEY = 'io.ox/office/portal/alltours/shown';
+    var ANY_PORTAL_TOUR_SHOWN_KEY = 'portal/alltours/shown';
 
     // selector for any tool pane without hidden contents
     var TOOL_PANE_SELECTOR = '.tool-pane:not(.hidden-contents)';
@@ -333,7 +333,7 @@ define('io.ox/office/portal/portaltour', [
                 // launch the Drive application
                 .navigateTo('io.ox/files/main')
                 // wait for and highlight the 'Documents' folder (TODO: ensure visible folder side-pane)
-                .waitForAndReferTo('.window-container[data-app-name="io.ox/files"] ' + DOCUMENTRS_FOLDER_SELECTOR, { position: 'bottom', hotspot: '.folder-label>div' })
+                .waitForAndReferTo('.window-container[data-app-name="io.ox/files"] ' + DOCUMENTRS_FOLDER_SELECTOR, { position: 'bottom', hotspot: '.folder-label' })
                 // launch the editor application when leaving this step backwards
                 .on('back', this.launchEditorApp.bind(this));
         };
