@@ -17,10 +17,10 @@ define('io.ox/office/portal/portalutils', [
     'io.ox/office/tk/keycodes',
     'io.ox/office/tk/utils/dateutils',
     'io.ox/office/tk/utils/driveutils',
+    'io.ox/office/tk/utils/presenterutils',
     'io.ox/office/baseframework/app/extensionregistry',
-    'io.ox/office/tk/utils/scheduler',
     'gettext!io.ox/office/portal/main'
-], function (Capabilities, Utils, KeyCodes, DateUtils, DriveUtils, ExtensionRegistry, Scheduler, gt) {
+], function (Capabilities, Utils, KeyCodes, DateUtils, DriveUtils, PresenterUtils, ExtensionRegistry, gt) {
 
     'use strict';
 
@@ -216,8 +216,11 @@ define('io.ox/office/portal/portalutils', [
      * @returns {String}
      *  The application base name string.
      */
-    PortalUtils.getActiveApp = function (app) {
-        return (app.attributes.title).toLowerCase();
+    PortalUtils.getActiveApp = function (app, options) {
+        var translated = Utils.getBooleanOption(options, 'translated', true),
+            string = (translated) ? app.attributes.title : app.attributes.appBaseName;
+
+        return (string).toLowerCase();
     };
 
     /**
@@ -393,8 +396,7 @@ define('io.ox/office/portal/portalutils', [
         link.on('touchend', cancel);
 
         // check if a long tap should be triggered after 750 ms
-        Scheduler.setTimeout(hold, 750, null, 'PortalUtils iosContextEventHandler');
-
+        window.setTimeout(hold, 750);
     };
 
     /**
@@ -460,6 +462,24 @@ define('io.ox/office/portal/portalutils', [
         return { action: 'new', target_folder_id: DriveUtils.getStandardDocumentsFolderId() };
     };
 
+    /**
+     * Launch options to create a new encrypted document in the default 'Documents'
+     * folder in Drive.
+     *
+     * @returns {jQuery.Promise}
+     *  A promise which returns the necessary parameters for creating a new encrypted document in the default folder.
+     */
+    PortalUtils.getNewEncryptedLaunchOptions = function () {
+        var promise = require(['io.ox/guard/auth/authorizer']).then(function (authorizer) {
+            return authorizer.authorize();
+        });
+
+        // set authorization data to the model
+        return promise.then(function (auth_code) {
+            return _.extend(PortalUtils.getNewLaunchOptions(), { auth_code: auth_code, cryptoAction: 'Encrypt' });
+        });
+    };
+
     /**
      * runs ox-Drive with assigned folder id
      * then it calls "selectFile" in the Drive app with assigned file-descriptor
@@ -492,13 +512,13 @@ define('io.ox/office/portal/portalutils', [
      * Shows the document in the Presenter.
      *
      * @param {Object} baton
-     * A baton object which has a backbone cid.
-     * Note: Unfortunately there are cases where the cid is the file-descriptor (e.g. in Drive),
-     * so better take a look at the baton before using it here.
+     *  A baton object which has a backbone cid.
+     *  Note: Unfortunately there are cases where the cid is the file-descriptor (e.g. in Drive),
+     *  so better take a look at the baton before using it here.
      *
-     * @param {Boolean} [default=false]
+     * @param {Boolean} [busy=false]
      *  If assigned current ox app is set to busy mode
-     *  and back to idle after drive is loaded
+     *  and back to idle after the Presenter is loaded.
      *
      */
     PortalUtils.showInPresenter = function (baton, busy) {
@@ -512,11 +532,9 @@ define('io.ox/office/portal/portalutils', [
         // is expected to have a backbone cid. To launch the Presenter, a baton
         // with a file descriptor as a cid is needed. Therefore 'getFileModelFromDescriptor'
         // is used to create it.
-        DriveUtils.getFileModelFromDescriptor(baton.data).then(function (data) {
-            return ox.launch('io.ox/presenter/main', data).then(function () {
+        DriveUtils.getFileModelFromDescriptor(baton.data).then(PresenterUtils.launchPresenter).then(function () {
 
-                if (win) { win.idle(); }
-            });
+            if (win) { win.idle(); }
         });
     };
 
