@@ -97,7 +97,7 @@ define('io.ox/office/portal/spreadsheet/fulltour', [
             .title(gt.pgettext('tour', 'Formulas'))
             .content(gt.pgettext('tour', 'You can use all the regular spreadsheet formulas by typing them into a cell.'))
             .on('before:show', function () {
-                this.getDocView().cancelCellEditMode();
+                this.getDocView().cancelTextEditMode();
                 this.executeItem('cell/active/parse', getLocalizedFormula('\'=SUM'));
             })
             .waitForAndReferTo(this.EDITOR_APP_PANE_SELECTOR + ' .selection-layer .active-cell', { position: 'bottom', hotspot: true });
@@ -108,23 +108,23 @@ define('io.ox/office/portal/spreadsheet/fulltour', [
             .content(gt.pgettext('tour', 'As soon as you start typing a formula, autocompletion offers you a list of matching functions to choose from.'))
             .on('before:show', function () {
                 var docView = this.getDocView();
-                docView.cancelCellEditMode();
-                docView.enterCellEditMode({ text: getLocalizedFormula('=SUM'), stickyList: true });
+                docView.cancelTextEditMode();
+                docView.enterTextEditMode('cell', { text: getLocalizedFormula('=SUM'), stickyList: true });
             })
             .waitForAndReferToPopup({ position: 'bottom', hotspot: true });
 
         // describe the formula label in the status pane
         this.step()
             .title(gt.pgettext('tour', 'Displaying hidden formulas'))
-            .content(gt.pgettext('tour', 'If a result is displayed in a cell, the calculating formula will be displayed in the lower right hand corner of the screen.'))
+            .content(gt.pgettext('tour', 'If a result is displayed in a cell, the calculating formula will be displayed in the formula bar.'))
             .on('before:show', function () {
                 // need to launch explicitly, in case this step is reached by using the Back button in a short tour
                 self.launchEditorApp().done(function () {
-                    this.getDocView().cancelCellEditMode();
+                    this.getDocView().cancelTextEditMode();
                     this.executeItem('cell/active/parse', getLocalizedFormula('=SUM(1, 2, 3)'));
                 }.bind(this));
             })
-            .waitForAndReferToGroup(this.EDITOR_WINDOW_SELECTOR + ' .status-pane', 'view/formula', { position: 'top', hotspot: true });
+            .waitForAndReferTo(this.EDITOR_WINDOW_SELECTOR + ' .formula-pane .textarea-container', { position: 'bottom', hotspot: true });
 
         // describe the 'Close' button, switch to 'Documents' folder in Drive
         if (!this.isShortTour()) {
