@@ -14,13 +14,21 @@
  */
 
 define('io.ox/office/presentation/app/application', [
+
     'io.ox/office/tk/utils',
     'io.ox/office/tk/utils/driveutils',
+    'io.ox/office/tk/utils/presenterutils',
+
+    'io.ox/office/baseframework/utils/errorcode',
+    'io.ox/office/baseframework/utils/errorcontext',
+
     'io.ox/office/editframework/app/editapplication',
+
     'io.ox/office/presentation/model/model',
     'io.ox/office/presentation/view/view',
     'io.ox/office/presentation/app/controller'
-], function (Utils, DriveUtils, EditApplication, PresentationModel, PresentationView, PresentationController) {
+
+], function (Utils, DriveUtils, PresenterUtils, ErrorCode, ErrorContext, EditApplication, PresentationModel, PresentationView, PresentationController) {
 
     'use strict';
 
@@ -44,6 +52,7 @@ define('io.ox/office/presentation/app/application', [
         // base constructor ---------------------------------------------------
 
         EditApplication.call(this, PresentationModel, PresentationView, PresentationController, launchOptions, {
+            importFailedHandler: importFailedHandler,
             prepareFlushHandler: prepareFlushDocument,
             prepareRenameHandler: prepareRenameHandler,
             postProcessHandler: postProcessDocument,
@@ -81,6 +90,23 @@ define('io.ox/office/presentation/app/application', [
             return self.getModel().updateDocumentFormatting();
         }
 
+        /**
+         * Handler will be called by base class if importing the document
+         * failed. The functions handles Presentation specific errors.
+         */
+        function importFailedHandler(response) {
+
+            var // specific error code sent by the server
+                error = new ErrorCode(response);
+
+            //  fulfilling task DOCS-733 - "Improve OOM Error Message in Client" - [https://jira.open-xchange.com/browse/DOCS-733]
+            switch (error.getCodeAsConstant()) {
+                case 'LOADDOCUMENT_COMPLEXITY_TOO_HIGH_ERROR':
+                    self.setInternalError(error, ErrorContext.PRESENTATION, null, { showMessage: false });
+                    break;
+            }
+        }
+
         /**
          * Preprocessing before the document will be flushed for downloading,
          * printing, sending as mail, or closing.
@@ -113,7 +139,7 @@ define('io.ox/office/presentation/app/application', [
             }
 
             // only send changed attributes when user has edit rights
-            if (!self.getModel().getEditMode()) {
+            if (!self.isEditable()) {
                 return self;
             }
 
@@ -169,7 +195,7 @@ define('io.ox/office/presentation/app/application', [
 
             // launch the Presenter application
             promise = promise.then(function (model) {
-                return ox.launch('io.ox/presenter/main', model);
+                PresenterUtils.launchPresenter(model, launchOptions.auth_code);
             });
 
             // release the blocked screen of this application
