@@ -16,11 +16,10 @@
 define('io.ox/office/presentation/app/controller', [
     'io.ox/office/tk/utils',
     'io.ox/office/editframework/utils/color',
-    'io.ox/office/editframework/utils/hyperlinkutils',
     'io.ox/office/editframework/utils/mixedborder',
-    'io.ox/office/editframework/app/editcontroller',
-    'io.ox/office/editframework/utils/paragraphspacing',
     'io.ox/office/editframework/utils/attributeutils',
+    'io.ox/office/editframework/utils/hyperlinkutils',
+    'io.ox/office/editframework/app/editcontroller',
     'io.ox/office/drawinglayer/utils/drawingutils',
     'io.ox/office/drawinglayer/view/drawinglabels',
     'io.ox/office/presentation/format/paragraphstyles',
@@ -28,7 +27,7 @@ define('io.ox/office/presentation/app/controller', [
     'io.ox/office/textframework/components/hyperlink/hyperlink',
     'io.ox/office/textframework/utils/position',
     'io.ox/office/textframework/format/tablestyles'
-], function (Utils, Color, HyperlinkUtils, MixedBorder, EditController, ParagraphSpacing, AttributeUtils, DrawingUtils, DrawingLabels, ParagraphStyles, Config, Hyperlink, Position, TableStyles) {
+], function (Utils, Color, MixedBorder, AttributeUtils, HyperlinkUtils, EditController, DrawingUtils, DrawingLabels, ParagraphStyles, Config, Hyperlink, Position, TableStyles) {
 
     'use strict';
 
@@ -69,9 +68,9 @@ define('io.ox/office/presentation/app/controller', [
 
             self.update = function () {
                 if (docModel.isAndroidTyping()) {
-                    self.executeDelayed(self.update, { delay: 1000, infoString: 'Text: android: update', app: app });
+                    return self.executeDelayed(self.update, 'PresentationController.update', 1000);
                 } else {
-                    originalUpdate();
+                    return originalUpdate();
                 }
             };
         }
@@ -83,19 +82,19 @@ define('io.ox/office/presentation/app/controller', [
 
             'view/zoom': {
                 parent: 'app/valid',
-                get: function () { return docView.getZoomFactor() / 100; },
+                get: function () { return docView.getZoomFactor(); },
                 set: function (zoom) { docView.setZoomType(zoom * 100); }
             },
 
             'view/zoom/dec': {
                 parent: 'app/valid',
-                enable: function () { return docView.getZoomFactor() > docView.getMinZoomFactor(); },
+                enable: function () { return docView.getZoomFactor() * 100 > docView.getMinZoomFactor(); },
                 set: function () { docView.decreaseZoomLevel(); }
             },
 
             'view/zoom/inc': {
                 parent: 'app/valid',
-                enable: function () { return docView.getZoomFactor() < docView.getMaxZoomFactor(); },
+                enable: function () { return docView.getZoomFactor() * 100 < docView.getMaxZoomFactor(); },
                 set: function () { docView.increaseZoomLevel(); }
             },
 
@@ -110,6 +109,10 @@ define('io.ox/office/presentation/app/controller', [
                 set: function (state) { docView.getSlidePane().toggle(state); }
             },
 
+            'document/noslidepanefocus': { // whether the slidepane or the document has the virtual focus
+                enable: function () { return !docView.hasSlidepaneVirtualFocus(); }
+            },
+
             'document/slideexists': {
                 parent: 'app/valid',
                 enable: function () { return !docModel.isEmptySlideView(); }
@@ -143,6 +146,7 @@ define('io.ox/office/presentation/app/controller', [
             },
 
             'document/selectall': {
+                parent: 'document/noslidepanefocus',
                 // enabled in read-only mode
                 set: function () { docModel.selectAll(); },
                 // restrict keyboard shortcut to application pane
@@ -151,6 +155,7 @@ define('io.ox/office/presentation/app/controller', [
             },
 
             'document/selectDrawing': {
+                parent: 'document/noslidepanefocus',
                 set: function (options) {
                     docModel.getSelection().selectNextDrawing({ backwards: Utils.getBooleanOption(options, 'backwards', false) });
                 },
@@ -160,6 +165,7 @@ define('io.ox/office/presentation/app/controller', [
                 set: function () { docModel.getSelection().setSelectionIntoTextframe({ complete: true }); }
             },
             'document/switchCursorIntoTextframe': {
+                parent: 'document/noslidepanefocus',
                 set: function () { docModel.getSelection().toggleTextFrameAndTextSelection({ complete: true }); },
                 shortcut: { keyCode: 'F2' }
             },
@@ -223,7 +229,7 @@ define('io.ox/office/presentation/app/controller', [
 
             'document/present': {
                 parent: 'app/valid',
-                enable: function () { return Config.PRESENTER_AVAILABLE && !app.isDocumentEncrypted(); },
+                enable: function () { return Config.PRESENTER_AVAILABLE; },
                 set: function () { return app.startPresenter(); }
             },
 
@@ -233,6 +239,9 @@ define('io.ox/office/presentation/app/controller', [
                 parent: 'document/editable/text',
                 get: function () { return docModel.getAttributes('paragraph', { maxIterations: 10 }) || {}; }
             },
+            'paragraph/odf/implicit': {
+                enable: function () { return !app.isODF() || !docModel.getSelection().isCursorInImplicitParagraph(); } // no paragraph handling in implicit paragraphs in ODP
+            },
             'paragraph/attributes': {
                 parent: 'paragraph/group',
                 get: function (paragraph) { return paragraph.paragraph || {}; }
@@ -262,14 +271,8 @@ define('io.ox/office/presentation/app/controller', [
             },
             'paragraph/spacing': {
                 parent: ['paragraph/attributes', 'insert/comment/supported/odf'],
-                get: function (attributes) { return ParagraphSpacing.helper.computeMultiplier(attributes, docModel); },
-                set: function (multiplier) {
-                    var marginBottom = ParagraphSpacing.helper.computeMarginBottom(multiplier, docModel);
-
-                    // bug 46249:  margin top needs to be considered when 'Paragraph spacing' is set to none in our GUI
-                    var marginTop = ParagraphSpacing.helper.getZeroSpaceMargin();
-                    docModel.setAttributes('paragraph', { paragraph: { marginTop: marginTop, marginBottom: marginBottom } });
-                }
+                get: function (attributes) { return docModel.getParagraphSpacing(attributes); },
+                set: function (multiplier) { return docModel.setParagraphSpacing(multiplier); }
             },
 
             'paragraph/explicit': {
@@ -299,14 +302,14 @@ define('io.ox/office/presentation/app/controller', [
 
             // toggle default bullet list, or select bullet type
             'paragraph/list/bullet': {
-                parent: ['paragraph/attributes'],
-                get: _.partial(docModel.getListStyleId, 'bullet'),
+                parent: 'paragraph/attributes',
+                get: function (attributes) { return docModel.getEffectiveListStyleId('bullet', attributes); },
                 set: function (value) { docModel.setListStyleId('bullet', value, this.getValue()); }
             },
             // toggle default numbered list, or select numbering type
             'paragraph/list/numbered': {
-                parent: ['paragraph/attributes'],
-                get: _.partial(docModel.getListStyleId, 'numbering'),
+                parent: 'paragraph/attributes',
+                get: function (attributes) { return docModel.getEffectiveListStyleId('numbering', attributes); },
                 set: function (value) { docModel.setListStyleId('numbering', value, this.getValue()); }
             },
 
@@ -318,13 +321,13 @@ define('io.ox/office/presentation/app/controller', [
             },
             // increase list level by one
             'paragraph/list/incindent': {
-                parent: ['paragraph/explicit', 'paragraph/list/indent'],
+                parent: ['paragraph/explicit', 'paragraph/list/indent', 'slide/noodfmasterview'],
                 enable: function (paraAttrs) { return docModel.isListIndentChangeable(paraAttrs, { increase: true }); },
                 set: function () { docModel.changeListIndent({ increase: true, validatedLevel: true }); }
             },
             // decrease list level by one
             'paragraph/list/decindent': {
-                parent: ['paragraph/explicit', 'paragraph/list/indent'],
+                parent: ['paragraph/explicit', 'paragraph/list/indent', 'slide/noodfmasterview'],
                 enable: function (paraAttrs) { return docModel.isListIndentChangeable(paraAttrs, { increase: false }); },
                 set: function () { docModel.changeListIndent({ increase: false, validatedLevel: true }); }
             },
@@ -338,7 +341,7 @@ define('io.ox/office/presentation/app/controller', [
             },
             'slide/insertlayoutslide': {
                 parent: 'document/editable',
-                enable: function () { return docModel.isMasterView(); },
+                enable: function () { return docModel.isMasterView() && !app.isODF(); },
                 set: function () { docModel.insertLayoutSlide(); }
             },
             'slide/duplicateslides': {
@@ -386,6 +389,10 @@ define('io.ox/office/presentation/app/controller', [
                 parent: 'debug/slideattributes',
                 set: function (dialogType) { return docModel.showInsertImageDialogForSlideBackground(dialogType); }
             },
+            'slide/noodfmasterview': {
+                enable: function () { return !(app.isODF() && docModel.isMasterView()); }
+            },
+
             // characters
 
             'character/group': {
@@ -411,14 +418,7 @@ define('io.ox/office/presentation/app/controller', [
             },
             'character/fontname': {
                 parent: 'character/attributes',
-                get: function (attributes) {
-                    var fontName = attributes.fontName;
-                    if (AttributeUtils.isCharacterFontThemed(attributes)) {
-                        var target = docModel.getTargetChainForNode(docModel.getSelection().getEnclosingParagraph());
-                        if (target) { fontName = docModel.getThemeCollection().getTheme('', target).getFontName(fontName); }
-                    }
-                    return fontName;
-                },
+                get: function (attributes) { return attributes.fontName; },
                 set: function (fontName) { docModel.setAttribute('character', 'fontName', fontName); }
             },
             'character/fontsize': {
@@ -464,6 +464,10 @@ define('io.ox/office/presentation/app/controller', [
                 get: function (attributes) { return attributes.color; },
                 set: function (color) { docModel.setAttribute('character', 'color', color); }
             },
+            'character/fillcolor': {
+                parent: ['character/attributes', 'insert/comment/odf/supported'],
+                enable: _.constant(false) // TODO
+            },
             'character/language': {
                 parent: 'character/attributes',
                 get: function (attributes) { return attributes.language; },
@@ -497,10 +501,6 @@ define('io.ox/office/presentation/app/controller', [
                 shortcut: { keyCode: 'SPACE', ctrl: true }
             },
 
-            'character/format': {
-                parent: 'app/valid'
-            },
-
             'character/insert/break': {
                 parent: 'document/editable/text',
                 set: function () { return docModel.insertHardBreak(); }
@@ -651,6 +651,10 @@ define('io.ox/office/presentation/app/controller', [
                 parent: 'document/editable',
                 enable: function () { return docModel.getSelection().isAnyDrawingSelectionExceptTable() || docModel.getSelection().isMultiSelection(); }
             },
+            'document/editable/anydrawingexceptodfreadonly': {
+                parent: 'document/editable/anydrawing',
+                enable: function () { return !docModel.isODFReadOnyPlaceHolderDrawingProcessing(); }
+            },
             'document/editable/onlysupporteddrawings': {
                 parent: 'document/editable',
                 enable: function () { return docModel.getSelection().areOnlySupportedDrawingsSelected(); }
@@ -658,15 +662,21 @@ define('io.ox/office/presentation/app/controller', [
             'drawing/shapes/support/fill': {
                 parent: 'document/editable/onlysupporteddrawings',
                 enable: function () {
-                    var selection = docModel.getSelection();
-                    return (/^(shape|group)$/).test(selection.getSelectedDrawingType()) || (selection.getSelectionType() === 'text');
+                    var allSelectedTypes = docModel.getSelection().getSelectedDrawingTypes({ forceObject: true });
+                    return allSelectedTypes.shape === 1 || allSelectedTypes.group === 1;
                 }
             },
             'drawing/shapes/support/line': {
                 parent: 'document/editable/onlysupporteddrawings',
                 enable: function () {
-                    var selection = docModel.getSelection();
-                    return (/^(shape|group|image)$/).test(selection.getSelectedDrawingType()) || (selection.getSelectionType() === 'text');
+                    var allSelectedTypes = docModel.getSelection().getSelectedDrawingTypes({ forceObject: true });
+                    return allSelectedTypes.shape === 1 || allSelectedTypes.group === 1 || allSelectedTypes.image === 1 || allSelectedTypes.connector === 1;
+                }
+            },
+            'drawing/shapes/support/lineendings': {
+                parent: ['drawing/attributes/full', 'document/editable/onlysupporteddrawings'],
+                enable: function (attrs) {
+                    return (attrs && attrs.geometry) ? DrawingLabels.isPresetConnector(attrs.geometry.presetShape) : false;
                 }
             },
 
@@ -685,7 +695,7 @@ define('io.ox/office/presentation/app/controller', [
             },
 
             'drawing/delete': {
-                parent: 'document/editable/anydrawing',
+                parent: 'document/editable/anydrawingexceptodfreadonly',
                 set: function () {
                     var selection = docModel.getSelection();
                     if (docModel.isDrawingSelected()) {
@@ -701,38 +711,53 @@ define('io.ox/office/presentation/app/controller', [
                 }
             },
 
+            'drawing/type/shape': {
+                parent: 'document/editable',
+                enable: function () { return (docModel.getSelection().getClosestSelectedDrawingType() === 'shape' || docModel.getSelection().getClosestSelectedDrawingType() === 'connector'); }
+            },
+
             'drawing/type/label': {
-                parent: 'document/editable/drawing',
-                get: function () { return DrawingLabels.getDrawingTypeLabel(docModel.getSelection().getClosestSelectedDrawingType()); }
+                parent: ['drawing/attributes/full', 'document/editable/drawing'],
+                get: function (attrs) {
+                    var connector       = (attrs && attrs.geometry) ? DrawingLabels.isPresetConnector(attrs.geometry.presetShape) : false,
+                        originalType    = docModel.getSelection().getClosestSelectedDrawingType(),
+                        type            = (originalType === 'shape' && connector) ? 'connector' : originalType;
+
+                    return DrawingLabels.getDrawingTypeLabel(type);
+                }
             },
 
             'drawing/anydrawing': {
                 enable: function () { return docModel.getSelection().isAnyTextFrameSelection({ allDrawingTypesAllowed: true }); }
             },
 
-            'drawing/anydrawingexcepttable': {
-                enable: function () { return docModel.getSelection().isAnyDrawingSelectionExceptTable(); }
+            'drawing/anydrawingselectionwithouttable': {
+                enable: function () { return docModel.getSelection().isDrawingSelectionWithoutTable(); }
+            },
+
+            'drawing/anytextframeselection': {
+                enable: function () { return docModel.getSelection().isAnyTextFrameSelection({ allowGroup: true }); }
             },
 
             'drawing/notsingledrawing': {
                 parent: 'document/editable/anydrawing',
-                enable: function () { return docModel.getSelection().isUngroupableSelection() || !docModel.getSelection().getClosestSelectedDrawingType(); }
+                enable: function () { return docModel.getSelection().isMultiSelection() || docModel.getSelection().isUngroupableSelection(); }
             },
 
             'drawing/textframeautofit': {
-                parent: ['drawing/anydrawing', 'drawing/anydrawingexcepttable'],
-                get: function () { return docModel.isAutoResizableTextFrame() ? 'autofit' : (docModel.isAutoTextHeightTextFrame() ? 'autotextheight' : 'noautofit'); },
+                parent: ['drawing/anydrawingselectionwithouttable', 'drawing/anytextframeselection'], // at least one shape, but not with a table
+                get: function () { return docModel.getDrawingAutoResizeState(); },
                 set: function (fitState) { docModel.handleTextFrameAutoFit(fitState === 'autofit', fitState === 'autotextheight'); }
             },
 
             'drawing/lockratio': {
-                enable: function () { return docModel.getSelection().isAnyDrawingSelectionExceptTable() || (docModel.getSelection().isMultiSelectionSupported() && docModel.getSelection().isMultiSelectionWithoutTable()); },
+                parent: ['drawing/anydrawingselectionwithouttable'],
                 get: function () { return docModel.isLockedRatioDrawing(); },
                 set: function (state) { docModel.handleDrawingLockRatio(state); }
             },
 
             'drawing/verticalalignment': {
-                enable: docModel.getSelection().isAnyTextFrameSelection({ allDrawingTypesAllowed: true }),
+                enable: function () { return docModel.getSelection().isAnyTextFrameSelection({ allDrawingTypesAllowed: true }); },
                 get: function () { return docModel.getVerticalAlignmentMode(); },
                 set: function (mode) { docModel.setVerticalAlignmentMode(mode); }
             },
@@ -744,6 +769,11 @@ define('io.ox/office/presentation/app/controller', [
                 get: function (attributes) { return attributes.fill || {}; }
             },
 
+            'drawing/fill/style/support': {
+                parent: 'drawing/attributes/full',
+                enable: function (attributes) { return !((attributes && attributes.geometry) ? DrawingLabels.isPresetConnector(attributes.geometry.presetShape) : false); }
+            },
+
             'drawing/fill/color': {
                 parent: 'drawing/fill/attributes',
                 get: function (attributes) { return attributes.color; },
@@ -757,6 +787,22 @@ define('io.ox/office/presentation/app/controller', [
                 get: function (attributes) { return attributes.line || {}; }
             },
 
+            'drawing/line/endings': {
+                parent: ['drawing/line/attributes', 'drawing/shapes/support/lineendings'],
+                get: function (lineAttrs) { return lineAttrs.headEndType + ':' + lineAttrs.tailEndType; },
+                set: function (endings) { docModel.setLineEnds(endings); }
+            },
+
+            'drawing/border/style/support': {
+                parent: 'drawing/attributes/full',
+                enable: function (attributes) { return !((attributes && attributes.geometry) ? DrawingLabels.isPresetConnector(attributes.geometry.presetShape) : false); }
+            },
+
+            'drawing/line/style/support': {
+                parent: 'drawing/attributes/full',
+                enable: function (attributes) { return (attributes && attributes.geometry) ? DrawingLabels.isPresetConnector(attributes.geometry.presetShape) : false; }
+            },
+
             'drawing/border/style': {
                 parent: 'drawing/line/attributes',
                 get: function (attributes) { return DrawingUtils.getPresetBorder(attributes); },
@@ -771,8 +817,8 @@ define('io.ox/office/presentation/app/controller', [
 
             'drawing/fontscale': {
                 parent: 'document/editable',
-                get: function () { return parseFloat(docModel.getSelection().getClosestSelectedDrawing().find('>.textframecontent').attr('font-scale') || 1); },
-                enable: function () { return docModel.getSelection().getClosestSelectedDrawing().length > 0; }
+                get: function () { return parseFloat($(docModel.getSelection().getSelectedDrawings({ forceArray: true })).find('>.textframecontent').attr('font-scale') || 1); },
+                enable: function () { return docModel.getSelection().getSelectedDrawings({ forceArray: true }).length > 0; }
             },
 
             // group and ungroup of drawings
@@ -792,9 +838,27 @@ define('io.ox/office/presentation/app/controller', [
                 set: function (value) { docModel.changeDrawingOrder(value); }
             },
 
-            'drawing/rotate': {
-                enable: function () { return docModel.getSelection().isAnyDrawingSelectionExceptTable(); },
-                set: function (value) { docModel.rotateFlipDrawing(value); }
+            // parent item for drawing objects that can be flipped and rotated
+            'drawing/operation/transform': {
+                parent: 'drawing/anydrawingselectionwithouttable'
+            },
+
+            // (stateless command) flips the selected drawing objects horizontally
+            'drawing/transform/fliph': {
+                parent: 'drawing/operation/transform',
+                set: function () { docModel.transformDrawings(0, true, false); }
+            },
+
+            // (stateless command) flips the selected drawing objects vertically
+            'drawing/transform/flipv': {
+                parent: 'drawing/operation/transform',
+                set: function () { docModel.transformDrawings(0, false, true); }
+            },
+
+            // (stateless command) rotates the selected drawing objects by the passed angle
+            'drawing/transform/rotate': {
+                parent: 'drawing/operation/transform',
+                set: function (angle) { docModel.transformDrawings(angle, false, false); }
             },
 
             // drawing/s alignment
@@ -889,6 +953,63 @@ define('io.ox/office/presentation/app/controller', [
                 }
             },
 
+            // placeholders
+
+            'placeholder/insert': {
+                parent: ['document/editable/slideexists'],
+                enable: function () { return docModel.isMasterView(); }
+            },
+
+            'placeholder/title': {
+                parent: ['document/editable/slideexists'],
+                enable: function () { return docModel.isMasterView(); },
+                get: function () { return docModel.hasPlaceholderObjectOnSlide('title'); },
+                set: function () { return docModel.togglePlaceholderObjectOnSlide('title'); }
+            },
+
+            'placeholder/body': {
+                parent: ['document/editable/slideexists'],
+                enable: function () { return docModel.isMasterView() && docModel.isMasterSlideId(docModel.getActiveSlideId()); },
+                get: function () { return docModel.hasPlaceholderObjectOnSlide('body'); },
+                set: function () { return docModel.togglePlaceholderObjectOnSlide('body'); }
+            },
+
+            'placeholder/footers': {
+                parent: ['document/editable/slideexists'],
+                enable: function () { return docModel.isMasterView(); },
+                get: function () { return docModel.hasPlaceholderObjectOnSlide('footers'); },
+                set: function () { return docModel.togglePlaceholderObjectOnSlide('footers'); }
+            },
+
+            'placeholder/insertcustom': {
+                parent: ['document/editable/slideexists'],
+                enable: function () { return docModel.isMasterView() && !docModel.isMasterSlideId(docModel.getActiveSlideId()); },
+                set: function (value, inputOptions) {
+                    return docModel.insertPlaceholderDrawingPreparation(value, inputOptions);
+                }
+            },
+
+            'placeholder/odfdatetime': {
+                parent: ['document/editable/slideexists'],
+                enable: function () { return docModel.isMasterView() && docModel.isLayoutSlideId(docModel.getActiveSlideId()); },
+                get: function () { return docModel.hasPlaceholderObjectOnSlide('dt'); },
+                set: function () { return docModel.togglePlaceholderObjectOnSlide('dt'); }
+            },
+
+            'placeholder/odffooter': {
+                parent: ['document/editable/slideexists'],
+                enable: function () { return docModel.isMasterView() && docModel.isLayoutSlideId(docModel.getActiveSlideId()); },
+                get: function () { return docModel.hasPlaceholderObjectOnSlide('ftr'); },
+                set: function () { return docModel.togglePlaceholderObjectOnSlide('ftr'); }
+            },
+
+            'placeholder/odfslidenum': {
+                parent: ['document/editable/slideexists'],
+                enable: function () { return docModel.isMasterView() && docModel.isLayoutSlideId(docModel.getActiveSlideId()); },
+                get: function () { return docModel.hasPlaceholderObjectOnSlide('sldNum'); },
+                set: function () { return docModel.togglePlaceholderObjectOnSlide('sldNum'); }
+            },
+
             // insert a new slide, either blank or with a specifically chosen layout
 
             'layoutslidepicker/insertslide': {
@@ -904,7 +1025,7 @@ define('io.ox/office/presentation/app/controller', [
                 // - visa verse `get` will be able to preselect the corresponding layout slide
                 //   of any currently selected standard slide from the former one's return value.
                 get: function () {
-                    return docModel.getLayoutSlideId(docModel.getActiveSlideId());
+                    return app.isODF() ? '' : docModel.getLayoutSlideId(docModel.getActiveSlideId());
                 },
                 set: function (slideId) {
                   //Utils.info('+++ slide/insertslide +++ slideId : ', slideId);
@@ -920,13 +1041,22 @@ define('io.ox/office/presentation/app/controller', [
             // change respectively reset the currently selected slide's layout
 
             'layoutslidepicker/changelayout': {
+                parent: ['layoutslidepicker/insertslide'],
+                enable: function () { return !docModel.isEmptySlideView(); },
+                set: function (slideId) {
+                    docModel.changeLayoutForMultipleSlides(slideId, docModel.getSlidePaneSelection());
+                }
+            },
+
+            // changing the master slide -> only possible in ODF
+            'layoutslidepicker/changemaster': {
                 parent: ['layoutslidepicker/insertslide'],
                 enable: function () { return !docModel.isEmptySlideView(); },
                 get: function () {
                     return docModel.getLayoutSlideId(docModel.getActiveSlideId());
                 },
                 set: function (slideId) {
-                    docModel.changeLayoutForMultipleSlides(slideId, docModel.getSlidePaneSelection());
+                    docModel.changeODFMasterForMultipleSlides(slideId, docModel.getSlidePaneSelection());
                 }
             },
 
@@ -1032,7 +1162,7 @@ define('io.ox/office/presentation/app/controller', [
                 set: function () { docModel.getFieldManager().removeField(); }
             },
             'document/insertfooter': {
-                parent: 'document/editable/slideexists',
+                parent: ['document/editable/slideexists', 'slide/noodfmasterview'],
                 set: function () { docModel.getFieldManager().openFooterDialog(); }
             },
             'document/insertfield': {
@@ -1097,7 +1227,7 @@ define('io.ox/office/presentation/app/controller', [
         });
 
         // update GUI after changed selection
-        this.listenTo(docModel, 'selection', function () { self.update(); });
+        this._updateOnEvent(docModel, 'selection');
 
         // destroy class members on destruction
         this.registerDestructor(function () {
