@@ -16,12 +16,13 @@ define('io.ox/office/presentation/components/drawing/drawingresize', [
     'io.ox/office/tk/utils',
     'io.ox/office/tk/utils/tracking',
     'io.ox/office/editframework/utils/attributeutils',
+    'io.ox/office/drawinglayer/utils/drawingutils',
     'io.ox/office/drawinglayer/view/drawingframe',
     'io.ox/office/textframework/utils/operations',
     'io.ox/office/textframework/utils/dom',
     'io.ox/office/textframework/utils/position',
     'io.ox/office/presentation/utils/presentationutils'
-], function (Utils, Tracking, AttributeUtils, DrawingFrame, Operations, DOM, Position, PresentationUtils) {
+], function (Utils, Tracking, AttributeUtils, DrawingUtils, DrawingFrame, Operations, DOM, Position, PresentationUtils) {
 
     'use strict';
 
@@ -32,6 +33,9 @@ define('io.ox/office/presentation/components/drawing/drawingresize', [
 
     var ACTIVE_RESIZING = 'activeresizing';
 
+    // constant for delaying shape formatting during resize for different browsers
+    var TEXTSHAPE_UPDATE_RESIZE_DELAY = _.browser.Chrome ? 5 : _.browser.Firefox ? 100 : 250;
+
     // static class DrawingSlideResize ========================================
 
     var DrawingSlideResize = {};
@@ -76,12 +80,10 @@ define('io.ox/office/presentation/components/drawing/drawingresize', [
             isMultiSelection = false,
             // a collector for all move boxes and drawing informations
             allDrawings = null,
-            // constant for delaying shape formatting during resize for different browsers
-            TEXTSHAPE_UPDATE_RESIZE_DELAY = _.browser.Chrome ? 5 : _.browser.Firefox ? 100 : 250,
             // the empty drawing node that contains the selection node
-            selectionDrawing = null,
-            // a debounced function for updating text frame shapes
-            updateTextFrameShapesDebounced = model.createDebouncedMethod($.noop, updateTextFrameShapes, { delay: TEXTSHAPE_UPDATE_RESIZE_DELAY, infoString: 'Presentation: DrawingResize.updateTextFrameShapesDebounced', app: app });
+            selectionDrawing = null;
+
+        var updateTextFrameShapesDebounced = model.createDebouncedMethod('DrawingSlideResize.drawDrawingSelection.updateTextFrameShapesDebounced', null, updateTextFrameShapes, { delay: TEXTSHAPE_UPDATE_RESIZE_DELAY });
 
         // debounced callback for updating text frames in allDrawings
         function updateTextFrameShapes() {
@@ -116,7 +118,7 @@ define('io.ox/office/presentation/components/drawing/drawingresize', [
             if (isResize) { // don't evaluate lock ratio on move, just for resize
                 drawingNode.addClass(ACTIVE_RESIZING);
                 if (drawingNode.data('selection')) { drawingNode.data('selection').addClass(ACTIVE_RESIZING); }
-                lockResizeAspectRatio = (attrs && attrs.drawing && attrs.drawing.noChangeAspect) || Utils.SMALL_DEVICE;
+                lockResizeAspectRatio = (attrs && attrs.drawing && attrs.drawing.aspectLocked) || Utils.SMALL_DEVICE;
             }
 
             var oneMoveBox = cloneDiv(drawingNode, isResize);
@@ -210,12 +212,14 @@ define('io.ox/office/presentation/components/drawing/drawingresize', [
          *     If this method is called during resizing of the shape.
          */
         function updateTextFrameInShape(drawingNode, moveBox, options) {
+            var mergedAttributes = app.getModel().getDrawingStyles().getElementAttributes(drawingNode);
+
             if (DrawingFrame.isGroupDrawingFrame(drawingNode)) {
                 moveBox.find('.textframecontent').children('img').remove();
-                DrawingFrame.previewOnResizeDrawingsInGroup(drawingNode, options);
+                DrawingFrame.previewOnResizeDrawingsInGroup(app, drawingNode, mergedAttributes, options);
             } else {
                 moveBox.children('img').remove();
-                DrawingFrame.updateShapeFormatting(drawingNode, options);
+                DrawingFrame.updateShapeFormatting(app, drawingNode, mergedAttributes, options);
             }
         }
 
@@ -234,89 +238,6 @@ define('io.ox/office/presentation/components/drawing/drawingresize', [
             });
         }
 
-        // helper function to convert degrees to radians. If no valid degree is passed, returns null.
-        function convertDegreeToRadian(deg) {
-            return _.isNumber(deg) ? (deg * Math.PI / 180) : null;
-        }
-
-        // helper function to normalize rotated drawings pixels shift for move. Returns coordinates object
-        function getNormalizedMoveCoordinates(drawing, shiftXo, shiftYo) {
-            var tempX = null;
-            var tempY = null;
-            var angle = DrawingFrame.getDrawingRotationAngle(model, drawing);
-            var rad = convertDegreeToRadian(angle);
-
-            if (rad) {
-                tempX = shiftXo * Math.cos(rad) + shiftYo * Math.sin(rad);
-                tempY = shiftYo * Math.cos(rad) - shiftXo * Math.sin(rad);
-                shiftXo = tempX;
-                shiftYo = tempY;
-            }
-
-            return { x: shiftXo, y: shiftYo };
-        }
-
-        // helper function to normalize drawing pixels delta for resize. Returns coordinates object
-        function getNormalizedResizeDeltas(drawing, deltaXo, deltaYo, useX, useY, scaleX, scaleY) {
-            var localX = null;
-            var localY = null;
-            var angle = DrawingFrame.getDrawingRotationAngle(model, drawing);
-            var rad = convertDegreeToRadian(angle);
-
-            if (rad) {
-                localX = useX ? (deltaXo * Math.cos(rad) + deltaYo * Math.sin(rad)) * scaleX : 0;
-                localY = useY ? (deltaYo * Math.cos(rad) - deltaXo * Math.sin(rad)) * scaleY : 0;
-            } else {
-                localX = useX ? deltaXo * scaleX : 0;
-                localY = useY ? deltaYo * scaleY : 0;
-            }
-
-            return { x: localX, y: localY };
-        }
-
-        // helper function to normalize offset of rotated drawings. Returns object of top and left offset properties.
-        function normalizeOffset(drawingNode, moveBox) {
-            var moveBoxOffsetLeft = moveBox.offset().left;
-            var moveBoxOffsetTop = moveBox.offset().top;
-            var angle = DrawingFrame.getDrawingRotationAngle(model, drawingNode);
-            var tLeft, tTop, dLeft, dTop;
-            if (_.isNumber(angle)) {
-                $(drawingNode).css({ transform: '' }); // reset to def to get values
-                tLeft = $(drawingNode).offset().left;
-                tTop = $(drawingNode).offset().top;
-                $(drawingNode).css({ transform: 'rotate(' + angle + 'deg)' }); // return property to it's value
-
-                dLeft = tLeft - $(drawingNode).offset().left;
-                dTop = tTop - $(drawingNode).offset().top;
-
-                moveBoxOffsetLeft += dLeft;
-                moveBoxOffsetTop += dTop;
-            }
-            return { left: moveBoxOffsetLeft, top: moveBoxOffsetTop };
-        }
-
-        // helper function to normalize resize offset of rotated drawings. Returns object of top and left offset properties,
-        // and sendMoveOperation flag, to send appropriate move operations if drawing is rotated and needs to be translated to the position.
-        function normalizeResizeOffset(drawingNode, moveBox) {
-            var moveBoxOffsetTop, moveBoxOffsetLeft;
-            var sendMoveOperation = false;
-            var angle = DrawingFrame.getDrawingRotationAngle(model, drawingNode);
-
-            if (_.isNumber(angle)) {
-                moveBox.css({ transform: 'rotate(' + (-angle) + 'deg)' });
-                moveBoxOffsetLeft = moveBox.offset().left;
-                moveBoxOffsetTop = moveBox.offset().top;
-                moveBox.css({ transform: '' });
-
-                sendMoveOperation = true;
-            } else {
-                moveBoxOffsetLeft = moveBox.offset().left;
-                moveBoxOffsetTop = moveBox.offset().top;
-            }
-
-            return { left: moveBoxOffsetLeft, top: moveBoxOffsetTop, sendMoveOperation: sendMoveOperation };
-        }
-
         function extendAndGenerateOp(generator, drawingNode, operationProperties, target) {
             PresentationUtils.extendPlaceholderProp(app, drawingNode, operationProperties);
             model.extendPropertiesWithTarget(operationProperties, target);
@@ -346,7 +267,7 @@ define('io.ox/office/presentation/components/drawing/drawingresize', [
             // initialing the moving of the drawing according to the passed tracking event
             function startMoveDrawing() {
 
-                zoomFactor = app.getView().getZoomFactor() / 100;
+                zoomFactor = app.getView().getZoomFactor();
 
                 startScrollX = scrollNode.scrollLeft();
                 startScrollY = scrollNode.scrollTop();
@@ -382,7 +303,11 @@ define('io.ox/office/presentation/components/drawing/drawingresize', [
                 if (_.isNumber(shiftX) && _.isNumber(shiftY) && ((shiftX !== 0) || (shiftY !== 0))) {
 
                     var updateMoveBox = function (oneDrawing) {
-                        var normalizedCoords = getNormalizedMoveCoordinates(oneDrawing.drawingNode, shiftX, shiftY);
+                        var oneDrawingNode = oneDrawing.drawingNode;
+                        var flipH = DrawingFrame.isFlippedHorz(oneDrawingNode);
+                        var flipV = DrawingFrame.isFlippedVert(oneDrawingNode);
+                        var rotation = DrawingFrame.getDrawingRotationAngle(model, oneDrawingNode);
+                        var normalizedCoords = DrawingFrame.getNormalizedMoveCoordinates(shiftX, shiftY, rotation, flipH, flipV);
                         oneDrawing.moveBox.css({ cursor: event.cursor, left: normalizedCoords.x, top: normalizedCoords.y, width: oneDrawing.width, height: oneDrawing.height });
                     };
 
@@ -412,7 +337,7 @@ define('io.ox/office/presentation/components/drawing/drawingresize', [
             function stopMoveDrawing(event) {
 
                 var // the operations generator
-                    generator = model.createOperationsGenerator(),
+                    generator = model.createOperationGenerator(),
                     //
                     availablePos = null,
                     //
@@ -443,7 +368,7 @@ define('io.ox/office/presentation/components/drawing/drawingresize', [
                             generator.generateDrawingOperations(node, start, { ignoreFamily: 'changes presentation', target: target });
                         }
 
-                        var normalizedOffset = normalizeOffset(oneDrawing.drawingNode, oneDrawing.moveBox);
+                        var normalizedOffset = DrawingFrame.normalizeMoveOffset(model, oneDrawing.drawingNode, oneDrawing.moveBox);
 
                         // setting the new attributes of the drawing
                         operationProperties = {
@@ -453,8 +378,15 @@ define('io.ox/office/presentation/components/drawing/drawingresize', [
                                 top: Utils.convertLengthToHmm((normalizedOffset.top - rootNode.offset().top) / zoomFactor, 'px') }
                             }
                         };
+
+                        // marking place holder drawings in ODF as modified by the user
+                        if (app.isODF() && PresentationUtils.requiresUserTransformedProperty(drawingNode)) { operationProperties.attrs.presentation = { userTransformed: true }; }
+
                         extendAndGenerateOp(generator, oneDrawing.drawingNode, operationProperties, target);
 
+                        // adding operations for all drawings, that are dependent from this moved drawing
+                        if (app.isODF()) { model.checkODFDependentDrawings(generator, drawingNode, operationProperties, 'move'); }
+
                         // check whether a drawing is moved above the slide
                         if (operationProperties.attrs.drawing.top < 0) { isMovedAboveSlide = true; }
                     };
@@ -556,7 +488,9 @@ define('io.ox/office/presentation/components/drawing/drawingresize', [
                 // correction factor for resizing to the left/top
                 scaleX = 0, scaleY = 0,
                 // a collector for the rows of a table drawing
-                allRows = null;
+                allRows = null,
+                // a counter for the update resize event (to check, whether the drawing was really resized, 50395)
+                updateResizeCounter = 0;
 
             // initializes resizing the drawing according to the passed tracking event
             function startResizeDrawing(event) {
@@ -574,6 +508,7 @@ define('io.ox/office/presentation/components/drawing/drawingresize', [
                         scaleX = 1;
                         oneMoveBox.css({ left: 0, right: 'auto' });
                     }
+                    if (DrawingFrame.isFlippedHorz(drawingNode)) { scaleX *= -1; }
 
                     if (useTop) {
                         scaleY = -1;
@@ -582,10 +517,13 @@ define('io.ox/office/presentation/components/drawing/drawingresize', [
                         scaleY = 1;
                         oneMoveBox.css({ top: 0, bottom: 'auto' });
                     }
+                    if (DrawingFrame.isFlippedVert(drawingNode)) { scaleY *= -1; }
 
                 }
 
-                zoomFactor = app.getView().getZoomFactor() / 100;
+                updateResizeCounter = 0; // resetting the counter
+
+                zoomFactor = app.getView().getZoomFactor();
 
                 startScrollX = scrollNode.scrollLeft();
                 startScrollY = scrollNode.scrollTop();
@@ -633,15 +571,15 @@ define('io.ox/office/presentation/components/drawing/drawingresize', [
             function updateResize(event) {
 
                 var // the horizontal shift
-                    deltaX = (event.pageX / zoomFactor - event.startX / zoomFactor + scrollX),
+                    deltaX = event.pageX / zoomFactor - event.startX / zoomFactor + scrollX,
                     // the vertical shift
-                    deltaY = (event.pageY / zoomFactor - event.startY / zoomFactor + scrollY),
+                    deltaY = event.pageY / zoomFactor - event.startY / zoomFactor + scrollY,
                     // the scaling factor for the width
                     scaleWidth = 1,
                     // the scaling factor for the height
                     scaleHeight = 1,
                     // normalize and scale deltas of the dimensions
-                    normalizedDeltas = getNormalizedResizeDeltas(drawingNode, deltaX, deltaY, useX, useY, scaleX, scaleY);
+                    normalizedDeltas = DrawingFrame.getNormalizedResizeDeltas(deltaX, deltaY, useX, useY, scaleX, scaleY, DrawingFrame.getDrawingRotationAngle(model, drawingNode));
 
                 // helper function to set the height of rows and cells in table drawing nodes
                 function updateVerticalTableHeight(drawingNode, moveBox, oldHeight) {
@@ -672,34 +610,53 @@ define('io.ox/office/presentation/components/drawing/drawingresize', [
                 function updateDrawingDimension(drawingNode, moveBox, oldWidth, oldHeight, lockAspectRatio) {
 
                     var canvasExpansion = 0; // an optional expansion of the canvas, for example for arrows
-
-                    // update drawing size
-                    finalWidth = Math.max(0, oldWidth + normalizedDeltas.x);
-                    finalHeight = Math.max(0, oldHeight + normalizedDeltas.y);
+                    var sumWidth = oldWidth + normalizedDeltas.x;
+                    var sumHeight = oldHeight + normalizedDeltas.y;
+                    var signWidth = sumWidth > 0 ? 1 : -1;
+                    var signHeight = sumHeight > 0 ? 1 : -1;
+                    var flipH = sumWidth < 0;
+                    var flipV = sumHeight < 0;
+                    var moveBoxTextframe = moveBox.find('.textframe');
+                    var transformProp = 'scaleX(' + (flipH ? -1 : 1) + ') scaleY(' + (flipV ? -1 : 1) + ')';
+                    var topPos, bottomPos, leftPos, rightPos;
 
                     // use the same scaling factor for vertical and horizontal resizing, if both are enabled
                     // -> the larger number wins
                     if (useX && useY && (lockAspectRatio || event.shiftKey)) {
-                        scaleWidth = finalWidth / oldWidth;
-                        scaleHeight = finalHeight / oldHeight;
+                        scaleWidth = Math.abs(sumWidth / oldWidth); // scale shouldn't be negative
+                        scaleHeight = Math.abs(sumHeight / oldHeight);
 
                         if (scaleWidth > scaleHeight) {
-                            finalHeight = scaleWidth * oldHeight;
+                            sumHeight = scaleWidth * oldHeight * signHeight;  // return sign of current width/height after scale
                         } else {
-                            finalWidth = scaleHeight * oldWidth;
+                            sumWidth = scaleHeight * oldWidth * signWidth;
                         }
                     }
 
+                    topPos = useTop ? 'auto' : Math.min(0, sumHeight);
+                    bottomPos = useTop ? Math.min(0, sumHeight) : 'auto';
+                    leftPos = useLeft ? 'auto' : Math.min(0, sumWidth);
+                    rightPos = useLeft ? Math.min(0, sumWidth) : 'auto';
+
+                    // update drawing size
+                    finalWidth = Math.abs(sumWidth);
+                    finalHeight = Math.abs(sumHeight);
+
+                    moveBox.css({ width: finalWidth, height: finalHeight, top: topPos, left: leftPos, bottom: bottomPos, right: rightPos, transform: transformProp });
+                    moveBox.toggleClass(DrawingFrame.FLIPPED_HORIZONTALLY_CLASSNAME, flipH);
+                    moveBox.toggleClass(DrawingFrame.FLIPPED_VERTICALLY_CLASSNAME, flipV);
+                    moveBox.data({ flipH: flipH, flipV: flipV });
+                    moveBoxTextframe.toggleClass('flipH', DrawingFrame.isOddFlipHVCount(moveBoxTextframe, '.slide'));
+
                     // make move box visible when tracking position has moved
                     DrawingFrame.toggleTracking(drawingNode.data('selection'), true);
 
-                    moveBox.css({ width: finalWidth, height: finalHeight });
-
                     // simulating height changes of tables (makes only sense for single drawing selections because of performance)
                     if (useY && !isMultiSelection && DrawingFrame.isTableDrawingFrame(drawingNode)) { updateVerticalTableHeight(drawingNode, moveBox, oldHeight); }
 
                     if (!DrawingFrame.isGroupContentNode(moveBox)) {
                         canvasExpansion = drawingNode.data('canvasexpansion') || 0; // canvas expansion was saved at the drawing node
+                        if (_.isObject(canvasExpansion)) { return; } // avoid flickering during resize
                         canvasExpansion *= 2;
                         moveBox.find('canvas, .cropping-frame img').css({ width: finalWidth + canvasExpansion + 2, height: finalHeight + canvasExpansion + 2 }); // make smooth transition, until canvas is updated
                     }
@@ -711,18 +668,22 @@ define('io.ox/office/presentation/components/drawing/drawingresize', [
 
                 // debounce updating of text frames in allDrawings on slower browsers & devices
                 updateTextFrameShapesDebounced();
+
+                updateResizeCounter++; // the drawing is really resized
             }
 
             // stop resizing of drawing
             function stopResizeDrawing() {
 
                 var // the operations generator
-                    generator = model.createOperationsGenerator();
+                    generator = model.createOperationGenerator(),
+                    // whether a operation was generated
+                    operationGenerated = false;
 
                 // helper function to generate the operation for resizing one drawing
                 function generateResizeOperation(drawingNode, moveBox, start) {
-
-                    var normalizedOffset = normalizeResizeOffset(drawingNode, moveBox);
+                    var normalizedOffset = DrawingFrame.normalizeResizeOffset(model, drawingNode, moveBox, useTop, useLeft);
+                    var rootNodeOffset = rootNode.offset();
 
                     if (moveBox.css('display') !== 'none' && moveBox.width() && moveBox.height()) { // generate operations only if moveBox has real w/h value, measured without outer
                         // setting the new attributes of the drawing
@@ -734,15 +695,32 @@ define('io.ox/office/presentation/components/drawing/drawingresize', [
                             }
                         };
 
+                        if (moveBox.data('flipV')) {
+                            operationProperties.attrs.drawing.flipV = !DrawingFrame.isFlippedVert(drawingNode);
+                            operationProperties.attrs.drawing.top = Utils.convertLengthToHmm((normalizedOffset.top - rootNodeOffset.top) / zoomFactor, 'px');
+                        }
+                        if (moveBox.data('flipH')) {
+                            operationProperties.attrs.drawing.flipH = !DrawingFrame.isFlippedHorz(drawingNode);
+                            operationProperties.attrs.drawing.left = Utils.convertLengthToHmm((normalizedOffset.left - rootNodeOffset.left) / zoomFactor, 'px');
+                        }
+
+                        // marking place holder drawings in ODF as modified by the user
+                        if (app.isODF() && PresentationUtils.requiresUserTransformedProperty(drawingNode)) { operationProperties.attrs.presentation = { userTransformed: true }; }
+
                         // evaluating useTop and useLeft to avoid sending of superfluous drawing information
-                        if (useTop || normalizedOffset.sendMoveOperation) { operationProperties.attrs.drawing.top = Utils.convertLengthToHmm((normalizedOffset.top - rootNode.offset().top) / zoomFactor, 'px'); }
-                        if (useLeft || normalizedOffset.sendMoveOperation) { operationProperties.attrs.drawing.left = Utils.convertLengthToHmm((normalizedOffset.left - rootNode.offset().left) / zoomFactor, 'px'); }
+                        if (useTop || normalizedOffset.sendMoveOperation) { operationProperties.attrs.drawing.top = Utils.convertLengthToHmm((normalizedOffset.top - rootNodeOffset.top) / zoomFactor, 'px'); }
+                        if (useLeft || normalizedOffset.sendMoveOperation) { operationProperties.attrs.drawing.left = Utils.convertLengthToHmm((normalizedOffset.left - rootNodeOffset.left) / zoomFactor, 'px'); }
 
                         if (useX && DrawingFrame.isNoWordWrapDrawingFrame(drawingNode) && DrawingFrame.isAutoResizeHeightDrawingFrame(drawingNode)) {
                             operationProperties.attrs.shape = { wordWrap: true };
                         }
 
                         extendAndGenerateOp(generator, drawingNode, operationProperties, target);
+
+                        // adding operations for all drawings, that are dependent from this moved drawing
+                        if (app.isODF()) { model.checkODFDependentDrawings(generator, drawingNode, operationProperties, 'resize'); }
+
+                        operationGenerated = true; // setting marker for generated operation
                     }
                 }
 
@@ -781,20 +759,32 @@ define('io.ox/office/presentation/components/drawing/drawingresize', [
 
                             rowCounter++;
                         });
+
+                        if (app.isODF() && model.useSlideMode()) { // table height must be send to the filter via operation
+                            model.trigger('drawingHeight:update', drawingNode);
+                        }
+
+                        operationGenerated = true; // setting marker for generated operation
                     }
                 }
 
+                if (updateResizeCounter === 0) { return; } // no resize -> no operation
+
                 _.each(allDrawings, function (oneDrawing) {
 
+                    operationGenerated = false;
+
                     if (DrawingFrame.isTableDrawingFrame(oneDrawing.drawingNode)) {
                         generateTableDrawingResizeOperations(oneDrawing.drawingNode, oneDrawing.moveBox, oneDrawing.start, oneDrawing.height);
                     } else {
                         generateResizeOperation(oneDrawing.drawingNode, oneDrawing.moveBox, oneDrawing.start);
                     }
 
-                    // prevent flickering on finalize resizing by replacing original canvas with repainted one
-                    var copyCanvas = oneDrawing.moveBox.children('canvas');
-                    oneDrawing.drawingNode.children('.textframecontent').not('.copy').children('canvas').replaceWith(copyCanvas);
+                    if (operationGenerated) { // <- do not use canvas copy, if no operation could be generated (for example after setting width to 0)
+                        // prevent flickering on finalize resizing by replacing original canvas with repainted one
+                        var copyCanvas = oneDrawing.moveBox.children('canvas');
+                        oneDrawing.drawingNode.children('.textframecontent').not('.copy').children('canvas').replaceWith(copyCanvas);
+                    }
                 });
 
                 // Applying the operations (undo group is created automatically)
@@ -868,13 +858,13 @@ define('io.ox/office/presentation/components/drawing/drawingresize', [
 
             function startRotateDrawing() {
                 var drawingOffset;
-
-                zoomFactor = app.getView().getZoomFactor() / 100;
+                var drawingPos;
+                zoomFactor = app.getView().getZoomFactor();
                 startAngle = DrawingFrame.getDrawingRotationAngle(model, drawingNode);
-                if (_.isNumber(startAngle)) {
-                    $(drawingNode).css({ transform: '' }); // reset to def to get values
+                if (_.isNumber(startAngle) && (startAngle !== 0)) {
+                    $(drawingNode).css('transform', ''); // reset to def to get values
                     drawingOffset = drawingNode.offset();
-                    $(drawingNode).css({ transform: 'rotate(' + startAngle + 'deg)' }); // return property to it's value
+                    DrawingFrame.updateCssTransform(drawingNode, startAngle);
                 } else {
                     startAngle = 0;
                     drawingOffset = drawingNode.offset();
@@ -892,7 +882,7 @@ define('io.ox/office/presentation/components/drawing/drawingresize', [
                 if (isMultiSelection) {
                     collectAndPrepareDrawingsForRotation();
                 } else {
-                    var drawingPos = Position.getOxoPosition(rootNode, drawingNode, 0);
+                    drawingPos = Position.getOxoPosition(rootNode, drawingNode, 0);
                     allDrawings.push({ drawingNode: drawingNode, start: drawingPos, rotation: startAngle });
 
                 }
@@ -903,21 +893,23 @@ define('io.ox/office/presentation/components/drawing/drawingresize', [
             }
 
             function updateRotate(event) {
-                var radians = Math.atan2((event.pageX + scrollX - centerX), (event.pageY + scrollY - centerY));
-                rotationAngle = (radians * (180 / Math.PI) * -1) + 180;
-                // round to full degrees
-                rotationAngle = parseInt(rotationAngle, 10);
+
+                var radians = Math.atan2(event.pageX + scrollX - centerX, event.pageY + scrollY - centerY);
+                rotationAngle = Math.round(180 - radians * 180 / Math.PI);
 
                 if (event.shiftKey) {
-                    rotationAngle = Math.round(rotationAngle / 15) * 15; // make 15 deg step with shift key
+                    rotationAngle = Utils.round(rotationAngle, 15); // make 15 deg step with shift key
+                }
+                if (DrawingFrame.isFlippedVert(drawingNode)) {
+                    rotationAngle += 180;
                 }
                 if (isMultiSelection) {
                     _.each(allDrawings, function (obj) {
-                        var startAngleTemp = obj.rotation;
-                        obj.drawingNode.css('transform', 'rotate(' + (rotationAngle - startAngle + startAngleTemp) + 'deg)');
+                        var objAngle = rotationAngle - startAngle + obj.rotation;
+                        DrawingFrame.updateCssTransform(obj.drawingNode, objAngle);
                     });
                 } else {
-                    drawingNode.css('transform', 'rotate(' + (rotationAngle) + 'deg)');
+                    DrawingFrame.updateCssTransform(drawingNode, rotationAngle);
                 }
             }
 
@@ -932,25 +924,15 @@ define('io.ox/office/presentation/components/drawing/drawingresize', [
             }
 
             function stopRotateDrawing() {
-                var generator = model.createOperationsGenerator();
+                var generator = model.createOperationGenerator();
                 var operationProperties;
 
                 if (_.isNumber(rotationAngle)) {
                     if (isMultiSelection) {
                         _.each(allDrawings, function (obj) {
-                            var startAngleTemp = obj.rotation;
-
-                            var tempRotationAngle = rotationAngle - startAngle + startAngleTemp;
-                            // for 360 degrees apply 0 rotation
-                            tempRotationAngle = tempRotationAngle === 360 ? 0 : tempRotationAngle;
-
-                            // normalize negative and angles greater than 360
-                            if (tempRotationAngle < 0) {
-                                tempRotationAngle += 360;
-                            }
-                            if (tempRotationAngle > 360) {
-                                tempRotationAngle -= 360;
-                            }
+                            var tempRotationAngle = rotationAngle - startAngle + obj.rotation;
+                            // get value for angle between 0 and 359 degree
+                            tempRotationAngle = Utils.mod(tempRotationAngle, 360);
 
                             operationProperties = {
                                 start: obj.start,
@@ -959,13 +941,17 @@ define('io.ox/office/presentation/components/drawing/drawingresize', [
                             extendAndGenerateOp(generator, obj.drawingNode, operationProperties, target);
                         });
                     } else {
-                        // for 360 degrees apply 0 rotation
-                        rotationAngle = rotationAngle === 360 ? 0 : rotationAngle;
+                        // normalize angle between 0 and 359 deg
+                        rotationAngle =  Utils.mod(rotationAngle, 360);
 
                         operationProperties = {
                             start: Position.getOxoPosition(rootNode, drawingNode, 0),
                             attrs: { drawing: { rotation: rotationAngle } }
                         };
+
+                        // marking place holder drawings in ODF as modified by the user
+                        if (app.isODF() && PresentationUtils.requiresUserTransformedProperty(drawingNode)) { operationProperties.attrs.presentation = { userTransformed: true }; }
+
                         extendAndGenerateOp(generator, drawingNode, operationProperties, target);
                     }
 
@@ -989,12 +975,10 @@ define('io.ox/office/presentation/components/drawing/drawingresize', [
                 if (!generatedOp) { // reset to start angle if tracking was canceled
                     if (isMultiSelection) {
                         _.each(allDrawings, function (obj) {
-                            var startAngleTemp = obj.rotation || 0;
-
-                            obj.drawingNode.css('transform', 'rotate(' + startAngleTemp + 'deg)');
+                            DrawingFrame.updateCssTransform(obj.drawingNode, obj.rotation || 0);
                         });
                     } else {
-                        drawingNode.css('transform', 'rotate(' + startAngle + 'deg)');
+                        DrawingFrame.updateCssTransform(drawingNode, startAngle);
                     }
                 } else {
                     if (isMultiSelection) {
@@ -1074,7 +1058,7 @@ define('io.ox/office/presentation/components/drawing/drawingresize', [
                 resizeNode.off(TRACKING_EVENT_NAMES);
                 resizeNode.on(TRACKING_EVENT_NAMES, drawingResizeHandler);
                 drawingResizeHandler.call(this, event);
-            } else if ($(event.target).hasClass('rotate-handle')) {
+            } else if (DrawingFrame.isRotateHandle(event.target)) {
                 selectionDrawing.off(TRACKING_EVENT_NAMES); // <- should not be necessary, but it is (more and more setAttributes OPs)
                 selectionDrawing.on(TRACKING_EVENT_NAMES, drawingRotateHandler);
                 drawingRotateHandler.call(this, event);
@@ -1145,11 +1129,14 @@ define('io.ox/office/presentation/components/drawing/drawingresize', [
             drawingNode = drawingNode.closest(DrawingFrame.GROUPCONTENT_SELECTOR).parent();
         }
 
-        if (!model.getEditMode()) {
+        if (!app.isEditable()) {
             options.movable = options.resizable = options.rotatable = false;
         }
 
-        options.scaleHandles = 100 / app.getView().getZoomFactor();
+        var currentZoomFactor = app.getView().getZoomFactor();
+        options.zoomValue    = 100 * currentZoomFactor;
+        options.scaleHandles = 1 / currentZoomFactor;
+        options.rotation     = DrawingFrame.getDrawingRotationAngle(model, drawingNode) || 0;
 
         // removing an existing selection (possible for example in additional text frame selections)
         if (drawingNode.data('selection')) { DrawingFrame.clearSelection(drawingNode); }
@@ -1160,11 +1147,6 @@ define('io.ox/office/presentation/components/drawing/drawingresize', [
         // shifting the selection into an overlay node
         selectionDrawing = shiftSelectionToOverlayNode();
 
-        DrawingFrame.updateResizersMousePointers(drawingNode, DrawingFrame.getDrawingRotationAngle(model, drawingNode));
-
-        // set visible drawing anchor
-        app.getView().setVisibleDrawingAnchor(drawingNode, AttributeUtils.getExplicitAttributes(drawingNode));
-
         toggleTracking(drawingNode, options.movable);
         toggleTracking(selectionDrawing, options.movable);
         // initialize resize tracking
@@ -1173,11 +1155,11 @@ define('io.ox/office/presentation/components/drawing/drawingresize', [
         toggleTracking(selectionBox.find('.rotate-handle'), options.rotatable);
 
         if (options.movable || options.resizeable || options.rotatable) {
-            selectionDrawing.on('tracking:start', trackingStartHandler);
-            drawingNode.on('tracking:start', trackingStartHandler);
+            model.listenTo(selectionDrawing, 'tracking:start', trackingStartHandler);
+            model.listenTo(drawingNode, 'tracking:start', trackingStartHandler);
         } else {
-            selectionDrawing.off('tracking:start', trackingStartHandler);
-            drawingNode.on('tracking:start', trackingStartHandler);
+            model.stopListeningTo(selectionDrawing, 'tracking:start', trackingStartHandler);
+            model.stopListeningTo(drawingNode, 'tracking:start', trackingStartHandler);
         }
     };
 
