@@ -14,57 +14,70 @@
 
 define('io.ox/office/presentation/format/slidestyles', [
     'io.ox/office/tk/utils',
-    'io.ox/office/tk/utils/deferredutils',
-    'io.ox/office/textframework/utils/dom',
     'io.ox/office/tk/render/canvas',
+    'io.ox/office/textframework/utils/dom',
     'io.ox/office/editframework/utils/attributeutils',
     'io.ox/office/editframework/utils/gradient',
     'io.ox/office/editframework/utils/pattern',
     'io.ox/office/editframework/utils/texture',
     'io.ox/office/editframework/model/stylecollection',
     'gettext!io.ox/office/presentation/main'
-
-], function (Utils, DeferredUtils, DOM, Canvas, AttributeUtils, Gradient, Pattern, Texture, StyleCollection, gt) {
+], function (Utils, Canvas, DOM, AttributeUtils, Gradient, Pattern, Texture, StyleCollection, gt) {
 
     'use strict';
 
-    var // definitions for slide attributes
-        DEFINITIONS = {
+    // definitions for slide attributes
+    var DEFINITIONS = {
 
-            /**
-             * Whether the drawings from layout or master slide shall be visible.
-             */
-            followMasterShapes: { def: true },
+        /**
+         * Whether the drawings from layout or master slide shall be visible.
+         */
+        followMasterShapes: { def: true },
 
-            /**
-             * Whether the date place holder will be inherited.
-             */
-            isDate: { def: false },
+        /**
+         * Whether the date place holder will be inherited.
+         */
+        isDate: { def: false },
 
-            /**
-             * Whether the header place holder will be inherited.
-             */
-            isFooter: { def: false },
+        /**
+         * Whether the header place holder will be inherited.
+         */
+        isFooter: { def: false },
 
-            /**
-             * Whether the footer place holder will be inherited.
-             */
-            isHeader: { def: false },
-            /**
-             * Whether the slide number place holder will be inherited.
-             */
-            isSlideNum: { def: false },
+        /**
+         * Whether the footer place holder will be inherited.
+         */
+        isHeader: { def: false },
+        /**
+         * Whether the slide number place holder will be inherited.
+         */
+        isSlideNum: { def: false },
 
-            /**
-             * Whether the drawings from layout or master slide shall be visible.
-             */
-            hidden: { def: false },
+        /**
+         * Whether the drawings from layout or master slide shall be visible.
+         */
+        hidden: { def: false },
 
-            /**
-             * The type of a layout slide
-             */
-            type: { def: '' }
-        };
+        /**
+         * The type of a layout slide
+         */
+        type: { def: '' },
+
+        /**
+         * The fixed text in ODF placeholder drawings of type 'ftr'
+         */
+        footerText: { def: '' },
+
+        /**
+         * The fixed text in ODF placeholder drawings of type 'dt'
+         */
+        dateText: { def: '' },
+
+        /**
+         * The field text in ODF placeholder drawings of type 'dt'
+         */
+        dateField: { def: '' }
+    };
 
     // Info for the properties 'isDate', 'isFooter', 'isHeader' and 'isSildeNum'.
     // In OOXML file there is an 'hf' element. If this does not exist, all values are set
@@ -74,8 +87,6 @@ define('io.ox/office/presentation/format/slidestyles', [
     // filter for the loading operations of the document. If the client changes one of these
     // values in the UI, all four values need to be set.
 
-    // private global functions ===============================================
-
     // class SlideStyles =======================================================
 
     /**
@@ -86,23 +97,17 @@ define('io.ox/office/presentation/format/slidestyles', [
      *
      * @extends StyleCollection
      *
-     * @param {TextModel} docModel
-     *  The text document model containing instance.
+     * @param {PresentationModel} docModel
+     *  The presentation document model containing this instance.
      */
-    function SlideStyles(docModel) {
-
-        // show the Notification if slide background imgage failures exist
-        var showBackgroundImageFailureNotificationDebounced = docModel.createDebouncedMethod($.noop, showBackgroundImageFailureNotification, { delay: 1000, infoString: 'Presentation: slidestyles.showBackgroundImageFailureNotification', app: docModel.getApp() });
+    var SlideStyles = StyleCollection.extend({ constructor: function (docModel) {
 
         // SlideIds with background image failures, with a boolean flag which indicates if a notification for this slide was displayed
         var backgroundImageFailureSlideIds = {};
 
         // base constructor ---------------------------------------------------
 
-        StyleCollection.call(this, docModel, 'slide', {
-            families: 'fill',
-            formatHandler: updateSlideFormatting
-        });
+        StyleCollection.call(this, docModel, 'slide', { families: 'fill' });
 
         // private functions --------------------------------------------------
 
@@ -145,7 +150,7 @@ define('io.ox/office/presentation/format/slidestyles', [
                 // the slide ID that is used for the theme color
                 themeSlideId = themeSlideIdStr || slideId,
                 // the target chain needed to resolve the current theme
-                target = docModel.getTargetChain(themeSlideId),
+                targets = docModel.getTargetChain(themeSlideId),
                 // if updateBackground was triggered by image load in preview dialog
                 isImageLoad = Utils.getBooleanOption(options, 'imageLoad', false),
                 // if updateBackground is triggered in preview dialog
@@ -166,8 +171,8 @@ define('io.ox/office/presentation/format/slidestyles', [
             // -> in the current solution, the visible slide gets a slide background with correct theming, although no slide
             //    background is specified for this slide.
             function checkInheritedFillAttrs() {
-                if (!docModel.isMasterSlideId(slideId) && docModel.hasDefaultScheme(slideId)) {
-                    var backgroundSlideId = docModel.getMostTopBackgroundSlide(_.rest(target));
+                if (!docModel.isMasterSlideId(slideId) && docModel.hasDefaultTheme(slideId)) {
+                    var backgroundSlideId = docModel.getMostTopBackgroundSlide(_.rest(targets));
                     if (backgroundSlideId) {
                         inheritedFillAttrs = docModel.getSlideAttributesByFamily(backgroundSlideId, 'fill');
                         if (AttributeUtils.isFillThemed(inheritedFillAttrs)) {
@@ -189,20 +194,20 @@ define('io.ox/office/presentation/format/slidestyles', [
                     break;
 
                 case 'solid':
-                    cssProps.background = docModel.getCssColor(fillAttrs.color, 'fill', target);
+                    cssProps.background = docModel.getCssColor(fillAttrs.color, 'fill', targets);
                     break;
 
                 case 'gradient':
                     var
                         elmSlide  = $slide[0],
                         gradient  = Gradient.create(Gradient.getDescriptorFromAttributes(fillAttrs)),
-                        dataUrl   = Gradient.parseImageDataUrl(gradient, docModel, { width: elmSlide.offsetWidth, height: elmSlide.offsetHeight }, target);
+                        dataUrl   = Gradient.parseImageDataUrl(gradient, docModel, { width: elmSlide.offsetWidth, height: elmSlide.offsetHeight }, targets);
 
                     cssProps.background = 'url("' + dataUrl + '")';
                     break;
 
                 case 'pattern':
-                    cssProps.background = 'url("' + Pattern.createDataURL(fillAttrs.pattern, fillAttrs.backgroundColor, fillAttrs.color, docModel.getTheme(target)) + '")';
+                    cssProps.background = 'url("' + Pattern.createDataURL(fillAttrs.pattern, fillAttrs.color2, fillAttrs.color, docModel.getThemeModel(targets)) + '")';
                     break;
 
                 case 'bitmap':
@@ -248,27 +253,24 @@ define('io.ox/office/presentation/format/slidestyles', [
          *   String base64 png image url, if the promise is resolved.
          */
         function generateImageURLfromCanvas(fillAttrs, isPreview, slideId) {
-            var def = DeferredUtils.createDeferred(docModel.getApp(), 'SlideStyles: generateImageURLfromCanvas'); // the result deferred
-            var tempCanvas = new Canvas();
             var slideSize = docModel.getSlideDocumentSize();
             var slideW = Utils.convertHmmToLength(slideSize.width, 'px', 1);
             var slideH = Utils.convertHmmToLength(slideSize.height, 'px', 1);
+            var tempCanvas = new Canvas(docModel).initialize({ width: slideW, height: slideH });
 
-            tempCanvas.initialize({ width: slideW, height: slideH });
-            tempCanvas.render(function (tempCtx) {
-                Texture.getTextureFill(docModel, tempCtx, fillAttrs, slideW, slideH, 0, { isSlide: true, noAlpha: isPreview }).then(function (textureFill) {
-                    tempCtx.setFillStyle(textureFill).drawRect(0, 0, slideW, slideH, 'fill');
-                    def.resolve(tempCanvas.getDataURL());
-                })
-                .fail(function () {
+            return tempCanvas.render(function (tempCtx) {
+                var promise = Texture.getTextureFill(docModel, tempCtx, fillAttrs, slideW, slideH, 0, { isSlide: true, noAlpha: isPreview });
+                promise.fail(function () {
                     if (!_.isEmpty(slideId) && !(slideId in backgroundImageFailureSlideIds)) {
                         backgroundImageFailureSlideIds[slideId] = true;
                         showBackgroundImageFailureNotificationDebounced();
                     }
                 });
+                return promise.then(function (textureFill) {
+                    tempCtx.setFillStyle(textureFill).drawRect(0, 0, slideW, slideH, 'fill');
+                    return tempCanvas.getDataURL();
+                });
             });
-
-            return def.promise();
         }
 
         /**
@@ -315,6 +317,9 @@ define('io.ox/office/presentation/format/slidestyles', [
             }
         }
 
+        // show the Notification if slide background imgage failures exist
+        var showBackgroundImageFailureNotificationDebounced = this.createDebouncedMethod('Slidestyles.showBackgroundImageFailureNotificationDebounced', null, showBackgroundImageFailureNotification, { delay: 1000 });
+
         /**
          * Will be called for every page whose attributes have been changed.
          *
@@ -325,6 +330,9 @@ define('io.ox/office/presentation/format/slidestyles', [
          *  A map of attribute maps (name/value pairs), keyed by attribute family,
          *  containing the effective attribute values merged from style sheets and
          *  explicit attributes.
+         *
+         * @returns {jQuery.Promise}
+         *  A promise that is resolved, after the slide background is set.
          */
         function updateSlideFormatting(slide, mergedAttributes) {
 
@@ -333,16 +341,22 @@ define('io.ox/office/presentation/format/slidestyles', [
                 // getting the old 'hidden' state (the model is already updated)
                 oldHiddenState = (slide.attr('isHidden') === 'true'),
                 // whether the hidden state of a slide was changed
-                hiddenStateChanged = (mergedAttributes.slide.hidden !== oldHiddenState);
+                hiddenStateChanged = (mergedAttributes.slide.hidden !== oldHiddenState),
+                // a promise for handling the slide background
+                backgroundPromise = null;
 
             // updating the slide background
-            updateBackground(slide, mergedAttributes, slideId);
+            backgroundPromise = updateBackground(slide, mergedAttributes, slideId);
 
             // setting a marker at the slide, so that changes can be recognized
             if (hiddenStateChanged) { slide.attr('isHidden', mergedAttributes.slide.hidden); }
 
             // inform the view, that the merged slide attributes (including 'fill') need to be updated
-            docModel.trigger('change:slideAttributes', { slideId: slideId, hiddenStateChanged: hiddenStateChanged, isHidden: mergedAttributes.slide.hidden });
+            backgroundPromise.done(function () {
+                docModel.trigger('change:slideAttributes', { slideId: slideId, hiddenStateChanged: hiddenStateChanged, isHidden: mergedAttributes.slide.hidden });
+            });
+
+            return backgroundPromise;
         }
 
         // public methods -----------------------------------------------------
@@ -397,20 +411,20 @@ define('io.ox/office/presentation/format/slidestyles', [
         // initialization -----------------------------------------------------
 
         // register the attribute definitions for the style family
-        docModel.registerAttributeDefinitions('slide', DEFINITIONS);
+        docModel.registerAttributes('slide', DEFINITIONS);
+
+        // register the formatting handler for DOM elements
+        this.registerFormatHandler(updateSlideFormatting);
 
         // destroy all class members on destruction
         this.registerDestructor(function () {
             docModel = null;
         });
 
-    } // class SlideStyles
-
-    // constants --------------------------------------------------------------
+    } }); // class SlideStyles
 
     // exports ================================================================
 
-    // derive this class from class StyleCollection
-    return StyleCollection.extend({ constructor: SlideStyles });
+    return SlideStyles;
 
 });
