@@ -13,14 +13,14 @@
  */
 
 define('io.ox/office/presentation/model/dynfontsizemixin', [
-    'io.ox/office/textframework/utils/dom',
-    'io.ox/office/drawinglayer/view/drawingframe',
     'io.ox/office/tk/utils',
+    'io.ox/office/drawinglayer/view/drawingframe',
     'io.ox/office/editframework/utils/attributeutils',
+    'io.ox/office/textframework/utils/dom',
     'io.ox/office/textframework/utils/position',
     'io.ox/office/textframework/utils/operations',
     'io.ox/office/presentation/utils/presentationutils'
-], function (DOM, DrawingFrame, Utils, AttributeUtils, Position, Operations, PresentationUtils) {
+], function (Utils, DrawingFrame, AttributeUtils, DOM, Position, Operations, PresentationUtils) {
 
     'use strict';
 
@@ -29,10 +29,11 @@ define('io.ox/office/presentation/model/dynfontsizemixin', [
 
     var INDEX_ARRAY = [0, 1, 2, 3, 4, 5];
 
-    // mixin DynFontSizeMixin =========================================================
+    // mix-in class DynFontSizeMixin ==========================================
 
-    function DynFontSizeMixin() {
+    function DynFontSizeMixin(app) {
 
+        // self reference (the document model)
         var self = this;
 
         // all drawings nodes that need to be updated
@@ -69,8 +70,8 @@ define('io.ox/office/presentation/model/dynfontsizemixin', [
                 //all is fine
                 // console.log('all is fine');
                 return null;
-            } else if (currentHeight < maxHeight * 1.02 && currentHeight > maxHeight * 0.95) {
-                //all is scaled but fine in 95% - 102%
+            } else if (currentHeight < maxHeight * 1.1 && currentHeight > maxHeight * 0.90) {
+                // all is scaled but fine in 90% - 110%
                 // console.log('all is scaled but fine');
                 return null;
             } else {
@@ -234,14 +235,9 @@ define('io.ox/office/presentation/model/dynfontsizemixin', [
                 }
                 return;
             }
-            var maxHeight = 0;
-            if (_.browser.IE) {
-                // fix for Bug 48665
-                maxHeight = $drawing.data('widthHeightRev') ? $drawing.width() : $drawing.height();
-                maxHeight = maxHeight - (parseFloat(textFrame[0].style.top) || 0) - (parseFloat(textFrame[0].style.paddingBottom) || 0);
-            } else {
-                maxHeight = $drawing.data('widthHeightRev') ? textFrame.width() : textFrame.height();
-            }
+            // fix for Bug 48665
+            var maxHeight = $drawing.data('widthHeightRev') ? $drawing.width() : $drawing.height();
+            maxHeight = maxHeight -/* (parseFloat(textFrame[0].style.top) || 0) -*/ (parseFloat(textFrame[0].style.paddingBottom) || 0);
 
             if (!maxHeight) {
                 return;
@@ -278,7 +274,7 @@ define('io.ox/office/presentation/model/dynfontsizemixin', [
 
             var def = null;
             if (_.browser.IE) {
-                def = self.iterateArraySliced(INDEX_ARRAY, innerUpdate, { slice: 1, infoString: 'DynFontSizeMixin:updateDrawing()', app: self.getApp() });
+                def = self.iterateArraySliced(INDEX_ARRAY, innerUpdate, 'DynFontSizeMixin.updateDrawing', { slice: 1 });
             } else {
                 _.each(INDEX_ARRAY, innerUpdate);
                 def = $.when(true);
@@ -368,7 +364,8 @@ define('io.ox/office/presentation/model/dynfontsizemixin', [
             // iterating over all drawings
             _.each(drawings, function (drawing) {
                 // TODO: operate correct on grouped drawings (width/height are different to ungrouped drawings)
-                if ($(drawing).is('.grouped')) { return; }
+                // Also no text resize for 'title' place holders
+                if ($(drawing).is('.grouped') || PresentationUtils.isTitlePlaceHolderDrawing(drawing)) { return; }
 
                 var slide = $(drawing).closest(DOM.SLIDE_SELECTOR);
                 slideID = self.getSlideId(slide);
@@ -385,9 +382,9 @@ define('io.ox/office/presentation/model/dynfontsizemixin', [
             if (defs.length) {
                 return $.when.apply($, defs).then(function () {
                     //controller update must be called for changed font-size in the toolbar
-                    self.getApp().getController().update();
+                    app.getController().update();
 
-                    if (!self.getEditMode()) {
+                    if (!app.isEditable()) {
                         return;
                     }
                     var ops = [];
@@ -433,44 +430,145 @@ define('io.ox/office/presentation/model/dynfontsizemixin', [
 
             var selection = self.getSelection();
             // the operations generator
-            var generator = self.createOperationsGenerator();
+            var generator = self.createOperationGenerator();
             // the options for the setAttributes operation
             var operationOptions = {};
             // a selected text frame node or the text frame containing the selection
-            var textFrame = selection.getAnyTextFrameDrawing({ forceTextFrame: true });
+            var textFrame = null;
+            // a collector for all affected drawings in a multi drawing selection
+            var textFrameCollector = null;
+            // a selected drawing node
+            var selectedDrawing = null;
 
-            // collecting the attributes for the operation
-            operationOptions.attrs =  {};
-            operationOptions.attrs.shape = {};
+            /**
+             * Helper function to handle all shapes inside a specified drawing group node.
+             */
+            function handleShapesInGroup(groupNode) {
 
-            operationOptions.attrs.shape.autoResizeText   = autoResizeText || false;
-            operationOptions.attrs.shape.autoResizeHeight = autoResizeHeight || false;
-            operationOptions.attrs.shape.noAutoResize = (!autoResizeText && !autoResizeHeight);
+                _.each(DrawingFrame.getAllGroupDrawingChildren(groupNode), function (child) {
 
-            if (selection.isAdditionalTextframeSelection()) {
-                operationOptions.start = Position.getOxoPosition(self.getNode(), textFrame, 0);
-            } else {
-                operationOptions.start = selection.getStartPosition();
+                    if (DrawingFrame.isTextFrameShapeDrawingFrame(child)) {
+
+                        textFrame = $(child);
+
+                        // collecting the attributes for the operation
+                        operationOptions.attrs =  {};
+                        operationOptions.attrs.shape = {};
+
+                        if (!app.isODF()) { operationOptions.attrs.shape.autoResizeText   = autoResizeText || false; }
+                        operationOptions.attrs.shape.autoResizeHeight = autoResizeHeight || false;
+                        operationOptions.attrs.shape.noAutoResize = (!autoResizeText && !autoResizeHeight);
+
+                        operationOptions.start = Position.getOxoPosition(self.getNode(), textFrame, 0);
+
+                        if (autoResizeText || autoResizeHeight) { // Bug 48714 fix for undo
+                            operationOptions.attrs.drawing = {};
+                            PresentationUtils.extendPlaceholderProp(app, textFrame, operationOptions);
+                        }
+
+                        // generate the 'setAttributes' operation
+                        generator.generateOperation(Operations.SET_ATTRIBUTES, operationOptions);
+
+                        // collecting the affected drawings
+                        textFrameCollector = textFrameCollector || [];
+                        textFrameCollector.push(textFrame);
+                    }
+                });
             }
 
-            if (autoResizeText || autoResizeHeight) {
-                // Bug 48714 fix for undo
-                operationOptions.attrs.drawing = {};
-                PresentationUtils.extendPlaceholderProp(self.getApp(), textFrame, operationOptions);
-            }
+            // multiselection
+            if (selection.isMultiSelectionSupported() && selection.isMultiSelection()) {
 
-            // generate the 'setAttributes' operation
-            generator.generateOperation(Operations.SET_ATTRIBUTES, operationOptions);
+                _.each(selection.getMultiSelection(), function (drawingItem) {
+
+                    var drawingNode = selection.getDrawingNodeFromMultiSelection(drawingItem);
+
+                    // filter to modify only text frames
+                    if (DrawingFrame.isTextFrameShapeDrawingFrame(drawingNode)) { // selected drawing text frame in a multi drawing selection
+
+                        textFrame = drawingNode;
+
+                        // collecting the attributes for the operation
+                        operationOptions.attrs =  {};
+                        operationOptions.attrs.shape = {};
+
+                        if (!app.isODF()) { operationOptions.attrs.shape.autoResizeText   = autoResizeText || false; }
+                        operationOptions.attrs.shape.autoResizeHeight = autoResizeHeight || false;
+                        operationOptions.attrs.shape.noAutoResize = (!autoResizeText && !autoResizeHeight);
+                        if (app.isODF()) { operationOptions.attrs.shape.wordWrap = true; } // odf requires wordWrap value, later this might be (autoResizeHeight && !autoResizeText)
+
+                        operationOptions.start = drawingItem.startPosition;
+
+                        if (autoResizeText || autoResizeHeight) { // Bug 48714 fix for undo
+                            operationOptions.attrs.drawing = {};
+                            PresentationUtils.extendPlaceholderProp(app, textFrame, operationOptions);
+                        }
+
+                        // generate the 'setAttributes' operation
+                        generator.generateOperation(Operations.SET_ATTRIBUTES, operationOptions);
+
+                        // collecting the affected drawings
+                        textFrameCollector = textFrameCollector || [];
+                        textFrameCollector.push(textFrame);
+
+                    } else if (DrawingFrame.isGroupDrawingFrameWithShape(drawingNode)) { // selected drawing groups in a multi drawing selection
+                        handleShapesInGroup(drawingNode);
+                    }
+                });
+
+            } else if (selection.isAnyDrawingSelection()) {
+
+                textFrame = selection.getAnyTextFrameDrawing({ forceTextFrame: true });
+
+                // collecting the attributes for the operation
+                operationOptions.attrs =  {};
+                operationOptions.attrs.shape = {};
+
+                if (!app.isODF()) { operationOptions.attrs.shape.autoResizeText   = autoResizeText || false; }
+                operationOptions.attrs.shape.autoResizeHeight = autoResizeHeight || false;
+                operationOptions.attrs.shape.noAutoResize = (!autoResizeText && !autoResizeHeight);
+                if (app.isODF()) { operationOptions.attrs.shape.wordWrap = true; } // odf requires wordWrap value, later this might be (autoResizeHeight && !autoResizeText)
+
+                if (selection.isAdditionalTextframeSelection()) {  // a text inside a text frame is selected
+                    operationOptions.start = Position.getOxoPosition(self.getNode(), textFrame, 0);
+                    if (autoResizeText || autoResizeHeight) { // Bug 48714 fix for undo
+                        operationOptions.attrs.drawing = {};
+                        PresentationUtils.extendPlaceholderProp(app, textFrame, operationOptions);
+                    }
+                    generator.generateOperation(Operations.SET_ATTRIBUTES, operationOptions); // generate the 'setAttributes' operation
+                } else {
+                    if (textFrame && textFrame.length > 0) { // the text frame itself is selected
+                        operationOptions.start = selection.getStartPosition();
+                        if (autoResizeText || autoResizeHeight) { // Bug 48714 fix for undo
+                            operationOptions.attrs.drawing = {};
+                            PresentationUtils.extendPlaceholderProp(app, textFrame, operationOptions);
+                        }
+                        generator.generateOperation(Operations.SET_ATTRIBUTES, operationOptions); // generate the 'setAttributes' operation
+                    } else {
+                        selectedDrawing = selection.getSelectedDrawing(); // this might be a group drawing, that is selected
+                        if (DrawingFrame.isGroupDrawingFrameWithShape(selectedDrawing)) {
+                            handleShapesInGroup(selectedDrawing);
+                        }
+                    }
+                }
+
+            }
 
             // apply all collected operations
             self.applyOperations(generator);
 
-            self.updateDynFontSizeDebounced(textFrame);
+            if (textFrameCollector) {
+                _.each(textFrameCollector, function (oneTextFrame) {
+                    self.updateDynFontSizeDebounced(oneTextFrame);
+                });
+            } else {
+                self.updateDynFontSizeDebounced(textFrame);
+            }
         };
 
-        self.updateDynFontSizeDebounced = self.createDebouncedMethod(registerDrawing, updateDynFontSizeInDrawings, { delay: 500, infoString: 'Presentation: DynfontSizeMixin.updateDynFontSizeDebounced', app: self.getApp() });
+        self.updateDynFontSizeDebounced =  app.isODF() ? function () { return $.when(); } : self.createDebouncedMethod('DynfontSizeMixin.updateDynFontSizeDebounced', registerDrawing, updateDynFontSizeInDrawings, { delay: 500 });
 
-        self.getPreFlushDocumentPromise = function () { return updateDynFontSizeInDrawings(); };
+        self.getPreFlushDocumentPromise = app.isODF() ? function () { return $.when(); } : function () { return updateDynFontSizeInDrawings(); };
 
         // initialization -----------------------------------------------------
 
