@@ -53,7 +53,7 @@ define('io.ox/office/presentation/model/pagehandlermixin', [
         function pageProcessMouseDownHandler(event) {
 
             var // whether the user has privileges to edit the document
-                readOnly = self.getEditMode() !== true,
+                readOnly = !app.isEditable(),
                 // the slide node
                 slideRootNode = null,
                 // jQuerified target of the event
@@ -158,6 +158,9 @@ define('io.ox/office/presentation/model/pagehandlermixin', [
             // clear a possible multi selection in the slide pane
             self.trigger('slidepane:clearselection');
 
+            // set the virtual focus to the document
+            app.getView().setVirtualFocusSlidepane(false);
+
             // make sure that the clickable parts in the hyperlink popup are processed by the browser
             if (Hyperlink.isClickableNode($eventTarget, readOnly)) {
                 return;
