@@ -13,7 +13,8 @@
  */
 
 define('io.ox/office/presentation/model/slideattributesmixin', [
-], function () {
+    'io.ox/office/presentation/utils/presentationutils'
+], function (PresentationUtils) {
 
     'use strict';
 
@@ -300,14 +301,14 @@ define('io.ox/office/presentation/model/slideattributesmixin', [
                 // the master slide attributes
                 masterAttrs = slideIdSet.masterId ? self.getSlideAttributesByFamily(slideIdSet.masterId, family) : null,
                 // the default attributes of the family
-                attributes = self.getDefaultAttributes(family);
+                attributes = this.getAttributePool().getDefaultValues(family);
 
             if (attributes && attributes[family]) { attributes = attributes[family]; }
 
             // merging the collected attributes from master and layout slides and drawings (never overwrite attribute set)
             if (masterAttrs) { attributes = _.extend({}, masterAttrs); }
-            if (layoutAttrs) { attributes = attributes ? _.extend(attributes, layoutAttrs) : _.extend({}, layoutAttrs); }
-            if (slideAttrs) { attributes = attributes ? _.extend(attributes, slideAttrs) : _.extend({}, slideAttrs); }
+            if (layoutAttrs) { attributes = _.extend(attributes || {}, layoutAttrs); }
+            if (slideAttrs) { attributes = _.extend(attributes || {}, slideAttrs); }
 
             return attributes;
         };
@@ -341,6 +342,86 @@ define('io.ox/office/presentation/model/slideattributesmixin', [
             emptySlideAttributesModel();
         };
 
+        /**
+         * Convenience function for receiving the 'isDate' property of the slide family of
+         * a slide specified by its ID converted to a boolean (ODP functionality).
+         *
+         * @param {String} id
+         *  The slide ID.
+         *
+         * @returns {Boolean}
+         *  Whether the slide specified by the ID needs a visible 'date' footer object.
+         */
+        this.isDateDrawingSlide = function (id) {
+            return !!self.getSlideFamilyAttributeForSlide(id, 'slide', 'isDate');
+        };
+
+        /**
+         * Convenience function for receiving the 'isFooter' property of the slide family of
+         * a slide specified by its ID converted to a boolean (ODP functionality).
+         *
+         * @param {String} id
+         *  The slide ID.
+         *
+         * @returns {Boolean}
+         *  Whether the slide specified by the ID needs a visible 'ftr' footer object.
+         */
+        this.isFooterDrawingSlide = function (id) {
+            return !!self.getSlideFamilyAttributeForSlide(id, 'slide', 'isFooter');
+        };
+
+        /**
+         * Convenience function for receiving the 'isSlideNum' property of the slide family of
+         * a slide specified by its ID converted to a boolean (ODP functionality).
+         *
+         * @param {String} id
+         *  The slide ID.
+         *
+         * @returns {Boolean}
+         *  Whether the slide specified by the ID needs a visible 'sldNum' footer object.
+         */
+        this.isSlideNumberDrawingSlide = function (id) {
+            return !!self.getSlideFamilyAttributeForSlide(id, 'slide', 'isSlideNum');
+        };
+
+        /**
+         * ODP only.
+         * Convenience function that checks, if a specified drawing is a footer place holder drawing
+         * (type 'dt', 'ftr' or 'sldNum') that is visible on a document slide specified by its ID.
+         *
+         * @param {String} id
+         *  The document slide ID.
+         *
+         * @param {HTMLElement|jQuery} drawing
+         *  The drawing node.
+         *
+         * @returns {Boolean}
+         *  Whether the specified drawing is a footer place holder drawing that is visible on the
+         *  document slide specified by its ID.
+         */
+        this.isVisiblePlaceHolderFooterDrawing = function (id, drawing) {
+
+            return self.isVisiblePlaceHolderFooterDrawingType(PresentationUtils.getPlaceHolderDrawingType(drawing));
+        };
+
+        this.isVisiblePlaceHolderFooterDrawingType = function (id, type) {
+            var
+                isVisible = !!type;
+
+            if (isVisible) {
+                isVisible = (
+                    ((type === 'dt') && self.isDateDrawingSlide(id)) ||
+                    ((type === 'ftr') && self.isFooterDrawingSlide(id)) ||
+                    ((type === 'sldNum') && self.isSlideNumberDrawingSlide(id))
+                );
+            }
+            return isVisible;
+        };
+
+        this.isPlaceHolderFooterDrawingType = function (type) {
+            return (!!type && _.contains(self.getPresentationFooterTypes(), type));
+        };
+
         // initialization -----------------------------------------------------
 
         // destroy all class members on destruction
