@@ -15,11 +15,11 @@
 define('io.ox/office/presentation/model/slideformatmanager', [
     'io.ox/office/tk/utils',
     'io.ox/office/tk/object/triggerobject',
-    'io.ox/office/tk/object/timermixin',
+    'io.ox/office/editframework/utils/attributeutils',
     'io.ox/office/textframework/utils/config',
     'io.ox/office/textframework/utils/dom',
     'io.ox/office/presentation/utils/presentationutils'
-], function (Utils, TriggerObject, TimerMixin, Config, DOM, PresentationUtils) {
+], function (Utils, TriggerObject, AttributeUtils, Config, DOM, PresentationUtils) {
 
     'use strict';
 
@@ -33,7 +33,6 @@ define('io.ox/office/presentation/model/slideformatmanager', [
      * @constructor
      *
      * @extends TriggerObject
-     * @extends TimerMixin
      *
      * @param {PresentationApplication} app
      *  The application instance.
@@ -63,10 +62,9 @@ define('io.ox/office/presentation/model/slideformatmanager', [
             // a collector for slide IDs, that are waiting to inform the listeners, because dependent slides are currently formatted
             waitingIDs = null;
 
-        // base constructors --------------------------------------------------
+        // base constructor ---------------------------------------------------
 
-        TriggerObject.call(this);
-        TimerMixin.call(this);
+        TriggerObject.call(this, app);
 
         // private methods ----------------------------------------------------
 
@@ -145,18 +143,32 @@ define('io.ox/office/presentation/model/slideformatmanager', [
                 // whether the document slides need to be updated because of a customized template text
                 updateCustomizedTemplateTexts = false,
                 // a container for all drawings of type 'group' on the slide
-                groupDrawings = null;
+                groupDrawings = null,
+                // a helper index for body place holder drawings without index (after loading)
+                odfBodyIndex = 0,
+                // a jQuery promise object
+                promise = null;
 
             // updating one drawing on the slide
             function updateOneDrawing(drawing) {
 
                 var // the paragraphs in one drawing
-                    paragraphs = $(drawing).find(DOM.PARAGRAPH_NODE_SELECTOR);
+                    // -> reading the paragraphs after drawingStyles.updateElementFormatting because of implicit paragraphs in ODP
+                    paragraphs = null,
+                    // the attribute object of family 'presentation' of the drawing
+                    presentationAttrs = null;
 
                 if (!model || model.destroyed) { return; } // the model might have been destroyed in the meantime
 
+                if (app.isODF() && PresentationUtils.isBodyPlaceHolderWithoutIndexDrawing(drawing)) { // repairing the missing index
+                    presentationAttrs = AttributeUtils.getExplicitAttributes(drawing, { family: 'presentation', direct: true });
+                    presentationAttrs.phIndex = odfBodyIndex++; // modifying the original presentation attribute
+                }
+
                 drawingStyles.updateElementFormatting(drawing);
 
+                paragraphs = $(drawing).find(DOM.PARAGRAPH_NODE_SELECTOR);
+
                 // also updating all paragraphs inside text frames (not searching twice for the drawings)
                 // -> using option 'suppressFontSize', so that the dynamic font size calculation is NOT
                 //    started during formatting of a complete slide.
@@ -195,45 +207,52 @@ define('io.ox/office/presentation/model/slideformatmanager', [
 
             slide.addClass('leftshift');
 
-            // updating the slide ...
-            model.getSlideStyles().updateElementFormatting(slide);
-
             // appending drawings of type 'group' to the end of the drawing list, so that it is not necessary
             // to update the complete group after each client
             handleGroupNodes();
 
+            // updating the slide ...
+            promise = model.getSlideStyles().updateElementFormatting(slide);
+
             // updating all drawings via iteration
-            return self.iterateArraySliced(allDrawings, updateOneDrawing, { infoString: 'SlideFormatManager: formatOneSlide', app: app })
-                .then(function () {
-                    // updating the lists also synchronously
-                    model.updateLists(null, paragraphContainer);
-                    // updating the customized template texts on document slides
-                    if (updateCustomizedTemplateTexts) { updateAllCustomizedTemplateTextOnSlide(id); }
-                })
-                .always(function () {
+            promise = promise.then(function () {
+                return self.iterateArraySliced(allDrawings, updateOneDrawing, 'SlideFormatManager.formatOneSlide');
+            });
 
-                    // removing marker for handled drawing groups (performance)
-                    _.each(groupDrawings, function (oneDrawing) { $(oneDrawing).removeData('grouphandling'); });
+            promise.done(function () {
+                // updating the lists also synchronously
+                model.updateLists(null, paragraphContainer);
+                // updating the customized template texts on document slides
+                if (updateCustomizedTemplateTexts) { updateAllCustomizedTemplateTextOnSlide(id); }
+            });
 
-                    // shifting back the slide after formatting
-                    slide.css('left', '');
-                    slide.removeClass('leftshift');
+            promise.always(function () {
 
-                    if (visibilityChanged) {
-                        // making the slide invisible again
-                        if (!model || model.destroyed) { return; } // the model might have been destroyed in the meantime
-                        model.handleContainerVisibility(slide, { makeVisible: false });
-                    }
+                // removing marker for handled drawing groups (performance)
+                _.each(groupDrawings, function (oneDrawing) { $(oneDrawing).removeData('grouphandling'); });
 
-                    // let the new formatted slide stay in the DOM for some seconds
-                    model.getSlideVisibilityManager().registerOperationSlideId(id);
+                // shifting back the slide after formatting
+                slide.css('left', '');
+                slide.removeClass('leftshift');
 
-                    // this task is no longer running
-                    if (runningTasks[id]) { delete runningTasks[id]; }
-                })
-                .done(function () {
-                    removeTask(id); // updating the collector of unformatted slides
-                });
+                if (visibilityChanged) {
+                    // making the slide invisible again
+                    if (!model || model.destroyed) { return; } // the model might have been destroyed in the meantime
+                    model.handleContainerVisibility(slide, { makeVisible: false });
+                }
+
+                // let the new formatted slide stay in the DOM for some seconds
+                model.getSlideVisibilityManager().registerOperationSlideId(id);
+
+                // this task is no longer running
+                if (runningTasks[id]) { delete runningTasks[id]; }
+            });
+
+            promise.done(function () {
+                removeTask(id); // updating the collector of unformatted slides
+            });
+
+            return promise;
         }
 
         /**
@@ -266,7 +285,9 @@ define('io.ox/office/presentation/model/slideformatmanager', [
             });
 
             // -> iterating asynchronously over the collected slide IDs (formatting slide(s) asynchronously)
-            return self.iterateArraySliced(newSlideIDs, function (id) { return formatOneSlide(model.getSlideById(id), id); }, { delay: 'immediate', infoString: 'SlideFormatManager: formatSlides', app: app });
+            return self.iterateArraySliced(newSlideIDs, function (id) {
+                return formatOneSlide(model.getSlideById(id), id);
+            }, 'SlideFormatManager.formatSlides');
         }
 
         /**
@@ -275,7 +296,7 @@ define('io.ox/office/presentation/model/slideformatmanager', [
          * @returns {undefined}
          */
         function registerIdleTimeChecker() {
-            idleTimeChecker = self.createDebouncedMethod($.noop, idleSlideFormatHandler, { delay: idleTime, infoString: 'Presentation: idleSlideFormatHandler', app: app });
+            idleTimeChecker = self.createDebouncedMethod('SlideFormatManager.idleTimeChecker', null, idleSlideFormatHandler, { delay: idleTime });
             model.getNode().on('keydown mousedown touchstart', idleTimeChecker);
         }
 
@@ -285,7 +306,7 @@ define('io.ox/office/presentation/model/slideformatmanager', [
          */
         function deregisterIdleTimeChecker() {
             model.getNode().off('keydown mousedown touchstart', idleTimeChecker);
-            idleTimeChecker = $.noop;
+            idleTimeChecker = _.noop;
         }
 
         /**
@@ -613,7 +634,7 @@ define('io.ox/office/presentation/model/slideformatmanager', [
         function informListeners(allSlideIDs) {
             self.executeDelayed(function () {
                 if (model && !model.destroyed) { model.trigger('slidestate:formatted', allSlideIDs); }
-            }, { delay: 50, infoString: 'Presentation: Trigger slidestate:formatted', app: app });
+            }, 'SlideFormatManager.informListeners', 50);
         }
 
         // methods ------------------------------------------------------------
@@ -756,10 +777,13 @@ define('io.ox/office/presentation/model/slideformatmanager', [
             if (shiftedSlides) { return; } // only one set of shifted slides is supported
 
             _.each(idSet, function (id) {
-                model.getSlideById(id).addClass('leftshift'); // using negative left offset, so that the scroll bar is not influenced
+                var oneSlide = model.getSlideById(id);
+                if (oneSlide) {
+                    oneSlide.addClass('leftshift');  // using negative left offset, so that the scroll bar is not influenced
+                    shiftedSlides = shiftedSlides || [];
+                    shiftedSlides.push(id); // avoing 'null' values in shiftSlides container
+                }
             });
-
-            shiftedSlides = idSet;
         };
 
         /**
@@ -769,8 +793,10 @@ define('io.ox/office/presentation/model/slideformatmanager', [
         this.shiftSlideSetIntoView = function () {
 
             _.each(shiftedSlides, function (id) {
+                var oneSlide = null;
                 if (!self.isRunningTask(id)) { // not shifting into view, if the slide is currently formatted
-                    model.getSlideById(id).removeClass('leftshift'); // using negative left offset, so that the scroll bar is not influenced
+                    oneSlide = model.getSlideById(id);
+                    if (oneSlide) { oneSlide.removeClass('leftshift'); } // using negative left offset, so that the scroll bar is not influenced
                 }
             });
 
