@@ -14,24 +14,25 @@
 
 define('io.ox/office/presentation/utils/operations', [
     'io.ox/office/textframework/utils/operations'
-], function (TextOperations) {
+], function (BaseTextOperations) {
 
     'use strict';
 
-    // static class PresentationOperations ============================================
+    // static class PresentationOperations ====================================
 
     /**
-     * Provides constants for the names of all document operations used in presentation
-     * documents.
+     * Provides constants for the names of all document operations used in
+     * presentation documents.
      *
-     * @extends TextEditOperations
+     * @extends BaseTextOperations
      */
-    var PresentationOperations = _.extend(TextOperations, {
+    var PresentationOperations = BaseTextOperations.extend({
 
         SLIDE_INSERT: 'insertSlide',
         MASTER_SLIDE_INSERT: 'insertMasterSlide',
         LAYOUT_SLIDE_INSERT: 'insertLayoutSlide',
         LAYOUT_SLIDE_MOVE: 'moveLayoutSlide',
+        MASTER_CHANGE: 'changeMaster', // only supported in ODF
         LAYOUT_CHANGE: 'changeLayout',
         SLIDE_MOVE: 'moveSlide'
     });
