@@ -65,6 +65,21 @@ define('io.ox/office/presentation/utils/presentationutils', [
         ctrTitle: 1
     };
 
+    PresentationUtils.TITLE_OR_SUBTITLE_PLACEHOLDER_TYPES = {
+        title: 1,
+        ctrTitle: 1,
+        subTitle: 1
+    };
+
+    /**
+     * The place holder types, whose content cannot be modified or that cannot be
+     * deleted on master slides in ODF.
+     */
+    PresentationUtils.ODF_MASTER_READONLY_TYPES = {
+        title: 1,
+        body: 1
+    };
+
     /**
      * The place holder drawing types, in that no text content can be inserted.
      */
@@ -103,11 +118,30 @@ define('io.ox/office/presentation/utils/presentationutils', [
         ctrTitle: gt('Click to add title'),
         subTitle: gt('Click to add subtitle'),
         media: gt('Media clip'),
-        clipArt: gt('Online picture'),
+        clipArt: gt('Online image'),
         chart: gt('Chart'),
         dgm: gt('Smart Art'),
         tbl: gt('Click to add table'),
-        pic: gt('Click to add picture'),
+        pic: gt('Click to add image'),
+        sldNum: gt('Slide Number'),
+        ftr: gt('Footer'),
+        dt: gt('Date')
+    };
+
+    /**
+     * The default texts that are inserted, if the place holder drawing is empty (ODF format).
+     */
+    PresentationUtils.PLACEHOLDER_TEMPLATE_TEXTS_ODF = {
+        body: gt('Click to add text'),
+        title: gt('Click to add title'),
+        ctrTitle: gt('Click to add title'),
+        subTitle: gt('Click to add text'),
+        media: gt('Media clip'),
+        clipArt: gt('Online image'),
+        chart: gt('Chart'),
+        dgm: gt('Smart Art'),
+        tbl: gt('Click to add table'),
+        pic: gt('Click to add image'),
         sldNum: gt('Slide Number'),
         ftr: gt('Footer'),
         dt: gt('Date')
@@ -118,7 +152,7 @@ define('io.ox/office/presentation/utils/presentationutils', [
      * Info: These strings need to be used by the filter.
      */
     PresentationUtils.PLACEHOLDER_TEMPLATE_TEXTS_CLICK = {
-        pic: gt('Click icon to add picture'),
+        pic: gt('Click icon to add image'),
         tbl: gt('Click icon to add table'),
         chart: gt('Click icon to add chart'),
         dgm: gt('Click icon to add smart art graphic'),
@@ -146,6 +180,54 @@ define('io.ox/office/presentation/utils/presentationutils', [
         dt: null
     };
 
+    /**
+     * The supported buttons inside a place holder drawing in ODF format.
+     */
+    PresentationUtils.PLACEHOLDER_TEMPLATE_BUTTONS_ODF = {
+        contentBody: ['picture', 'table'],
+        body: ['picture', 'table'],
+        title: null,
+        ctrTitle: null,
+        subTitle: null,
+        media: ['media'],
+        clipArt: ['clipart'],
+        chart: ['chart'],
+        dgm: ['smartart'],
+        tbl: ['table'],
+        pic: ['picture'],
+        sldNum: null,
+        ftr: null,
+        dt: null
+    };
+
+    /**
+     * Supported names for inserting custom drawing placeholders.
+     */
+    PresentationUtils.PLACEHOLDER_DRAWING_NAMES = {
+        content:    gt('Content placeholder'),
+        contentv:   gt('Vertical content placeholder'),
+        text:       gt('Text placeholder'),
+        textv:      gt('Vertical text placeholder'),
+        picture:    gt('Image placeholder'),
+        table:      gt('Table placeholder')
+    };
+
+    /**
+     * The template text inserted into supported placeholder drawings.
+     */
+    PresentationUtils.PLACEHOLDER_TEXT_CONTENT = [
+        gt('Edit Master text styles'),
+        gt('Second level'),
+        gt('Third level'),
+        gt('Fourth level'),
+        gt('Fifth level')
+    ];
+
+    /**
+     * The template text inserted into title placeholder drawing.
+     */
+    PresentationUtils.PLACEHOLDER_TITLE_CONTENT = gt('Click to edit Master title style');
+
     /**
      * The default index for place holders in presentation attributes.
      *
@@ -167,7 +249,7 @@ define('io.ox/office/presentation/utils/presentationutils', [
      *  Whether the specified attribute set contains presentation place holder attributes.
      */
     PresentationUtils.isPlaceHolderAttributeSet = function (attrs) {
-        return attrs && attrs.presentation && (attrs.presentation.phType || _.isNumber(attrs.presentation.phIndex));
+        return !!(attrs && attrs.presentation && (attrs.presentation.phType || _.isNumber(attrs.presentation.phIndex)));
     };
 
     /**
@@ -182,7 +264,22 @@ define('io.ox/office/presentation/utils/presentationutils', [
      *  Whether the specified attribute set contains presentation place holder attributes of 'title' drawing.
      */
     PresentationUtils.isTitlePlaceHolderAttributeSet = function (attrs) {
-        return attrs && attrs.presentation && attrs.presentation.phType && PresentationUtils.TITLE_PLACEHOLDER_TYPES[attrs.presentation.phType];
+        return !!(attrs && attrs.presentation && attrs.presentation.phType && PresentationUtils.TITLE_PLACEHOLDER_TYPES[attrs.presentation.phType]);
+    };
+
+    /**
+     * Check, whether the specified attribute set (explicit attributes from a drawing) contain the presentation
+     * place holder attributes of a title or subtitle place holder drawing. This means, that the phType is set to
+     * 'title', 'ctrTitle' or 'subTitle'.
+     *
+     * @param {Object} attrs
+     *  The attribute object. This should be the explicit attributes from a drawing.
+     *
+     * @returns {Boolean}
+     *  Whether the specified attribute set contains presentation place holder attributes of 'title' or 'subtitle' drawing.
+     */
+    PresentationUtils.isTitleOrSubtitlePlaceHolderAttributeSet = function (attrs) {
+        return !!(attrs && attrs.presentation && attrs.presentation.phType && PresentationUtils.TITLE_OR_SUBTITLE_PLACEHOLDER_TYPES[attrs.presentation.phType]);
     };
 
     /**
@@ -197,39 +294,51 @@ define('io.ox/office/presentation/utils/presentationutils', [
      *  Whether the specified attribute set contains presentation place holder attributes of 'body' drawing.
      */
     PresentationUtils.isBodyPlaceHolderAttributeSet = function (attrs) {
-        return attrs && attrs.presentation && _.isNumber(attrs.presentation.phIndex) && (attrs.presentation.phType === PresentationUtils.DEFAULT_PLACEHOLDER_TYPE || !attrs.presentation.phType);
+        return !!(attrs && attrs.presentation && _.isNumber(attrs.presentation.phIndex) && (attrs.presentation.phType === PresentationUtils.DEFAULT_PLACEHOLDER_TYPE || !attrs.presentation.phType));
     };
 
     /**
      * Check, whether the specified attribute set (explicit attributes from a drawing) contain the presentation
      * place holder attributes of a body place holder drawing for inserting text only. This means, that the
      * phType is set explicitely to 'body'.
+     * Info: In ODF file format this is quite different, because there is no place holder of type body, that
+     *       accepts only text input.
      *
      * @param {Object} attrs
      *  The attribute object. This should be the explicit attributes from a drawing.
      *
+     * @param {Boolean} [isODF=false]
+     *  Whether this is an ODF application. If not specified, the value is set to 'false'.
+     *
      * @returns {Boolean}
      *  Whether the specified attribute set contains presentation place holder attributes of 'body' drawing
      *  that allows only text insertion.
      */
-    PresentationUtils.isTextBodyPlaceHolderAttributeSet = function (attrs) {
-        return attrs && attrs.presentation && _.isNumber(attrs.presentation.phIndex) && (attrs.presentation.phType === PresentationUtils.DEFAULT_PLACEHOLDER_TYPE);
+    PresentationUtils.isTextBodyPlaceHolderAttributeSet = function (attrs, isODF) {
+        var odf = isODF || false;
+        return !!(!odf && attrs && attrs.presentation && _.isNumber(attrs.presentation.phIndex) && (attrs.presentation.phType === PresentationUtils.DEFAULT_PLACEHOLDER_TYPE));
     };
 
     /**
      * Check, whether the specified attribute set (explicit attributes from a drawing) contain the presentation
      * place holder attributes of a body place holder drawing that allows any content (text, table, picture, ...).
-     * This means, that the phType is explicitely undefined.
+     * This means, that the phType is explicitely undefined and the phIndex is explicitely defined.
+     * Info: In ODF file format this is quite different. The phType is set to 'body' and it is not necessary,
+     *       that a phIndex is specified.
      *
      * @param {Object} attrs
      *  The attribute object. This should be the explicit attributes from a drawing.
      *
+     * @param {Boolean} [isODF=false]
+     *  Whether this is an ODF application. If not specified, the value is set to 'false'.
+     *
      * @returns {Boolean}
      *  Whether the specified attribute set contains presentation place holder attributes of 'body' drawing
      *  that allows input of any content (text, table, picture, ...).
      */
-    PresentationUtils.isContentBodyPlaceHolderAttributeSet = function (attrs) {
-        return attrs && attrs.presentation && _.isNumber(attrs.presentation.phIndex) && !attrs.presentation.phType;
+    PresentationUtils.isContentBodyPlaceHolderAttributeSet = function (attrs, isODF) {
+        var odf = isODF || false;
+        return !!(attrs && attrs.presentation && (_.isNumber(attrs.presentation.phIndex) || odf) && (!attrs.presentation.phType || (odf && attrs.presentation.phType === PresentationUtils.DEFAULT_PLACEHOLDER_TYPE)));
     };
 
     /**
@@ -244,7 +353,7 @@ define('io.ox/office/presentation/utils/presentationutils', [
      *  that no text can be inserted.
      */
     PresentationUtils.isPlaceHolderWithoutTextAttributeSet = function (attrs) {
-        return attrs && attrs.presentation && attrs.presentation.phType && PresentationUtils.NO_TEXT_PLACEHOLDER_TYPE[attrs.presentation.phType];
+        return !!(attrs && attrs.presentation && attrs.presentation.phType && PresentationUtils.NO_TEXT_PLACEHOLDER_TYPE[attrs.presentation.phType]);
     };
 
     /**
@@ -258,7 +367,55 @@ define('io.ox/office/presentation/utils/presentationutils', [
      *  user defined template text.
      */
     PresentationUtils.isCustomPromptPlaceHolderAttributeSet = function (attrs) {
-        return attrs && attrs.presentation && attrs.presentation.customPrompt;
+        return !!(attrs && attrs.presentation && attrs.presentation.customPrompt);
+    };
+
+    /**
+     * Check, whether the specified attribute set (explicit attributes from a drawing) contain the presentation
+     * place holder attributes of a place holder drawing in that in ODF in the master view the content cannot be
+     * modified.
+     *
+     * @param {Object} attrs
+     *  The attribute object. This should be the explicit attributes from a drawing.
+     *
+     * @returns {Boolean}
+     *  Whether the specified attribute set contains presentation place holder attributes of a drawing that cannot
+     *  be deleted or whose content cannot be modified in ODF masterview.
+     */
+    PresentationUtils.isODFReadOnlyPlaceHolderAttributeSet = function (attrs) {
+        return !!(attrs && attrs.presentation && attrs.presentation.phType && PresentationUtils.ODF_MASTER_READONLY_TYPES[attrs.presentation.phType]);
+    };
+
+    /**
+     * Check, whether the specified attribute set (explicit attributes from a drawing) contain the presentation
+     * place holder attributes of a body place holder drawing without specified index. This means, that the phType
+     * is set to 'body' and the phIndex is not specified (used for ODF).
+     *
+     * @param {Object} attrs
+     *  The attribute object. This should be the explicit attributes from a drawing.
+     *
+     * @returns {Boolean}
+     *  Whether the specified attribute set contains presentation place holder attributes of 'body' drawing without
+     *  specified index.
+     */
+    PresentationUtils.isBodyPlaceHolderAttributeSetWithoutIndex = function (attrs) {
+        return !!(attrs && attrs.presentation && !_.isNumber(attrs.presentation.phIndex) && (attrs.presentation.phType === PresentationUtils.DEFAULT_PLACEHOLDER_TYPE));
+    };
+
+    /**
+     * Checking, whether the specified attribute set (explicit attributes from a drawing) specifies
+     * a place holder drawing whose size and/or position was modified by the user.
+     * This check is important for inheritance from master slide in ODP documents.
+     *
+     * @param {Object} attrs
+     *  The attribute object. This should be the explicit attributes from a drawing.
+     *
+     * @returns {Boolean}
+     *  Whether the specified attribute set specifies a place holder drawing whose size
+     *  and/or position was modified by the user..
+     */
+    PresentationUtils.isUserModifiedPlaceHolderAttributeSet = function (attrs) {
+        return !!((attrs && attrs.presentation && attrs.presentation.userTransformed) || false);
     };
 
     /**
@@ -332,6 +489,20 @@ define('io.ox/office/presentation/utils/presentationutils', [
         return PresentationUtils.isTitlePlaceHolderAttributeSet(AttributeUtils.getExplicitAttributes(drawing));
     };
 
+    /**
+     * Check, whether the specified drawing is a title or a subtitle drawing that contains place holder attributes.
+     * This means, that the phType is set to 'title', 'ctrTitle' or 'subTitle'.
+     *
+     * @param {HTMLElement|jQuery} drawing
+     *  The drawing node.
+     *
+     * @returns {Boolean}
+     *  Whether the specified drawing contains presentation place holder attributes of type 'title' or 'subTitle'.
+     */
+    PresentationUtils.isTitleOrSubtitlePlaceHolderDrawing = function (drawing) {
+        return PresentationUtils.isTitleOrSubtitlePlaceHolderAttributeSet(AttributeUtils.getExplicitAttributes(drawing));
+    };
+
     /**
      * Check, whether the specified drawing is a body drawing that contains place holder attributes. This means, that
      * the phType is set to 'body or is not specified and the the phIndex is specified.
@@ -449,6 +620,73 @@ define('io.ox/office/presentation/utils/presentationutils', [
         return PresentationUtils.isCustomPromptPlaceHolderAttributeSet(AttributeUtils.getExplicitAttributes(drawing));
     };
 
+    /**
+     * Check, whether the specified drawing is a place holder drawing that cannot be deleted or whose content
+     * cannot be modified in master view in ODF files.
+     *
+     * @param {HTMLElement|jQuery} drawing
+     *  The drawing node.
+     *
+     * @returns {Boolean}
+     *  Whether the specified drawing is a place holder drawing that cannot be deleted or whose content
+     *  cannot be modified in master view in ODF files.
+     */
+    PresentationUtils.isODFReadOnlyPlaceHolderDrawing = function (drawing) {
+        return PresentationUtils.isODFReadOnlyPlaceHolderAttributeSet(AttributeUtils.getExplicitAttributes(drawing));
+    };
+
+    /**
+     * Check, whether the specified drawing is a place holder drawing with explicitely set phType to 'body' and
+     * undefined 'phIndex' (used for ODF).
+     *
+     * @param {HTMLElement|jQuery} drawing
+     *  The drawing node.
+     *
+     * @returns {Boolean}
+     *  Whether the specified drawing is a place holder drawing with explicitely set phType to 'body' and
+     *  undefined 'phIndex'.
+     */
+    PresentationUtils.isBodyPlaceHolderWithoutIndexDrawing = function (drawing) {
+        return PresentationUtils.isBodyPlaceHolderAttributeSetWithoutIndex(AttributeUtils.getExplicitAttributes(drawing));
+    };
+
+    /**
+     * Checking, whether the specified drawing is a place holder drawing whose size
+     * and/or position was modified by the user.
+     * This check is important for inheritance from master slide in ODP documents.
+     *
+     * @param {HTMLElement|jQuery} drawing
+     *  The drawing node.
+     *
+     * @returns {Boolean}
+     *  Whether the specified drawing is a place holder drawing whose size
+     *  and/or position was modified by the user.
+     */
+    PresentationUtils.isUserModifiedPlaceHolderDrawing = function (drawing) {
+        return PresentationUtils.isUserModifiedPlaceHolderAttributeSet(AttributeUtils.getExplicitAttributes(drawing));
+    };
+
+    /**
+     * Checking, whether the specified drawing requires the property 'userTransformed'.
+     * This is the case of place holder drawings in ODF, that are moved or resized
+     * by the user.
+     * This check is important for inheritance from master slide in ODP documents.
+     * This check can be used after a drawing was moved or resized by the user, so
+     * that a valid operation can be generated.
+     *
+     * @param {HTMLElement|jQuery} drawing
+     *  The drawing node.
+     *
+     * @returns {Boolean}
+     *  Whether the specified drawing requires the property 'userTransformed'. This is
+     *  the case, if it is a place holder drawing whose size and/or position was modified
+     *  by the user.
+     */
+    PresentationUtils.requiresUserTransformedProperty = function (drawing) {
+        var attrs = AttributeUtils.getExplicitAttributes(drawing);
+        return PresentationUtils.isPlaceHolderAttributeSet(attrs) && !PresentationUtils.isUserModifiedPlaceHolderAttributeSet(attrs);
+    };
+
     /**
      * Getting an object containing the keys 'target', 'type' and 'index' for a specified drawing. This
      * object can be used to get attributes and list styles from the model for the drawing
@@ -487,8 +725,8 @@ define('io.ox/office/presentation/utils/presentationutils', [
             drawingObj.index = drawingAttrs.presentation.phIndex;
 
             if (useDefaultValues) {
-                if (drawingObj.type && !_.isNumber(drawingObj.index)) { drawingObj.index = PresentationUtils.getDefaultPlaceHolderIndex(); }
-                if (_.isNumber(drawingObj.index) && !drawingObj.type) { drawingObj.type = PresentationUtils.getDefaultPlaceHolderType(); }
+                if (drawingObj.type && !_.isNumber(drawingObj.index)) { drawingObj.index = PresentationUtils.DEFAULT_PLACEHOLDER_INDEX; }
+                if (_.isNumber(drawingObj.index) && !drawingObj.type) { drawingObj.type = PresentationUtils.DEFAULT_PLACEHOLDER_TYPE; }
             }
         }
 
@@ -496,23 +734,30 @@ define('io.ox/office/presentation/utils/presentationutils', [
     };
 
     /**
-     * Getting the default place holder type.
+     * Receiving a valid set for the properties 'type' and 'index', so that the model can be accessed.
+     * Typically the specified attributes parameter is the set of explicit drawing attributes.
      *
-     * @returns {String}
-     *  The default place holder type.
+     * @param {Object} attrs
+     *  The attributes object. This are typically the explicit attributes set at a drawing.
+     *
+     * @returns {Object|Null}
+     *  An object containing the properties 'type' and 'index'. 'type' is a string, that describes
+     *  the place holder type, 'index' is a number describing the index specified for the given
+     *  place holder type.
+     *  If the specified attribute does not contain a 'presentation' property or inside this
+     *  'presentation' property neither 'phType' nor 'phIndex' are defined, null is returned.
      */
-    PresentationUtils.getDefaultPlaceHolderType = function () {
-        return PresentationUtils.DEFAULT_PLACEHOLDER_TYPE;
-    };
+    PresentationUtils.getValidTypeIndexSet = function (attrs) {
 
-    /**
-     * Getting the default place holder index.
-     *
-     * @returns {Number}
-     *  The default place holder index.
-     */
-    PresentationUtils.getDefaultPlaceHolderIndex = function () {
-        return PresentationUtils.DEFAULT_PLACEHOLDER_INDEX;
+        // it is necessary that at least one of phType or phIndex is defined in the attributes
+        if (!attrs || !attrs.presentation || !('phType' in attrs.presentation || 'phIndex' in attrs.presentation)) {
+            return null;
+        }
+
+        return {
+            type: Utils.getStringOption(attrs.presentation, 'phType', PresentationUtils.DEFAULT_PLACEHOLDER_TYPE),
+            index: Utils.getIntegerOption(attrs.presentation, 'phIndex', PresentationUtils.DEFAULT_PLACEHOLDER_INDEX)
+        };
     };
 
     /**
@@ -521,19 +766,24 @@ define('io.ox/office/presentation/utils/presentationutils', [
      * @param {HTMLElement|jQuery} drawing
      *  The drawing node.
      *
+     * @param {Boolean} [isODF=false]
+     *  Whether this is an ODF application. If not specified, the value is set to 'false'.
+     *
      * @returns {String|Null}
      *  The default text for a place holder drawing. Or null, if it cannot be determined.
      */
-    PresentationUtils.getPlaceHolderTemplateText = function (drawing) {
+    PresentationUtils.getPlaceHolderTemplateText = function (drawing, isODF) {
 
         var // the place holder type
-            type = PresentationUtils.getPlaceHolderDrawingType(drawing);
+            type = PresentationUtils.getPlaceHolderDrawingType(drawing),
+            // whether this is an ODF application.
+            odf = isODF || false;
 
         if (!type && _.isNumber(PresentationUtils.getPlaceHolderDrawingIndex(drawing))) {
-            type = PresentationUtils.getDefaultPlaceHolderType();
+            type = PresentationUtils.DEFAULT_PLACEHOLDER_TYPE;
         }
 
-        return type ? PresentationUtils.PLACEHOLDER_TEMPLATE_TEXTS[type] : null;
+        return type ? (odf ? PresentationUtils.PLACEHOLDER_TEMPLATE_TEXTS_ODF[type] : PresentationUtils.PLACEHOLDER_TEMPLATE_TEXTS[type]) : null;
     };
 
     /**
@@ -543,11 +793,30 @@ define('io.ox/office/presentation/utils/presentationutils', [
      * @param {type} String
      *  The string describing the place holder type. The content body type must use the empty string.
      *
+     * @param {Boolean} [isODF=false]
+     *  Whether this is an ODF application. If not specified, the value is set to 'false'.
+     *
      * @returns {Array|Null}
      *  An array containing strings for the required buttons for the specified place holder type.
      */
-    PresentationUtils.getPlaceHolderTemplateButtonsList = function (type) {
-        return PresentationUtils.PLACEHOLDER_TEMPLATE_BUTTONS[(type || 'contentBody')]; // using special name for content body place holders
+    PresentationUtils.getPlaceHolderTemplateButtonsList = function (type, isODF) {
+        var buttonMap = isODF ? PresentationUtils.PLACEHOLDER_TEMPLATE_BUTTONS_ODF : PresentationUtils.PLACEHOLDER_TEMPLATE_BUTTONS;
+        return buttonMap[type || 'contentBody']; // using special name for content body place holders
+    };
+
+    /**
+     * Getting the default representation string for fields in footer place holder types in ODF.
+     *
+     * @param {type} String
+     *  The string describing the place holder type.
+     *
+     * @returns {String}
+     *  The default representation string for fields in footer place holder types in ODF. Or an
+     *  empty string, if it cannot be determined.
+     */
+    PresentationUtils.getODFFooterRepresentation = function (type) {
+        var representationContent = PresentationUtils.PLACEHOLDER_TEMPLATE_TEXTS_ODF[type];
+        return representationContent ? ('<' + representationContent + '>') : '';
     };
 
     /**
@@ -565,14 +834,22 @@ define('io.ox/office/presentation/utils/presentationutils', [
      *  The rectangle with the properties 'top', 'left', 'width' and 'height'.
      *  The values are given in pixel relative to the app-content-root node.
      *
+     * @param {Boolean} [notScaleBoxSize=false]
+     *  Optional flag to prevent the scaling from the box size. The default is false,
+     *  so when it's not provided the box is not scaled. This is useful when a box is
+     *  not based on the px size from the selection box (created with the mouse), but
+     *  with fixed values. These fixed values are not depended on the scaling and
+     *  therefore must not be scaled.
+     *
+     *
      * @returns {Object}
      *  The rectangle with the properties 'top', 'left', 'width' and 'height'.
      *  The values are given in 1/100 mm relative to the slide.
      */
-    PresentationUtils.convertAppContentBoxToOperationBox = function (app, box) {
+    PresentationUtils.convertAppContentBoxToOperationBox = function (app, box, notScaleBoxSize) {
 
         var // the current zoom factor
-            zoomFactor = app.getView().getZoomFactor() / 100,
+            zoomFactor = app.getView().getZoomFactor(),
             // the active slide node
             activeSlide = app.getModel().getSlideById(app.getModel().getActiveSlideId()),
             // the offset of the active slide inside the content root node
@@ -586,16 +863,18 @@ define('io.ox/office/presentation/utils/presentationutils', [
             // the vertical scroll shift
             scrollTop = contentRootNode.scrollTop(),
             // the new box object
-            operationBox = {};
+            operationBox = {},
+            // flag if the width/height from the box should be scaled by the zoomFactor or not
+            notScaleBoxSizeFlag = _.isBoolean(notScaleBoxSize) ? notScaleBoxSize : false;
 
         // the left position of the user defined box relative to the slide (can be negative)
         operationBox.left = Utils.round((box.left - (slideOffset.left - pos.left) - scrollLeft) / zoomFactor, 1);
         // the top position of the user defined box relative to the slide (can be negative)
         operationBox.top = Utils.round((box.top - (slideOffset.top - pos.top) - scrollTop) / zoomFactor, 1);
         // the width of the box
-        operationBox.width = Utils.round(box.width / zoomFactor, 1);
+        operationBox.width = notScaleBoxSizeFlag ? box.width : Utils.round(box.width / zoomFactor, 1);
         // the height of the box
-        operationBox.height = Utils.round(box.height / zoomFactor, 1);
+        operationBox.height = notScaleBoxSizeFlag ? box.height : Utils.round(box.height / zoomFactor, 1);
 
         // converting to 1/100 mm
         operationBox.left = Utils.convertLengthToHmm(operationBox.left, 'px');
@@ -603,6 +882,9 @@ define('io.ox/office/presentation/utils/presentationutils', [
         operationBox.width = Utils.convertLengthToHmm(operationBox.width, 'px');
         operationBox.height = Utils.convertLengthToHmm(operationBox.height, 'px');
 
+        //workaround for Bug 52977, TODO: opBox is broken when zoomed out!!!
+        if (operationBox.left < 0) { operationBox.left = 0; }
+
         return operationBox;
     };
 
