@@ -14,14 +14,17 @@
 
 define.async('io.ox/office/presentation/view/control/layoutslidepicker', [
 
+    'io.ox/office/tk/render/canvas',
+
     'io.ox/office/tk/utils',
+    'io.ox/office/tk/forms',
 
     'io.ox/office/tk/locale/localedata',
     'io.ox/office/tk/control/radiolist',
 
     'io.ox/office/presentation/view/layouttypetitlemap'
 
-], function (Utils, LocaleData, RadioList, LayoutTypeTitleMap) {
+], function (Canvas, Utils, Forms, LocaleData, RadioList, LayoutTypeTitleMap) {
 
     'use strict';
 
@@ -44,6 +47,9 @@ define.async('io.ox/office/presentation/view/control/layoutslidepicker', [
         $thumbContainerBlueprint  = $('<div class="thumb-container" />'),
       //$thumbContainerBlueprint  = $('<div class="thumb-container io-ox-busy" />'),
 
+        // a container for the ODF layout slides
+        odfLayoutContainer = {},
+
         i18nLayoutTypeTitleDB     = {},
 
         // request the proper language data targeting layout type titles
@@ -74,18 +80,42 @@ define.async('io.ox/office/presentation/view/control/layoutslidepicker', [
         };
     }
 
-    function recalculatePickerOffset(picker, pickerNodeParent/*, contentSize, availableSize*/) {
+    function recalculatePickerOffsets(picker, pickerNodeParent, contentSize, availableSize, anchorPositionValues) {
         var
           //elmTrigger    = picker.getNode()[0],
             elmPicker     = picker.getMenuNode()[0],
 
           //triggerCoords = elmTriggerMenu.getBoundingClientRect(),
-            parentCoords  = pickerNodeParent.getBoundingClientRect();
+            parentCoords  = pickerNodeParent.getBoundingClientRect(),
 
-        elmPicker.style.marginTop   = ((math_round(parentCoords.top)/* + 5*/) + 'px');
-        elmPicker.style.marginLeft  = ((math_round(parentCoords.left)/* + 5*/) + 'px');
+            layoutConfig  = {},
+            verticalGap   = 5,
 
-      //return contentSize;
+            offsetTop     = math_round(parentCoords.top),
+            offsetLeft    = math_round(parentCoords.left);
+
+        if (anchorPositionValues.right < contentSize.width) {
+
+            // layoutConfig.preferredBorder = 'right';              // - all approaches
+            // layoutConfig.preferredAlignment = 'trailing';        //   that want to
+                                                                    //   take advantage
+            if (anchorPositionValues.bottom < contentSize.height) { //   of the already
+                                                                    //   build in calculation
+              //layoutConfig.preferredBorder = 'bottom';            //   unfortunately do fail.
+
+                elmPicker.style.marginTop = ((offsetTop + (availableSize.height - contentSize.height) + anchorPositionValues.bottom + anchorPositionValues.height/* + 40*/) + 'px'); // 40 in this case is the computed css height value of <div class="view-pane">
+            } else {
+                elmPicker.style.marginTop = ((offsetTop - anchorPositionValues.height) + 'px');
+            }
+            elmPicker.style.marginLeft  = ((offsetLeft - anchorPositionValues.right - anchorPositionValues.width + verticalGap) + 'px');
+        } else {
+            elmPicker.style.marginTop = (offsetTop + 'px');
+            elmPicker.style.marginLeft  = (offsetLeft + 'px');
+
+            // elmPicker.style.marginTop   = ((offsetTop + verticalGap) + 'px');
+            // elmPicker.style.marginLeft  = ((offsetLeft + verticalGap) + 'px');
+        }
+        return layoutConfig;
     }
 
     /**
@@ -105,13 +135,22 @@ define.async('io.ox/office/presentation/view/control/layoutslidepicker', [
             thumbBoxRegistry,
 
             promisedThumbList,
-            promisedThumbCount;
+            promisedThumbCount,
+
+            // whether the simplified handling for ODF layout slides is required
+            isOdfLayout = Utils.getBooleanOption(initOptions, 'isOdfLayout', false),
+
+            // whether this is an ODF application
+            isODFApp = docView.getApp().isODF(),
+
+            // the canvas object for the ODF layout slides
+            canvas = null;
 
           //isMenuContentExists;
 
         // base constructor ---------------------------------------------------
 
-        RadioList.call(this, Utils.extendOptions({
+        RadioList.call(this, docView, Utils.extendOptions({
 
             // hints
             tooltip: '+++ missing wording for this tooltip +++',
@@ -124,15 +163,13 @@ define.async('io.ox/office/presentation/view/control/layoutslidepicker', [
             toggle: true,
 
             itemDesign: 'grid',
-            gridColumns: 5,
+            gridColumns: (Utils.SMALL_DEVICE) ? 1 : 5,
 
             smallerVersion: {
                 hideLabel: true
             },
-            updateLayoutHandler: function (/*contentSize, availableSize*/) {
-
-                recalculatePickerOffset(self, pickerNodeParent);
-              //return recalculatePickerOffset(self, pickerNodeParent/*, contentSize, availableSize*/);
+            updateLayoutHandler: function (contentSize, availableSize, anchorPositionValues) {
+                return recalculatePickerOffsets(self, pickerNodeParent, contentSize, availableSize, anchorPositionValues);
             },
             rootContainerNode: pickerNodeParent
 
@@ -149,12 +186,11 @@ define.async('io.ox/office/presentation/view/control/layoutslidepicker', [
 
         function getMasterTypeTitle(/*key*/) {
             var
-              //defaultTitle = LayoutTypeTitleMap['master'];  // - linter warning.
-              //defaultTitle = LayoutTypeTitleMap[key];       // - does work, but too complicated.
-                defaultTitle = LayoutTypeTitleMap.master;     // - go with what the linter did suggest.
+                defaultTitle = LayoutTypeTitleMap.master;
 
             return (i18nLayoutTypeTitleDB[defaultTitle] || defaultTitle);
         }
+
         function getLayoutTypeTitle(slideId) {
           //return LayoutTypeTitleMap[docModel.getSlideFamilyAttributeForSlide(slideId, 'slide', 'type')];
             var
@@ -193,6 +229,79 @@ define.async('io.ox/office/presentation/view/control/layoutslidepicker', [
             }
         }
 
+        /**
+         * Rendering the content of the thumbs for ODF layout slides.
+         *
+         * @param {jQuery} $thumbContainer
+         *  The container node for the ODF layout thumb.
+         *
+         * @param {String} layoutId
+         *  The ID of the ODF layout slide.
+         */
+        function renderODFLayoutThumb($thumbContainer, layoutId) {
+
+            var // the data object for the ODF layout description
+                data = null,
+                // the image node
+                img = null,
+                // the width of the thumb container in px
+                thumbPixelWidth = $thumbContainer.width(),
+                // the height of the thumb container in px
+                thumbPixelHeight = $thumbContainer.height(),
+                // the horizontal stretching for the thumb container
+                horzFactor = thumbPixelWidth / 100,
+                // the vertical stretching for the thumb container
+                vertFactor = thumbPixelHeight / 100,
+                // the data URL string
+                dataUrlString = null;
+
+            if (odfLayoutContainer[layoutId]) {
+                dataUrlString = odfLayoutContainer[layoutId];
+            } else {
+
+                canvas = canvas || new Canvas(Canvas.SINGLETON);
+
+                data = docModel.getODFLayoutData(layoutId, horzFactor, vertFactor);
+
+                if (data) {
+
+                    canvas.initialize({ width: thumbPixelWidth, height: thumbPixelHeight });
+
+                    canvas.render(function (context) {
+
+                        var greyPath = data.greyPath;
+                        var bluePath = data.bluePath;
+
+                        if (greyPath) {
+                            context.setLineStyle({ style: '#BBBBBB', width: 1 });
+                            context.setFillStyle('#FFFFFF');
+                            context.drawPath(greyPath);
+                        }
+                        if (bluePath) {
+                            context.setLineStyle({ style: '#FFFFFF', width: 0 });
+                            context.setFillStyle('#3C73AA');
+                            context.drawPath(bluePath);
+                        }
+                    });
+
+                    dataUrlString = canvas.getDataURL();
+
+                    // saving the URL in the container
+                    odfLayoutContainer[layoutId] = dataUrlString;
+                }
+            }
+
+            if (dataUrlString) {
+                // the image for size rendering
+                img = $('<img>');
+                // update the image element
+                img.attr({ src: dataUrlString });
+                // appending the image into the DOM
+                $thumbContainer.append(img);
+            }
+
+        }
+
         function rerenderEveryLayoutThumb() {
             if (thumbBoxRegistry) {
                 thumbBoxRegistry.all().forEach(function (tuple) {
@@ -211,7 +320,7 @@ define.async('io.ox/office/presentation/view/control/layoutslidepicker', [
             var
                 $thumbContainer = $thumbContainerBlueprint.clone();
 
-            thumbBoxRegistry.put(slideId, $thumbContainer);
+            if (thumbBoxRegistry) { thumbBoxRegistry.put(slideId, $thumbContainer); }
 
           //$thumbContainer.attr('data-container-id', slideId);
 
@@ -233,12 +342,15 @@ define.async('io.ox/office/presentation/view/control/layoutslidepicker', [
           //$thumbContainer.busy();
             $thumbContainer.prependTo($buttonNode);
 
-            renderLayoutThumb($thumbContainer, slideId);
+            if (isOdfLayout) {
+                renderODFLayoutThumb($thumbContainer, slideId);
+            } else {
+                renderLayoutThumb($thumbContainer, slideId);
+            }
         }
 
         function getSectionId(slideId) {
             return [
-
                 'master_id_',
                 docModel.isMasterSlideId(slideId) ? slideId : docModel.getMasterSlideId(slideId)
 
@@ -256,9 +368,9 @@ define.async('io.ox/office/presentation/view/control/layoutslidepicker', [
         function createOptionButton(slideId) {
             // first parameter is the `data-value` payload value that will be passed along with all form control events.
             var
-                copy = getCustomSlideTitle(docModel, slideId) || getLayoutTypeTitle(slideId) || ('layout / ' + slideId);
+                copy = isOdfLayout ? docModel.getOdfLayoutSlideTitle(slideId) : (getCustomSlideTitle(docModel, slideId) || getLayoutTypeTitle(slideId) || ((isODFApp ? 'master / ' : 'layout / ') + slideId));
 
-            self.createOptionButton(slideId, { label: copy, tooltip: copy, section: getSectionId(slideId) });
+            self.createOptionButton(slideId, { label: copy, tooltip: copy, section: isOdfLayout ? null : getSectionId(slideId) });
           //self.createOptionButton(slideId, { label: ('layout / ' + slideId), section: getSectionId(slideId) });
         }
 
@@ -268,7 +380,7 @@ define.async('io.ox/office/presentation/view/control/layoutslidepicker', [
 
                 createMenuSection(slideId);
 
-            } else if (docModel.isLayoutSlideId(slideId)) {
+            } else if (isOdfLayout || docModel.isLayoutSlideId(slideId)) {
 
                 createOptionButton(slideId);
             }
@@ -277,6 +389,7 @@ define.async('io.ox/office/presentation/view/control/layoutslidepicker', [
         function handleLayoutThumbUpdate(evt, slideIdList) {
             slideIdList.forEach(updateLayoutThumb);
         }
+
         function handleEveryInitialPromiseStateResolved() {
 
             disableEveryInitialPromiseStateObservation();
@@ -289,6 +402,7 @@ define.async('io.ox/office/presentation/view/control/layoutslidepicker', [
             promisedThumbList = [];
             promisedThumbCount = promiseCount;
         }
+
         function disableEveryInitialPromiseStateObservation() {
             promisedThumbList = null;
             promisedThumbCount = -1;
@@ -297,6 +411,7 @@ define.async('io.ox/office/presentation/view/control/layoutslidepicker', [
         function createThumbRegistry() {
             thumbBoxRegistry = new ThumbBoxRegistry();
         }
+
         function deleteThumbRegistry() {
             if (thumbBoxRegistry) { // does not necessarily exist e.g. if there are no instances
 
@@ -324,10 +439,12 @@ define.async('io.ox/office/presentation/view/control/layoutslidepicker', [
             docView.forceLayoutMasterSlideFormatting();
 
             var
-                masterLayoutSlideIdList = docModel.getMasterSlideOrder();
+                masterLayoutSlideIdList = isOdfLayout ? docModel.getOdfLayoutSlideIDs() : docModel.getMasterSlideOrder();
 
-            createThumbRegistry();
-            enableEveryInitialPromiseStateObservation(masterLayoutSlideIdList.filter(docModel.isLayoutSlideId).length);
+            if (!isOdfLayout) {
+                createThumbRegistry();
+                enableEveryInitialPromiseStateObservation(masterLayoutSlideIdList.filter(docModel.isLayoutSlideId).length);
+            }
 
             masterLayoutSlideIdList.forEach(createMenuItem);
 
@@ -347,42 +464,32 @@ define.async('io.ox/office/presentation/view/control/layoutslidepicker', [
 
         // initialization -----------------------------------------------------
 
-        function initialize() {
-
-            // destroy class members on destruction
-            self.registerDestructor(function () {
-
-                clearMenuContent();
-
-                self.stopListeningTo(menu, 'popup:hide', clearMenuContent);
-                self.stopListeningTo(menu, 'popup:beforeshow', createMenuContent);
-
-              //self.stopListeningTo(menu, 'popup:beforeshow', handleBeforeShowPopup);
-                self.stopListeningTo(menu, 'create:item', prependThumbContainer);
-
-                self = initOptions = docModel = docView = null;
-            });
-
-            if (!css_value__thumb_height) {
-                css_value__thumb_height = (THUMBNAIL_HEIGHT + 'px');
-            }
-            if (!css_value__thumb_width) {
-                css_value__thumb_width = (Math.round(THUMBNAIL_HEIGHT * docModel.getSlideRatio()) + 'px');
-            }
-
-            self.getMenuNode().addClass('layout-slide-picker');
-
-            self.listenTo(menu, 'popup:hide', clearMenuContent);
-            self.listenTo(menu, 'popup:beforeshow', createMenuContent);
-
-          //self.listenTo(menu, 'popup:beforeshow', handleBeforeShowPopup);
-            self.listenTo(menu, 'create:item', prependThumbContainer);
-
-            menu.clearContents();
-          //isMenuContentExists = false;
+        if (!css_value__thumb_height) {
+            css_value__thumb_height = (THUMBNAIL_HEIGHT + 'px');
         }
 
-        initialize();
+        if (!css_value__thumb_width) {
+            css_value__thumb_width = (Math.round(THUMBNAIL_HEIGHT * docModel.getSlideRatio()) + 'px');
+        }
+
+        this.getMenuNode().addClass('layout-slide-picker');
+
+        // @bugfix: https://bugs.open-xchange.com/show_bug.cgi?id=49089
+        // fixing an IE 11 specific bug
+        //
+        // marker for touch devices and browser types
+        Forms.addDeviceMarkers(this.getMenuNode());
+
+        this.listenTo(menu, 'popup:hide', clearMenuContent);
+        this.listenTo(menu, 'popup:beforeshow', createMenuContent);
+        this.listenTo(menu, 'create:item', prependThumbContainer);
+
+        menu.clearContents();
+
+        // destroy class members on destruction
+        this.registerDestructor(function () {
+            self = initOptions = docModel = docView = menu = pickerNodeParent = null;
+        });
 
     } // class LayoutSlidePicker
 
