@@ -66,7 +66,7 @@ define('io.ox/office/presentation/view/dialog/insertdatedialog', [
 
         // base constructor ---------------------------------------------------
 
-        Dialogs.ModalDialog.call(this, { title: insertFieldTitle, width: dialogWidth });
+        Dialogs.ModalDialog.call(this, view, { title: insertFieldTitle, width: dialogWidth });
 
         // private methods ----------------------------------------------------
 
@@ -157,11 +157,13 @@ define('io.ox/office/presentation/view/dialog/insertdatedialog', [
             return show.call(this).done(function () {
                 var formatIndex = $fieldSelectBox[0] ? ($fieldSelectBox[0].selectedIndex + 1) : null;
                 var options = { fieldFormat: $fieldSelectBox.val(), automatic: Forms.isCheckedButtonNode(autoUpdateDateCheckbox), formatIndex: formatIndex };
-                model.getFieldManager().insertField('datetime', options);
+                var dateTimeType = model.getApp().isODF() ? 'date' : 'datetime';
+                model.getFieldManager().insertField(dateTimeType, options);
             }).always(function () {
                 // blocking keyboard input during applying of operations
                 model.setBlockKeyboardEvent(false);
-                self = model = view = numberFormatter = null;
+                self = model = numberFormatter = controlRootNode = categoryCodesDate = null;
+                $fieldSelectBox = $fieldFormat = autoUpdateDateCheckbox = null;
             });
         });
 
