@@ -26,17 +26,7 @@ define('io.ox/office/presentation/view/dialog/insertfooterdialog', [
     'use strict';
 
     // Global constants and variables
-    var insertFieldTitle = /*#. Insert footer fields from dialog menu*/ gt('Footer'),
-        dialogWidth = Utils.SMALL_DEVICE ? 320 : 420,
-        // container node for first column (category drop-down, fields type list)
-        $controlArea = null,
-        dateCheckbox = null,
-        dateContainer = null,
-        footerTxtContainer = null,
-        slideNumCheckbox = null,
-        footerTxtCheckbox = null,
-        autoRadioBtn = null,
-        fixedRadioBtn = null;
+    var dialogWidth = Utils.SMALL_DEVICE ? 320 : 420;
 
     // class InsertFooterDialog ===============================================
 
@@ -78,11 +68,26 @@ define('io.ox/office/presentation/view/dialog/insertfooterdialog', [
             model = view.getDocModel(),
             numberFormatter = model.getNumberFormatter(),
             // fetch locale date formats
-            categoryCodesDate = numberFormatter.getCategoryCodes('date');
+            categoryCodesDate = numberFormatter.getCategoryCodes('date'),
+            // whether this is an ODF application
+            isODF = model.getApp().isODF(),
+            // default fall back date option
+            defaultDateOption = 'datetime1',
+            insertFieldTitle = /*#. Insert footer fields from dialog menu*/ gt('Footer'),
+            // container node for first column (category drop-down, fields type list)
+            $controlArea = null,
+            dateCheckbox = null,
+            dateContainer = null,
+            footerTxtContainer = null,
+            slideNumCheckbox = null,
+            footerTxtCheckbox = null,
+            autoRadioBtn = null,
+            fixedRadioBtn = null,
+            applyallBtn = null;
 
         // base constructor ---------------------------------------------------
 
-        Dialogs.ModalDialog.call(this, { title: insertFieldTitle, width: dialogWidth });
+        Dialogs.ModalDialog.call(this, view, { title: insertFieldTitle, width: dialogWidth });
 
         // private methods ----------------------------------------------------
 
@@ -129,11 +134,13 @@ define('io.ox/office/presentation/view/dialog/insertfooterdialog', [
 
             if (categoryCodesDate.length) {
                 _.each(categoryCodesDate, function (formatCode, index) {
-                    localDateFormatList.push({ value: 'datetime' + (index + 1), label: getDateTimeRepresentation(formatCode.value) });
+                    localDateFormatList.push({ value: (isODF ? formatCode.value : 'datetime' + (index + 1)), label: getDateTimeRepresentation(formatCode.value) });
+                    if (isODF && index === 0) { defaultDateOption = formatCode.value; }
                 });
             } else {
                 localDateFormatList.push({ value: LocaleData.SHORT_DATE, label: getDateTimeRepresentation(LocaleData.SHORT_DATE) },
-                        { value: 'datetime1', label: getDateTimeRepresentation(LocaleData.LONG_DATE) });
+                        { value: (isODF ? LocaleData.LONG_DATE : 'datetime1'), label: getDateTimeRepresentation(LocaleData.LONG_DATE) });
+                if (isODF) { defaultDateOption = LocaleData.SHORT_DATE; }
             }
 
             return Forms.createSelectBoxMarkup(localDateFormatList);
@@ -176,7 +183,7 @@ define('io.ox/office/presentation/view/dialog/insertfooterdialog', [
 
             dateContainer = $('<div class="date-container">').append(autoRadio, populateFieldFormats(), fixedRadio, fixedDateTextArea);
             // depending from auto or fixed date, disable select and input fields
-            dateContainer.find('select').prop('disabled', !isDate || !isAutoDate).toggleClass('disabled', !isDate || !isAutoDate).val((dateObject && dateObject.dtType) || 'datetime1');
+            dateContainer.find('select').prop('disabled', !isDate || !isAutoDate).toggleClass('disabled', !isDate || !isAutoDate).val((dateObject && dateObject.dtType) || defaultDateOption);
             dateContainer.find('input').prop('disabled', !isDate || isAutoDate).toggleClass('disabled', !isDate || isAutoDate);
             if (isDate && !isAutoDate) {
                 dateContainer.find('input').val(dateObject && dateObject.dtText);
@@ -233,12 +240,14 @@ define('io.ox/office/presentation/view/dialog/insertfooterdialog', [
                 var checkedOptions = [];
                 var diffContent;
                 var diffState;
+                var odfRepresentation = null;
 
                 if (Forms.isCheckedButtonNode(dateCheckbox)) {
                     if (Forms.isCheckedButtonNode(autoRadioBtn)) {
                         selectedOption = $controlArea.find('option:selected');
                         formatIndex = selectedOption.length ? (selectedOption.index() + 1) : null;
-                        obj = { type: 'dt', automatic: true, formatIndex: formatIndex, representation: selectedOption[0].text };
+                        if (isODF) { odfRepresentation = categoryCodesDate[selectedOption.index()]; }
+                        obj = { type: 'dt', automatic: true, formatIndex: formatIndex, representation: isODF ? (odfRepresentation ? odfRepresentation.value : '') : selectedOption[0].text };
                     } else {
                         obj = { type: 'dt', automatic: false, representation: dateContainer.find('input').val() };
                     }
@@ -251,20 +260,26 @@ define('io.ox/office/presentation/view/dialog/insertfooterdialog', [
                     checkedOptions.push({ type: 'ftr', ftrText: footerTxtContainer.find('input').val() });
                 }
 
-                switch (action) {
-                    case 'ok':
-                        diffContent = model.getFieldManager().diffInputContent(dialogOptions, checkedOptions);
-                        diffState = model.getFieldManager().diffStateCheckboxes(dialogOptions, checkedOptions);
-                        model.getFieldManager().insertFooter(diffContent, diffState);
-                        break;
-                    case 'applyall':
-                        model.getFieldManager().insertAllFooters(checkedOptions);
+                if (isODF) {
+                    model.getFieldManager().insertFooterODF(checkedOptions, (action === 'applyall'));
+                } else {
+
+                    switch (action) {
+                        case 'ok':
+                            diffContent = model.getFieldManager().diffInputContent(dialogOptions, checkedOptions);
+                            diffState = model.getFieldManager().diffStateCheckboxes(dialogOptions, checkedOptions);
+                            model.getFieldManager().insertFooter(diffContent, diffState);
+                            break;
+                        case 'applyall':
+                            model.getFieldManager().insertAllFooters(checkedOptions);
+                    }
                 }
             }).always(function () {
                 // blocking keyboard input during applying of operations
                 model.setBlockKeyboardEvent(false);
 
-                self = model = view = numberFormatter = null;
+                self = model = numberFormatter = categoryCodesDate = dateContainer = applyallBtn = null;
+                $controlArea = dateCheckbox = footerTxtContainer = slideNumCheckbox = footerTxtCheckbox = autoRadioBtn = fixedRadioBtn = null;
             });
         });
 
@@ -296,7 +311,7 @@ define('io.ox/office/presentation/view/dialog/insertfooterdialog', [
 
         // add additional button
         this.addButton('applyall', gt('Apply to all'));
-        var applyallBtn = this.getButton('applyall');
+        applyallBtn = this.getButton('applyall');
         applyallBtn.detach();
         applyallBtn.addClass('btn-apply-all btn-primary');
         this.getFooter().append(applyallBtn);
@@ -348,12 +363,6 @@ define('io.ox/office/presentation/view/dialog/insertfooterdialog', [
             dateContainer.find('select').prop('disabled', true).addClass('disabled');
         });
 
-        // clean up after closing
-        this.on('close', function () {
-            $controlArea = dateCheckbox = dateContainer = footerTxtContainer = slideNumCheckbox = footerTxtCheckbox = autoRadioBtn = fixedRadioBtn = null;
-            self = model = numberFormatter = categoryCodesDate = null;
-        });
-
     } // class InsertFooterDialog
 
     // exports ================================================================
