@@ -15,12 +15,11 @@
 define('io.ox/office/presentation/view/slidepreviewmixin', [
 
     'io.ox/office/tk/utils',
-    'io.ox/office/textframework/utils/dom',
-    'io.ox/office/tk/utils/deferredutils',
+    'io.ox/office/tk/forms',
 
     'less!io.ox/office/presentation/view/style'
 
-], function (Utils, DOM, DeferredUtils) {
+], function (Utils, Forms) {
 
     'use strict';
 
@@ -71,34 +70,34 @@ define('io.ox/office/presentation/view/slidepreviewmixin', [
 
             THUMBNAIL_HEIGHT = 50,
 
-            SELECTOR__MASTER_SLIDE            = '.masterslidelayer',
-            SELECTOR__LAYOUT_SLIDE            = '.layoutslidelayer',
-            SELECTOR__PAGE_CONTENT            = '.pagecontent',
-            SELECTOR__SLIDE                   = '.slide',
+            SELECTOR__MASTER_SLIDE              = '.masterslidelayer',
+            SELECTOR__LAYOUT_SLIDE              = '.layoutslidelayer',
+            SELECTOR__PAGE_CONTENT              = '.pagecontent',
+            SELECTOR__SLIDE                     = '.slide',
 
-            SELECTOR__SLIDE_CONTAINER         = '.slidecontainer',
-            SELECTOR__SLIDEPANE_CONTAINER     = '.slide-pane-container',
+            SELECTOR__SLIDE_CONTAINER           = '.slidecontainer',
+            SELECTOR__SLIDEPANE_CONTAINER       = '.slide-pane-container',
 
-            SELECTOR__OVERLAY                 = '.collaborative-overlay',
+            SELECTOR__DRAWING                   = '.drawing',
+            SELECTOR__COLLABORATIVE_OVERLAY     = '.collaborative-overlay',
+            SELECTOR__DRAWINGSELECTION_OVERLAY  = '.drawingselection-overlay',
 
-            CLASS_NAME__UNFORCE_BACKGROUND    = 'unforce-background',
-            CLASS_NAME__INVISIBLE_BACKGROUND  = 'invisiblebackground',
-            CLASS_NAME__INVISIBLE_DRAWINGS    = 'invisibledrawings',
-            CLASS_NAME__INVISIBLE_SLIDE       = 'invisibleslide',
-            CLASS_NAME__LEFTSHIFT_SLIDE       = 'leftshift',
-            CLASS_NAME__NOT_SELECTABLE        = 'notselectable',
-            CLASS_NAME__SELECTED              = 'selected',
-            CLASS_NAME__APP_TOOLTIP           = 'app-tooltip',
+            CLASS_NAME__FORCEPLACEHOLDERVISIBILITY  = 'forceplaceholdervisibility',
 
-            CLASS_NAME__EDIT_MODE             = 'edit-mode',
+            CLASS_NAME__UNFORCE_BACKGROUND      = 'unforce-background',
+            CLASS_NAME__INVISIBLE_BACKGROUND    = 'invisiblebackground',
+            CLASS_NAME__INVISIBLE_DRAWINGS      = 'invisibledrawings',
+            CLASS_NAME__INVISIBLE_SLIDE         = 'invisibleslide',
+            CLASS_NAME__LEFTSHIFT_SLIDE         = 'leftshift',
+            CLASS_NAME__NOT_SELECTABLE          = 'notselectable',
+            CLASS_NAME__FIELD_HIGHLIGHT         = 'sf-highlight',
 
-          //CLASS_NAME__THUMB_MODE            = 'thumb-mode',
-            CLASS_NAME__PREVIEW_MODE          = 'preview-mode',
+            CLASS_NAME__EDIT_MODE               = 'edit-mode',
 
-            CLASS_NAME__F6_TARGET             = 'f6-target',
-            SELECTOR__F6_TARGET               = '.' + CLASS_NAME__F6_TARGET,
+          //CLASS_NAME__THUMB_MODE              = 'thumb-mode',
+            CLASS_NAME__PREVIEW_MODE            = 'preview-mode',
 
-            ATTRIBUTE__CONTENT_EDITABLE       = 'contenteditable',
+            IS_ODF = false, // boolean value constant that indicates whether the workerd document features ODF or not.
 
             previewMasterMap    = {}, // does refer to available preview-master layer-blueprints each as already sanitized DOM fragment.
 
@@ -107,6 +106,9 @@ define('io.ox/office/presentation/view/slidepreviewmixin', [
 
             thumbRegistry       = {}, // keeps track of render state of all available thumbs and, if necessary, stores them too.
 
+            fieldDataStore      = {}, // caches/stores slide specific field data for the time a preview does not yet exist
+                                      // due to referring to a still not completely formatted slide (incomplete attribution).
+
             fieldUpdateCache    = [], // does cache all data objects that have been received by listening to
                                       // '...Fields:update' events before all internal states were initialized.
 
@@ -357,14 +359,14 @@ define('io.ox/office/presentation/view/slidepreviewmixin', [
                     }
                     deferredRequest.resolve({ thumb: renderStateItem.thumb });
 
-                }, { infoString: 'Text: SlidePreviewMixin: getThumbDeferred', app: app });
+                }, 'SlidePreviewMixin.getThumbDeferred');
 
                 // forget timer reference as soon as every request/render promise is out of 'pending' state.
                 requestTimer.always(function () { requestTimer = null; });
             }
 
             // create and return the debounced and queued `getThumbDeferred` method with a delay of 10ms per thumb request/render promise.
-            return self.createDebouncedMethod(registerRequestPromise, getThumbDeferredFromPrioritizedQueues, { delay: 20, infoString: 'SlidePreviewMixin getThumbDeferred()', app: app/* delay: 100, maxDelay: 400*/ });
+            return self.createDebouncedMethod('SlidePreviewMixin.getThumbDeferred', registerRequestPromise, getThumbDeferredFromPrioritizedQueues, { delay: 20 });
         }());
 
         // function getThumbDeferred(deferredRequest, slideId) {
@@ -377,17 +379,9 @@ define('io.ox/office/presentation/view/slidepreviewmixin', [
         // }
 
         function requestThumb(slideId) {
-            var thumbRequest = DeferredUtils.createDeferred(app, 'SlidePreviewMixin: requestThumb');
+            var thumbRequest = self.createDeferred('SlidePreviewMixin.requestThumb');
 
             if (slideId in thumbRegistry) {
-
-              //self.executeDelayed((function (thumbRequest, slideId) {
-              //    return function () {
-              //
-              //        getThumbDeferred(thumbRequest, slideId);
-              //    };
-              //}(thumbRequest, slideId)));
-
                 getThumbDeferred(thumbRequest, slideId);
             } else {
                 thumbRequest.reject(new ReferenceError('Slide ID does not match.'));
@@ -573,114 +567,246 @@ define('io.ox/office/presentation/view/slidepreviewmixin', [
         //     return $targetNode;
         // }
 
+        /**
+         * Removes the specified CSS class from the passed node and all its
+         * siblings.
+         *
+         * @param {HTMLElement|jQuery} node
+         *  The DOM element to be manipulated.
+         *
+         * @param {String} className
+         *  The CSS class to be removed from the passed node.
+         */
+        function removeClass(node, className) {
+            $(node).find('.' + className).addBack().removeClass(className);
+        }
+
         /**
          * Sanitizing helper that assures any preview fragment
          * of being in a visible state.
          */
-        function preventInvisibleslide(node/*, idx, list*/) {
-            var $node = $(node);
-
-            $node.removeClass(CLASS_NAME__INVISIBLE_SLIDE);
-            $node.children().toArray().forEach(preventInvisibleslide);
+        function preventInvisibleSlide(node) {
+            removeClass(node, CLASS_NAME__INVISIBLE_SLIDE);
         }
 
         /**
          * Sanitizing helper that assures any preview fragment
          * of being not shifted to the left.
          */
-        function preventLeftshiftslide(node/*, idx, list*/) {
-            var $node = $(node);
-
-            $node.removeClass(CLASS_NAME__LEFTSHIFT_SLIDE);
-            $node.children().toArray().forEach(preventLeftshiftslide);
+        function preventLeftShiftSlide(node) {
+            removeClass(node, CLASS_NAME__LEFTSHIFT_SLIDE);
         }
 
         /**
          * Sanitizing helper that assures any preview fragment
          * of not being a F6 target.
          */
-        function preventF6Target(node/*, idx, list*/) {
-            var $node = $(node);
-
-            $node.find(SELECTOR__F6_TARGET).addBack(SELECTOR__F6_TARGET).removeClass(CLASS_NAME__F6_TARGET);
+        function preventF6Target(node) {
+            removeClass(node, 'f6-target');
         }
 
         /**
          * Sanitizing helper that prevents any preview fragment
          * from being in a selectable state.
          */
-        function preventNotselectable(node/*, idx, list*/) {
-            var $node = $(node);
-
-            $node.removeClass(CLASS_NAME__NOT_SELECTABLE);
-            $node.children().toArray().forEach(preventNotselectable);
+        function preventNotSelectable(node) {
+            removeClass(node, CLASS_NAME__NOT_SELECTABLE);
         }
 
         /**
          * Sanitizing helper that prevents any `slide` classified preview
          * fragment from being in a selectable state.
          */
-        function assureNotselectableSlide(node/*, idx, list*/) {
-            var $node = $(node);
+        function assureNotSelectableSlide(node) {
+            $(node).find(SELECTOR__SLIDE).addBack(SELECTOR__SLIDE).addClass(CLASS_NAME__NOT_SELECTABLE);
+        }
 
-            if ($node.hasClass('slide')) {
-                $node.addClass(CLASS_NAME__NOT_SELECTABLE);
-            }
-            $node.children().toArray().forEach(assureNotselectableSlide);
+        /**
+         * Sanitizing helper that prevents every data field
+         * being displayed in its selected/highlighted state.
+         */
+        function preventHighlightedFields(node) {
+            removeClass(node, CLASS_NAME__FIELD_HIGHLIGHT);
         }
 
         /**
          * Sanitizing helper that prevents any preview fragment
          * from being in a selected state.
          */
-        function preventSelectedElement(node/*, idx, list*/) {
-            var $node = $(node);
-
-            $node.removeClass(CLASS_NAME__SELECTED);
-            $node.children().toArray().forEach(preventSelectedElement);
+        function preventSelectedElement(node) {
+            removeClass(node, Forms.SELECTED_CLASS);
         }
 
         /**
          * Sanitizing helper that prevents any preview fragment
          * from being in an editable state.
          */
-        function preventContendEditable(node/*, idx, list*/) {
-            var $node = $(node);
-
-            if (_.isString($node.attr(ATTRIBUTE__CONTENT_EDITABLE))) {
-                $node.removeAttr(ATTRIBUTE__CONTENT_EDITABLE);
-            }
-            $node.children().toArray().forEach(preventContendEditable);
+        function preventContendEditable(node) {
+            $(node).find('[contenteditable]').addBack().removeAttr('contenteditable');
         }
 
         /**
          * Sanitizing helper that prevents any preview fragment
          * from triggering the tooltip display on hover.
          */
-        function preventApplicationTooltip(node/*, idx, list*/) {
-            var $node = $(node);
-
-            $node.removeClass(CLASS_NAME__APP_TOOLTIP);
-            $node.children().toArray().forEach(preventApplicationTooltip);
+        function preventApplicationTooltip(node) {
+            removeClass(node, Forms.APP_TOOLTIP_CLASS);
         }
 
+        /**
+         *
+         *  ODP specific visibility handling
+         */
+        function handleOdfVisibilityOfPlaceholderFooterDrawings(slideId, $node) {
+            if (IS_ODF) {
+                var
+                    drawingItemList = $node.find(SELECTOR__DRAWING).toArray().map(function (elmNode) {
+                        var
+                            $node = $(elmNode);
+
+                        return {
+                            type: $node.attr('placeholdertype'),
+                            $node: $node
+                        };
+                    }).filter(function (drawingItem) {
+
+                        return docModel.isPlaceHolderFooterDrawingType(drawingItem.type);
+                    });
+
+                drawingItemList.forEach(function (drawingItem) {
+                    if (docModel.isVisiblePlaceHolderFooterDrawingType(slideId, drawingItem.type)) {
+
+                        drawingItem.$node.addClass(CLASS_NAME__FORCEPLACEHOLDERVISIBILITY);
+                    } else {
+                        drawingItem.$node.removeClass(CLASS_NAME__FORCEPLACEHOLDERVISIBILITY);
+                    }
+                });
+            }
+        }
+
+        //  BEGIN - Field Data Support
+        //
+        //  - code block that implements support of
+        //    how to properly deal with field data
+        //
+        //    * be it updating already existing previews
+        //    * or handling field data pre storing/caching
+        //      with deferred field data updates
+        //    * and regardless of being word- or ODF-formatted.
+        //
+        //
+
         function getSlideIdFromFieldData(data) {
             return data.slideID;
         }
-        function updateField(data/*, idx, list*/) {
+        function getFieldIdFromFieldData(data) {
+            return data.fieldID;
+        }
+
+        function putFieldData(data) {
+          //window.console.log('+++ putFieldData - slide ' + getSlideIdFromFieldData(data) + ' still needs to be formatted.');
             var
-                $preview = previewStore[data.slideID],
-                $field   = $preview.find('[data-fid="' + data.fieldID + '"] > span');
+                slideId   = getSlideIdFromFieldData(data),
+                fieldId   = getFieldIdFromFieldData(data),
 
-            if ($field && $field[0]) {
+                groupedDataItem = fieldDataStore[slideId];
 
-              //$field.eq(0).text(data.value);
-                $field[0].innerHTML = data.value;
+            if (!groupedDataItem) {
+                groupedDataItem = fieldDataStore[slideId] = {}; // - no array in order to prevent pushing
+            }                                                   //   data-objects multiple times that do
+            groupedDataItem[fieldId] = data;                    //   target the same `slideId.fieldId` combination.
+        }
+
+        function getFieldDataBySlideId(slideId) {
+            return fieldDataStore[slideId];
+        }
+        function deleteFieldDataBySlideId(slideId) {
+            return (delete fieldDataStore[slideId]);
+        }
+
+        function renderPrestoredFieldData(slideId) {
+            var
+                groupedDataItem = getFieldDataBySlideId(slideId);
+
+            if (groupedDataItem) {
+                Object.keys(groupedDataItem).forEach(function (fieldId) {
+
+                    updateField(groupedDataItem[fieldId]);
+                });
+                deleteFieldDataBySlideId(slideId);
             }
         }
-        function handleFieldUpdate(evt, fieldDataList) {
 
-            fieldDataList.forEach(updateField);
+        function updateField(data) {
+            var
+                isVisibleField,
+
+                slideId   = getSlideIdFromFieldData(data),
+                fieldId   = getFieldIdFromFieldData(data),
+
+                $preview  = previewStore[slideId],
+                $field    = ($preview && $preview.find('[data-fid="' + fieldId + '"] > span')),
+
+                elmField  = ($field && $field[0]);
+
+            // if (IS_ODF && isMasterView && docModel.isStandardSlideId(slideId)) {
+            //     return;
+            // }
+            // @Note: this guard is implemented into 'io.ox/office/presentation/components/field/slidefield' around line 1126
+
+            if (elmField) { // preview already does exist, field also can bee accessed ... proceed with updating all slide specific field data.
+
+                $field.eq(0).text(data.value);
+                $field.parent().removeClass(CLASS_NAME__FIELD_HIGHLIGHT);
+
+                if (data.masterViewField === true) {
+
+                    $field    = $field.closest('[placeholdertype="' + data.fieldType + '"]');
+                    elmField  = $field[0];
+                }
+                if (elmField && _.isBoolean(isVisibleField = data.visible)) {
+                    var
+                        fieldStyle = elmField.style;
+
+                    if (isVisibleField) {
+                        fieldStyle.display = 'initial';   // - directly restore an elements style value from e.g. 'none' like
+                                                          //   from an applied css-rule to its default / initial render value.
+                        fieldStyle.visibility = 'visible';
+                    } else {
+                        fieldStyle.visibility = 'hidden';
+
+                        fieldStyle.display = '';          // - directly reset an elements style value,
+                    }                                     //   allowing e.g. css-rules taking place again.
+                }
+            }
+        }
+
+        function handleUpdateField(data/*, idx, list*/) {
+            var
+                slideId = getSlideIdFromFieldData(data),
+                attributionItem = attributionMap[slideId];
+
+        //  if (IS_ODF && isMasterView && docModel.isStandardSlideId(slideId)) { return; }
+            if (!IS_ODF || !isMasterView || !docModel.isStandardSlideId(slideId)) {
+
+                // - does apply for either non ODF documents only, or,
+                //   if featuring ODF, then for standards slides only.
+
+                if (attributionItem.isMustFormat) { // - preview does not yet exist,
+                                                    //   because attribution has not yet been taken place;
+                    putFieldData(data);             // - do cache slide specific field data.
+
+                } else {
+                                                    // - preview might exist already;
+                    updateField(data);              // - therefore proceed with updating all slide specific field data.
+                }
+            }
+        }
+
+        function handleFieldUpdate(evt, fieldDataList) {
+          //window.console.log('+++ handleFieldUpdate +++ fieldDataList : ', fieldDataList);
+
+            fieldDataList.forEach(handleUpdateField);
 
             var
                 filterByCurrentView   = isStandardView ? docModel.isStandardSlideId : docModel.isLayoutOrMasterId,
@@ -699,9 +825,29 @@ define('io.ox/office/presentation/view/slidepreviewmixin', [
             }
         }
 
+        // please keep this commented block for debugging.
+        //
+        // function handleMasterFieldUpdate(evt, fieldDataList) {
+        //   //window.console.log('+++ handleMasterFieldUpdate +++ fieldDataList : ', evt, fieldDataList);
+        //
+        //     handleFieldUpdate(evt, fieldDataList);
+        // }
+        // function handleMasterFieldUpdateBeforeCompiledView(evt, fieldDataList) {
+        //   //window.console.log('+++ handleMasterFieldUpdateBeforeCompiledView +++ fieldDataList : ', evt, fieldDataList);
+        //
+        //     handleFieldUpdateBeforeCompiledView(evt, fieldDataList);
+        // }
+
         var handleFieldUpdateBeforeCompiledView = function (evt, fieldDataList) {
+          //window.console.log('+++ handleFieldUpdateBeforeCompiledView +++ fieldDataList : ', evt, fieldDataList);
+
             fieldUpdateCache = fieldUpdateCache.concat(fieldDataList);
         };
+
+        //
+        //
+        //  END - Field Data Support
+
         var handleSlideStateFormattedBeforeCompiledView = function (evt, slideIdList) {
             formattedSlideCache = formattedSlideCache.concat(slideIdList);
         };
@@ -751,8 +897,10 @@ define('io.ox/office/presentation/view/slidepreviewmixin', [
 
             $masterPreviewBlueprint = getSanitizedPreviewBlueprint($pageNode.clone());
 
-          //$masterPreviewBlueprint.find(SELECTOR__OVERLAY).remove();
-            $masterPreviewBlueprint.find(SELECTOR__OVERLAY).empty();
+          //$masterPreviewBlueprint.find(SELECTOR__COLLABORATIVE_OVERLAY).remove();
+            $masterPreviewBlueprint.find(SELECTOR__COLLABORATIVE_OVERLAY).empty();
+
+            $masterPreviewBlueprint.find(SELECTOR__DRAWINGSELECTION_OVERLAY).remove();
 
           //Utils.info('+++ compileMasterPreviewBlueprint +++');
           //Utils.info('+++ compileMasterPreviewBlueprint :: $masterPreviewBlueprint ', $masterPreviewBlueprint);
@@ -775,8 +923,10 @@ define('io.ox/office/presentation/view/slidepreviewmixin', [
 
             $standardPreviewBlueprint = getSanitizedPreviewBlueprint($pageNode.clone());
 
-            $standardPreviewBlueprint.find(SELECTOR__OVERLAY).remove();
-          //$standardPreviewBlueprint.find(SELECTOR__OVERLAY).empty();
+            $standardPreviewBlueprint.find(SELECTOR__COLLABORATIVE_OVERLAY).remove();
+          //$standardPreviewBlueprint.find(SELECTOR__COLLABORATIVE_OVERLAY).empty();
+
+            $standardPreviewBlueprint.find(SELECTOR__DRAWINGSELECTION_OVERLAY).remove();
 
           //Utils.info('+++ compileStandardPreviewBlueprint +++');
           //Utils.info('+++ compileStandardPreviewBlueprint :: $standardPreviewBlueprint ', $standardPreviewBlueprint);
@@ -839,6 +989,7 @@ define('io.ox/office/presentation/view/slidepreviewmixin', [
                 .find(SELECTOR__MASTER_SLIDE).eq(0)
                 .children('[data-container-id="' + masterId + '"]').eq(0);
         }
+
         /**
          *
          * @param $preview
@@ -850,6 +1001,7 @@ define('io.ox/office/presentation/view/slidepreviewmixin', [
                 .find(SELECTOR__LAYOUT_SLIDE).eq(0)
                 .children('[data-container-id="' + layoutId + '"]').eq(0);
         }
+
         /**
          *
          * @param $preview
@@ -894,6 +1046,7 @@ define('io.ox/office/presentation/view/slidepreviewmixin', [
                 }
             }
         }
+
         /**
          *
          * @param data
@@ -932,6 +1085,7 @@ define('io.ox/office/presentation/view/slidepreviewmixin', [
                 }
             }
         }
+
         /**
          *
          * @param slideId
@@ -1010,10 +1164,11 @@ define('io.ox/office/presentation/view/slidepreviewmixin', [
             preventSelectedElement($fragment);
 
             preventApplicationTooltip($fragment);
+            preventHighlightedFields($fragment);
 
-            preventNotselectable($fragment);
-            preventInvisibleslide($fragment);
-            preventLeftshiftslide($fragment);
+            preventNotSelectable($fragment);
+            preventInvisibleSlide($fragment);
+            preventLeftShiftSlide($fragment);
 
             return $fragment;
         }
@@ -1081,7 +1236,7 @@ define('io.ox/office/presentation/view/slidepreviewmixin', [
                 $master = (previewMasterMap[masterId] && previewMasterMap[masterId].clone()) || $('<div/>'); // fail silently.
                 $layout = createLayoutFragment(slideId);
 
-                assureNotselectableSlide($master);
+                assureNotSelectableSlide($master);
 
                 $layout.prependTo($preview.find(SELECTOR__LAYOUT_SLIDE));
             }
@@ -1181,7 +1336,7 @@ define('io.ox/office/presentation/view/slidepreviewmixin', [
                 $master         = createLayoutFragment(masterId);
                 $layout         = createLayoutFragment(layoutId);
 
-                assureNotselectableSlide($master);
+                assureNotSelectableSlide($master);
 
                 $layout.prependTo($preview.find(SELECTOR__LAYOUT_SLIDE).empty());
             }
@@ -1227,11 +1382,11 @@ define('io.ox/office/presentation/view/slidepreviewmixin', [
                 masterId        = slideIdSet.masterId,
                 layoutId        = slideIdSet.layoutId,
 
-                $masterSource   = docModel.getSlideById(masterId).parent(SELECTOR__SLIDE_CONTAINER),
+                $masterSource   = masterId ? docModel.getSlideById(masterId).parent(SELECTOR__SLIDE_CONTAINER) : null,
                 $layoutSource   = docModel.getSlideById(layoutId).parent(SELECTOR__SLIDE_CONTAINER),
                 $contentSource  = docModel.getSlideById(slideId),
 
-                $master         = $masterSource.clone(),
+                $master         = masterId ? $masterSource.clone() : null,
                 $layout         = $layoutSource.clone(),
                 $content        = $contentSource.clone(),
 
@@ -1240,34 +1395,39 @@ define('io.ox/office/presentation/view/slidepreviewmixin', [
                 showLayoutSlide = docModel.isFollowMasterShapeSlide(slideId),
                 showMasterSlide = showLayoutSlide ? docModel.isFollowMasterShapeSlide(layoutId) : false;
 
-            preserveShapes($masterSource, $master);
+            if ($masterSource) { preserveShapes($masterSource, $master); }
             preserveShapes($layoutSource, $layout);
             preserveShapes($contentSource, $content);
 
-            preventContendEditable($master);
+            if ($master) { preventContendEditable($master); }
             preventContendEditable($layout);
             preventContendEditable($content);
 
-            preventSelectedElement($master);
+            if ($master) { preventSelectedElement($master); }
             preventSelectedElement($layout);
             preventSelectedElement($content);
 
-            preventApplicationTooltip($master);
+            if ($master) { preventApplicationTooltip($master); }
             preventApplicationTooltip($layout);
             preventApplicationTooltip($content);
 
-            assureNotselectableSlide($master);
-            assureNotselectableSlide($layout);
+            if ($master) { preventHighlightedFields($master); }
+            preventHighlightedFields($layout);
 
-            preventInvisibleslide($master);
-            preventInvisibleslide($layout);
+            if ($master) { assureNotSelectableSlide($master); }
+            assureNotSelectableSlide($layout);
 
-            preventLeftshiftslide($master);
-            preventLeftshiftslide($layout);
+            if ($master) { preventInvisibleSlide($master); }
+            preventInvisibleSlide($layout);
+
+            if ($master) { preventLeftShiftSlide($master); }
+            preventLeftShiftSlide($layout);
+
+            handleOdfVisibilityOfPlaceholderFooterDrawings(slideId, $layout);
 
             $content.removeClass(CLASS_NAME__INVISIBLE_SLIDE);  // this line acknowledges remote clients.
 
-            $master.prependTo($preview.find(SELECTOR__MASTER_SLIDE));
+            if ($master) { $master.prependTo($preview.find(SELECTOR__MASTER_SLIDE)); }
             $layout.prependTo($preview.find(SELECTOR__LAYOUT_SLIDE));
             $content.prependTo($preview.find(SELECTOR__PAGE_CONTENT));
 
@@ -1339,6 +1499,7 @@ define('io.ox/office/presentation/view/slidepreviewmixin', [
             preventSelectedElement($content);
 
             preventApplicationTooltip($content);
+            preventHighlightedFields($content);
 
             $content.removeClass(CLASS_NAME__INVISIBLE_SLIDE);  // this line acknowledges remote clients.
 
@@ -1384,6 +1545,7 @@ define('io.ox/office/presentation/view/slidepreviewmixin', [
 
           //Utils.info('+++ assignEveryMasterPreviewItemInitially :: time : ', (new Date() - time));
         }
+
         function assignEveryStandardPreviewItemInitially() {
           //var time = (new Date());
 
@@ -1476,6 +1638,7 @@ define('io.ox/office/presentation/view/slidepreviewmixin', [
 
                     layoutOrMasterIdList.push(slideId);
                 }
+                renderPrestoredFieldData(slideId);
             });
 
             if (isStandardView) {
@@ -1641,12 +1804,19 @@ define('io.ox/office/presentation/view/slidepreviewmixin', [
             self.stopListeningTo(docModel, 'slideNumFields:update', handleFieldUpdateBeforeCompiledView);
             self.stopListeningTo(docModel, 'slideDateFields:update', handleFieldUpdateBeforeCompiledView);
 
+            self.stopListeningTo(docModel, 'masterfield:update', handleFieldUpdateBeforeCompiledView);
+          //self.stopListeningTo(docModel, 'masterfield:update', handleMasterFieldUpdateBeforeCompiledView); // please keep this commented line for debugging.
+
+          //window.console.log('+++ fieldUpdateCache : ', fieldUpdateCache);
             handleFieldUpdate({}, fieldUpdateCache);
             handleFieldUpdateBeforeCompiledView = fieldUpdateCache = null;
 
             self.listenTo(docModel, 'slideNumFields:update', handleFieldUpdate);
             self.listenTo(docModel, 'slideDateFields:update', handleFieldUpdate);
 
+            self.listenTo(docModel, 'masterfield:update', handleFieldUpdate);
+          //self.listenTo(docModel, 'masterfield:update', handleMasterFieldUpdate); // please keep this commented line for debugging.
+
             self.listenTo(docModel, 'inserted:slide', handleInsertSlide);
 
           //Utils.info('+++ compileView :: time : ', (new Date() - time));
@@ -1679,6 +1849,8 @@ define('io.ox/office/presentation/view/slidepreviewmixin', [
          */
         function initHandler() {
 
+            IS_ODF    = app.isODF();
+
             docModel  = app.getModel();
             $pageNode = docModel.getNode();
 
@@ -1709,10 +1881,19 @@ define('io.ox/office/presentation/view/slidepreviewmixin', [
             self.listenTo(docModel, 'slideNumFields:update', handleFieldUpdateBeforeCompiledView);
             self.listenTo(docModel, 'slideDateFields:update', handleFieldUpdateBeforeCompiledView);
 
+            self.listenTo(docModel, 'masterfield:update', handleFieldUpdateBeforeCompiledView);
+          //self.listenTo(docModel, 'masterfield:update', handleMasterFieldUpdateBeforeCompiledView); // please keep this commented line for debugging.
+
             // slide size has changed - e.g. orientation change.
             self.listenTo(docModel, 'slidesize:change', handleSlideSizeChange);
         }
 
+        // destroy all class members
+        this.registerDestructor(function () {
+            self = docModel = slidepane = $pageNode = imgNodeBlueprint = $masterPreviewBlueprint = $standardPreviewBlueprint = null;
+            thumb_scale_value = css_value__thumb_scale = previewMasterMap = previewStore = attributionMap = thumbRegistry = fieldUpdateCache = formattedSlideCache = null;
+        });
+
         //
         // --------------------------------------------------------------------
 
