@@ -13,10 +13,10 @@
  */
 
 define('io.ox/office/settings/units', [
+    'io.ox/office/tk/config',
     'io.ox/office/tk/locale/localedata',
-    'io.ox/office/settings/view/settingslabels',
-    'settings!io.ox/office'
-], function (LocaleData, Labels, Settings) {
+    'io.ox/office/settings/view/settingslabels'
+], function (Config, LocaleData, Labels) {
 
     'use strict';
 
@@ -38,12 +38,12 @@ define('io.ox/office/settings/units', [
     // private global functions ===============================================
 
     function getStandardUnit() {
-        var unit = Settings.get('units/standard');
+        var unit = Config.get('units/standard');
         return unit ? unit : LocaleData.UNIT;
     }
 
     function setStandardUnit(unit) {
-        Settings.set('units/standard', unit).save();
+        Config.set('units/standard', unit);
     }
 
     // class Units ============================================================
