@@ -13,19 +13,19 @@
  */
 
 define('io.ox/office/settings/userdictionary', [
-    'io.ox/office/tk/dialogs',
-    'io.ox/office/tk/keycodes',
     'io.ox/core/event',
-    'settings!io.ox/office',
+    'io.ox/office/tk/config',
     'io.ox/office/tk/utils',
+    'io.ox/office/tk/keycodes',
+    'io.ox/office/tk/dialogs',
     'gettext!io.ox/office/settings/main'
-], function (Dialogs, KeyCodes, Event, Settings, Utils, gt) {
+], function (Event, Config, Utils, KeyCodes, Dialogs, gt) {
 
     'use strict';
 
     var
         // the key for save/get the user dictionary to the user settings
-        settingsKey = 'userdictionary',
+        SETTINGS_KEY = 'userdictionary',
         // for sorting the elements in the dictionary
         wordSortIteratee = function (word) {
             return word.toLowerCase();
@@ -39,9 +39,10 @@ define('io.ox/office/settings/userdictionary', [
 
         // public methods -----------------------------------------------------
         this.refresh = function (settings) {
-            settings.appendTitle(/*#. Label for the user dictionary section in the documents settings */gt('User dictionary'));
+
+            settings.append($('<div style="display: block; height: 0; margin-top: -15px">'));
             settings.appendButton(/*#. Button label for open the user dictionary dialog */gt('Edit user dictionary'), new Dialog().show).attr('data-action', 'edituserdic');
-            settings.append($('<div style="display: block; height: 20px">'));
+            settings.append($('<div style="display: block; height: 0; margin-bottom: 20px">'));
         };
     }
 
@@ -54,7 +55,7 @@ define('io.ox/office/settings/userdictionary', [
     UserDictionary.getDictionary = function () {
 
         if (!dictionary) {
-            dictionary = Settings.get(settingsKey, []);
+            dictionary = Config.get(SETTINGS_KEY, []);
         }
 
         return dictionary;
@@ -113,7 +114,7 @@ define('io.ox/office/settings/userdictionary', [
         }
 
         if (userDicChanges) {
-            Settings.set(settingsKey, dictionary).save();
+            Config.set(SETTINGS_KEY, dictionary);
             UserDictionary.trigger('save', _.isArray(newWords) ? newWords : [], _.isArray(removedWords) ? removedWords : []);
         }
     }
@@ -138,7 +139,7 @@ define('io.ox/office/settings/userdictionary', [
     }
 
     /**
-     * The User Dictionary Dialog which is visible if the user press the
+     * The User Dictionary Edit Dialog which is visible if the user presses the setting's edit button.
      */
     function Dialog() {
 
@@ -261,7 +262,7 @@ define('io.ox/office/settings/userdictionary', [
             var wordLabel = $('<div>')
                 .css({
                     whiteSpace: 'nowrap',
-                    width: 'calc(100% - 15px',
+                    width: 'calc(100% - 15px)',
                     textOverflow: 'ellipsis',
                     overflow: 'hidden',
                     float: 'left',
@@ -330,7 +331,7 @@ define('io.ox/office/settings/userdictionary', [
          */
         this.show = function () {
 
-            var dialog = new Dialogs.ModalDialog({
+            var dialog = new Dialogs.ModalDialog('io-ox-office-settings', {
                 okLabel: /*#. Button label for the save button for the user dictionary dialog. */gt('Save'),
                 title: /*#. Title of the user dictionary dialog. */gt('User dictionary'),
                 validator: onPressSaveButton
