@@ -39,6 +39,12 @@ define('io.ox/office/spreadsheet/app/application', [
     /**
      * The OX Spreadsheet application.
      *
+     * In additions of the events triggered by the base classes, the following
+     * events will be triggered:
+     *  - 'docs:preview:activesheet'
+     *      Triggered during the import process when the active sheet has been
+     *      loaded, and import of all other sheets starts.
+     *
      * @constructor
      *
      * @extends EditApplication
@@ -66,7 +72,8 @@ define('io.ox/office/spreadsheet/app/application', [
             prepareLoseEditRightsHandler: prepareLoseEditRights,
             prepareRenameHandler: prepareRenameHandler,
             realTimeDelay: 10,
-            supportsOnlineSync: true
+            supportsOnlineSync: true,
+            isSnapshotApp: false
         });
 
         // private methods ----------------------------------------------------
@@ -97,7 +104,10 @@ define('io.ox/office/spreadsheet/app/application', [
          */
         function previewHandler(previewData) {
             var activeSheet = Utils.getIntegerOption(previewData, 'activeSheet', 0);
-            return docView.activatePreviewSheet(activeSheet);
+            var success = self.getController().activatePreviewSheet(activeSheet);
+            // notify view components, e.g. repaint the sheet tabs once during import
+            if (success) { self.trigger('docs:preview:activesheet'); }
+            return success;
         }
 
         /**
@@ -139,12 +149,14 @@ define('io.ox/office/spreadsheet/app/application', [
          */
         function finalizePendingDocumentChanges(options) {
 
-            // commit current text of the cell in-place edit mode (without validation)
-            docView.leaveCellEditMode('force');
+            // commit current edit text (without validation)
+            var promise = docView.leaveTextEditMode({ commitMode: 'force' });
 
             // wait for the dependency manager recalculating all dirty formulas
-            options = _.extend({}, options, { volatile: false });
-            var promise = docModel.getDependencyManager().recalcFormulas(options);
+            promise = promise.then(function () {
+                options = _.extend({}, options, { volatile: false });
+                return docModel.getDependencyManager().recalcFormulas(options);
+            });
 
             // do not forward the rejected state of the dependency manager after a timeout
             promise = promise.then(null, function (cause) {
@@ -153,8 +165,8 @@ define('io.ox/office/spreadsheet/app/application', [
 
             // send all changed view settings (after recalculating the formulas which may
             // initially set the 'document modified' flag)
-            return promise.done(function () {
-                docView.sendChangedViewAttributes();
+            return promise.then(function () {
+                return self.getController().sendChangedViewAttributes();
             });
         }
 
