@@ -14,14 +14,11 @@
 
 define('io.ox/office/spreadsheet/app/drawingcontroller', [
     'io.ox/office/tk/utils',
-    'io.ox/office/editframework/utils/color',
-    'io.ox/office/drawinglayer/utils/drawingutils',
     'io.ox/office/drawinglayer/view/drawinglabels',
     'io.ox/office/spreadsheet/utils/operations',
-    'io.ox/office/spreadsheet/model/formula/tokenarray',
     'io.ox/office/spreadsheet/view/chartcreator',
     'gettext!io.ox/office/spreadsheet/main'
-], function (Utils, Color, DrawingUtils, DrawingLabels, Operations, TokenArray, ChartCreator, gt) {
+], function (Utils, DrawingLabels, Operations, ChartCreator, gt) {
 
     'use strict';
 
@@ -35,17 +32,9 @@ define('io.ox/office/spreadsheet/app/drawingcontroller', [
      */
     function DrawingControllerMixin(app, docModel, docView) {
 
-        var self = this,
+        var self = this;
 
-            sourceSelector = false,
-
-            chartSourceToken = null,
-
-            // the token arrays containing the highlighted ranges of the selected drawing object
-            tokenArrays = [],
-
-            // the unique identifier of the range highlighting mode
-            highlightUid = null;
+        var sourceSelector = false;
 
         // private methods ----------------------------------------------------
 
@@ -81,34 +70,6 @@ define('io.ox/office/spreadsheet/app/drawingcontroller', [
             return $.Deferred().reject();
         }
 
-        /**
-         * changeSelection
-         * if only one drawing is selected and this is a chart, the function highlights its source cells via token array
-         */
-        function changeSelectionHandler(evt, selection) {
-
-            if (highlightUid) {
-                docView.endRangeHighlighting(highlightUid);
-                highlightUid = null;
-            }
-
-            tokenArrays = [];
-
-            if (selection.drawings.length === 1) {
-
-                var chartModel = docView.getDrawingCollection().findModel(selection.drawings[0], { type: 'chart' });
-
-                if (chartModel) {
-                    chartModel.getTokenArrays(tokenArrays);
-                }
-            }
-
-            // highlight the source ranges of the chart in the active sheet
-            if (tokenArrays.length > 0) {
-                highlightUid = docView.startRangeHighlighting(tokenArrays, { priority: true, resolveNames: true });
-            }
-        }
-
         /**
          * Returns the position of the selected drawing object, if exactly one
          * drawing object is currently selected.
@@ -127,9 +88,9 @@ define('io.ox/office/spreadsheet/app/drawingcontroller', [
          *  The drawing model currently selected.
          */
         function getDrawingModel(type) {
-            var drawingIndices = getDrawingPosition();
-            if (drawingIndices) {
-                return docView.getDrawingCollection().findModel(drawingIndices, { type: type });
+            var drawingPos = getDrawingPosition();
+            if (drawingPos) {
+                return docView.getDrawingCollection().getModel(drawingPos, { type: type });
             }
         }
 
@@ -178,7 +139,7 @@ define('io.ox/office/spreadsheet/app/drawingcontroller', [
                     undoProperties = { axis: properties.axis, attrs: gridModel.getUndoAttributeSet(properties.attrs) };
                     break;
 
-                case Operations.SET_DRAWING_ATTRIBUTES:
+                case Operations.CHANGE_DRAWING:
                     undoProperties = { attrs: chartModel.getUndoAttributeSet(properties.attrs) };
                     break;
 
@@ -202,7 +163,7 @@ define('io.ox/office/spreadsheet/app/drawingcontroller', [
          *  The title text from the passed attribute set.
          */
         function getChartTitle(attributes) {
-            if (_.isObject(attributes) && _.isArray(attributes.text.link)) { return attributes.text.link[0] || ''; }
+            if (_.isObject(attributes) && _.isArray(attributes.text.link)) { return (attributes.text.link[0] || '').trim(); }
             return '';
         }
 
@@ -248,15 +209,16 @@ define('io.ox/office/spreadsheet/app/drawingcontroller', [
          *  applied successfully, or that will be rejected on any error.
          */
         function setChartTitle(chartModel, titleId, title) {
-            return setChartTitleAttributes(chartModel, titleId, { text: { link: [title] }, character: ChartCreator.getHeadChar() });
+            return setChartTitleAttributes(chartModel, titleId, { text: { link: [title] }, character: ChartCreator.getHeadChar(docModel) });
         }
 
         function selectNewChartSource() {
 
-            var // enter custom selection mode
-                promise = docView.enterCustomSelectionMode('chartsource', {
-                    statusLabel: /*#. change source data for a chart object in a spreadsheet */ gt('Select source data')
-                });
+            // enter custom selection mode
+            var promise = docView.enterCustomSelectionMode('chartsource', {
+                //#. change source data for a chart object in a spreadsheet
+                statusLabel: gt('Select source data')
+            });
 
             // set selected range as source data
             promise.done(function (selection) {
@@ -264,20 +226,16 @@ define('io.ox/office/spreadsheet/app/drawingcontroller', [
                 var range = selection.ranges[0];
                 var sheet = docView.getActiveSheet();
 
-                if (!chartSourceToken) {
-                    chartSourceToken = new TokenArray(docView.getSheetModel(), 'chart');
-                }
-
-                chartSourceToken.clearTokens().appendRange(range, { sheet: sheet, abs: true });
-
                 var chart = getDrawingModel('chart');
 
                 var possSources = chart.getDataSourceInfo();
                 if (possSources.warn) {
                     return ChartCreator.updateSeries({ app: app, sourceRange: range, sourceSheet: sheet, chartModel: chart });
                 }
+                var forceNames;
+                if (chart.isXYType()) { forceNames = chart.isNamesLabel(); }
 
-                return ChartCreator.updateSeries({ app: app, sourceRange: range, sourceSheet: sheet, chartModel: chart, axis: possSources.axis });
+                return ChartCreator.updateSeries({ app: app, sourceRange: range, sourceSheet: sheet, chartModel: chart, axis: possSources.axis, forceNames: forceNames });
             });
         }
 
@@ -302,27 +260,29 @@ define('io.ox/office/spreadsheet/app/drawingcontroller', [
             if (possSources.warn) {
                 return yellChartDirection(possSources.warn);
             }
-            return ChartCreator.updateSeries({ app: app, sourceRange: possSources.range, sourceSheet: possSources.sheet, chartModel: chartModel, axis: possSources.axis, chartAttrs: data, typeChanged: true });
+            var forceNames;
+            if (chartModel.isXYType()) { forceNames = chartModel.isNamesLabel(); }
+            return ChartCreator.updateSeries({ app: app, sourceRange: possSources.range, sourceSheet: possSources.sheet, chartModel: chartModel, axis: possSources.axis, chartData: data, forceNames: forceNames/*, typeChanged: true*/ });
         }
 
         function isFirstRowColEnabled(chartModel, rowCol) {
-            if (!chartModel) { return null; }
+            if (!chartModel) { return false; }
 
             var possSources = chartModel.getDataSourceInfo();
-            if (possSources.warn) { return null; }
+            if (possSources.warn) { return false; }
             if (possSources.axis) { rowCol = Math.abs(rowCol - 1); }
             if (rowCol === 1) {
-                return chartModel.isTitleLabel() || chartModel.getFirstPointsCount() > 1;
+                return isTitleLabelEnabled(chartModel);
             } else {
-                return chartModel.isNamesLabel() || chartModel.getSeriesCount() > 1;
+                return chartModel.isNamesLabel() || (chartModel.getSeriesCount() > 1);
             }
         }
 
         function isFirstRowCol(chartModel, rowCol) {
-            if (!chartModel) { return null; }
+            if (!chartModel) { return false; }
 
             var possSources = chartModel.getDataSourceInfo();
-            if (possSources.warn) { return null; }
+            if (possSources.warn) { return false; }
             if (possSources.axis) { rowCol = Math.abs(rowCol - 1); }
             if (rowCol === 1) {
                 return chartModel.isTitleLabel();
@@ -338,8 +298,8 @@ define('io.ox/office/spreadsheet/app/drawingcontroller', [
 
             if (possSources.axis) { rowCol = Math.abs(rowCol - 1); }
 
-            var forceTitle;// = undefined;
-            var forceNames;// = undefined;
+            var forceTitle;
+            var forceNames;
             if (rowCol === 1) {
                 forceNames = chartModel.isNamesLabel();
                 forceTitle = value;
@@ -350,25 +310,42 @@ define('io.ox/office/spreadsheet/app/drawingcontroller', [
             return ChartCreator.updateSeries({ app: app, sourceRange: possSources.range, sourceSheet: possSources.sheet, chartModel: chartModel, axis: possSources.axis, forceTitle: forceTitle, forceNames: forceNames });
         }
 
+        function isTitleLabelEnabled(chartModel) {
+            if (chartModel.isTitleLabel()) {
+                return true;
+            }
+            var min = 1;
+            if (chartModel.isAreaOrLine()) { min = 2; }
+            return chartModel.getFirstPointsCount() > min;
+        }
+
+        function exchangeEnabled(chartModel) {
+            var min = 0;
+            if (chartModel.isAreaOrLine()) { min = 1; }
+            return chartModel.getSeriesCount() > min;
+        }
+
         function exchange(chartModel) {
             var possSources = chartModel.getDataSourceInfo();
             if (possSources.warn) {
                 return yellChartDirection(possSources.warn);
             }
-            return ChartCreator.updateSeries({ app: app, sourceRange: possSources.range, sourceSheet: possSources.sheet, chartModel: chartModel, axis: 1 - possSources.axis, forceTitle: chartModel.isNamesLabel(), forceNames: chartModel.isTitleLabel() });
+            var forceTitle = chartModel.isNamesLabel();
+            var forceNames = chartModel.isTitleLabel();
+            return ChartCreator.updateSeries({ app: app, sourceRange: possSources.range, sourceSheet: possSources.sheet, chartModel: chartModel, axis: 1 - possSources.axis, forceTitle: forceTitle, forceNames: forceNames });
         }
 
         function addAxisDef(axisId, defs) {
 
-            var // the base path of axis items
-                keyPath = 'drawing/chart/axis/' + axisId + '/';
+            // the base path of axis items
+            var keyPath = 'drawing/chart/axis/' + axisId + '/';
 
             function getCorrectAxisId(chartModel) {
                 return chartModel ? chartModel.getAxisIdForDrawing(axisId) : axisId;
             }
 
             function getStandardLineAttributes(visible) {
-                return { line: visible ? ChartCreator.getStandardShape() : ChartCreator.getNoneShape() };
+                return { line: visible ? ChartCreator.getStandardShape(docModel) : ChartCreator.getNoneShape() };
             }
 
             function setAxisAttributes(chartModel, attrs) {
@@ -383,27 +360,27 @@ define('io.ox/office/spreadsheet/app/drawingcontroller', [
 
             // parent item providing access to a chart axis model
             defs[keyPath + 'model'] = {
-                parent: ['drawing/chart', 'drawing/chart/axes/enabled'],
+                parent: ['drawing/chart/valid', 'drawing/chart/axes/enabled'],
                 get: function (chartModel) { return chartModel ? chartModel.getAxisModel(getCorrectAxisId(chartModel)) : null; }
             };
 
             // parent item providing access to the attributes of a chart axis model
             defs[keyPath + 'attributes'] = {
-                parent: [keyPath + 'model', 'drawing/chart'],
+                parent: [keyPath + 'model', 'drawing/chart/valid'],
                 get: function (axisModel) { return axisModel ? axisModel.getMergedAttributeSet(true) : null; },
                 set: function (attributes) { return setAxisAttributes(this.getParentValue(1), attributes); }
             };
 
             // return or modify the visibility of the axis caption labels
             defs[keyPath + 'labels/visible'] = {
-                parent: [keyPath + 'attributes', 'drawing/chart'],
+                parent: [keyPath + 'attributes', 'drawing/chart/valid'],
                 get: function (attributes) { return _.isObject(attributes) && (attributes.axis.label === true) && this.areParentsEnabled(); },
                 set: function (visible) { return setAxisAttributes(this.getParentValue(1), { axis: { label: visible } }); }
             };
 
             // return or modify the visibility of the axis line
             defs[keyPath + 'line/visible'] = {
-                parent: [keyPath + 'attributes', 'drawing/chart'],
+                parent: [keyPath + 'attributes', 'drawing/chart/valid'],
                 get: function (attributes) { return _.isObject(attributes) && (attributes.line.type !== 'none'); },
                 set: function (visible) { return setAxisAttributes(this.getParentValue(1), getStandardLineAttributes(visible)); }
             };
@@ -418,14 +395,14 @@ define('io.ox/office/spreadsheet/app/drawingcontroller', [
 
             // parent item providing access to the attributes of a chart axis grid model
             defs[keyPath + 'grid/attributes'] = {
-                parent: [keyPath + 'grid/model', 'drawing/chart'],
+                parent: [keyPath + 'grid/model', 'drawing/chart/valid'],
                 get: function (gridModel) { return gridModel ? gridModel.getMergedAttributeSet(true) : null; },
                 set: function (attributes) { return setGridLineAttributes(this.getParentValue(1), attributes); }
             };
 
             // return or modify the visibility of the axis grid lines
             defs[keyPath + 'grid/visible'] = {
-                parent: [keyPath + 'grid/attributes', 'drawing/chart'],
+                parent: [keyPath + 'grid/attributes', 'drawing/chart/valid'],
                 get: function (attributes) { return _.isObject(attributes) && (attributes.line.type !== 'none'); },
                 set: function (visible) { return setGridLineAttributes(this.getParentValue(1), getStandardLineAttributes(visible)); }
             };
@@ -440,7 +417,7 @@ define('io.ox/office/spreadsheet/app/drawingcontroller', [
 
             // parent item providing access to the attributes of a chart axis title model
             defs[keyPath + 'title/attributes'] = {
-                parent: [keyPath + 'title/model', 'drawing/chart'],
+                parent: [keyPath + 'title/model', 'drawing/chart/valid'],
                 get: function (titleModel) { return titleModel ? titleModel.getMergedAttributeSet(true) : null; },
                 set: function (attributes) {
                     var chartModel = this.getParentValue(1);
@@ -450,7 +427,7 @@ define('io.ox/office/spreadsheet/app/drawingcontroller', [
 
             // return or modify the text contents of a chart axis title
             defs[keyPath + 'title/text'] = {
-                parent: [keyPath + 'title/attributes', 'drawing/chart'],
+                parent: [keyPath + 'title/attributes', 'drawing/chart/valid'],
                 get: function (attributes) { return getChartTitle(attributes); },
                 set: function (title) {
                     var chartModel = this.getParentValue(1);
@@ -460,7 +437,7 @@ define('io.ox/office/spreadsheet/app/drawingcontroller', [
 
             // remove the main title from a chart (disabled if title does not exist)
             defs[keyPath + 'title/delete'] = {
-                parent: [keyPath + 'title/text', 'drawing/chart'],
+                parent: [keyPath + 'title/text', 'drawing/chart/valid'],
                 enable: function () { return this.getValue().length > 0; },
                 set: function () {
                     var chartModel = this.getParentValue(1);
@@ -476,19 +453,8 @@ define('io.ox/office/spreadsheet/app/drawingcontroller', [
         function registerDefinitions() {
             var defs = {};
 
-            defs['image/insert'] = {
-                parent: 'sheet/operation/unlocked',
-                set: function (imageDesc) { return docView.insertImages(imageDesc); }
-            };
-
-            // show image drive, file or url dialog
-            defs['image/insert/dialog'] = {
-                parent: 'sheet/operation/unlocked',
-                set: function (dialogType) { return docView.showInsertImageDialog(dialogType); }
-            };
-
             defs['chart/insert'] = {
-                parent: 'sheet/operation/unlocked',
+                parent: 'drawing/insert/enable',
                 enable: function () {
                     var ranges = docView.getSelectedRanges();
                     return (ranges.length === 1) && !docView.getSheetModel().isSingleCellInRange(ranges[0]);
@@ -496,126 +462,98 @@ define('io.ox/office/spreadsheet/app/drawingcontroller', [
                 set: function (id) { return ChartCreator.createChart(app, DrawingLabels.CHART_TYPE_STYLES[id]); }
             };
 
-            defs['drawing/operation'] = {
-                parent: 'sheet/operation/unlocked',
-                enable: function () { return docView.hasDrawingSelection(); }
-            };
-
-            defs['drawing/model'] = {
-                parent: 'drawing/operation',
-                get: getDrawingModel
-            };
-
-            defs['drawing/type/label'] = {
-                parent: 'drawing/model',
-                get: function (drawingModel) { return DrawingLabels.getDrawingTypeLabel(drawingModel ? drawingModel.getType() : ''); }
-            };
-
-            defs['drawing/delete'] = {
-                parent: 'drawing/operation',
-                set: function () { return docView.deleteDrawings(); }
-            };
-
-            defs['drawing/image'] = {
-                parent: 'drawing/operation',
-                enable: function () { return _.isObject(this.getValue()); },
-                get: function () { return getDrawingModel('image'); }
-            };
-
             defs['drawing/chart'] = {
                 parent: 'drawing/operation',
                 enable: function () { return _.isObject(this.getValue()); },
                 get: function () { return getDrawingModel('chart'); }
             };
 
-            defs['drawing/chartlabels'] = {
+            defs['drawing/chart/valid'] = {
                 parent: 'drawing/chart',
+                enable: function (chartModel) { return chartModel.isSupported(); }
+            };
+
+            defs['drawing/chartlabels'] = {
+                parent: 'drawing/chart/valid',
                 get: function () { return docView.getChartLabelsMenu().isVisible(); },
                 set: function (state) { docView.getChartLabelsMenu().toggle(state); }
             };
 
             defs['drawing/chartexchange'] = {
-                parent: 'drawing/chart',
-                enable: function (chartModel) { return chartModel.getSeriesCount() > 0; },
-                set: function () {
-                    var chart = getDrawingModel('chart');
-                    return exchange(chart);
-                }
+                parent: 'drawing/chart/valid',
+                enable: exchangeEnabled,
+                set: function () { return exchange(this.getParentValue()); }
             };
 
             defs['drawing/chartfirstcol'] = {
-                parent: 'drawing/chart',
+                parent: 'drawing/chart/valid',
                 enable: function (chartModel) { return isFirstRowColEnabled(chartModel, 0); },
                 get: function (chartModel) { return isFirstRowCol(chartModel, 0); },
-                set: function (state) { return setFirstRowCol(getDrawingModel('chart'), 0, state); }
+                set: function (state) { return setFirstRowCol(this.getParentValue(), 0, state); }
             };
 
             defs['drawing/chartfirstrow'] = {
-                parent: 'drawing/chart',
+                parent: 'drawing/chart/valid',
                 enable: function (chartModel) { return isFirstRowColEnabled(chartModel, 1); },
                 get: function (chartModel) { return isFirstRowCol(chartModel, 1); },
-                set: function (state) { return setFirstRowCol(getDrawingModel('chart'), 1, state); }
+                set: function (state) { return setFirstRowCol(this.getParentValue(), 1, state); }
             };
 
             defs['drawing/charttype'] = {
-                parent: 'drawing/chart',
+                parent: 'drawing/chart/valid',
                 get: function (chartModel) { return chartModel ? chartModel.getChartTypeForGui() : null; },
                 set: changeChartType
             };
 
             // parent item providing access to the attributes of a chart model
             defs['drawing/chart/attributes'] = {
-                parent: 'drawing/chart',
-                get: function (chartModel) { return chartModel ? chartModel.getMergedAttributeSet(true) : null; },
-                set: function (attributes) { this.getParentValue().setAttributes(attributes); }
+                parent: 'drawing/chart/valid',
+                get: function (chartModel) { return chartModel ? chartModel.getMergedAttributeSet(true) : null; }
             };
 
             defs['drawing/chartvarycolor'] = {
-                parent: ['drawing/chart', 'drawing/chart/attributes'],
+                parent: ['drawing/chart/valid', 'drawing/chart/attributes'],
                 enable: function (chartModel) { return chartModel.isVaryColorEnabled(); },
-                get: function (chartModel, attributes) { return attributes ? attributes.chart.varyColors : null; },
-                set: function (state) { this.getParentValue().changeVaryColors(state); }
+                get: function (chartModel) { return chartModel ? chartModel.isVaryColor() : null; },
+                set: function (state) { return this.getParentValue().changeVaryColors(state); }
             };
 
             defs['drawing/chartdatalabel'] = {
-                parent: ['drawing/chart', 'drawing/chart/attributes'],
-                get: function (chartModel, attributes) { return attributes ? attributes.chart.dataLabel : false; },
-                set: function (state) { return createAndApplyChartOperation(this.getParentValue(), Operations.SET_DRAWING_ATTRIBUTES, { attrs: { chart: { dataLabel: state } } }); }
-            };
-
-            defs['drawing/chartmarkeronly'] = {
-                parent: ['drawing/chart'],
-                enable: function (chartModel) { var data = chartModel ? chartModel.getMergedAttributeSet(true).chart : {}; return data.type === 'line2d' || data.type === 'scatter2d'; },
-                get: function (chartModel) { return chartModel ? chartModel.isMarkerOnly() : false; },
-                set: function (state) { this.getParentValue().setMarkerOnly(state); }
+                parent: 'drawing/chart/valid',
+                get: function (chartModel) { return chartModel ? (!_.isEmpty(chartModel.getDataLabel())) : null; },
+                set: function (state) { return this.getParentValue().setDataLabel(state); }
             };
 
             defs['drawing/chartcolorset'] = {
-                parent: 'drawing/chart',
+                parent: 'drawing/chart/valid',
                 get: function (chartModel) { return chartModel ? chartModel.getColorSet() : null; },
-                set: function (colorset) { this.getParentValue().changeColorSet(colorset); }
+                set: function (colorset) { return this.getParentValue().changeColorSet(colorset); }
             };
 
             defs['drawing/chartstyleset'] = {
-                parent: 'drawing/chart',
+                parent: 'drawing/chart/valid',
                 get: function (chartModel) { return chartModel ? chartModel.getStyleSet() : null; },
-                set: function (colorset) { this.getParentValue().changeStyleSet(colorset); }
+                set: function (colorset) { return this.getParentValue().changeStyleSet(colorset); }
+            };
+
+            defs['drawing/chartdatasource'] = {
+                parent: 'drawing/chart/valid'
             };
 
             defs['drawing/chartsource'] = {
-                parent: 'drawing/chart',
+                parent: 'drawing/chart/valid',
                 get: function () { return sourceSelector; },
                 set: selectNewChartSource
             };
 
             defs['drawing/chartlegend/pos'] = {
-                parent: 'drawing/chart',
+                parent: 'drawing/chart/valid',
                 get: function (chartModel) { return chartModel ? chartModel.getLegendModel().getMergedAttributeSet(true).legend.pos : null; },
                 set: function (pos) { return createAndApplyChartOperation(this.getParentValue(), Operations.SET_CHART_LEGEND_ATTRIBUTES, { attrs: { legend: { pos: pos } } }); }
             };
 
             defs['drawing/chart/axes/enabled'] = {
-                parent: 'drawing/chart',
+                parent: 'drawing/chart/valid',
                 enable: function (chartModel) { return chartModel.isAxesEnabled(); }
             };
 
@@ -624,63 +562,31 @@ define('io.ox/office/spreadsheet/app/drawingcontroller', [
 
             // parent item providing access to the main title model of a chart
             defs['drawing/chart/title/model'] = {
-                parent: 'drawing/chart',
+                parent: 'drawing/chart/valid',
                 get: function (chartModel) { return chartModel ? chartModel.getTitleModel('main') : null; }
             };
 
             // parent item providing access to the attributes of the main title model of a chart
             defs['drawing/chart/title/attributes'] = {
-                parent: ['drawing/chart/title/model', 'drawing/chart'],
+                parent: ['drawing/chart/title/model', 'drawing/chart/valid'],
                 get: function (titleModel) { return titleModel ? titleModel.getMergedAttributeSet(true) : null; },
                 set: function (attributes) { return setChartTitleAttributes(this.getParentValue(1), 'main', attributes); }
             };
 
             // return or modify the text contents of the main title of a chart
             defs['drawing/chart/title/text'] = {
-                parent: ['drawing/chart/title/attributes', 'drawing/chart'],
+                parent: ['drawing/chart/title/attributes', 'drawing/chart/valid'],
                 get: function (attributes) { return getChartTitle(attributes); },
                 set: function (title) { return setChartTitle(this.getParentValue(1), 'main', title); }
             };
 
             // remove the main title from a chart (disabled if title does not exist)
             defs['drawing/chart/title/delete'] = {
-                parent: ['drawing/chart/title/text', 'drawing/chart'],
+                parent: ['drawing/chart/title/text', 'drawing/chart/valid'],
                 enable: function () { return this.getValue().length > 0; },
                 set: function () { return setChartTitle(this.getParentValue(1), 'main', ''); }
             };
 
-            // IMAGE
-
-            defs['drawing/border/style'] = {
-                parent: 'drawing/image',
-                get: function (imageModel) { return DrawingUtils.getPresetBorder(imageModel ? imageModel.getMergedAttributeSet(true).line : null); },
-                set: function (preset) {
-                    var attributes = this.getParentValue().getMergedAttributeSet(true),
-                        options = { line: DrawingUtils.resolvePresetBorder(preset) };
-
-                    if (attributes.line.color.type === 'auto') {
-                        options.line.color = { type: 'rgb', value: '000000' };
-                    }
-
-                    return docView.changeDrawings(options);
-                }
-            };
-
-            defs['drawing/border/color'] = {
-                parent: 'drawing/image',
-                get: function (imageModel) { return imageModel ? imageModel.getMergedAttributeSet(true).line.color : Color.AUTO; },
-                set: function (color) {
-                    var attributes = this.getParentValue().getMergedAttributeSet(true),
-                        options = { line: { color: color } };
-
-                    if (attributes.line.type !== 'solid') {
-                        options.line.type = 'solid';
-                    }
-
-                    return docView.changeDrawings(options);
-                }
-            };
-
             self.registerDefinitions(defs);
         }
 
@@ -688,10 +594,8 @@ define('io.ox/office/spreadsheet/app/drawingcontroller', [
 
         registerDefinitions();
 
-        this.listenTo(docView, 'change:selection', changeSelectionHandler);
-
         this.registerDestructor(function () {
-            self = app = docModel = docView = chartSourceToken = tokenArrays = null;
+            self = app = docModel = docView = null;
         });
 
     } // class DrawingControllerMixin
