@@ -16,27 +16,30 @@ define('io.ox/office/spreadsheet/controller/controller', [
     'io.ox/office/tk/utils',
     'io.ox/office/editframework/utils/mixedborder',
     'io.ox/office/editframework/app/editcontroller',
-    'io.ox/office/spreadsheet/utils/config',
-    'io.ox/office/spreadsheet/utils/sheetutils',
     'io.ox/office/spreadsheet/utils/paneutils',
     'io.ox/office/spreadsheet/app/drawingcontroller',
+    'io.ox/office/spreadsheet/controller/viewmixin',
     'io.ox/office/spreadsheet/controller/searchmixin',
-    'io.ox/office/spreadsheet/controller/sortmixin'
-], function (Utils, MixedBorder, EditController, Config, SheetUtils, PaneUtils, DrawingControllerMixin, SearchMixin, SortMixin) {
+    'io.ox/office/spreadsheet/controller/sheetmixin',
+    'io.ox/office/spreadsheet/controller/sortmixin',
+    'io.ox/office/spreadsheet/controller/namemixin',
+    'io.ox/office/spreadsheet/controller/tablemixin',
+    'io.ox/office/spreadsheet/controller/drawingmixin'
+], function (Utils, MixedBorder, EditController, PaneUtils, DrawingControllerMixin, ViewMixin, SearchMixin, SheetMixin, SortMixin, NameMixin, TableMixin, DrawingMixin) {
 
     'use strict';
 
     // class SpreadsheetController ============================================
 
     /**
-     * The controller of a OX Spreadsheet application.
+     * The controller of a spreadsheet application.
      *
      * @constructor
      *
      * @extends EditController
      * @extends DrawingControllerMixin
      */
-    function SpreadsheetController(app, docModel, docView) {
+    var SpreadsheetController = EditController.extend({ constructor: function (app, docModel, docView) {
 
         // self reference
         var self = this;
@@ -45,8 +48,13 @@ define('io.ox/office/spreadsheet/controller/controller', [
 
         EditController.call(this, app, docModel, docView, searchHandler);
         DrawingControllerMixin.call(this, app, docModel, docView);
-        SearchMixin.call(this, app, docView);
-        SortMixin.call(this, app, docView);
+        ViewMixin.call(this, docView);
+        SearchMixin.call(this, docView);
+        SheetMixin.call(this, docView);
+        SortMixin.call(this, docView);
+        NameMixin.call(this, docView);
+        TableMixin.call(this, docView);
+        DrawingMixin.call(this, docView);
 
         // private methods ----------------------------------------------------
 
@@ -58,224 +66,136 @@ define('io.ox/office/spreadsheet/controller/controller', [
             return self.executeSearchCommand(command, settings);
         }
 
-        // initialization -----------------------------------------------------
+        /**
+         * Returns the merged formatting attributes of the current selection.
+         * According to the current selection mode and text edit mode, the
+         * following attributes will be returned:
+         *  (1) Cell selection mode: The attribute set of the active cell.
+         *  (2) Cell edit mode: The attribute set of the edited cell, including
+         *      pending edit attributes.
+         *  (3) Drawing selection mode: The mixed attribute set of all selected
+         *      drawing objects with text contents.
+         *  (4) Drawing edit mode: The mixed attribute set of the current text
+         *      selection in the edited drawing object.
+         *
+         * @returns {Object}
+         *  The merged formatting attributes of the current selection.
+         */
+        function getActiveAttributeSet() {
+
+            // return the formatting attributes of the active text editor
+            var textEditor = docView.getActiveTextEditor();
+            if (textEditor) { return textEditor.getAttributeSet(); }
+
+            // selected drawings: return the mixed attributes of the text framework selection
+            if (docView.hasDrawingSelection()) {
+                return docView.getTextAttributeSet();
+            }
+
+            // otherwise, return attribute set of the active cell
+            return docView.getCellCollection().getAttributeSet(docView.getActiveCell());
+        }
+
+        /**
+         * Changes the formatting attributes of the current selection.
+         * According to the current selection mode and text edit mode, the
+         * following attributes will be changed:
+         *  (1) Cell selection mode: All selected cells.
+         *  (2) Cell edit mode: The pending edit attributes of the edited cell.
+         *  (3) Drawing selection mode: All selected drawing objects with text
+         *      contents.
+         *  (4) Drawing edit mode: The current text selection in the edited
+         *      drawing object.
+         *
+         * @param {Object} attributeSet
+         *  An incomplete attribute set that will be applied to the current
+         *  selection.
+         *
+         * @returns {jQuery.Promise}
+         *  A promise that will be resolved when the passed attributes have
+         *  been applied successfully.
+         */
+        function setAttributeSet(attributeSet) {
+
+            // send the formatting attributes to the active text editor
+            var textEditor = docView.getActiveTextEditor();
+            if (textEditor) { return textEditor.setAttributeSet(attributeSet); }
+
+            // selected drawings: send the attributes to the text framework
+            if (docView.hasDrawingSelection()) {
+                return docView.setTextAttributeSet(attributeSet);
+            }
+
+            // otherwise, fill the entire cell selection with the attributes
+            return docView.fillRangeContents({ a: attributeSet });
+        }
+
+        /**
+         * Changes the character formatting of the current selection. See
+         * method SpreadsheetController.setAttributeSet() for details.
+         *
+         * @param {Object} charAttrs
+         *  The character attributes (simple key/value map) that will be
+         *  applied to the current selection.
+         *
+         * @returns {jQuery.Promise}
+         *  A promise that will be resolved when the passed attributes have
+         *  been applied successfully.
+         */
+        function setCharacterAttributes(charAttrs) {
+            return setAttributeSet({ character: charAttrs });
+        }
+
+        /**
+         * Returns the list style identifier for the passed mixed paragraph
+         * attributes.
+         *
+         * @param {String} listType
+         *  The list type, either 'bullet' or 'numbering'.
+         *
+         * @param {Object} paraAttrs
+         *  The mixed paragraph attributes.
+         *
+         * @returns {String|Null}
+         *  The list style identifier for the passed paragraph attributes.
+         */
+        function getListStyleId(listType, paraAttrs) {
+            return _.isEmpty(paraAttrs) ? '' : docModel.getEffectiveListStyleId(listType, paraAttrs);
+        }
+
+        // item registration --------------------------------------------------
 
         // register all controller items
         this.registerDefinitions({
 
             // selection mode -------------------------------------------------
 
-            // enabled if the document is editable, and no drawing objects are selected
+            // enabled if the document is editable, and cell selection mode is active (no drawing objects are selected)
             'document/editable/cell': {
-                parent: 'document/editable',
-                enable: function () { return !docView.hasDrawingSelection(); }
-            },
-
-            // enabled if the document is editable, and at least one drawing object is selected
-            'document/editable/drawing': {
-                parent: 'document/editable',
-                enable: function () { return docView.hasDrawingSelection(); }
+                parent: ['document/editable/worksheet', 'view/selection/cell']
             },
 
+            // enabled if the document is in read-only state, and cell selection mode is active (no drawing objects are selected)
             'document/readonly/cell': {
-                parent: 'document/readonly',
-                enable: function () { return !docView.hasDrawingSelection(); }
+                parent: ['document/readonly/worksheet', 'view/selection/cell']
             },
 
-            // document view --------------------------------------------------
-
-            // parent item, enabled if the in-place cell edit mode is NOT active
-            'view/cell/editmode/off': {
-                parent: 'app/valid',
-                enable: function () { return !docView.isCellEditMode(); }
-            },
-
-            'view/statuspane/show': {
-                parent: 'app/valid',
-                get: function () { return docView.getStatusPane().isVisible(); },
-                set: function (state) { docView.getStatusPane().toggle(state); }
-            },
-
-            // index of the active sheet in the array of visible sheets (not model sheet index!)
-            'view/sheet/active': {
-                parent: 'app/valid',
-                get: function () { return docView.getActiveSheet({ visible: true }); },
-                set: function (index) { docView.setActiveSheet(index, { visible: true }); }
-            },
-
-            'view/sheet/prev': {
-                parent: 'app/valid',
-                enable: function () { return docView.getActiveSheet({ visible: true }) > 0; },
-                set: function () { docView.activatePreviousSheet(); },
-                shortcut: { keyCode: 'PAGE_UP', ctrlOrMeta: true, alt: true }
-            },
-
-            'view/sheet/next': {
-                parent: 'app/valid',
-                enable: function () { return docView.getActiveSheet({ visible: true }) + 1 < docView.getVisibleSheetCount(); },
-                set: function () { docView.activateNextSheet(); },
-                shortcut: { keyCode: 'PAGE_DOWN', ctrlOrMeta: true, alt: true }
-            },
-
-            'view/subtotals/type': {
-                parent: 'app/valid',
-                enable: function () {
-                    var subtotals = docView.getSubtotalResult();
-                    return (subtotals.cells > 1) && (this.getValue() in subtotals);
-                },
-                get: function () { return app.getUserSettingsValue('subtotalType', 'sum'); },
-                set: function (subtotalType) { app.setUserSettingsValue('subtotalType', subtotalType); }
-            },
-
-            'view/status': {
-                parent: 'app/valid',
-                enable: function () { return _.isString(docView.getStatusLabel()); },
-                get: function () { return docView.getStatusLabel(); }
-            },
-
-            'view/formula': {
-                parent: 'view/cell/editmode/off',
-                enable: function () { return docView.isSingleCellSelection() && !docView.hasDrawingSelection() && (this.getValue() !== null); },
-                get: function () { return docView.getActiveTokenDesc(); }
-            },
-
-            'view/sheet/more': {
-                parent: 'app/valid'
-            },
-
-            'view/grid/show': {
-                parent: 'app/valid',
-                get: function () { return docView.getSheetViewAttribute('showGrid'); },
-                set: function (state) { docView.setSheetViewAttribute('showGrid', state); }
-            },
-
-            'view/split/dynamic': {
-                parent: 'view/cell/editmode/off',
-                get: function () { return docView.hasDynamicSplit(); },
-                set: function (state) { docView.setDynamicSplit(state); }
-            },
-
-            'view/split/frozen': {
-                parent: 'view/cell/editmode/off',
-                get: function () { return docView.hasFrozenSplit(); },
-                set: function (value) {
-                    if (value === 'toggle') { value = !docView.hasFrozenSplit(); }
-                    docView.setFrozenSplit(value);
-                }
-            },
-
-            'view/split/frozen/fixed': {
-                parent: 'view/cell/editmode/off',
-                set: function (value) { docView.setFixedFrozenSplit(value.cols, value.rows); }
-            },
-
-            'view/zoom': {
-                parent: 'app/valid',
-                get: function () { return docView.getZoom(); },
-                set: function (zoom) { docView.setZoom(zoom); }
-            },
-
-            'view/zoom/dec': {
-                parent: 'view/zoom',
-                enable: function (zoom) { return zoom > SheetUtils.MIN_ZOOM; },
-                set: function () { docView.decZoom(); }
-            },
-
-            'view/zoom/inc': {
-                parent: 'view/zoom',
-                enable: function (zoom) { return zoom < SheetUtils.MAX_ZOOM; },
-                set: function () { docView.incZoom(); }
-            },
-
-            // document operations --------------------------------------------
-
-            'document/formula/recalcall': {
-                parent: 'document/editable',
-                set: function () { return docModel.getDependencyManager().recalcFormulas({ all: true }); }
+            // enabled if the document is editable, and at least one drawing object is selected;
+            // item value is the drawing selection (array of drawing positions)
+            'document/editable/drawing': {
+                parent: ['document/editable/worksheet', 'view/selection/drawing'],
+                get: function () { return docView.getSelectedDrawings(); }
             },
 
             // sheet operations -----------------------------------------------
 
-            'sheet/attributes': {
-                parent: 'document/editable',
-                get: function () { return docView.getSheetAttributeSet(true).sheet; }
-            },
-
-            'sheet/visible': {
-                parent: 'sheet/attributes',
-                enable: function () { return docView.getVisibleSheetCount() > 1; },
-                get: function (attributes) { return attributes.visible; },
-                set: function (visible) { return docView.changeSheet({ sheet: { visible: visible } }); }
-            },
-
-            'sheet/unhide': {
-                parent: 'document/editable',
-                enable: function () { return docView.getHiddenSheetCount() > 0; },
-                set: function () { return docView.showUnhideSheetsDialog(); }
-            },
-
-            'sheet/showall': {
-                parent: 'document/editable',
-                enable: function () { return docView.getHiddenSheetCount() > 0; },
-                set: function () { return docView.showAllSheets(); }
-            },
-
-            'sheet/insert': {
-                parent: 'document/editable',
-                enable: function () { return docModel.getSheetCount() < Config.MAX_SHEET_COUNT; },
-                set: function () { return docView.insertSheet(); }
-            },
-
-            'sheet/delete': {
-                parent: 'document/editable',
-                enable: function () { return docView.getVisibleSheetCount() > 1; },
-                set: function () { return docView.deleteSheet(); }
-            },
-
-            'sheet/name': {
-                parent: 'document/editable',
-                get: function () { return docView.getSheetName(); },
-                set: function (sheetName) { return docView.renameSheet(sheetName); }
-            },
-
-            'sheet/rename/dialog': {
-                parent: 'sheet/name',
-                set: function () { return docView.showRenameSheetDialog(); }
-            },
-
-            'sheet/copy/dialog': {
-                parent: ['sheet/insert', 'document/ooxml'],
-                set: function () { return docView.showCopySheetDialog(); }
-            },
-
-            'sheet/move': {
-                parent: 'document/editable',
-                set: function (data) { return docView.moveSheet(data.from, data.to); }
-            },
-
-            'sheet/reorder/dialog': {
-                parent: 'document/editable',
-                enable: function () { return docView.getVisibleSheetCount() > 1; },
-                set: function () { return docView.showReorderSheetsDialog(); }
-            },
-
             // Parent item for various sheet-level operations in the active sheet, enabled if:
-            // - document is in edit mode,
-            // - in-place cell edit mode is not active,
-            // - the active sheet is not locked.
-            // The type of the selection (cells or drawing objects) does not matter.
-            'sheet/operation/unlocked': {
-                parent: ['document/editable', 'view/cell/editmode/off'],
-                enable: function () { return !docView.isSheetLocked(); }
-            },
-
-            // Parent item for various sheet-level operations in the active sheet, enabled if:
-            // - document is in edit mode,
+            // - document is editable,
             // - cell selection (no drawing selection),
-            // - in-place cell edit mode is not active.
+            // - text edit mode is not active.
             // Note that the active sheet may be locked.
             'sheet/operation/cell': {
-                parent: ['document/editable/cell', 'view/cell/editmode/off']
+                parent: ['document/editable/cell', 'view/editmode/off']
             },
 
             // Parent item for various sheet-level operations in the active sheet. Works similar
@@ -298,57 +218,6 @@ define('io.ox/office/spreadsheet/controller/controller', [
                 set: function () { return docView.deleteHyperlink(); }
             },
 
-            // defined names operations ---------------------------------------
-
-            'names/menu/toggle': {
-                parent: 'document/editable/cell',
-                get: function () { return docView.getDefinedNamesMenu().isVisible(); },
-                set: function (state) { docView.getDefinedNamesMenu().toggle(state); }
-            },
-
-            'name/insert/dialog': {
-                parent: 'sheet/operation/unlocked/cell',
-                set: function () { return docView.showInsertNameDialog(); }
-            },
-
-            'name/edit/dialog': {
-                parent: 'sheet/operation/unlocked/cell',
-                set: function (label) { return docView.showChangeNameDialog(label); }
-            },
-
-            'name/delete': {
-                parent: 'sheet/operation/unlocked/cell',
-                set: function (label) { return docView.deleteName(label); }
-            },
-
-            // table operations -----------------------------------------------
-
-            // toggles the table filter, if a table is selected in the active
-            // sheet, otherwise toggles the auto filter of the active sheet
-            'table/filter': {
-                parent: 'sheet/operation/unlocked/cell',
-                // TODO: filtering real tables has been disabled, until OOXML filter supports import/export of filter settings
-                enable: function () { return !docView.isRealTableSelected(); },
-                get: function () { return docView.hasTableFilter(); },
-                set: function (state) { return docView.toggleTableFilter(state); },
-                alwaysDirty: true // bug 49541: TODO: rework refreshing toggle buttons when actions fails (back to old state)
-            },
-
-            // refreshes the filter and sorting of the selected table range
-            'table/refresh': {
-                parent: 'sheet/operation/unlocked/cell',
-                enable: function () { return docView.canRefreshTable(); },
-                set: function () { return docView.refreshTable(); }
-            },
-
-            // Applies formatting attributes for the specified table column.
-            // Expected value is an object with the properties 'tableName', 'tableCol',
-            // and 'attributes' (incomplete attribute set with filter and sorting attributes).
-            'table/column/attributes': {
-                parent: 'sheet/operation/unlocked/cell',
-                set: function (data) { return docView.changeTableColumn(data.tableName, data.tableCol, data.attributes); }
-            },
-
             // column operations ----------------------------------------------
 
             // parent item to get the mixed column attributes
@@ -456,7 +325,7 @@ define('io.ox/office/spreadsheet/controller/controller', [
             },
 
             'function/insert/dialog': {
-                parent: 'sheet/operation/cell', // can be used in locked sheets
+                parent: 'document/editable/cell', // can be used in locked sheets
                 set: function () { return docView.showInsertFunctionDialog(); }
             },
 
@@ -487,7 +356,7 @@ define('io.ox/office/spreadsheet/controller/controller', [
                 parent: 'sheet/operation/unlocked/cell',
                 enable: function () { return docView.hasAnyRangeSelected(); },
                 get: function () { return docView.hasMergedRangeSelected(); },
-                set: function (type) { return docView.mergeRanges(type); }
+                set: function (mergeMode) { return docView.mergeRanges(mergeMode); }
             },
 
             'cell/autofill': {
@@ -496,59 +365,97 @@ define('io.ox/office/spreadsheet/controller/controller', [
             },
 
             'cell/autoformula': {
-                parent: 'sheet/operation/cell', // can be used in locked sheets
+                parent: 'document/editable/cell', // can be used in locked sheets
                 enable: function () { return docView.getSelectedRanges().length === 1; },
                 set: function (funcName) { return docView.insertAutoFormula(funcName); }
             },
 
+            // formatting attributes ------------------------------------------
+
+            // Parent iten for the attribute set of the current selection:
+            // (1) Cell selection mode: The attribute set of the active cell.
+            // (2) Cell edit mode: The attribute set of the edited cell (including pending edit attributes).
+            // (3) Drawing selection mode: The mixed attribute set of all drawing objects with text contents.
+            // (4) Drawing edit mode: The mixed attribute set of the text selection in the edited drawing object.
+            'document/attributes': {
+                parent: 'document/editable/worksheet',
+                enable: function () { return this.getValue() !== null; },
+                get: getActiveAttributeSet
+            },
+
             // cell attributes ------------------------------------------------
 
             'cell/attributes': {
                 parent: 'document/editable/cell',
-                get: function () { return docView.getActiveAttributeSet(); },
+                get: function () { return docView.getCellCollection().getAttributeSet(docView.getActiveCell()); },
                 set: function (attributes) { return docView.fillRangeContents({ a: attributes }); }
             },
 
             'cell/stylesheet': {
-                parent: ['cell/attributes', 'view/cell/editmode/off'],
+                parent: ['cell/attributes', 'view/editmode/off'],
                 get: function (attributes) { return attributes.styleId; },
                 set: function (styleId) { return docView.fillRangeContents({ a: { styleId: styleId } }); }
             },
 
-            'cell/attributes/clear': {
-                parent: ['cell/attributes', 'view/cell/editmode/off'],
+            // reset all explicit attributes in the selection (item key predetermined by text framework!)
+            'character/reset': {
+                parent: ['cell/attributes', 'view/editmode/off'],
                 set: function () { return docView.fillRangeContents({ s: '' }); }
             },
 
             // cell attributes (family 'cell') ----------------------------
 
             'cell/attributes/cell': {
-                parent: ['cell/attributes', 'view/cell/editmode/off'],
-                get: function (attributes) { return attributes.cell; }
+                parent: ['cell/attributes', 'view/editmode/off'],
+                get: function (attributes) { return attributes.cell || {}; }
             },
 
             'cell/fillcolor': {
                 parent: 'cell/attributes/cell',
                 get: function (attributes) { return attributes.fillColor; },
-                set: function (color) { return docView.setCellAttribute('fillColor', color); }
+                set: function (color) { return docView.setCellAttributes({ fillType: 'solid', fillColor: color }); }
             },
 
             'cell/linebreak': {
                 parent: 'cell/attributes/cell',
                 get: function (attributes) { return attributes.wrapText; },
-                set: function (wrap) { return docView.setCellAttribute('wrapText', wrap); }
+                set: function (wrap) { return docView.setCellAttributes({ wrapText: wrap }); }
+            },
+
+            'cell/unlocked': {
+                parent: 'cell/attributes/cell',
+                enable: function (attributes) { return !attributes.unlocked && !docView.isSheetLocked(); },
+                set: function () { return docView.setCellAttributes({ unlocked: true }); }
+            },
+
+            'cell/locked': {
+                parent: 'cell/attributes/cell',
+                enable: function (attributes) { return attributes.unlocked && !docView.isSheetLocked(); },
+                set: function () { return docView.setCellAttributes({ unlocked: false }); }
+            },
+
+            'cell/unhideformula': {
+                parent: 'cell/attributes/cell',
+                enable: function (attributes) { return attributes.hidden && !docView.isSheetLocked(); },
+                set: function () { return docView.setCellAttributes({ hidden: false }); }
+            },
+
+            'cell/hideformula': {
+                parent: 'cell/attributes/cell',
+                enable: function (attributes) { return !attributes.hidden && !docView.isSheetLocked(); },
+                set: function () { return docView.setCellAttributes({ hidden: true }); }
             },
 
             'cell/alignhor': {
                 parent: 'cell/attributes/cell',
                 get: function (attributes) { return attributes.alignHor; },
-                set: function (alignment) { return docView.setCellAttribute('alignHor', alignment); }
+                set: function (alignment) { return docView.setCellAttributes({ alignHor: alignment }); }
             },
 
             'cell/alignvert': {
                 parent: 'cell/attributes/cell',
                 get: function (attributes) { return attributes.alignVert; },
-                set: function (alignment) { return docView.setCellAttribute('alignVert', alignment); }
+                set: function (alignment) { return docView.setCellAttributes({ alignVert: alignment }); }
             },
 
             // border mode, as Boolean map with position keys (left, top, ...)
@@ -572,7 +479,7 @@ define('io.ox/office/spreadsheet/controller/controller', [
 
             // a single mixed border for all borders in the selection
             'cell/border/value': {
-                parent: ['cell/border/visible', 'view/cell/editmode/off'],
+                parent: ['cell/border/visible', 'view/editmode/off'],
                 get: function (borderAttributes) { return MixedBorder.mixBorders(_.values(borderAttributes)); }
             },
 
@@ -625,85 +532,136 @@ define('io.ox/office/spreadsheet/controller/controller', [
 
             // cell attributes (family 'character') ---------------------------
 
-            // also enabled in in-place cell edit mode
-            'cell/attributes/character': {
-                parent: 'cell/attributes',
-                get: function (attributes) { return attributes.character; }
+            'document/attributes/character': {
+                parent: 'document/attributes',
+                get: function (attributes) { return attributes.character || {}; }
             },
 
             'character/bold': {
-                parent: 'cell/attributes/character',
+                parent: 'document/attributes/character',
                 get: function (attributes) { return attributes.bold; },
-                set: function (state) { return docView.setCharacterAttribute('bold', state); },
+                set: function (state) { return setCharacterAttributes({ bold: state }); },
                 shortcut: { keyCode: 'B', ctrlOrMeta: true, value: function (state) { return !state; } }
             },
 
             'character/italic': {
-                parent: 'cell/attributes/character',
+                parent: 'document/attributes/character',
                 get: function (attributes) { return attributes.italic; },
-                set: function (state) { return docView.setCharacterAttribute('italic', state); },
+                set: function (state) { return setCharacterAttributes({ italic: state }); },
                 shortcut: { keyCode: 'I', ctrlOrMeta: true, value: function (state) { return !state; } }
             },
 
             'character/underline': {
-                parent: 'cell/attributes/character',
+                parent: 'document/attributes/character',
                 get: function (attributes) { return attributes.underline; },
-                set: function (state) { return docView.setCharacterAttribute('underline', state); },
+                set: function (state) { return setCharacterAttributes({ underline: state }); },
                 shortcut: { keyCode: 'U', ctrlOrMeta: true, value: function (state) { return !state; } }
             },
 
             'character/strike': {
-                parent: 'cell/attributes/character',
+                parent: 'document/attributes/character',
                 get: function (attributes) { return _.isString(attributes.strike) ? (attributes.strike !== 'none') : null; },
-                set: function (state) { return docView.setCharacterAttribute('strike', state ? 'single' : 'none'); }
+                set: function (state) { return setCharacterAttributes({ strike: state ? 'single' : 'none' }); }
             },
 
             'character/color': {
-                parent: 'cell/attributes/character',
+                parent: 'document/attributes/character',
                 get: function (attributes) { return attributes.color; },
-                set: function (color) { return docView.setCharacterAttribute('color', color); }
+                set: function (color) { return setCharacterAttributes({ color: color }); }
+            },
+
+            'character/fillcolor': {
+                parent: 'document/attributes/character',
+                enable: _.constant(false) // TODO
             },
 
             'character/fontname': {
-                parent: 'cell/attributes/character',
+                parent: 'document/attributes/character',
                 get: function (attributes) { return attributes.fontName; },
-                set: function (fontName) { return docView.setCharacterAttribute('fontName', fontName); }
+                set: function (fontName) { return setCharacterAttributes({ fontName: fontName }); }
             },
 
             'character/fontsize': {
-                parent: 'cell/attributes/character',
+                parent: 'document/attributes/character',
                 get: function (attributes) { return attributes.fontSize; },
-                set: function (fontSize) { return docView.setCharacterAttribute('fontSize', fontSize); }
+                set: function (fontSize) { return setCharacterAttributes({ fontSize: fontSize }); }
             },
 
-            'character/format': {
-                parent: 'app/valid'
+            'character/vertalign': {
+                parent: 'document/attributes/character',
+                enable: _.constant(false) // TODO
             },
 
-            // debugging ------------------------------------------------------
+            // paragraph attributes (family 'paragraph' in shape text) --------
 
-            'debug/highlight/formulas': {
-                parent: 'debug/enabled',
-                get: function () { return docView.isHighlightFormulasMode(); },
-                set: function (enable) { docView.setHighlightFormulasMode(enable); }
+            'document/attributes/paragraphs': {
+                parent: ['document/attributes', 'view/selection/drawing'],
+                get: function (attributes) { return attributes.paragraph || {}; }
+            },
+
+            'paragraph/alignment': {
+                parent: 'document/attributes/paragraphs',
+                get: function (attributes) { return attributes.alignment; },
+                set: function (alignment) { docModel.setAttribute('paragraph', 'alignment', alignment); }
+            },
+
+            'paragraph/lineheight': {
+                parent: 'document/attributes/paragraphs',
+                get: function (attributes) { return attributes.lineHeight; },
+                set: function (lineHeight) { docModel.setAttribute('paragraph', 'lineHeight', lineHeight); }
+            },
+
+            'paragraph/spacing': {
+                parent: 'document/attributes/paragraphs',
+                get: function (attributes) { return docModel.getParagraphSpacing(attributes); },
+                set: function (multiplier) { return docModel.setParagraphSpacing(multiplier); }
+            },
+
+            // toggle default bullet list, or select bullet type
+            'paragraph/list/bullet': {
+                parent: 'document/attributes/paragraphs',
+                enable: function () { return !app.isODF(); },
+                get: function (attributes) { return getListStyleId('bullet', attributes); },
+                set: function (value) { docModel.setListStyleId('bullet', value, this.getValue()); }
+            },
+
+            // toggle default numbered list, or select numbering type
+            'paragraph/list/numbered': {
+                parent: 'document/attributes/paragraphs',
+                enable: function () { return !app.isODF(); },
+                get: function (attributes) { return getListStyleId('numbering', attributes); },
+                set: function (value) { docModel.setListStyleId('numbering', value, this.getValue()); }
+            },
+
+            // increase list level by one
+            'paragraph/list/incindent': {
+                parent: 'document/attributes/paragraphs',
+                enable: function (paraAttrs) { return !app.isODF() && docModel.isListIndentChangeable(paraAttrs, { increase: true }); },
+                set: function () { docModel.changeListIndent({ increase: true, validatedLevel: true }); }
+            },
+
+            // decrease list level by one
+            'paragraph/list/decindent': {
+                parent: 'document/attributes/paragraphs',
+                enable: function (paraAttrs) { return !app.isODF() && docModel.isListIndentChangeable(paraAttrs, { increase: false }); },
+                set: function () { docModel.changeListIndent({ increase: false, validatedLevel: true }); }
             }
         });
 
-        // update GUI after changed selection, and after receiving view updates
-        this.listenTo(docView, 'change:sheet:viewattributes update:selection:data celledit:enter celledit:change celledit:leave', function () {
-            self.update();
-        });
+        // initialization -----------------------------------------------------
+
+        // update GUI after changed text selection in drawing objects
+        this._updateOnEvent(docModel, 'selection');
 
         // destroy all class members on destruction
         this.registerDestructor(function () {
             self = app = docModel = docView = null;
         });
 
-    } // class SpreadsheetController
+    } }); // class SpreadsheetController
 
     // exports ================================================================
 
-    // derive this class from class EditController
-    return EditController.extend({ constructor: SpreadsheetController });
+    return SpreadsheetController;
 
 });
