@@ -14,12 +14,12 @@
 
 define('io.ox/office/spreadsheet/model/cellautostylecollection', [
     'io.ox/office/tk/utils',
-    'io.ox/office/tk/container/simplemap',
+    'io.ox/office/tk/container/valuemap',
     'io.ox/office/editframework/utils/border',
     'io.ox/office/editframework/utils/attributeutils',
     'io.ox/office/editframework/model/autostylecollection',
     'io.ox/office/spreadsheet/utils/sheetutils'
-], function (Utils, SimpleMap, Border, AttributeUtils, AutoStyleCollection, SheetUtils) {
+], function (Utils, ValueMap, Border, AttributeUtils, AutoStyleCollection, SheetUtils) {
 
     'use strict';
 
@@ -48,7 +48,10 @@ define('io.ox/office/spreadsheet/model/cellautostylecollection', [
         var odf = docModel.getApp().isODF();
 
         // the collection of cell style sheets this instance is based on
-        var styleSheets = docModel.getStyleCollection('cell');
+        var styleSheets = docModel.getCellStyles();
+
+        // the attribute pool for cell attributes
+        var attributePool = styleSheets.getAttributePool();
 
         // the names of all supported attribute families, as flag set
         var supportedFamilySet = styleSheets.getSupportedFamilies();
@@ -60,10 +63,10 @@ define('io.ox/office/spreadsheet/model/cellautostylecollection', [
         var standardFormat = numberFormatter.getStandardFormat();
 
         // a cache for parsed number formats for all existing auto-styles
-        var parsedFormatCache = new SimpleMap();
+        var parsedFormatCache = new ValueMap();
 
         // a cache for visible border maps for all existing auto-styles
-        var borderMapCache = new SimpleMap();
+        var borderMapCache = new ValueMap();
 
         // base constructor ---------------------------------------------------
 
@@ -145,7 +148,7 @@ define('io.ox/office/spreadsheet/model/cellautostylecollection', [
          * created, and the appropriate remote operations will be inserted into
          * the passed generators.
          *
-         * @param {SheetOperationsGenerator} generator
+         * @param {SheetOperationGenerator} generator
          *  The operations generator to be filled with the operation.
          *
          * @param {String} styleId
@@ -209,13 +212,10 @@ define('io.ox/office/spreadsheet/model/cellautostylecollection', [
             if (ooxml) {
                 var applyFlags = {};
                 _.each(attributeSet, function (attributes, family) {
-                    var definitions = docModel.getAttributeDefinitions(family);
-                    if (definitions && (family in supportedFamilySet)) {
-                        _.each(attributes, function (value, name) {
-                            var definition = definitions[name];
-                            if (definition && definition.apply) {
-                                applyFlags[definition.apply] = true;
-                            }
+                    var definitionMap = attributePool.getRegisteredAttributes(family);
+                    if (definitionMap && (family in supportedFamilySet)) {
+                        definitionMap.forEachSupported(attributes, function (value, name, definition) {
+                            if (definition.apply) { applyFlags[definition.apply] = true; }
                         });
                     }
                 });
@@ -233,11 +233,14 @@ define('io.ox/office/spreadsheet/model/cellautostylecollection', [
                     // copy all formatting attributes with active 'apply' flag from the style sheet to the attribute set
                     _.each(styleAttributeSet, function (styleAttributes, family) {
                         if (family !== 'apply') {
-                            _.each(docModel.getAttributeDefinitions(family), function (definition, name) {
-                                if (definition.apply && styleAttributeSet.apply[definition.apply]) {
-                                    AttributeUtils.insertAttribute(attributeSet, family, name, styleAttributes[name]);
-                                }
-                            });
+                            var definitionMap = attributePool.getRegisteredAttributes(family);
+                            if (definitionMap) {
+                                definitionMap.forEach(function (definition, name) {
+                                    if (definition.apply && styleAttributeSet.apply[definition.apply]) {
+                                        AttributeUtils.insertAttribute(attributeSet, family, name, styleAttributes[name]);
+                                    }
+                                });
+                            }
                         }
                     });
 
@@ -277,7 +280,7 @@ define('io.ox/office/spreadsheet/model/cellautostylecollection', [
 
         // destroy class members on destruction
         this.registerDestructor(function () {
-            self = docModel = styleSheets = null;
+            self = docModel = styleSheets = attributePool = null;
             numberFormatter = standardFormat = null;
             parsedFormatCache = borderMapCache = null;
         });
