@@ -6,7 +6,8 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
- * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Daniel Rentz <daniel.rentz@open-xchange.com>
  */
@@ -40,18 +41,26 @@ define('io.ox/office/spreadsheet/model/cellmodel', [
      *  sign); or null for simple value cells without a formula.
      *
      * @property {Number|Null} si
-     *  The identifier of a shared formula this cell refers to; or null if this
-     *  cell is not part of a shared formula.
+     *  The index of a shared formula this cell refers to; or null if this cell
+     *  is not part of a shared formula.
      *
      * @property {Range|Null} sr
-     *  The bounding range of the shared formula this cell refers to; or null
-     *  if this cell is not the anchor cell of a shared formula.
+     *  The bounding range of the shared formula this cell refers to, if this
+     *  cell is the anchor cell of the shared formula; or null otherwise.
+     *
+     * @property {Range|Null} mr
+     *  The bounding range of the matrix formula starting at this cell; or null
+     *  otherwise.
      *
      * @property {String} s
      *  The identifier of the auto-style for the cell.
      *
+     * @property {ParsedFormat} pf
+     *  The parsed number format for the cell, according to the number format
+     *  attribute contained in the auto-style referred by this cell model.
+     *
      * @property {String|Null} d
-     *  The formatted  display string of the cell, according to its current
+     *  The formatted display string of the cell, according to its current
      *  value and number format. May be null, if the value cannot be formatted
      *  with the current number format. In this case, the cell renderer will
      *  show a 'railroad track' error (repeated hash marks) in the cell.
@@ -81,9 +90,11 @@ define('io.ox/office/spreadsheet/model/cellmodel', [
         this.f = null;
         this.si = null;
         this.sr = null;
+        this.mr = null;
         this.s = '';
 
         // calculated properties, cached for performance
+        this.pf = null; // MUST be initialized by caller after construction
         this.d = '';
         this.t = null;
         this.url = null;
@@ -116,66 +127,6 @@ define('io.ox/office/spreadsheet/model/cellmodel', [
         return cellModel1.a.compareTo(cellModel2.a);
     };
 
-    /**
-     * Returns whether the passed cell model contains a value (is not blank).
-     * Can be used as callback predicate for filters.
-     *
-     * @param {CellModel} [cellModel]
-     *  A cell model, or null, or undefined. The latter will be treated as
-     *  undefined blank cells, and this method will return false.
-     *
-     * @returns {Boolean}
-     *  Whether the passed cell model contains a value (is not blank).
-     */
-    CellModel.hasValue = function (cellModel) {
-        return cellModel && !cellModel.isBlank();
-    };
-
-    /**
-     * Returns whether the passed cell model contains a formula. Can be used as
-     * callback predicate for filters.
-     *
-     * @param {CellModel} [cellModel]
-     *  A cell model, or null, or undefined. The latter will be treated as
-     *  undefined blank cells, and this method will return false.
-     *
-     * @returns {Boolean}
-     *  Whether the passed cell model contains a formula.
-     */
-    CellModel.hasFormula = function (cellModel) {
-        return cellModel && cellModel.isFormula();
-    };
-
-    /**
-     * Returns whether the passed cell model contains a formula or a shared formula. Can be used as
-     * callback predicate for filters.
-     *
-     * @param {CellModel} [cellModel]
-     *  A cell model, or null, or undefined. The latter will be treated as
-     *  undefined blank cells, and this method will return false.
-     *
-     * @returns {Boolean}
-     *  Whether the passed cell model contains a formula or a shared formula.
-     */
-    CellModel.hasAnyFormula = function (cellModel) {
-        return cellModel && (cellModel.isFormula() || cellModel.isSharedFormula());
-    };
-
-    /**
-     * Returns whether the passed cell model contains a shared formula. Can be used as
-     * callback predicate for filters.
-     *
-     * @param {CellModel} [cellModel]
-     *  A cell model, or null, or undefined. The latter will be treated as
-     *  undefined blank cells, and this method will return false.
-     *
-     * @returns {Boolean}
-     *  Whether the passed cell model contains a shared formula.
-     */
-    CellModel.hasSharedFormula = function (cellModel) {
-        return cellModel && cellModel.isSharedFormula();
-    };
-
     /**
      * Returns the column index of the passed cell model. Used in sorted model
      * arrays as sorter callback.
@@ -204,6 +155,26 @@ define('io.ox/office/spreadsheet/model/cellmodel', [
         return cellModel.a[1];
     };
 
+    // protected methods ------------------------------------------------------
+
+    /**
+     * Creates, updates, or removes the token array stored at the property 't'
+     * of this cell model, according to the current formula expression stored
+     * at the property 'f'.
+     *
+     * @param {SheetModel} sheetModel
+     *  The model of the sheet containing this cell, needed to create a new
+     *  token array instance.
+     */
+    CellModel.prototype._updateTokenArray = function (sheetModel) {
+        if (this.f) {
+            if (!this.t) { this.t = new TokenArray(sheetModel, 'cell'); }
+            this.t.parseFormula('op', this.f, { refAddress: this.a });
+        } else {
+            this.t = null;
+        }
+    };
+
     // public methods ---------------------------------------------------------
 
     /**
@@ -221,10 +192,12 @@ define('io.ox/office/spreadsheet/model/cellmodel', [
         cellModel.f = this.f;
         cellModel.si = this.si;
         cellModel.sr = this.sr ? this.sr.clone() : null;
+        cellModel.mr = this.mr ? this.mr.clone() : null;
         cellModel.s = this.s;
+        cellModel.pf = this.pf;
         cellModel.d = this.d;
         cellModel.url = this.url;
-        cellModel.getTokenArray(sheetModel);
+        cellModel._updateTokenArray(sheetModel);
         return cellModel;
     };
 
@@ -290,69 +263,92 @@ define('io.ox/office/spreadsheet/model/cellmodel', [
     };
 
     /**
-     * Returns whether this cell model contains a formula expression or is a shared formula.
+     * Returns whether this cell model represents a normal formula cell, i.e.
+     * the cell contains a formula expression, but is neither part of a shared
+     * formula nor a matrix formula.
      *
      * @returns {Boolean}
-     *  Whether this cell model contains a formula expression or a shared formula.
+     *  Whether this cell model represents a normal formula cell.
      */
-    CellModel.prototype.isFormula = function () {
-        return !!this.f;
+    CellModel.prototype.isNormalFormula = function () {
+        return !!this.f && (this.si === null) && !this.mr;
     };
 
     /**
-     * Returns if the cell model contains a shared formula.
+     * Returns whether this cell model is part of a shared formula, regardless
+     * whether the cell is the anchor of the shared formula.
      *
-     * @returns {Boolean} true if the cell model contains a shared formula, otherwise false.
+     * @returns {Boolean}
+     *  Whether this cell model is part of a shared formula.
      */
     CellModel.prototype.isSharedFormula = function () {
         return this.si !== null;
     };
 
     /**
-     * Returns if the cell model contains a shared formula but not a formula.
+     * Returns whether this cell model contains a formula, either as normal
+     * formula cell, or as part of a shared formula, or as the anchor cell of a
+     * matrix formula.
      *
-     * @returns {Boolean} true if the cell model contains a shared formula without formula, otherwise false.
+     * @returns {Boolean}
+     *  Whether this cell model represents a formula cell.
      */
-    CellModel.prototype.isSharedFormulaWithoutFormula = function () {
-        return this.si !== null && !this.f;
+    CellModel.prototype.isAnyFormula = function () {
+        return !!this.f || (this.si !== null) || !!this.mr;
     };
 
     /**
-     * Returns the token array containing the parsed formula expression of this
-     * cell model.
+     * Returns whether this cell model is the anchor cell of a shared formula.
      *
-     * @param {SheetModel} sheetModel
-     *  The sheet model containing this cell model, needed to create a new
-     *  token array instance on demand.
-     *
-     * @returns {TokenArray|Null}
-     *  The token array of this cell model; or null, if the cell model does not
-     *  contain a formula expression.
+     * @returns {Boolean}
+     *  Whether this cell model is the anchor cell of a shared formula.
      */
-    CellModel.prototype.getTokenArray = function (sheetModel) {
-        if (!this.f || this.t) { return this.t; }
-        this.t = new TokenArray(sheetModel, 'cell');
-        this.t.parseFormula('op', this.f, { refAddress: this.a });
-        return this.t;
+    CellModel.prototype.isSharedAnchor = function () {
+        return !!this.sr;
+    };
+
+    /**
+     * Returns whether this cell model is the anchor cell of a matrix formula.
+     *
+     * @returns {Boolean}
+     *  Whether this cell model is the anchor cell of a matrix formula.
+     */
+    CellModel.prototype.isMatrixAnchor = function () {
+        return !!this.mr;
+    };
+
+    /**
+     * Returns whether this cell model contains an actual formula expression,
+     * either as normal formula cell, or as anchor cell of a shared formula or
+     * matrix formula.
+     *
+     * @returns {Boolean}
+     *  Whether this cell model contains an actual formula expression.
+     */
+    CellModel.prototype.isAnyAnchor = function () {
+        return !!this.f || !!this.sr || !!this.mr;
     };
 
     /**
      * Returns the formula expression of this cell model.
      *
-     * @param {SheetModel} sheetModel
-     *  The sheet model containing this cell model, needed to create a new
-     *  token array instance on demand.
-     *
      * @param {String} grammarId
-     *  The identifier of the formula grammar for the formula expression.
+     *  The identifier of the formula grammar for the formula expression. See
+     *  SpreadsheetDocument.getFormulaGrammar() for more details.
+     *
+     * @param {Address} [targetAddress]
+     *  The target address used to relocate the formula expression. If omitted,
+     *  the formula will be generated for the own address of this cell model.
      *
      * @returns {String|Null}
      *  The formula expression of this cell model; or null, if the cell model
      *  does not contain a formula expression.
      */
-    CellModel.prototype.getFormula = function (sheetModel, grammarId) {
-        // shortcut for operation grammar: return the 'f' property directly
-        return !this.isFormula() ? null : (grammarId === 'op') ? this.f : this.getTokenArray(sheetModel).getFormula(grammarId, { refAddress: this.a, targetAddress: this.a });
+    CellModel.prototype.getFormula = function (grammarId, targetAddress) {
+        return !this.t ? null :
+            // shortcut for operation grammar without relocation: return the 'f' property directly
+            ((grammarId === 'op') && !targetAddress) ? this.f :
+            this.t.getFormula(grammarId, { refAddress: this.a, targetAddress: targetAddress || this.a });
     };
 
     /**
@@ -375,56 +371,78 @@ define('io.ox/office/spreadsheet/model/cellmodel', [
      * Changes the formula expression of this cell model, and returns whether
      * the formula expression has changed.
      *
+     * @param {SheetModel} sheetModel
+     *  The sheet model containing this cell model, needed to create a new
+     *  token array instance on demand.
+     *
      * @param {String|Null} formula
      *  The new formula expression for the cell. The value null will delete the
      *  formula expression, and the cell becomes a simple value cell.
      *
+     * @param {Boolean} [importing=false]
+     *  If set to true, the token array of the cell model will NOT be created
+     *  (this will be done later during post-processing phase of the import
+     *  process to improve performance).
+     *
      * @returns {Boolean}
      *  Whether the formula expression has changed.
      */
-    CellModel.prototype.setFormula = function (formula) {
+    CellModel.prototype.setFormula = function (sheetModel, formula, importing) {
         formula = formula || null;
         if (this.f === formula) { return false; }
         this.f = formula;
-        this.t = null;
+        if (!importing) { this._updateTokenArray(sheetModel); }
         return true;
     };
 
     /**
-     * Change the value of the shared formula id.
+     * Changes the index of the shared formula this cell refers to.
      *
-     * @param {Number|Null} id
-     *  The identifier of the shared formula, or null to remove the identifier
-     *  of a shared formula from this cell model.
+     * @param {Number|Null} si
+     *  The index of a shared formula, or null to remove the existing index of
+     *  a shared formula from this cell model.
      *
      * @returns {Boolean}
-     *  Whether the identifier of the shared formula has changed.
+     *  Whether the index of the shared formula has changed.
      */
-    CellModel.prototype.setSharedFormulaID = function (id) {
-        if (this.si === id) { return false; }
-        this.si = id;
+    CellModel.prototype.setSharedIndex = function (si) {
+        if (this.si === si) { return false; }
+        this.si = si;
         return true;
     };
 
     /**
-     * Changes the bounding range of the shared formula.
+     * Changes the bounding range of the shared formula this cell refers to.
      *
      * @param {Range|Null} range
-     *  The new bounding range of the shared formula, or null to remove the
+     *  The new bounding range of a shared formula, or null to remove the
      *  bounding range from this cell model.
      *
      * @returns {Boolean}
      *  Whether the bounding range of the shared formula has changed.
      */
-    CellModel.prototype.setSharedFormulaRange = function (range) {
-        if (((this.sr === null) && (range === null)) ||
-            (this.sr && range && this.sr.equals(range))) {
-            return false;
-        }
+    CellModel.prototype.setSharedRange = function (range) {
+        if ((!this.sr && !range) || (this.sr && range && this.sr.equals(range))) { return false; }
         this.sr = range ? range.clone() : null;
         return true;
     };
 
+    /**
+     * Changes the bounding range of the matrix formula starting at this cell.
+     *
+     * @param {Range|Null} range
+     *  The new bounding range of a matrix formula, or null to remove the
+     *  bounding range from this cell model.
+     *
+     * @returns {Boolean}
+     *  Whether the bounding range of the matrix formula has changed.
+     */
+    CellModel.prototype.setMatrixRange = function (range) {
+        if ((!this.mr && !range) || (this.mr && range && this.mr.equals(range))) { return false; }
+        this.mr = range ? range.clone() : null;
+        return true;
+    };
+
     /**
      * Changes the dynamic URL of this cell model, and returns whether the cell
      * URL has changed.
