@@ -16,11 +16,10 @@ define('io.ox/office/spreadsheet/model/cellmodelmatrix', [
     'io.ox/office/tk/utils/iteratorutils',
     'io.ox/office/tk/container/sortedarray',
     'io.ox/office/tk/object/baseobject',
-    'io.ox/office/tk/object/timermixin',
     'io.ox/office/spreadsheet/utils/sheetutils',
     'io.ox/office/spreadsheet/utils/subtotalresult',
     'io.ox/office/spreadsheet/model/cellmodel'
-], function (IteratorUtils, SortedArray, BaseObject, TimerMixin, SheetUtils, SubtotalResult, CellModel) {
+], function (IteratorUtils, SortedArray, BaseObject, SheetUtils, SubtotalResult, CellModel) {
 
     'use strict';
 
@@ -49,12 +48,14 @@ define('io.ox/office/spreadsheet/model/cellmodelmatrix', [
      *  by their row index), or a row vector (false; cells will be sorted by
      *  their column index).
      */
-    var CellModelVector = SortedArray.extend({ constructor: function (matrix, columns) {
+    var CellModelVector = SortedArray.extend({ constructor: function (matrix, collection, columns) {
 
         // private properties -------------------------------------------------
 
         // reference to the parent cell matrix
         this._matrix = matrix;
+        // the column/row collection in oppsite direction needed to skip hidden columns/rows
+        this._collection = collection;
         // cached subtotal results for all cells in this vector
         this._subtotals = null;
         // name of the property in a cell model referring to this instance
@@ -114,20 +115,46 @@ define('io.ox/office/spreadsheet/model/cellmodelmatrix', [
         // return the cached subtotals directly
         if (this._subtotals) { return this._subtotals; }
 
+        // simultaneously iterate through the column/row collection to find hidden columns/rows efficiently
+        var collection = this._collection;
+        var iterator = collection.createIterator(collection.getFullInterval(), { visible: true, unique: true });
+        var iterResult = iterator.next();
+
         // collect the subtotals directly in synchronous mode
         var subtotals = this._subtotals = new SubtotalResult();
-        this.forEach(function (cellModel) { subtotals.addValue(cellModel.v); });
+        this.forEach(function (cellModel, index) {
+
+            // find the next visible column/row interval that does not end before the current cell
+            while (!iterResult.done && (iterResult.value.uniqueInterval.last < index)) {
+                iterResult = iterator.next();
+            }
+
+            // skip the cell model, if it is located in a hidden column/row
+            // (i.e., next visible column/row interval starts after the current cell model)
+            if (!iterResult.done && (iterResult.value.uniqueInterval.first <= index)) {
+                subtotals.addValue(cellModel.v);
+            }
+        });
         return subtotals;
     };
 
     /**
      * Invalidates the cached subtotals result of this cell vector.
      *
+     * @param {Interval} [changedInterval]
+     *  If specified, the cached subtotals will be invalidated only if this
+     *  vector contains at least one entry in that index interval.
+     *
      * @returns {CellModelVector}
      *  A reference to this instance.
      */
-    CellModelVector.prototype.clearSubtotals = function () {
-        this._subtotals = null;
+    CellModelVector.prototype.clearSubtotals = function (changedInterval) {
+        var dirty = this._subtotals;
+        if (dirty && changedInterval) {
+            var desc = this.find(changedInterval.first);
+            dirty = desc && (desc.index <= changedInterval.last);
+        }
+        if (dirty) { this._subtotals = null; }
         return this;
     };
 
@@ -155,14 +182,13 @@ define('io.ox/office/spreadsheet/model/cellmodelmatrix', [
      * @constructor
      *
      * @extends BaseObject
-     * @extends TimerMixin
      *
      * @param {Boolean} columns
      *  Whether this instance contains column vectors (true; vectors will be
      *  sorted by column index), or row vectors (false; vectors will be sorted
      *  by row index).
      */
-    var CellModelMatrix = BaseObject.extend({ constructor: function (columns) {
+    var CellModelMatrix = BaseObject.extend({ constructor: function (sheetModel, columns) {
 
         // self reference
         var self = this;
@@ -173,10 +199,15 @@ define('io.ox/office/spreadsheet/model/cellmodelmatrix', [
         // the sorted array of sorted cell vectors
         var matrix = new SortedArray(function (vector) { return sorter(vector.first()); });
 
+        // the column/row collection in matrix direction needed to skip hidden columns/rows
+        var collection1 = columns ? sheetModel.getColCollection() : sheetModel.getRowCollection();
+
+        // the column/row collection in oppsite direction needed to skip hidden columns/rows
+        var collection2 = columns ? sheetModel.getRowCollection() : sheetModel.getColCollection();
+
         // base constructor ---------------------------------------------------
 
-        BaseObject.call(this);
-        TimerMixin.call(this);
+        BaseObject.call(this, sheetModel);
 
         // private methods ----------------------------------------------------
 
@@ -187,7 +218,7 @@ define('io.ox/office/spreadsheet/model/cellmodelmatrix', [
          *  A new instance of a cell model vector.
          */
         function createVector() {
-            return new CellModelVector(self, columns);
+            return new CellModelVector(self, collection2, columns);
         }
 
         /**
@@ -379,7 +410,8 @@ define('io.ox/office/spreadsheet/model/cellmodelmatrix', [
          *      the iterator is done (see property 'done').
          */
         this.createSubtotalIterator = function (vectorIntervals) {
-            var iterator = createVectorIterator(vectorIntervals);
+            var visibleIntervals = IntervalArray.map(vectorIntervals, collection1.getVisibleIntervals, collection1);
+            var iterator = createVectorIterator(visibleIntervals);
             return IteratorUtils.createTransformIterator(iterator, function (vector, result) {
                 result.value = vector.getSubtotals();
                 return result;
@@ -388,6 +420,15 @@ define('io.ox/office/spreadsheet/model/cellmodelmatrix', [
 
         // initialization -----------------------------------------------------
 
+        // invalidate cached subtotal results if columns/rows will be hidden or shown
+        this.listenTo(collection2, 'change:entries', function (event, interval, changeInfo) {
+            if (changeInfo.visibilityChanged) {
+                matrix.forEach(function (vector) {
+                    vector.clearSubtotals(interval);
+                });
+            }
+        });
+
         this.registerDestructor(function () {
             matrix.forEach(function (vector) { vector.destroy(); });
             self = sorter = matrix = null;
