@@ -15,8 +15,9 @@
 define('io.ox/office/spreadsheet/model/cellstylecollection', [
     'io.ox/office/tk/utils',
     'io.ox/office/editframework/utils/color',
-    'io.ox/office/editframework/model/stylecollection'
-], function (Utils, Color, StyleCollection) {
+    'io.ox/office/editframework/model/stylecollection',
+    'io.ox/office/spreadsheet/utils/sheetutils'
+], function (Utils, Color, StyleCollection, SheetUtils) {
 
     'use strict';
 
@@ -32,7 +33,7 @@ define('io.ox/office/spreadsheet/model/cellstylecollection', [
      * @param {SpreadsheetModel} docModel
      *  The document model containing this instance.
      */
-    function CellStyleCollection(docModel) {
+    var CellStyleCollection = StyleCollection.extend({ constructor: function (docModel) {
 
         // self reference
         var self = this;
@@ -45,7 +46,7 @@ define('io.ox/office/spreadsheet/model/cellstylecollection', [
 
         // base constructor ---------------------------------------------------
 
-        StyleCollection.call(this, docModel, 'cell', { families: 'character apply' });
+        StyleCollection.call(this, docModel, 'cell', { poolId: SheetUtils.CELL_POOL_ID, families: 'character apply' });
 
         // private methods ----------------------------------------------------
 
@@ -116,10 +117,10 @@ define('io.ox/office/spreadsheet/model/cellstylecollection', [
 
             // standard styles
             createStyleSheet('Standard', 'markup', 1, {});
-            createStyleSheet('Positive', 'markup', 2, { character: { fontName: fontName, color: getRGB('006100') }, cell: { fillColor: getRGB('C6EFCE') } }, APPLY_FONT_FILL);
-            createStyleSheet('Neutral',  'markup', 3, { character: { fontName: fontName, color: getRGB('9C6500') }, cell: { fillColor: getRGB('FFEB9C') } }, APPLY_FONT_FILL);
-            createStyleSheet('Negative', 'markup', 4, { character: { fontName: fontName, color: getRGB('9C0006') }, cell: { fillColor: getRGB('FFC7CE') } }, APPLY_FONT_FILL);
-            createStyleSheet('Note',     'markup', 5, { character: { fontName: fontName, color: getScheme('dark1') }, cell: { fillColor: getRGB('FFFFCC'), borderTop: LIGHT_GRAY_BORDER, borderBottom: LIGHT_GRAY_BORDER, borderLeft: LIGHT_GRAY_BORDER, borderRight: LIGHT_GRAY_BORDER } }, APPLY_FILL_BORDER);
+            createStyleSheet('Positive', 'markup', 2, { character: { fontName: fontName, color: getRGB('006100') },   cell: { fillType: 'solid', fillColor: getRGB('C6EFCE') } }, APPLY_FONT_FILL);
+            createStyleSheet('Neutral',  'markup', 3, { character: { fontName: fontName, color: getRGB('9C6500') },   cell: { fillType: 'solid', fillColor: getRGB('FFEB9C') } }, APPLY_FONT_FILL);
+            createStyleSheet('Negative', 'markup', 4, { character: { fontName: fontName, color: getRGB('9C0006') },   cell: { fillType: 'solid', fillColor: getRGB('FFC7CE') } }, APPLY_FONT_FILL);
+            createStyleSheet('Note',     'markup', 5, { character: { fontName: fontName, color: getScheme('dark1') }, cell: { fillType: 'solid', fillColor: getRGB('FFFFCC'), borderTop: LIGHT_GRAY_BORDER, borderBottom: LIGHT_GRAY_BORDER, borderLeft: LIGHT_GRAY_BORDER, borderRight: LIGHT_GRAY_BORDER } }, APPLY_FILL_BORDER);
 
             // heading styles
             createStyleSheet('Title',     'headings', 1, { character: { bold: true, fontName: fontName, fontSize: 18, color: getScheme('dark2') } }, APPLY_FONT);
@@ -130,22 +131,22 @@ define('io.ox/office/spreadsheet/model/cellstylecollection', [
             createStyleSheet('Total',     'headings', 9, { character: { bold: true, fontName: fontName, fontSize: 11, color: getScheme('dark1') }, cell: { borderTop: { style: 'single', width: 26, color: getScheme('accent1') }, borderBottom: { style: 'double', width: 79, color: getScheme('accent1') } } }, APPLY_FONT_BORDER);
 
             // other content styles
-            createStyleSheet('Output',           'hidden', 1, { character: { fontName: fontName, color: getRGB('3F3F3F'), bold: true }, cell: { fillColor: getRGB('F2F2F2'), borderTop: DARK_GRAY_BORDER, borderBottom: DARK_GRAY_BORDER, borderLeft: DARK_GRAY_BORDER, borderRight: DARK_GRAY_BORDER } }, APPLY_FONT_FILL_BORDER);
-            createStyleSheet('Calculation',      'hidden', 2, { character: { fontName: fontName, color: getRGB('FA7D00'), bold: true }, cell: { fillColor: getRGB('F2F2F2'), borderTop: MED_GRAY_BORDER,  borderBottom: MED_GRAY_BORDER,  borderLeft: MED_GRAY_BORDER,  borderRight: MED_GRAY_BORDER } }, APPLY_FONT_FILL_BORDER);
-            createStyleSheet('Input',            'hidden', 3, { character: { fontName: fontName, color: getRGB('3F3F76') },             cell: { fillColor: getRGB('FFCC99'), borderTop: MED_GRAY_BORDER,  borderBottom: MED_GRAY_BORDER,  borderLeft: MED_GRAY_BORDER,  borderRight: MED_GRAY_BORDER } }, APPLY_FONT_FILL_BORDER);
+            createStyleSheet('Output',           'hidden', 1, { character: { fontName: fontName, color: getRGB('3F3F3F'), bold: true }, cell: { fillType: 'solid', fillColor: getRGB('F2F2F2'), borderTop: DARK_GRAY_BORDER, borderBottom: DARK_GRAY_BORDER, borderLeft: DARK_GRAY_BORDER, borderRight: DARK_GRAY_BORDER } }, APPLY_FONT_FILL_BORDER);
+            createStyleSheet('Calculation',      'hidden', 2, { character: { fontName: fontName, color: getRGB('FA7D00'), bold: true }, cell: { fillType: 'solid', fillColor: getRGB('F2F2F2'), borderTop: MED_GRAY_BORDER,  borderBottom: MED_GRAY_BORDER,  borderLeft: MED_GRAY_BORDER,  borderRight: MED_GRAY_BORDER } }, APPLY_FONT_FILL_BORDER);
+            createStyleSheet('Input',            'hidden', 3, { character: { fontName: fontName, color: getRGB('3F3F76') },             cell: { fillType: 'solid', fillColor: getRGB('FFCC99'), borderTop: MED_GRAY_BORDER,  borderBottom: MED_GRAY_BORDER,  borderLeft: MED_GRAY_BORDER,  borderRight: MED_GRAY_BORDER } }, APPLY_FONT_FILL_BORDER);
             createStyleSheet('Explanatory Text', 'hidden', 4, { character: { fontName: fontName, color: getRGB('7F7F7F'), italic: true } }, APPLY_FONT);
             createStyleSheet('Linked Cell',      'hidden', 5, { character: { fontName: fontName, color: getRGB('FA7D00') }, cell: { borderBottom: { style: 'double', width: 17, color: getRGB('FA7D00') } } }, APPLY_FONT_BORDER);
             createStyleSheet('Warning Text',     'hidden', 6, { character: { fontName: fontName, color: getRGB('FF0000') } }, APPLY_FONT);
-            createStyleSheet('Check Cell',       'hidden', 7, { character: { fontName: fontName, color: getScheme('light1'), bold: true }, cell: { fillColor: getRGB('A5A5A5'), borderTop: DOUBLE_GRAY_BORDER, borderBottom: DOUBLE_GRAY_BORDER, borderLeft: DOUBLE_GRAY_BORDER, borderRight: DOUBLE_GRAY_BORDER } }, APPLY_FONT_FILL_BORDER);
+            createStyleSheet('Check Cell',       'hidden', 7, { character: { fontName: fontName, color: getScheme('light1'), bold: true }, cell: { fillType: 'solid', fillColor: getRGB('A5A5A5'), borderTop: DOUBLE_GRAY_BORDER, borderBottom: DOUBLE_GRAY_BORDER, borderLeft: DOUBLE_GRAY_BORDER, borderRight: DOUBLE_GRAY_BORDER } }, APPLY_FONT_FILL_BORDER);
 
             // accent styles
             Utils.iterateRange(0, 6, function (index) {
                 var styleName = 'Accent ' + (index + 1);
                 var colorName = 'accent' + (index + 1);
-                createStyleSheet('20% - ' + styleName, 'themes', index,      { character: { fontName: fontName, color: getScheme('dark1') },  cell: { fillColor: getSchemeTint20(colorName) } }, APPLY_FONT_FILL);
-                createStyleSheet('40% - ' + styleName, 'themes', index + 6,  { character: { fontName: fontName, color: getScheme('dark1') },  cell: { fillColor: getSchemeTint40(colorName) } }, APPLY_FONT_FILL);
-                createStyleSheet('60% - ' + styleName, 'themes', index + 12, { character: { fontName: fontName, color: getScheme('light1') }, cell: { fillColor: getSchemeTint60(colorName) } }, APPLY_FONT_FILL);
-                createStyleSheet(styleName,            'themes', index + 18, { character: { fontName: fontName, color: getScheme('light1') }, cell: { fillColor: getScheme(colorName) } },        APPLY_FONT_FILL);
+                createStyleSheet('20% - ' + styleName, 'themes', index,      { character: { fontName: fontName, color: getScheme('dark1') },  cell: { fillType: 'solid', fillColor: getSchemeTint20(colorName) } }, APPLY_FONT_FILL);
+                createStyleSheet('40% - ' + styleName, 'themes', index + 6,  { character: { fontName: fontName, color: getScheme('dark1') },  cell: { fillType: 'solid', fillColor: getSchemeTint40(colorName) } }, APPLY_FONT_FILL);
+                createStyleSheet('60% - ' + styleName, 'themes', index + 12, { character: { fontName: fontName, color: getScheme('light1') }, cell: { fillType: 'solid', fillColor: getSchemeTint60(colorName) } }, APPLY_FONT_FILL);
+                createStyleSheet(styleName,            'themes', index + 18, { character: { fontName: fontName, color: getScheme('light1') }, cell: { fillType: 'solid', fillColor: getScheme(colorName) } },       APPLY_FONT_FILL);
             });
 
             // hyperlink style
@@ -172,11 +173,10 @@ define('io.ox/office/spreadsheet/model/cellstylecollection', [
             docModel = self = null;
         });
 
-    } // class CellStyleCollection
+    } }); // class CellStyleCollection
 
     // exports ================================================================
 
-    // derive this class from class StyleCollection
-    return StyleCollection.extend({ constructor: CellStyleCollection });
+    return CellStyleCollection;
 
 });
