@@ -14,11 +14,11 @@
 
 define('io.ox/office/spreadsheet/model/cellvaluecache', [
     'io.ox/office/tk/utils/iteratorutils',
-    'io.ox/office/tk/container/simplemap',
+    'io.ox/office/tk/container/valuemap',
     'io.ox/office/tk/object/triggerobject',
     'io.ox/office/spreadsheet/utils/sheetutils',
     'io.ox/office/spreadsheet/utils/scalarset'
-], function (IteratorUtils, SimpleMap, TriggerObject, SheetUtils, ScalarSet) {
+], function (IteratorUtils, ValueMap, TriggerObject, SheetUtils, ScalarSet) {
 
     'use strict';
 
@@ -63,11 +63,11 @@ define('io.ox/office/spreadsheet/model/cellvaluecache', [
         var cellCollection = sheetModel.getCellCollection();
 
         // a map used as cache for various results
-        var cacheMap = new SimpleMap();
+        var cacheMap = new ValueMap();
 
         // base constructor ---------------------------------------------------
 
-        TriggerObject.call(this);
+        TriggerObject.call(this, sheetModel.getDocModel());
 
         // private methods ----------------------------------------------------
 
