@@ -39,12 +39,21 @@ define('io.ox/office/spreadsheet/model/drawing/axismodel', [
         var gridModel = null;
         var format = null;
 
+        var indexName = 'axis' + axisId[0].toUpperCase() + 'Type';
+        var indexValue = axisId[1] === '2' ? 'secondary' : 'primary';
+
         var dataAxis = chartModel.getModelData()['axis' + axisId.toUpperCase()];
         if (dataAxis) {
-            titleModel = new TitleModel(chartModel, axisId, dataAxis, 'title');
+            titleModel = new TitleModel(chartModel, axisId, dataAxis, 'title', 'title');
             gridModel = new GridlineModel(chartModel, axisId, {}, dataAxis);
 
-            dataAxis.labelFormatter = function (info) { return info.label || formatNumber(info.value); };
+            dataAxis.labelFormatter = function (info) {
+                if (chartModel.isXYType()) {
+                    return formatNumber(info.value);
+                } else {
+                    return info.label || formatNumber(info.value);
+                }
+            };
         }
 
         // base constructor ---------------------------------------------------
@@ -68,7 +77,7 @@ define('io.ox/office/spreadsheet/model/drawing/axismodel', [
         }
 
         function isHorizontal() {
-            return chartModel.getAxisIdForDrawing(axisId) === 'x';
+            return chartModel.getAxisIdForDrawing(axisId[0]) === 'x';
         }
 
         function refreshMinMax() {
@@ -77,14 +86,7 @@ define('io.ox/office/spreadsheet/model/drawing/axismodel', [
                 return;
             }
 
-            // fix for Bug 46910 & Bug 49574
-            if (isHorizontal()) {
-                delete dataAxis.labelAngle;
-            } else {
-                dataAxis.labelAngle = 0;
-            }
-
-            if (axisId === 'x') {
+            if (axisId[0] === 'x') {
                 refreshAxisX(data);
             } else {
                 refreshAxisY(data);
@@ -143,17 +145,8 @@ define('io.ox/office/spreadsheet/model/drawing/axismodel', [
                     dataAxis.minimum = minValue;
                     dataAxis.maximum = maxValue;
                     dataAxis.interval = null;
-                } else {
-                    var intCount = 1 + ((maxValue - minValue) / interval);
-
-                    if (Math.abs(maxValue) < Math.abs(minValue)) {
-                        maxValue = Utils.roundUp(maxValue, interval);
-                        minValue = maxValue - (interval * intCount);
-                    } else {
-                        minValue = Utils.roundDown(minValue, interval);
-                        maxValue = minValue + (interval * intCount);
-                    }
                 }
+                // removed for Bug 52880
                 setMinMax(minValue, maxValue, interval);
             }
         }
@@ -169,6 +162,28 @@ define('io.ox/office/spreadsheet/model/drawing/axismodel', [
 
             if (min < 0 && format && format.format && format.format.category === 'date') { min = 0; }
 
+            var steps = (max - min) / interval;
+
+            if (!isHorizontal()) {
+
+                var attrs = self.getMergedAttributeSet(true);
+                if (attrs.axis.label) {
+
+                    var rect = chartModel.getRectangle();
+                    if (rect) {
+                        var height = rect.height / steps;
+                        var stepHeight = ChartStyleUtil.getHeightForCharacterProps(chartModel, attrs.character);
+
+                        var rel = stepHeight / height;
+                        if (rel > 1) {
+                            rel = Math.ceil(rel / 2) * 2;
+                            interval *= rel;
+                            steps = (max - min) / interval;
+                        }
+                    }
+                }
+            }
+
             dataAxis.minimum = min;
             dataAxis.maximum = max;
             dataAxis.interval = interval;
@@ -177,7 +192,7 @@ define('io.ox/office/spreadsheet/model/drawing/axismodel', [
             var i = 0;
 
             var index = 0;
-            var steps = (dataAxis.maximum - dataAxis.minimum) / dataAxis.interval;
+
             var lastLine = null;
             var line = null;
 
@@ -214,10 +229,14 @@ define('io.ox/office/spreadsheet/model/drawing/axismodel', [
                 index++;
             }
 
-            // workaround for Bug 49637
             if (!isHorizontal()) {
+                // workaround for Bug 49637
                 dataAxis.minimum -= dataAxis.interval * 0.001;
                 dataAxis.maximum += dataAxis.interval * 0.001;
+            } else if (chartModel.isXYType()) {
+                // workaround for Bug 53190
+                dataAxis.minimum -= dataAxis.interval * 0.1;
+                dataAxis.maximum += dataAxis.interval * 0.1;
             }
 
             for (; index < stripLines.length; index++) {
@@ -228,24 +247,25 @@ define('io.ox/office/spreadsheet/model/drawing/axismodel', [
         }
 
         function refreshAxisX(data) {
-            var area = chartModel.getMergedAttributeSet(true).chart.type.indexOf('area') === 0;
+            var area = chartModel.getChartType().indexOf('area') === 0;
             if (!data.linearX && (chartModel.isXYType() || area)) {
                 var minValue = Number.POSITIVE_INFINITY;
                 var maxValue = Number.NEGATIVE_INFINITY;
 
                 _.each(data.series, function (dd) {
-                    _.each(dd.dataPoints, function (dataPoint) {
-                        var value = dataPoint[axisId];
+                    if (dd[indexName] !== indexValue) { return; }
+
+                    _.each(dd.dps, function (dataPoint) {
+                        var value = dataPoint[axisId[0]];
                         minValue = Math.min(minValue, value);
                         maxValue = Math.max(maxValue, value);
                     });
                 });
 
-                if (chartModel.isXYType()) {
-                    var intervalCount = Utils.minMax(data.series.length, 2, 8);
+                if (chartModel.getChartType().indexOf('bubble') === 0) {
                     var diff = maxValue - minValue;
-                    maxValue +=  diff / intervalCount;
-                    minValue -=  diff / intervalCount;
+                    maxValue +=  diff / 8;
+                    minValue -=  diff / 8;
                 }
 
                 if (!isFinite(minValue) || !isFinite(maxValue)) {
@@ -292,58 +312,74 @@ define('io.ox/office/spreadsheet/model/drawing/axismodel', [
 
             if (stacking === 'percentStacked' || (stacking === 'stacked' && data.series.length > 1)) {
                 var first = data.series[0];
-                _.times(first.dataPoints.length, function (j) {
+                _.times(first.dps.length, function (j) {
                     var posValue = 0;
                     var negValue = 0;
                     _.each(data.series, function (dd) {
-                        var jValue = dd.dataPoints[j];
+                        if (dd[indexName] !== indexValue) { return; }
+
+                        var jValue = dd.dps[j];
                         if (!jValue) { return; }
-                        var useValue = jValue[axisId];
+                        var useValue = jValue[axisId[0]];
                         if (useValue > 0) {
                             posValue += useValue;
                         } else if (useValue < 0) {
                             negValue += useValue;
                         }
                     });
+
+                    // fix for Bug 52765
+                    if (format && format.date) { negValue = posValue; }
+
                     minValue = Math.min(minValue, negValue);
                     maxValue = Math.max(maxValue, posValue);
                 });
             } else {
                 _.each(data.series, function (dd) {
-                    _.each(dd.dataPoints, function (dataPoint) {
-                        var value = dataPoint[axisId];
+                    if (dd[indexName] !== indexValue) { return; }
+
+                    _.each(dd.dps, function (dataPoint) {
+                        var value = dataPoint[axisId[0]];
                         minValue = Math.min(minValue, value);
                         maxValue = Math.max(maxValue, value);
                     });
                 });
             }
 
+            var precision = 2;
+            if (format && format.date) { precision = 0; }
+
             if (chartModel.isXYType()) {
-                var diff = maxValue - minValue;
-                maxValue += diff / 8;
-                minValue -= diff / 8;
+                precision = 2;
+                var diff = (maxValue - minValue) / 4;
+                if (chartModel.getChartType().indexOf('bubble') === 0) { diff *= 1.5; }
+                maxValue += diff * 2;
+                minValue -= diff;
             } else if (stacking === 'percentStacked') {
                 format = {
                     exp: -2,
                     format: chartModel.getDocModel().getNumberFormatter().getParsedFormat('0%', { grammarId: 'ui' })
                 };
-                //Trial & error...
+
                 if (maxValue >= 0 && minValue >= 0) {
                     // scenario 1
                     minValue = givenMin || 0;
-                    maxValue = givenMax || 110;
+                    maxValue = givenMax || 100;
                 } else if (maxValue <= 0 && minValue <= 0) {
                     // scenario 2
                     maxValue = givenMax || 0;
-                    minValue = givenMin || -110;
+                    minValue = givenMin || -100;
                 } else {
                     // scenario 3
-                    maxValue =  givenMax || 110;
-                    if (-minValue > maxValue) {
-                        minValue =  givenMin || -110;
-                    } else {
-                        minValue =  givenMin || (-100 * ((-minValue) / maxValue));
-                    }
+                    var maxSize = Math.max(maxValue, -minValue);
+                    var tmpMaxValue = 100 * (maxValue / maxSize);
+                    var tmpMinValue = -100 * ((-minValue) / maxSize);
+
+                    tmpMinValue = Math.max(-100, Utils.round(tmpMinValue - 5, 10));
+                    tmpMaxValue = Math.min(100, Utils.round(tmpMaxValue + 5, 10));
+
+                    minValue = givenMin || tmpMinValue;
+                    maxValue = givenMax || tmpMaxValue;
                 }
             } else {
                 if (maxValue >= 0 && minValue >= 0) {
@@ -358,8 +394,8 @@ define('io.ox/office/spreadsheet/model/drawing/axismodel', [
                     // scenario 3
                     var ma = maxValue;
                     var mi = minValue;
-                    maxValue =  givenMax || makeMax(mi, ma);
-                    minValue =  givenMin || -makeMax(-ma, -mi);
+                    maxValue = givenMax || makeMax(mi, ma);
+                    minValue = givenMin || -makeMax(-ma, -mi);
                 }
             }
 
@@ -373,11 +409,6 @@ define('io.ox/office/spreadsheet/model/drawing/axismodel', [
                 minValue -= 0.5;
             }
 
-            var precision = 2;
-            if (format && format.date) {
-                precision = 0;
-            }
-
             if (Math.abs(maxValue - minValue) > 0.00000000001) {
                 minValue = round(minValue, precision);
                 maxValue = round(maxValue, precision);
@@ -442,12 +473,12 @@ define('io.ox/office/spreadsheet/model/drawing/axismodel', [
         /**
          * Generates the undo operations needed to restore this chart axis.
          *
-         * @param {SheetOperationsGenerator} generator
+         * @param {SheetOperationGenerator} generator
          *  The operations generator to be filled with the undo operations.
          *
          * @param {Array<Number>} position
          *  The position of the parent chart object in the sheet, as expected
-         *  by the method SheetOperationsGenerator.generateDrawingOperation().
+         *  by the method SheetOperationGenerator.generateDrawingOperation().
          *
          * @returns {AxisModel}
          *  A reference to this instance.
@@ -471,12 +502,12 @@ define('io.ox/office/spreadsheet/model/drawing/axismodel', [
          * Generates the operations and undo operations to update or restore
          * the formula expressions of the source link of the axis title object.
          *
-         * @param {SheetOperationsGenerator} generator
+         * @param {SheetOperationGenerator} generator
          *  The operations generator to be filled with the operations.
          *
          * @param {Array<Number>} position
          *  The position of the parent chart object in the sheet, as expected
-         *  by the method SheetOperationsGenerator.generateDrawingOperation().
+         *  by the method SheetOperationGenerator.generateDrawingOperation().
          *
          * @param {Object} changeDesc
          *  The properties describing the document change. The properties that
