@@ -52,12 +52,12 @@ define('io.ox/office/spreadsheet/model/drawing/dataseriesmodel', [
         /**
          * Generates the undo operations needed to restore this data series.
          *
-         * @param {SheetOperationsGenerator} generator
+         * @param {SheetOperationGenerator} generator
          *  The operations generator to be filled with the undo operations.
          *
          * @param {Array<Number>} position
          *  The position of the parent chart object in the sheet, as expected
-         *  by the method SheetOperationsGenerator.generateDrawingOperation().
+         *  by the method SheetOperationGenerator.generateDrawingOperation().
          *
          * @param {Number} index
          *  The index of this data series in the collection of all data series.
@@ -72,15 +72,45 @@ define('io.ox/office/spreadsheet/model/drawing/dataseriesmodel', [
         };
 
         /**
-         * Generates the operations and undo operations to update or restore
-         * the formula expressions of the source links of this data series.
+         * Generates the operations and undo operations needed to change the
+         * formatting attributes of this data series.
          *
-         * @param {SheetOperationsGenerator} generator
+         * @param {SheetOperationGenerator} generator
          *  The operations generator to be filled with the operations.
          *
          * @param {Array<Number>} position
          *  The position of the parent chart object in the sheet, as expected
-         *  by the method SheetOperationsGenerator.generateDrawingOperation().
+         *  by the method SheetOperationGenerator.generateDrawingOperation().
+         *
+         * @param {Number} index
+         *  The index of this data series in the collection of all data series.
+         *
+         * @param {Object} attributeSet
+         *  The incomplete attribute set with all formatting attributes to be
+         *  changed.
+         *
+         * @returns {DataSeriesModel}
+         *  A reference to this instance.
+         */
+        this.generateChangeOperations = function (generator, position, index, attributeSet) {
+            var undoAttrSet = this.getUndoAttributeSet(attributeSet);
+            if (!_.isEmpty(undoAttrSet)) {
+                generator.generateDrawingOperation(Operations.SET_CHART_DATASERIES_ATTRIBUTES, position, { series: index, attrs: undoAttrSet }, { undo: true });
+                generator.generateDrawingOperation(Operations.SET_CHART_DATASERIES_ATTRIBUTES, position, { series: index, attrs: attributeSet });
+            }
+            return this;
+        };
+
+        /**
+         * Generates the operations and undo operations to update or restore
+         * the formula expressions of the source links of this data series.
+         *
+         * @param {SheetOperationGenerator} generator
+         *  The operations generator to be filled with the operations.
+         *
+         * @param {Array<Number>} position
+         *  The position of the parent chart object in the sheet, as expected
+         *  by the method SheetOperationGenerator.generateDrawingOperation().
          *
          * @param {Number} index
          *  The index of this data series in the collection of all data series.
@@ -96,7 +126,7 @@ define('io.ox/office/spreadsheet/model/drawing/dataseriesmodel', [
             // when the value range will be deleted (e.g. while deleting a column), remove the entire data series from the chart
             if (changeDesc.type === 'moveCells') {
                 var valueRanges = this.resolveRanges('series.values');
-                if (valueRanges && MoveDescriptor.transformRanges(valueRanges, changeDesc.moveDescs).empty()) {
+                if (valueRanges && !valueRanges.empty() && MoveDescriptor.transformRanges(valueRanges, changeDesc.moveDescs).empty()) {
                     this.generateRestoreOperations(generator, position, index);
                     generator.generateDrawingOperation(Operations.DELETE_CHART_DATASERIES, position, { series: index });
                     return;
