@@ -13,9 +13,12 @@
  */
 
 define('io.ox/office/spreadsheet/model/drawing/drawingmodelmixin', [
+    'io.ox/office/tk/utils',
+    'io.ox/office/drawinglayer/utils/drawingutils',
     'io.ox/office/spreadsheet/utils/operations',
-    'io.ox/office/spreadsheet/utils/sheetutils'
-], function (Operations, SheetUtils) {
+    'io.ox/office/spreadsheet/utils/sheetutils',
+    'io.ox/office/spreadsheet/model/drawing/text/textframeutils'
+], function (Utils, DrawingUtils, Operations, SheetUtils, TextFrameUtils) {
 
     'use strict';
 
@@ -42,8 +45,11 @@ define('io.ox/office/spreadsheet/model/drawing/drawingmodelmixin', [
         endOffset: 'endRowOffset'
     };
 
-    // the names of all anchor attributes in the 'drawing' attribute family
-    var ANCHOR_ATTR_NAMES = ['anchorType'].concat(_.values(COL_ATTRIBUTE_NAMES)).concat(_.values(ROW_ATTRIBUTE_NAMES));
+    // rotation/flip drawing attribute names
+    var ROTATE_ATTRIBUTE_NAMES = ['rotation', 'flipH', 'flipV'];
+
+    // the names of all cell anchor attributes in the 'drawing' attribute family
+    var CELL_ANCHOR_ATTR_NAMES = ['anchorType'].concat(_.values(COL_ATTRIBUTE_NAMES)).concat(_.values(ROW_ATTRIBUTE_NAMES)).concat(ROTATE_ATTRIBUTE_NAMES);
 
     // class DrawingModelMixin ================================================
 
@@ -66,21 +72,24 @@ define('io.ox/office/spreadsheet/model/drawing/drawingmodelmixin', [
      *  A callback function invoked from the public method clone() which has to
      *  create and return a new instance cloned from this drawing model.
      *
-     * @param {Function} [generateRestoreOperations]
-     *  A callback function that will be invoked from the own public method
-     *  DrawingModelMixin.generateDeleteOperations() while generating document
-     *  operations that will delete this drawing object. An implementation must
-     *  generate more undo operations to restore the complete drawing object.
-     *
-     * @param {Function} [generateUpdateFormulaOperations]
-     *  A callback function that will be invoked from the own public method
-     *  DrawingModelMixin.generateUpdateFormulaOperations() while generating
-     *  document operations that involve to update the formula expressions in
-     *  this drawing object. Receives all parameters passed to the public
-     *  method mentioned before. May return an attribute set with additional
-     *  formatting attributes to be applied at this drawing object, or null.
+     * @param {Object} [initOptions]
+     *  Optional parameters:
+     *  @param {Function} [initOptions.generateRestoreOperations]
+     *      A callback function that will be invoked from the own public method
+     *      DrawingModelMixin.generaterestoreOperations() while generating
+     *      document operations that will delete this drawing object. An
+     *      implementation must generate more undo operations to restore the
+     *      complete drawing object.
+     *  @param {Function} [initOptions.generateUpdateFormulaOperations]
+     *      A callback function that will be invoked from the own public method
+     *      DrawingModelMixin.generateUpdateFormulaOperations() while
+     *      generating document operations that involve to update the formula
+     *      expressions in this drawing object. Receives all parameters passed
+     *      to the public method mentioned before. May return an attribute set
+     *      with additional formatting attributes to be applied at this drawing
+     *      object, or null.
      */
-    function DrawingModelMixin(sheetModel, cloneConstructor, generateRestoreOperations, generateUpdateFormulaOperations) {
+    function DrawingModelMixin(sheetModel, cloneConstructor, initOptions) {
 
         // self reference
         var self = this;
@@ -88,9 +97,21 @@ define('io.ox/office/spreadsheet/model/drawing/drawingmodelmixin', [
         // the document model instance
         var docModel = sheetModel.getDocModel();
 
+        // the attribute pool for drawing formatting
+        var attributePool = docModel.getDrawingAttributePool();
+
         // the drawing collection containing this drawing model
         var drawingCollection = sheetModel.getDrawingCollection();
 
+        // callback handler to generate additional restore operations
+        var generateRestoreOperationsHandler = Utils.getFunctionOption(initOptions, 'generateRestoreOperations', null);
+
+        // callback handler to generate additional operations to update formula expressions
+        var generateUpdateFormulaOperationsHandler = Utils.getFunctionOption(initOptions, 'generateUpdateFormulaOperations', null);
+
+        // whether this drawing object is embedded in another drawing object (e.g. group object)
+        var embedded = this.isEmbedded();
+
         // private methods ----------------------------------------------------
 
         /**
@@ -99,33 +120,34 @@ define('io.ox/office/spreadsheet/model/drawing/drawingmodelmixin', [
          * @returns {Object}
          *  A copy of the anchor attributes of this drawing object.
          */
-        function getAnchorAttributes() {
+        function getCellAnchorAttributes() {
             var drawingAttrs = self.getMergedAttributeSet(true).drawing;
-            return ANCHOR_ATTR_NAMES.reduce(function (attrs, name) {
+            return CELL_ANCHOR_ATTR_NAMES.reduce(function (attrs, name) {
                 attrs[name] = drawingAttrs[name];
                 return attrs;
             }, {});
         }
 
         /**
-         * Generates the anchor attributes needed to update the position of
-         * this drawing object, after cells have been moved in the document.
+         * Generates the cell anchor attributes needed to update the location
+         * of this top-level drawing object, after cells have been moved in the
+         * document.
          *
          * @param {MoveDescriptor} moveDescs
          *  An array of move descriptors that specify how to transform the
-         *  position of this drawing object.
+         *  location of this drawing object.
          *
          * @returns {Object|Null}
          *  The value null to indicate that this drawing object will be deleted
          *  from the sheet by the passed move descriptors; otherwise the anchor
-         *  attributes that need to ne applied at this drawing object to update
-         *  its position. An empty object indicates that the drawing object
+         *  attributes that need to be applied at this drawing object to update
+         *  its location. An empty object indicates that the drawing object
          *  will not be modified at all.
          */
         function generateMoveCellsAttributes(moveDescs) {
 
-            // copy of the current anchor attributes, will be recalculated below
-            var anchorAttrs = getAnchorAttributes();
+            // copy of the current cell anchor attributes, will be recalculated below
+            var anchorAttrs = getCellAnchorAttributes();
             // the cell range covered by the drawing object
             var drawingRange = self.getRange();
 
@@ -147,7 +169,7 @@ define('io.ox/office/spreadsheet/model/drawing/drawingmodelmixin', [
                 if (moveDesc.insert) {
 
                     // insertion mode: process the target intervals from first to last
-                    return moveDesc.targetIntervals.some(function (interval) {
+                    moveDesc.targetIntervals.every(function (interval) {
 
                         // the number of columns/rows to be inserted
                         var move = interval.size();
@@ -157,7 +179,7 @@ define('io.ox/office/spreadsheet/model/drawing/drawingmodelmixin', [
                         // the maximum number of columns/rows the drawing can be moved
                         var maxMove = Math.min(move, maxIndex - endIndex);
 
-                        // do nothing, if drawing cannot be move anymore
+                        // do nothing, if drawing cannot be moved anymore
                         if (maxMove === 0) { return false; }
 
                         // move end position, if the columns/rows are inserted inside the drawing object
@@ -170,7 +192,13 @@ define('io.ox/office/spreadsheet/model/drawing/drawingmodelmixin', [
                                 drawingRange.start.move(maxMove, columns);
                             }
                         }
+
+                        // continue to process the target intervals
+                        return true;
                     });
+
+                    // do not delete drawings when inserting cells
+                    return false;
                 }
 
                 // deletion mode: process the target intervals in reversed order
@@ -193,7 +221,7 @@ define('io.ox/office/spreadsheet/model/drawing/drawingmodelmixin', [
                         // move end position, if the columns/rows are deleted before the end
                         anchorAttrs[ATTR_NAMES.endIndex] -= move;
                         drawingRange.end.move(-move, columns);
-                    } else {
+                    } else if (interval.first <= endIndex) {
                         // cut end of drawing object at the deleted interval
                         if (interval.first === 0) { return true; }
                         anchorAttrs[ATTR_NAMES.endIndex] = interval.first;
@@ -214,7 +242,7 @@ define('io.ox/office/spreadsheet/model/drawing/drawingmodelmixin', [
             });
 
             // update the inactive anchor attributes according to anchor type (this may return to the old cell anchor)
-            return deleteDrawing ? null : _.extend(anchorAttrs, drawingCollection.getInactiveAnchorAttributes(anchorAttrs, { displayAnchor: true }));
+            return deleteDrawing ? null : _.extend(anchorAttrs, drawingCollection.getInactiveCellAnchorAttributes(anchorAttrs, { displayAnchor: true }));
         }
 
         // protected methods --------------------------------------------------
@@ -228,15 +256,32 @@ define('io.ox/office/spreadsheet/model/drawing/drawingmodelmixin', [
          *  DO NOT CALL from external code!
          *
          * @param {SheetModel} targetModel
-         *  The model instance of the new cloned sheet that will own the clone
-         *  returned by this method.
+         *  The model instance of the new cloned sheet that will own the target
+         *  drawing collection.
+         *
+         * @param {DrawingCollection} targetCollection
+         *  The drawing collection that will own the clone returned by this
+         *  method. May be the root drawing collection of the target sheet, or
+         *  an embedded drawing collection of a group object.
          *
          * @returns {DrawingModelMixin}
          *  A clone of this drawing model, initialized for ownership by the
          *  passed sheet model.
          */
-        this.clone = function (targetModel) {
-            return cloneConstructor.call(this, targetModel);
+        this.clone = function (targetModel, targetCollection) {
+
+            // the new clone of this drawing model
+            var cloneModel = cloneConstructor.call(this, targetModel, targetCollection);
+            // the embedded child collection of the new drawing model
+            var cloneCollection = cloneModel.getChildCollection();
+
+            // clone the child drawing collection (e.g. group objects)
+            this.forEachChildModel(function (childModel, childIndex) {
+                var childCloneModel = childModel.clone(targetModel, cloneCollection);
+                cloneCollection.implInsertModel([childIndex], childCloneModel);
+            });
+
+            return cloneModel;
         };
 
         // public methods -----------------------------------------------------
@@ -252,29 +297,14 @@ define('io.ox/office/spreadsheet/model/drawing/drawingmodelmixin', [
         };
 
         /**
-         * Returns the position of this drawing model in the drawing collection
-         * of the sheet.
+         * Returns the global document position of this drawing model, as used
+         * in document operations, including the leading sheet index.
          *
-         * @returns {Array<Number>|Null}
-         *  The sheet position of the drawing object, if it is still contained
-         *  in the drawing collection; otherwise null.
+         * @returns {Array<Number>}
+         *  The global document position of this drawing model.
          */
-        this.getSheetPosition = function () {
-            return drawingCollection.getModelPosition(this, { deep: true });
-        };
-
-        /**
-         * Returns the complete document position of this drawing model, as
-         * used in document operations, including the leading sheet index.
-         *
-         * @returns {Array<Number>|Null}
-         *  The complete position of the drawing object, if it is still
-         *  contained in the drawing collection, including the zero-based sheet
-         *  index as first array element; otherwise null.
-         */
-        this.getDocumentPosition = function () {
-            var position = this.getSheetPosition();
-            return position ? [sheetModel.getIndex()].concat(position) : null;
+        this.getDocPosition = function () {
+            return [sheetModel.getIndex()].concat(this.getPosition());
         };
 
         /**
@@ -285,28 +315,97 @@ define('io.ox/office/spreadsheet/model/drawing/drawingmodelmixin', [
          *  The address of the cell range covered by this drawing model.
          */
         this.getRange = function () {
+
+            // the drawing attributes contain the cell anchor values
             var anchorAttrs = this.getMergedAttributeSet(true).drawing;
+            // build the cell range address from the anchor attributes
             var range = Range.create(anchorAttrs.startCol, anchorAttrs.startRow, anchorAttrs.endCol, anchorAttrs.endRow);
+
             // shorten by one column/row, if the end offset is zero
             if ((anchorAttrs.endColOffset === 0) && !range.singleCol()) { range.end[0] -= 1; }
             if ((anchorAttrs.endRowOffset === 0) && !range.singleRow()) { range.end[1] -= 1; }
+
             return range;
         };
 
         /**
-         * Returns the sheet rectangle in pixels covered by this drawing
-         * object.
+         * Returns the rectangle in pixels covered by this drawing object,
+         * either relative to its parent area (the sheet area for top-level
+         * drawing objects, or the rectangle of the parent drawing object); or
+         * always absolute in the sheet area.
+         *
+         * @param {Object} [options]
+         *  Optional parameters:
+         *  - {Boolean} [options.absolute=false]
+         *      If set to true, this method will return the absolute sheet
+         *      position also for drawing objects embedded into other drawing
+         *      objects. By default, this method returns the location of the
+         *      specified drawing object relative to its parent object.
+         *
+         * @returns {Rectangle|Null}
+         *  The location of this drawing object in pixels according to the
+         *  current sheet zoom factor, either relative to its parent object
+         *  (sheet area for top-level drawing objects), or always absolute in
+         *  the sheet area (according to the passed options); or null, if the
+         *  drawing object is hidden by itself, or is located in a hidden group
+         *  object, or is located entirely in hidden columns or rows and thus
+         *  is invisible.
+         */
+        this.getRectangle = function (options) {
+            return drawingCollection.getRectangleForModel(this, options);
+        };
+
+        /**
+         * Returns the minimum pixel size this drawing object needs for proper
+         * rendering. For area-like objects, the minimum size is 5 pixels. For
+         * connector shapes, the minimum size is 1 pixel in order to be able to
+         * show horizontal or vertical straight lines.
+         *
+         * @returns {Number}
+         *  The minimum pixel size this drawing object needs for proper
+         *  rendering.
+         */
+        this.getMinSize = function () {
+            return this.isTwoPointShape() ? 1 : 5;
+        };
+
+        /**
+         * Returns whether the transformation attributes of this drawing model
+         * will lead to swapped width and height of the rendered drawing frame.
+         *
+         * @returns {Boolean}
+         *  Whether the transformation attributes will lead to swapped width
+         *  and height of the rendered drawing frame.
+         */
+        this.hasSwappedDimensions = function () {
+            return DrawingUtils.hasSwappedDimensions(this.getMergedAttributeSet(true).drawing);
+        };
+
+        /**
+         * Returns the DOM drawing frame that represents this drawing model.
+         * The DOM drawing frame is used to store the text contents of this
+         * drawing object.
+         *
+         * @returns {jQuery|Null}
+         *  The DOM drawing frame for this drawing model; or null, if no DOM
+         *  drawing frame could be found.
+         */
+        this.getModelFrame = function () {
+            return drawingCollection.getDrawingFrameForModel(this);
+        };
+
+        /**
+         * Refreshes the settings of the DOM drawing frame associated with this
+         * drawing model, and returns the cached rendering settings.
          *
          * @returns {Object|Null}
-         *  The position of this drawing object in the sheet in pixels,
-         *  according to the current sheet zoom factor, in the properties
-         *  'left', 'top', 'width', and 'height'; or null if the drawing object
-         *  is hidden by itself, or is located entirely in hidden columns or
-         *  rows and thus invisible.
+         *  A descriptor with rendering data for this drawing model; or null,
+         *  if no data is available for the drawing model. See description of
+         *  the method SheetDrawingCollection.refreshDrawingFrameForModel() for
+         *  details.
          */
-        this.getRectangle = function () {
-            // always return null for invisible drawing objects
-            return this.isVisible() ? drawingCollection.getRectangleForAnchor(this.getMergedAttributeSet(true).drawing) : null;
+        this.refreshModelFrame = function () {
+            return drawingCollection.refreshDrawingFrameForModel(this);
         };
 
         // operation generators -----------------------------------------------
@@ -315,54 +414,83 @@ define('io.ox/office/spreadsheet/model/drawing/drawingmodelmixin', [
          * Generates the operations, and the undo operations, to change the
          * attributes of this drawing object.
          *
-         * @param {SheetOperationsGenerator} generator
+         * @param {SheetOperationGenerator} generator
          *  The operations generator to be filled with the operations.
          *
-         * @param {Array<Number>} position
-         *  The position of this drawing object in the sheet, as expected by
-         *  the method SheetOperationsGenerator.generateDrawingOperation().
+         * @param {Object} attributeSet
+         *  The incomplete attribute set with all formatting attributes to be
+         *  changed.
          *
          * @returns {DrawingModelMixin}
          *  A reference to this instance.
          */
-        this.generateChangeOperations = function (generator, position, attributeSet) {
-            generator.generateDrawingOperation(Operations.SET_DRAWING_ATTRIBUTES, position, { attrs: this.getUndoAttributeSet(attributeSet) }, { undo: true });
-            generator.generateDrawingOperation(Operations.SET_DRAWING_ATTRIBUTES, position, { attrs: attributeSet });
+        this.generateChangeOperations = function (generator, attributeSet) {
+            var position = this.getPosition();
+            var undoAttrSet = this.getUndoAttributeSet(attributeSet);
+            if (!_.isEmpty(undoAttrSet)) {
+                generator.generateDrawingOperation(Operations.CHANGE_DRAWING, position, { attrs: undoAttrSet }, { undo: true });
+                generator.generateDrawingOperation(Operations.CHANGE_DRAWING, position, { attrs: attributeSet });
+            }
             return this;
         };
 
         /**
-         * Generates the operations, and the undo operations, to delete the
-         * specified drawing objects from this collection.
+         * Generates the undo operations needed to restore this drawing object.
          *
-         * @param {SheetOperationsGenerator} generator
-         *  The operations generator to be filled with the operations.
-         *
-         * @param {Array<Number>} position
-         *  The position of this drawing object in the sheet, as expected by
-         *  the method SheetOperationsGenerator.generateDrawingOperation().
+         * @param {SheetOperationGenerator} generator
+         *  The operations generator to be filled with the undo operations.
          *
          * @returns {DrawingModelMixin}
          *  A reference to this instance.
          */
-        this.generateDeleteOperations = function (generator, position) {
+        this.generateRestoreOperations = function (generator) {
 
-            // bug 47948: do not undo unsupported drawing types
-            var drawingType = this.getType();
-            if (drawingType !== 'undefined') {
+            // bug 47948: do not restore unsupported drawing types
+            if (!this.isDeepSupported()) { return this; }
 
-                // undo: create an 'insertDrawing' operation to restore the drawing model with its attributes
-                var undoProperties = { type: drawingType, attrs: this.getExplicitAttributeSet(true) };
-                generator.generateDrawingOperation(Operations.INSERT_DRAWING, position, undoProperties, { undo: true });
+            // the operation position of the drawing object in the root collection
+            var position = this.getPosition();
 
-                // additional undo operations for complex drawing contents
-                if (_.isFunction(generateRestoreOperations)) {
-                    generateRestoreOperations.call(this, generator, position);
-                }
+            // create an 'insertDrawing' operation to restore the drawing model with its attributes
+            var undoProperties = { type: this.getType() };
+            var attrSet = this.getExplicitAttributeSet(true);
+            if (!_.isEmpty(attrSet)) { undoProperties.attrs = attrSet; }
+            generator.generateDrawingOperation(Operations.INSERT_DRAWING, position, undoProperties, { undo: true });
+
+            // additional undo operations for complex drawing contents
+            if (generateRestoreOperationsHandler) {
+                generateRestoreOperationsHandler.call(this, generator, position);
             }
 
-            // generate the delete operation for this drawing object
-            generator.generateDrawingOperation(Operations.DELETE_DRAWING, position);
+            // generate the operations to restore the text contents
+            var modelFrame = this.getModelFrame();
+            if (TextFrameUtils.getTextFrame(modelFrame)) {
+                var textGenerator = docModel.createOperationGenerator();
+                textGenerator.generateContentOperations(modelFrame, [sheetModel.getIndex()].concat(position));
+                generator.appendOperations(textGenerator.getOperations(), { undo: true });
+            }
+
+            // generate the operations to restore all embedded drawing objects
+            this.forEachChildModel(function (childModel) {
+                childModel.generateRestoreOperations(generator);
+            });
+
+            return this;
+        };
+
+        /**
+         * Generates the operations to delete, and the undo operations to
+         * restore this drawing object.
+         *
+         * @param {SheetOperationGenerator} generator
+         *  The operations generator to be filled with the operations.
+         *
+         * @returns {DrawingModelMixin}
+         *  A reference to this instance.
+         */
+        this.generateDeleteOperations = function (generator) {
+            this.generateRestoreOperations(generator);
+            generator.generateDrawingOperation(Operations.DELETE_DRAWING, this.getPosition());
             return this;
         };
 
@@ -372,26 +500,25 @@ define('io.ox/office/spreadsheet/model/drawing/drawingmodelmixin', [
          * size or visibility of the columns or rows in the sheet has been
          * changed.
          *
-         * @param {SheetOperationsGenerator} generator
+         * @param {SheetOperationGenerator} generator
          *  The operations generator to be filled with the operations.
          *
-         * @param {Array<Number>} position
-         *  The position of this drawing object in the sheet, as expected by
-         *  the method SheetOperationsGenerator.generateDrawingOperation().
-         *
          * @returns {DrawingModelMixin}
          *  A reference to this instance.
          */
-        this.generateUpdateAnchorOperations = function (generator, position) {
+        this.generateUpdateAnchorOperations = function (generator) {
+
+            // nothing to do for embedded drawing objects
+            if (embedded) { return this; }
 
             // update the inactive anchor attributes according to the anchor type of the drawing object
-            var anchorAttrs = getAnchorAttributes();
-            _.extend(anchorAttrs, drawingCollection.getInactiveAnchorAttributes(anchorAttrs, { displayAnchor: true }));
+            var anchorAttrs = getCellAnchorAttributes();
+            _.extend(anchorAttrs, drawingCollection.getInactiveCellAnchorAttributes(anchorAttrs, { displayAnchor: true }));
 
             // create a change operation, if some attributes will be changed in this drawing
             var attributeSet = this.getReducedAttributeSet({ drawing: anchorAttrs });
             if (!_.isEmpty(attributeSet)) {
-                this.generateChangeOperations(generator, position, attributeSet);
+                this.generateChangeOperations(generator, attributeSet);
             }
 
             return this;
@@ -402,13 +529,9 @@ define('io.ox/office/spreadsheet/model/drawing/drawingmodelmixin', [
          * the formula expressions of the source links in this drawing object
          * that refer to some cells in this document.
          *
-         * @param {SheetOperationsGenerator} generator
+         * @param {SheetOperationGenerator} generator
          *  The operations generator to be filled with the operations.
          *
-         * @param {Array<Number>} position
-         *  The position of this drawing object in the sheet, as expected by
-         *  the method SheetOperationsGenerator.generateDrawingOperation().
-         *
          * @param {Object} changeDesc
          *  The properties describing the document change. The properties that
          *  are expected in this descriptor depend on the change type in its
@@ -418,36 +541,29 @@ define('io.ox/office/spreadsheet/model/drawing/drawingmodelmixin', [
          * @returns {DrawingModelMixin}
          *  A reference to this instance.
          */
-        this.generateUpdateFormulaOperations = function (generator, position, changeDesc) {
+        this.generateUpdateFormulaOperations = function (generator, changeDesc) {
 
-            // update the position of top-level drawing objects, if cells in the own sheet will be moved
-            var anchorAttrs = null;
-            if ((changeDesc.type === 'moveCells') && (position.length === 1) && (changeDesc.sheet === sheetModel.getIndex())) {
+            // whether a top-level drawing object is affected by a move operation in its own sheet
+            var topLevelMove = !embedded && (changeDesc.type === 'moveCells') && (changeDesc.sheet === sheetModel.getIndex());
+            // update the anchor of top-level drawing objects, if cells in the own sheet will be moved (may delete a complete object!)
+            var anchorAttrs = topLevelMove ? generateMoveCellsAttributes(changeDesc.moveDescs) : null;
 
-                // calculate the new anchor attributes
-                anchorAttrs = generateMoveCellsAttributes(changeDesc.moveDescs);
-
-                // delete the drawing object if the parent cells have been deleted
-                if (!anchorAttrs) {
-                    return this.generateDeleteOperations(generator, position);
-                }
+            // delete the top-level drawing object if all its parent cells have been deleted
+            if (topLevelMove && !anchorAttrs) {
+                return this.generateDeleteOperations(generator);
             }
 
             // the formatting attributes to be applied for this drawing object
             var attributeSet = null;
 
             // derived classes may generate new operations for child objects, and additional formatting attributes
-            if (_.isFunction(generateUpdateFormulaOperations)) {
-                attributeSet = generateUpdateFormulaOperations.call(this, generator, position, changeDesc);
+            if (generateUpdateFormulaOperationsHandler) {
+                attributeSet = generateUpdateFormulaOperationsHandler.call(this, generator, this.getPosition(), changeDesc);
             }
 
             // add the new anchor attributes to the attribute set
             if (!_.isEmpty(anchorAttrs)) {
-                if (attributeSet) {
-                    attributeSet.drawing = _.isEmpty(attributeSet.drawing) ? anchorAttrs : _.extend(attributeSet.drawing, anchorAttrs);
-                } else {
-                    attributeSet = { drawing: anchorAttrs };
-                }
+                attributeSet = attributePool.extendAttributeSet(attributeSet || {}, { drawing: anchorAttrs });
             }
 
             // reduce the attribute to the attributes that will actually change
@@ -457,17 +573,28 @@ define('io.ox/office/spreadsheet/model/drawing/drawingmodelmixin', [
 
             // create a change operation, if some attributes will be changed in this drawing
             if (!_.isEmpty(attributeSet)) {
-                this.generateChangeOperations(generator, position, attributeSet);
+                this.generateChangeOperations(generator, attributeSet);
             }
 
+            // generate the operations to update all embedded drawing objects
+            this.forEachChildModel(function (childModel) {
+                childModel.generateUpdateFormulaOperations(generator, changeDesc);
+            });
+
             return this;
         };
 
         // initialization -----------------------------------------------------
 
+        // add missing inactive anchor attributes that can be calculated from the existing anchor attributes
+        if (!embedded) {
+            var anchorAttrs = drawingCollection.getInactiveCellAnchorAttributes(this.getMergedAttributeSet(true).drawing);
+            this.setAttributes({ drawing: anchorAttrs }, { notify: 'never' });
+        }
+
         // destroy all class members on destruction
         this.registerDestructor(function () {
-            docModel = sheetModel = drawingCollection = cloneConstructor = null;
+            docModel = sheetModel = attributePool = drawingCollection = cloneConstructor = null;
         });
 
     } // class DrawingModelMixin
