@@ -39,7 +39,7 @@ define('io.ox/office/spreadsheet/model/drawing/titlemodel', [
      *  The identifier of this title object. Can be 'main' for the main title
      *  of the chart, or 'x', 'y', or 'z' for the respective axis title.
      */
-    var TitleModel = AttributedModel.extend({ constructor: function (chartModel, titleId, data, key) {
+    var TitleModel = AttributedModel.extend({ constructor: function (chartModel, titleId, data, textKey, dataKey) {
 
         var self = this;
         var sheetModel = chartModel.getSheetModel();
@@ -56,12 +56,12 @@ define('io.ox/office/spreadsheet/model/drawing/titlemodel', [
         this.refreshInfo = function () {
 
             var display = this.resolveText('text.link') || name;
-            var change = data[key] !== display;
-            data[key] = display;
+            var change = data[textKey] !== display;
+            data[textKey] = display;
 
             if (display) {
                 var attrs = self.getMergedAttributeSet(true);
-                ChartStyleUtil.handleCharacterProps(chartModel, attrs.character, data, key);
+                ChartStyleUtil.handleCharacterProps(chartModel, attrs.character, data, dataKey);
             }
             return change;
         };
@@ -75,12 +75,12 @@ define('io.ox/office/spreadsheet/model/drawing/titlemodel', [
         /**
          * Generates the undo operations needed to restore this title object.
          *
-         * @param {SheetOperationsGenerator} generator
+         * @param {SheetOperationGenerator} generator
          *  The operations generator to be filled with the undo operations.
          *
          * @param {Array<Number>} position
          *  The position of the parent chart object in the sheet, as expected
-         *  by the method SheetOperationsGenerator.generateDrawingOperation().
+         *  by the method SheetOperationGenerator.generateDrawingOperation().
          *
          * @returns {TitleModel}
          *  A reference to this instance.
@@ -97,12 +97,12 @@ define('io.ox/office/spreadsheet/model/drawing/titlemodel', [
          * Generates the operations and undo operations to update or restore
          * the formula expressions of the source link of this title object.
          *
-         * @param {SheetOperationsGenerator} generator
+         * @param {SheetOperationGenerator} generator
          *  The operations generator to be filled with the operations.
          *
          * @param {Array<Number>} position
          *  The position of the parent chart object in the sheet, as expected
-         *  by the method SheetOperationsGenerator.generateDrawingOperation().
+         *  by the method SheetOperationGenerator.generateDrawingOperation().
          *
          * @param {Object} changeDesc
          *  The properties describing the document change. The properties that
