@@ -15,8 +15,8 @@
 define('io.ox/office/spreadsheet/model/formula/deps/dependencyutils', [
     'io.ox/office/tk/config',
     'io.ox/office/tk/utils/logger',
-    'io.ox/office/spreadsheet/utils/address'
-], function (Config, Logger, Address) {
+    'io.ox/office/tk/container/valueset'
+], function (Config, Logger, ValueSet) {
 
     'use strict';
 
@@ -45,7 +45,7 @@ define('io.ox/office/spreadsheet/model/formula/deps/dependencyutils', [
      * @constant
      * @type {Number}
      */
-    DependencyUtils.TIMER_SLICE_DELAY = FAST_MODE ? 10 : 100;
+    DependencyUtils.TIMER_INTERVAL = FAST_MODE ? 10 : 100;
 
     /**
      * Duration for a single time slice of the background update task of the
@@ -63,7 +63,7 @@ define('io.ox/office/spreadsheet/model/formula/deps/dependencyutils', [
      * @constant
      * @type {Number}
      */
-    DependencyUtils.PRIORITY_TIMER_SLICE_DELAY = FAST_MODE ? 10 : 50;
+    DependencyUtils.PRIORITY_TIMER_INTERVAL = FAST_MODE ? 10 : 50;
 
     /**
      * Delay for starting the background update task of the dependency manager
@@ -88,10 +88,23 @@ define('io.ox/office/spreadsheet/model/formula/deps/dependencyutils', [
     // debug logger for the dependency manager
     Logger.extend(DependencyUtils, { enable: 'spreadsheet:log-deps', prefix: 'DEP' });
 
+    // classes ----------------------------------------------------------------
+
+    /**
+     * A set of instances of the class FormulaDescriptor.
+     *
+     * @constructor
+     *
+     * @extends ValueSet
+     */
+    DependencyUtils.FormulaSet = ValueSet.extend({ constructor: function () {
+        ValueSet.call(this, 'formulaKey');
+    } });
+
     // static methods ---------------------------------------------------------
 
     /**
-     * Returns the cell key for the specified sheet UID and cell address.
+     * Returns the formula key for the specified sheet UID and cell address.
      *
      * @param {String} sheetUid
      *  The UID of a sheet in a spreadsheet document.
@@ -100,26 +113,45 @@ define('io.ox/office/spreadsheet/model/formula/deps/dependencyutils', [
      *  The cell address to create a cell key for.
      *
      * @returns {String}
-     *  A unique map key for the specified cell address.
+     *  The formula key for the specified cell address.
      */
     DependencyUtils.getCellKey = function (sheetUid, address) {
         return sheetUid + '!' + address.key();
     };
 
     /**
-     * Converts the passed formula key of a cell formula to a readable cell
-     * address label for debug logging.
+     * Returns the formula key for the specified source link formula.
      *
-     * @param {String} formulaKey
-     *  A formula key of a any formula.
+     * @param {SourceLinkMixin} linkModel
+     *  An attributed model instance with the SourceLinkMixin class mixed in.
+     *
+     * @param {String} linkKey
+     *  The fully qualified attribute name of the source link formula.
      *
      * @returns {String}
-     * A readable cell address label for the passed key for debug logging, if
-     * available; otherwise the passed formula key as-is.
+     *  The formula key for the specified source link formula.
      */
-    DependencyUtils.getFormulaLabel = function (formulaKey) {
-        var result = /(.+!)(\d+),(\d+)$/.exec(formulaKey);
-        return result ? (result[1] + new Address(parseInt(result[2], 10), parseInt(result[3], 10))) : formulaKey;
+    DependencyUtils.getLinkKey = function (linkModel, linkKey) {
+        return linkModel.getUid() + '!' + linkKey;
+    };
+
+    // debugging methods ------------------------------------------------------
+
+    /**
+     * Returns a readable label for the passed cell range address for debug
+     * logging.
+     *
+     * @param {SheetModel} sheetModel
+     *  The model of the sheet containing the cell range.
+     *
+     * @param {Range} range
+     *  The address of a cell range.
+     *
+     * @returns {String}
+     *  A readable label for the passed cell range address for debug logging.
+     */
+    DependencyUtils.getRangeLabel = function (sheetModel, range) {
+        return sheetModel.getName() + '!' + (range.single() ? range.start : range);
     };
 
     /**
@@ -133,7 +165,20 @@ define('io.ox/office/spreadsheet/model/formula/deps/dependencyutils', [
      */
     DependencyUtils.getNameLabel = function (nameModel) {
         var sheetModel = nameModel.getSheetModel();
-        return 'name:' + (sheetModel ? (sheetModel.getName() + '!') : '') + nameModel.getLabel();
+        return '{NAME}' + (sheetModel ? sheetModel.getName() : '[0]') + '!' + nameModel.getLabel();
+    };
+
+    /**
+     * Returns a readable label for the passed table range for debug logging.
+     *
+     * @param {TableModel} tableModel
+     *  The model instance of a table range.
+     *
+     * @returns {String}
+     *  A readable label for the passed table range for debug logging.
+     */
+    DependencyUtils.getTableLabel = function (tableModel) {
+        return '{TABLE}' + tableModel.getSheetModel().getName() + '!' + tableModel.getName();
     };
 
     /**
@@ -147,19 +192,36 @@ define('io.ox/office/spreadsheet/model/formula/deps/dependencyutils', [
      *  A readable label for the passed formatting rule for debug logging.
      */
     DependencyUtils.getRuleLabel = function (ruleModel) {
-        return 'rule:' + ruleModel.getSheetModel().getName() + '!' + ruleModel.getUid();
+        return '{RULE}' + ruleModel.getSheetModel().getName() + '!' + ruleModel.getTargetRanges();
+    };
+
+    /**
+     * Returns a readable label for the passed source link for debug logging.
+     *
+     * @param {SourceLinkMixin} linkModel
+     *  The model instance of a source link.
+     *
+     * @returns {String}
+     *  A readable label for the passed source link for debug logging.
+     */
+    DependencyUtils.getLinkLabel = function (linkModel) {
+        return '{LINK}' + linkModel.getSheetModel().getName() + '!' + linkModel.getUid();
+    };
+
+    DependencyUtils.getTokenLabel = function (tokenModel) {
+        return tokenModel.getTargetRanges ? DependencyUtils.getRuleLabel(tokenModel) : DependencyUtils.getLinkLabel(tokenModel);
     };
 
     /**
      * Prints all formula descriptors in the passed map to the browser console,
      * if dependency logging is active.
      *
-     * @param {SimpleMap<FormulaDescriptor>} formulaMap
-     *  A map with all formula descriptors to be logged to the browser console.
+     * @param {FormulaSet} formulaSet
+     *  All formula descriptors to be logged to the browser console.
      */
-    DependencyUtils.logFormulaMap = DependencyUtils.isLoggingActive() ? function (formulaMap) {
-        formulaMap.forEach(function (formulaDesc, formulaKey) {
-            DependencyUtils.log('key=' + DependencyUtils.getFormulaLabel(formulaKey) + ' references=' + formulaDesc.references + ' circular=' + formulaDesc.circular);
+    DependencyUtils.logFormulaSet = DependencyUtils.isLoggingActive() ? function (formulaSet) {
+        formulaSet.forEach(function (formulaDesc) {
+            DependencyUtils.log('location=' + formulaDesc + ' key=' + formulaDesc.formulaKey + ' references=' + formulaDesc.references + ' circular=' + formulaDesc.circular);
         });
     } : _.noop;
 
