@@ -13,8 +13,9 @@
  */
 
 define('io.ox/office/spreadsheet/model/formula/deps/formuladescriptor', [
+    'io.ox/office/spreadsheet/model/formula/deps/dependencyutils',
     'io.ox/office/spreadsheet/model/formula/deps/referencecollection'
-], function (ReferenceCollection) {
+], function (DependencyUtils, ReferenceCollection) {
 
     'use strict';
 
@@ -29,6 +30,10 @@ define('io.ox/office/spreadsheet/model/formula/deps/formuladescriptor', [
      * @property {String} sheetUid
      *  The UID of the sheet model containing the formula expression.
      *
+     * @property {String} formulaKey
+     *  The unique key of this formula descriptor, used e.g. for storing this
+     *  descriptor in maps and sets.
+     *
      * @property {TokenArray} tokenArray
      *  The token array represented by this descriptor object.
      *
@@ -38,23 +43,25 @@ define('io.ox/office/spreadsheet/model/formula/deps/formuladescriptor', [
      *  address of the cell containing the formula. For shared formulas, this
      *  is the address of its anchor cell. For matrix formulas, for conditional
      *  formatting rules, and for data validation rules, this is the top-left
-     *  cell of the bounding range of the parent object.
+     *  cell of the bounding range of the parent object. For source links, this
+     *  will be the address A1.
      *
      * @property {Address|Null} cellAddress
      *  The actual address of a cell formula, i.e. the address of the cell the
      *  formula is associated with. Will differ to the reference address, if
      *  the cell is part of a shared formula, but is not its anchor cell. Will
-     *  be null, if this instance represents a formatting rule.
+     *  be null, if this instance does not represent a cell formula.
      *
      * @property {Range|Null} matrixRange
      *  The bounding range of a matrix formula; otherwise null. The start
      *  address of this range MUST be equal to the properties 'refAddress' and
      *  'cellAddress' of this instance.
      *
-     * @property {RuleModel|Null} ruleModel
-     *  For cell formulas, this property will be null (will be used to detect
-     *  cell formulas); for conditions of formtting rules, this will be the
-     *  parent rule model containing the formula.
+     * @property {RuleModel|SourceLinkMixin|Null} tokenModel
+     *  For conditions of formatting rules, this will be the parent rule model
+     *  containing the formula. For formulas of a source link model, this will
+     *  be the parent link model containing the formula (e.g. the data series
+     *  model of a chart). Otherwise, this property will be null.
      *
      * @property {ReferenceCollection} references
      *  A collection with source references the token array depends on
@@ -79,24 +86,22 @@ define('io.ox/office/spreadsheet/model/formula/deps/formuladescriptor', [
      *  represented by this descriptor. In this case, resolving the dependency
      *  chain for this formula will be stopped to prevent endless loops.
      */
-    function FormulaDescriptor(docModel, sheetUid, tokenArray, refAddress, cellAddress, matrixRange, ruleModel) {
+    function FormulaDescriptor(formulaKey, tokenArray, refAddress, cellAddress, matrixRange, tokenModel) {
 
         // public properties
-        this.sheetUid = sheetUid;
+        this.sheetUid = tokenArray.getSheetModel().getUid();
+        this.formulaKey = formulaKey;
         this.tokenArray = tokenArray;
         this.refAddress = refAddress;
         this.cellAddress = cellAddress || null;
-        this.matrixRange = matrixRange;
-        this.ruleModel = ruleModel || null;
+        this.matrixRange = matrixRange || null;
+        this.tokenModel = tokenModel || null;
         this.references = null;
         this.missingNames = null;
         this.missingFuncs = null;
         this.recalc = null;
         this.circular = false;
 
-        // private properties
-        this._docModel = docModel;
-
         // initialization -----------------------------------------------------
 
         // calculate the initial dependencies, and create the reference collection
@@ -106,6 +111,19 @@ define('io.ox/office/spreadsheet/model/formula/deps/formuladescriptor', [
 
     // public methods ---------------------------------------------------------
 
+    /**
+     *
+     * Returns the model of the sheet containing the formula represented by
+     * this instance.
+     *
+     * @returns {SheetModel}
+     *  The model of the sheet containing the formula represented by this
+     *  instance.
+     */
+    FormulaDescriptor.prototype.getSheetModel = function () {
+        return this.tokenArray.getSheetModel();
+    };
+
     /**
      * Returns whether the formula represented by this descriptor does not have
      * any external dependencies, and therefore does not need to be handled by
@@ -126,11 +144,11 @@ define('io.ox/office/spreadsheet/model/formula/deps/formuladescriptor', [
     FormulaDescriptor.prototype.refreshReferences = function () {
 
         // get the target position for resolving the dependencies
-        var depTarget = this.ruleModel ? this.ruleModel.getDependencyTarget() : this.cellAddress;
+        var depTarget = this.tokenModel ? this.tokenModel.getDependencyTarget() : (this.cellAddress || this.refAddress);
 
         // resolve the dependencies of the token array (cell ranges, and defined names)
         var dependencies = this.tokenArray.getDependencies(this.refAddress, depTarget);
-        this.references = new ReferenceCollection(this._docModel, dependencies);
+        this.references = new ReferenceCollection(this.tokenArray.getDocModel(), dependencies);
 
         // copy the other settings
         this.missingNames = dependencies.missingNames;
@@ -139,6 +157,19 @@ define('io.ox/office/spreadsheet/model/formula/deps/formuladescriptor', [
         this.circular = dependencies.circular;
     };
 
+    /**
+     * Returns a string representation for this formula descriptor for debug
+     * logging.
+     *
+     * @returns {String}
+     *  A string representation for this formula descriptor for debug logging.
+     */
+    FormulaDescriptor.prototype.toString = function () {
+        if (this.tokenModel) { return DependencyUtils.getTokenLabel(this.tokenModel) + '!' + this.formulaKey.split('!')[1]; }
+        if (this.cellAddress) { return this.getSheetModel().getName() + '!' + this.cellAddress; }
+        return '<!unknown!>' + this.formulaKey;
+    };
+
     // exports ================================================================
 
     return FormulaDescriptor;
