@@ -13,14 +13,17 @@
  */
 
 define('io.ox/office/spreadsheet/model/formula/deps/formuladictionary', [
-    'io.ox/office/tk/container/simplemap',
-    'io.ox/office/spreadsheet/utils/sheetutils'
-], function (SimpleMap, SheetUtils) {
+    'io.ox/office/tk/utils/iteratorutils',
+    'io.ox/office/tk/container/valuemap',
+    'io.ox/office/spreadsheet/utils/sheetutils',
+    'io.ox/office/spreadsheet/model/formula/deps/dependencyutils'
+], function (IteratorUtils, ValueMap, SheetUtils, DependencyUtils) {
 
     'use strict';
 
     // convenience shortcuts
     var RangeSet = SheetUtils.RangeSet;
+    var FormulaSet = DependencyUtils.FormulaSet;
 
     // class FormulaDictionary ================================================
 
@@ -32,14 +35,16 @@ define('io.ox/office/spreadsheet/model/formula/deps/formuladictionary', [
      *
      * @constructor
      */
-    function FormulaDictionary() {
+    function FormulaDictionary(docModel) {
 
+        // the document model
+        this._docModel = docModel;
         // several formula descriptor maps attached to ranges in range sets, mapped by sheet UID
-        this._rangeSets = new SimpleMap();
+        this._rangeSets = new ValueMap();
         // formula descriptors depending on a defined name, mapped by name key
-        this._nameMaps = new SimpleMap();
+        this._nameSets = new ValueMap();
         // formula descriptors depending on a table range, mapped by table key
-        this._tableMaps = new SimpleMap();
+        this._tableSets = new ValueMap();
 
     } // class FormulaDictionary
 
@@ -52,7 +57,20 @@ define('io.ox/office/spreadsheet/model/formula/deps/formuladictionary', [
      *  Whether this dictionary is completely empty.
      */
     FormulaDictionary.prototype.empty = function () {
-        return this._rangeSets.empty() && this._nameMaps.empty() && this._tableMaps.empty();
+        return this._rangeSets.empty() && this._nameSets.empty() && this._tableSets.empty();
+    };
+
+    /**
+     * Clears this dictionary completely.
+     *
+     * @returns {FormulaDictionary}
+     *  A reference to this instance.
+     */
+    FormulaDictionary.prototype.clear = function () {
+        this._rangeSets.clear();
+        this._nameSets.clear();
+        this._tableSets.clear();
+        return this;
     };
 
     /**
@@ -65,23 +83,23 @@ define('io.ox/office/spreadsheet/model/formula/deps/formuladictionary', [
     FormulaDictionary.prototype.clone = function () {
 
         // start with an empty dictionary
-        var clone = new FormulaDictionary();
+        var clone = new FormulaDictionary(this._docModel);
 
         // clone the formula maps of the cell range sets
         clone._rangeSets = this._rangeSets.clone(function (rangeSet) {
             return rangeSet.clone(function (newRange, oldRange) {
-                newRange.formulaMap = oldRange.formulaMap.clone();
+                newRange.formulaSet = oldRange.formulaSet.clone();
             });
         });
 
         // clone the formula descriptors mapped by name keys
-        clone._nameMaps = this._nameMaps.clone(function (formulaMap) {
-            return formulaMap.clone();
+        clone._nameSets = this._nameSets.clone(function (formulaSet) {
+            return formulaSet.clone();
         });
 
         // clone the formula descriptors mapped by table keys
-        clone._tableMaps = this._tableMaps.clone(function (formulaMap) {
-            return formulaMap.clone();
+        clone._tableSets = this._tableSets.clone(function (formulaSet) {
+            return formulaSet.clone();
         });
 
         return clone;
@@ -91,68 +109,62 @@ define('io.ox/office/spreadsheet/model/formula/deps/formuladictionary', [
      * Inserts a new formula descriptor into this dictionary. The formula
      * descriptor will be mapped by all of its source references.
      *
-     * @param {String} formulaKey
-     *  The key of the passed formula descriptor.
-     *
      * @param {FormulaDescriptor} formulaDesc
      *  The descriptor of a formula to be inserted into this dictionary.
      */
-    FormulaDictionary.prototype.insertFormula = function (formulaKey, formulaDesc) {
+    FormulaDictionary.prototype.insertFormula = function (formulaDesc) {
 
         // insert the formula descriptor into the formula maps for all source ranges
         formulaDesc.references.forEachRange(function (sheetUid, range) {
             var rangeSet = this._rangeSets.getOrConstruct(sheetUid, RangeSet);
             range = rangeSet.insert(range);
-            var formulaMap = range.formulaMap || (range.formulaMap = new SimpleMap());
-            formulaMap.insert(formulaKey, formulaDesc);
+            var formulaSet = range.formulaSet || (range.formulaSet = new FormulaSet());
+            formulaSet.insert(formulaDesc);
         }, this);
 
         // insert the formula descriptor into the formula maps for all defined names
         formulaDesc.references.forEachNameKey(function (nameKey) {
-            this._nameMaps.getOrConstruct(nameKey, SimpleMap).insert(formulaKey, formulaDesc);
+            this._nameSets.getOrConstruct(nameKey, FormulaSet).insert(formulaDesc);
         }, this);
 
         // insert the formula descriptor into the formula maps for all table ranges
         formulaDesc.references.forEachTableKey(function (tableKey) {
-            this._tableMaps.getOrConstruct(tableKey, SimpleMap).insert(formulaKey, formulaDesc);
+            this._tableSets.getOrConstruct(tableKey, FormulaSet).insert(formulaDesc);
         }, this);
     };
 
     /**
      * Removes a formula descriptor from this dictionary.
      *
-     * @param {String} formulaKey
-     *  The key of the passed formula descriptor.
-     *
      * @param {FormulaDescriptor} formulaDesc
      *  The descriptor of a formula to be removed form this dictionary.
      */
-    FormulaDictionary.prototype.removeFormula = function (formulaKey, formulaDesc) {
+    FormulaDictionary.prototype.removeFormula = function (formulaDesc) {
 
         // remove the formula descriptor from the formula maps for all source ranges
         formulaDesc.references.forEachRange(function (sheetUid, range) {
             this._rangeSets.with(sheetUid, function (rangeSet) {
                 if ((range = rangeSet.get(range, null))) {
-                    var formulaMap = range.formulaMap;
-                    formulaMap.remove(formulaKey);
-                    if (formulaMap.empty()) { rangeSet.remove(range); }
+                    var formulaSet = range.formulaSet;
+                    formulaSet.remove(formulaDesc);
+                    if (formulaSet.empty()) { rangeSet.remove(range); }
                 }
             }, this);
         }, this);
 
         // remove the formula descriptor from the formula maps for all defined names
         formulaDesc.references.forEachNameKey(function (nameKey) {
-            this._nameMaps.with(nameKey, function (formulaMap) {
-                formulaMap.remove(formulaKey);
-                if (formulaMap.empty()) { this._nameMaps.remove(nameKey); }
+            this._nameSets.with(nameKey, function (formulaSet) {
+                formulaSet.remove(formulaDesc);
+                if (formulaSet.empty()) { this._nameSets.remove(nameKey); }
             }, this);
         }, this);
 
         // remove the formula descriptor from the formula maps for all table ranges
         formulaDesc.references.forEachTableKey(function (tableKey) {
-            this._tableMaps.with(tableKey, function (formulaMap) {
-                formulaMap.remove(formulaKey);
-                if (formulaMap.empty()) { this._tableMaps.remove(tableKey); }
+            this._tableSets.with(tableKey, function (formulaSet) {
+                formulaSet.remove(formulaDesc);
+                if (formulaSet.empty()) { this._tableSets.remove(tableKey); }
             }, this);
         }, this);
     };
@@ -167,23 +179,22 @@ define('io.ox/office/spreadsheet/model/formula/deps/formuladictionary', [
      * @param {Address} address
      *  The address of the cell to look up formula descriptors for.
      *
-     * @returns {SimpleMap<FormulaDescriptor>}
-     *  All formula descriptors depending on the specified cell address, mapped
-     *  by formula key.
+     * @returns {FormulaSet}
+     *  All formula descriptors depending on the specified cell address.
      */
     FormulaDictionary.prototype.findFormulasForAddress = function (sheetUid, address) {
 
         // the collected formula descriptors
-        var formulaMap = new SimpleMap();
+        var formulaSet = new FormulaSet();
 
         // collect formula descriptors depending on all cell ranges containing the address
         this._rangeSets.with(sheetUid, function (rangeSet) {
             rangeSet.findByAddress(address).forEach(function (range) {
-                formulaMap.merge(range.formulaMap);
+                formulaSet.merge(range.formulaSet);
             });
         }, this);
 
-        return formulaMap;
+        return formulaSet;
     };
 
     /**
@@ -196,23 +207,22 @@ define('io.ox/office/spreadsheet/model/formula/deps/formuladictionary', [
      * @param {Range} range
      *  The address of the cell range to look up formula descriptors for.
      *
-     * @returns {SimpleMap<FormulaDescriptor>}
-     *  All formula descriptors depending on the specified cell range address,
-     *  mapped by formula key.
+     * @returns {FormulaSet}
+     *  All formula descriptors depending on the specified cell range address.
      */
     FormulaDictionary.prototype.findFormulasForRange = function (sheetUid, range) {
 
         // the collected formula descriptors
-        var formulaMap = new SimpleMap();
+        var formulaSet = new FormulaSet();
 
         // collect formula descriptors depending on all cell ranges overlapping with the range
         this._rangeSets.with(sheetUid, function (rangeSet) {
             rangeSet.findRanges(range).forEach(function (range) {
-                formulaMap.merge(range.formulaMap);
+                formulaSet.merge(range.formulaSet);
             });
         }, this);
 
-        return formulaMap;
+        return formulaSet;
     };
 
     /**
@@ -222,9 +232,9 @@ define('io.ox/office/spreadsheet/model/formula/deps/formuladictionary', [
      * @param {FormulaDescriptor} formulaDesc
      *  The descriptor of a formula to look up formula descriptors for.
      *
-     * @returns {SimpleMap<FormulaDescriptor>|Null}
-     *  All formula descriptors depending on the specified formula, mapped by
-     *  formula key; or null, if no other formula depends on the formula.
+     * @returns {FormulaSet|Null}
+     *  All formula descriptors depending on the specified formula; or null, if
+     *  no other formula depends on the formula.
      */
     FormulaDictionary.prototype.findFormulasForFormula = function (formulaDesc) {
 
@@ -247,13 +257,12 @@ define('io.ox/office/spreadsheet/model/formula/deps/formuladictionary', [
      * @param {String} nameKey
      *  The key of the defined name to look up formula descriptors for.
      *
-     * @returns {SimpleMap<FormulaDescriptor>|Null}
-     *  All formula descriptors depending on the specified defined name, mapped
-     *  by formula key; or null, if no other formula depends on the defined
-     *  name.
+     * @returns {FormulaSet|Null}
+     *  All formula descriptors depending on the specified defined name; or
+     *  null, if no other formula depends on the defined name.
      */
     FormulaDictionary.prototype.findFormulasForName = function (nameKey) {
-        return this._nameMaps.get(nameKey, null);
+        return this._nameSets.get(nameKey, null);
     };
 
     /**
@@ -263,13 +272,12 @@ define('io.ox/office/spreadsheet/model/formula/deps/formuladictionary', [
      * @param {String} tableKey
      *  The key of the table range to look up formula descriptors for.
      *
-     * @returns {SimpleMap<FormulaDescriptor>|Null}
-     *  All formula descriptors depending on the specified table range, mapped
-     *  by formula key; or null, if no other formula depends on the table
-     *  range.
+     * @returns {FormulaSet|Null}
+     *  All formula descriptors depending on the specified table range; or
+     *  null, if no other formula depends on the table range.
      */
     FormulaDictionary.prototype.findFormulasForTable = function (tableKey) {
-        return this._tableMaps.get(tableKey, null);
+        return this._tableSets.get(tableKey, null);
     };
 
     // exports ================================================================
