@@ -14,10 +14,10 @@
 
 define('io.ox/office/spreadsheet/model/formula/deps/referencecollection', [
     'io.ox/office/tk/utils/iteratorutils',
-    'io.ox/office/tk/container/simplemap',
+    'io.ox/office/tk/container/valuemap',
     'io.ox/office/spreadsheet/utils/sheetutils',
     'io.ox/office/spreadsheet/model/formula/deps/dependencyutils'
-], function (IteratorUtils, SimpleMap, SheetUtils, DependencyUtils) {
+], function (IteratorUtils, ValueMap, SheetUtils, DependencyUtils) {
 
     'use strict';
 
@@ -46,36 +46,27 @@ define('io.ox/office/spreadsheet/model/formula/deps/referencecollection', [
      */
     function ReferenceCollection(docModel, dependencies) {
 
+        // the document model
+        this._docModel = docModel;
         // maps sheet UIDs to range arrays
-        this._rangesMap = new SimpleMap();
-        // maps name keys to instances of NameModel
-        this._nameMap = new SimpleMap();
-        // maps table keys to instances of TableModel
-        this._tableMap = new SimpleMap();
+        this._rangesMap = new ValueMap();
+        // models of all defined names
+        this._nameSet = dependencies.nameSet;
+        // models of all table ranges
+        this._tableSet = dependencies.tableSet;
 
-        // separate all source ranges by sheets (also the root ranges of cell formulas, and other formulas)
+        // separate all source ranges by sheets (also the root ranges of cell formulas, and other formulas), and store
+        // them by sheet UID independently from sheet indexes, so this keeps working when inserting/deleting sheets etc.
         dependencies.depRanges.concat(dependencies.rootRanges).unify().forEach(function (range3d) {
             var range2d = range3d.toRange();
-            var sheetIterator = docModel.createSheetIntervalIterator(range3d.sheet1, range3d.sheet2, { types: 'worksheet' });
-            IteratorUtils.forEach(sheetIterator, function (sheetModel) {
+            var iterator = docModel.createSheetIterator({ first: range3d.sheet1, last: range3d.sheet2, cells: true });
+            IteratorUtils.forEach(iterator, function (sheetModel) {
                 this._rangesMap.getOrConstruct(sheetModel.getUid(), RangeArray).push(range2d);
             }, this);
         }, this);
 
         // merge the range addresses to prevent duplicates and overlapping ranges
-        this._rangesMap.forEach(function (ranges, sheetUid) {
-            this._rangesMap.insert(sheetUid, ranges.merge());
-        }, this);
-
-        // register the keys for all defined names referred by the token array
-        _.each(dependencies.names, function (nameModel) {
-            this._nameMap.insert(nameModel.getUid(), nameModel);
-        }, this);
-
-        // register the keys for all table ranges referred by the token array
-        _.each(dependencies.tables, function (tableModel) {
-            this._tableMap.insert(tableModel.getUid(), tableModel);
-        }, this);
+        this._rangesMap.transform('merge');
 
     } // class ReferenceCollection
 
@@ -88,7 +79,7 @@ define('io.ox/office/spreadsheet/model/formula/deps/referencecollection', [
      *  Whether this collection is empty.
      */
     ReferenceCollection.prototype.empty = function () {
-        return this._rangesMap.empty() && this._nameMap.empty() && this._tableMap.empty();
+        return this._rangesMap.empty() && this._nameSet.empty() && this._tableSet.empty();
     };
 
     /**
@@ -129,7 +120,7 @@ define('io.ox/office/spreadsheet/model/formula/deps/referencecollection', [
      *  The calling context for the callback function.
      */
     ReferenceCollection.prototype.forEachNameKey = function (callback, context) {
-        this._nameMap.forEachKey(function (nameKey) { callback.call(context, nameKey); });
+        this._nameSet.forEachKey(function (nameKey) { callback.call(context, nameKey); });
     };
 
     /**
@@ -147,7 +138,7 @@ define('io.ox/office/spreadsheet/model/formula/deps/referencecollection', [
      *  The calling context for the callback function.
      */
     ReferenceCollection.prototype.forEachTableKey = function (callback, context) {
-        this._tableMap.forEachKey(function (tableKey) { callback.call(context, tableKey); });
+        this._tableSet.forEachKey(function (tableKey) { callback.call(context, tableKey); });
     };
 
     /**
@@ -161,7 +152,7 @@ define('io.ox/office/spreadsheet/model/formula/deps/referencecollection', [
      *  Whether the name model is contained in this reference collection.
      */
     ReferenceCollection.prototype.containsName = function (nameModel) {
-        return this._nameMap.has(nameModel.getUid());
+        return this._nameSet.has(nameModel);
     };
 
     /**
@@ -175,7 +166,7 @@ define('io.ox/office/spreadsheet/model/formula/deps/referencecollection', [
      *  Whether the table model is contained in this reference collection.
      */
     ReferenceCollection.prototype.containsTable = function (tableModel) {
-        return this._tableMap.has(tableModel.getUid());
+        return this._tableSet.has(tableModel);
     };
 
     /**
@@ -187,9 +178,14 @@ define('io.ox/office/spreadsheet/model/formula/deps/referencecollection', [
      */
     ReferenceCollection.prototype.toString = function () {
         var labels = [];
-        this.forEachRange(function (sheetUid, range) { labels.push(sheetUid + '!' + range); });
-        this._nameMap.forEach(function (nameModel) { labels.push(DependencyUtils.getNameLabel(nameModel)); });
-        this._tableMap.forEach(function (tableModel) { labels.push(tableModel.getName()); });
+        this._rangesMap.forEach(function (ranges, sheetUid) {
+            var sheetModel = this._docModel.getSheetModel(this._docModel.getSheetIndexOfModel(sheetUid));
+            ranges.forEach(function (range) {
+                labels.push(DependencyUtils.getRangeLabel(sheetModel, range));
+            });
+        }, this);
+        labels = labels.concat(this._nameSet.map(DependencyUtils.getNameLabel));
+        labels = labels.concat(this._tableSet.map(DependencyUtils.getTableLabel));
         return labels.join();
     };
 
