@@ -14,8 +14,10 @@
 
 define('io.ox/office/spreadsheet/model/formula/funcs/conversionfuncs', [
     'io.ox/office/tk/utils',
+    'io.ox/office/tk/locale/parser',
+    'io.ox/office/tk/locale/formatter',
     'io.ox/office/spreadsheet/utils/errorcode'
-], function (Utils, ErrorCode) {
+], function (Utils, Parser, Formatter, ErrorCode) {
 
     'use strict';
 
@@ -623,7 +625,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/conversionfuncs', [
             name: { ooxml: '_xlfn.ARABIC' },
             minParams: 1,
             maxParams: 1,
-            type: 'val',
+            type: 'val:num',
             signature: 'val:str',
             resolve: function (roman) {
 
@@ -639,7 +641,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/conversionfuncs', [
                 }
 
                 // use number formatter to parse the roman number
-                var result = this.numberFormatter.parseRoman(roman);
+                var result = Parser.parseRoman(roman);
 
                 // throw #VALUE! error, if the text cannot be parsed
                 if (result === null) { throw ErrorCode.VALUE; }
@@ -652,7 +654,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/conversionfuncs', [
             name: { ooxml: '_xlfn.BASE' },
             minParams: 2,
             maxParams: 3,
-            type: 'val',
+            type: 'val:str',
             signature: 'val:int val:int val:int',
             resolve: function (number, radix, length) {
                 if ((number < 0) || (number > 0x1FFFFFFFFFFFFF)) { throw ErrorCode.NUM; }
@@ -666,7 +668,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/conversionfuncs', [
             category: 'conversion',
             minParams: 1,
             maxParams: 1,
-            type: 'val',
+            type: 'val:num',
             signature: 'val:str',
             resolve: convertBinToDec
         },
@@ -675,7 +677,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/conversionfuncs', [
             category: 'conversion',
             minParams: 1,
             maxParams: 2,
-            type: 'val',
+            type: 'val:str',
             signature: 'val:str val:int',
             resolve: function (number, length) {
                 return convertDecToHex(convertBinToDec(number), length);
@@ -686,7 +688,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/conversionfuncs', [
             category: 'conversion',
             minParams: 1,
             maxParams: 2,
-            type: 'val',
+            type: 'val:str',
             signature: 'val:str val:int',
             resolve: function (number, length) {
                 return convertDecToOct(convertBinToDec(number), length);
@@ -698,7 +700,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/conversionfuncs', [
             name: { ooxml: null, odf: 'ORG.LIBREOFFICE.COLOR' },
             minParams: 3,
             maxParams: 4,
-            type: 'val',
+            type: 'val:num',
             signature: 'val:int val:int val:int val:int',
             resolve: function (r, g, b, a) {
 
@@ -720,7 +722,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/conversionfuncs', [
             category: 'conversion',
             minParams: 3,
             maxParams: 3,
-            type: 'val',
+            type: 'val:num',
             signature: 'val:num val:str val:str',
             resolve: function (number, fromUnit, toUnit) {
                 return convert(number, fromUnit, toUnit);
@@ -733,14 +735,14 @@ define('io.ox/office/spreadsheet/model/formula/funcs/conversionfuncs', [
             hidden: true,
             minParams: 3,
             maxParams: 3,
-            type: 'val'
+            type: 'val:num'
         },
 
         DEC2BIN: {
             category: 'conversion',
             minParams: 1,
             maxParams: 2,
-            type: 'val',
+            type: 'val:str',
             signature: 'val:int val:int',
             resolve: convertDecToBin
         },
@@ -749,7 +751,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/conversionfuncs', [
             category: 'conversion',
             minParams: 1,
             maxParams: 2,
-            type: 'val',
+            type: 'val:str',
             signature: 'val:int val:int',
             resolve: convertDecToHex
         },
@@ -758,7 +760,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/conversionfuncs', [
             category: 'conversion',
             minParams: 1,
             maxParams: 2,
-            type: 'val',
+            type: 'val:str',
             signature: 'val:int val:int',
             resolve: convertDecToOct
         },
@@ -768,7 +770,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/conversionfuncs', [
             name: { ooxml: '_xlfn.DECIMAL' },
             minParams: 2,
             maxParams: 2,
-            type: 'val',
+            type: 'val:num',
             signature: 'val:str val:int',
             resolve: (function () {
                 var getTestRE = _.memoize(function (radix) {
@@ -799,7 +801,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/conversionfuncs', [
             category: 'conversion',
             minParams: 1,
             maxParams: 2,
-            type: 'val',
+            type: 'val:str',
             signature: 'val:str val:int',
             resolve: function (number, length) {
                 return convertDecToBin(convertHexToDec(number), length);
@@ -810,7 +812,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/conversionfuncs', [
             category: 'conversion',
             minParams: 1,
             maxParams: 1,
-            type: 'val',
+            type: 'val:num',
             signature: 'val:str',
             resolve: convertHexToDec
         },
@@ -819,7 +821,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/conversionfuncs', [
             category: 'conversion',
             minParams: 1,
             maxParams: 2,
-            type: 'val',
+            type: 'val:str',
             signature: 'val:str val:int',
             resolve: function (number, length) {
                 return convertDecToOct(convertHexToDec(number), length);
@@ -830,7 +832,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/conversionfuncs', [
             category: 'conversion',
             minParams: 1,
             maxParams: 2,
-            type: 'val',
+            type: 'val:str',
             signature: 'val:str val:int',
             resolve: function (number, length) {
                 return convertDecToBin(convertOctToDec(number), length);
@@ -841,7 +843,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/conversionfuncs', [
             category: 'conversion',
             minParams: 1,
             maxParams: 1,
-            type: 'val',
+            type: 'val:num',
             signature: 'val:str',
             resolve: convertOctToDec
         },
@@ -850,7 +852,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/conversionfuncs', [
             category: 'conversion',
             minParams: 1,
             maxParams: 2,
-            type: 'val',
+            type: 'val:str',
             signature: 'val:str val:int',
             resolve: function (number, length) {
                 return convertDecToHex(convertOctToDec(number), length);
@@ -861,7 +863,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/conversionfuncs', [
             category: 'conversion',
             minParams: 1,
             maxParams: 2,
-            type: 'val',
+            type: 'val:str',
             signature: 'val:int val:int',
             resolve: function (number, depth) {
 
@@ -872,7 +874,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/conversionfuncs', [
                 if ((depth < 0) || (depth >= 5) || (number < 0) || (number > 3999)) { throw ErrorCode.VALUE; }
 
                 // use number formatter to format to a roman number
-                return this.numberFormatter.formatRoman(number, depth);
+                return Formatter.formatRoman(number, depth);
             }
         }
     };
