@@ -346,7 +346,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/databasefuncs', [
             category: 'database',
             minParams: 3,
             maxParams: 3,
-            type: 'val',
+            type: 'val:num',
             signature: 'ref:single val ref:single',
             resolve: function (dbRange, field, criteriaRange) {
                 return getResult(dbRange, field, criteriaRange, this, function (numbers, sum) {
@@ -359,7 +359,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/databasefuncs', [
             category: 'database',
             minParams: 3,
             maxParams: 3,
-            type: 'val',
+            type: 'val:num',
             signature: 'ref:single val ref:single',
             resolve: function (dbRange, field, criteriaRange) {
                 return getCountResult(dbRange, field, criteriaRange, this, false);
@@ -370,7 +370,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/databasefuncs', [
             category: 'database',
             minParams: 3,
             maxParams: 3,
-            type: 'val',
+            type: 'val:num',
             signature: 'ref:single val ref:single',
             resolve: function (dbRange, field, criteriaRange) {
                 return getCountResult(dbRange, field, criteriaRange, this, true);
@@ -381,7 +381,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/databasefuncs', [
             category: 'database',
             minParams: 3,
             maxParams: 3,
-            type: 'val',
+            type: 'val:any',
             signature: 'ref:single val ref:single',
             resolve: function (dbRange, field, criteriaRange) {
                 return getResult(dbRange, field, criteriaRange, this, function (values) {
@@ -396,7 +396,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/databasefuncs', [
             category: 'database',
             minParams: 3,
             maxParams: 3,
-            type: 'val',
+            type: 'val:num',
             signature: 'ref:single val ref:single',
             resolve: function (dbRange, field, criteriaRange) {
                 return getResult(dbRange, field, criteriaRange, this, function (numbers) {
@@ -409,7 +409,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/databasefuncs', [
             category: 'database',
             minParams: 3,
             maxParams: 3,
-            type: 'val',
+            type: 'val:num',
             signature: 'ref:single val ref:single',
             resolve: function (dbRange, field, criteriaRange) {
                 return getResult(dbRange, field, criteriaRange, this, function (numbers) {
@@ -422,7 +422,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/databasefuncs', [
             category: 'database',
             minParams: 3,
             maxParams: 3,
-            type: 'val',
+            type: 'val:num',
             signature: 'ref:single val ref:single',
             resolve: function (dbRange, field, criteriaRange) {
                 return getResult(dbRange, field, criteriaRange, this, function (numbers) {
@@ -435,7 +435,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/databasefuncs', [
             category: 'database',
             minParams: 3,
             maxParams: 3,
-            type: 'val',
+            type: 'val:num',
             signature: 'ref:single val ref:single',
             resolve: function (dbRange, field, criteriaRange) {
                 return getResult(dbRange, field, criteriaRange, this, function (numbers, sum) {
@@ -448,7 +448,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/databasefuncs', [
             category: 'database',
             minParams: 3,
             maxParams: 3,
-            type: 'val',
+            type: 'val:num',
             signature: 'ref:single val ref:single',
             resolve: function (dbRange, field, criteriaRange) {
                 return getResult(dbRange, field, criteriaRange, this, function (numbers, sum) {
@@ -461,7 +461,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/databasefuncs', [
             category: 'database',
             minParams: 3,
             maxParams: 3,
-            type: 'val',
+            type: 'val:num',
             signature: 'ref:single val ref:single',
             resolve: function (dbRange, field, criteriaRange) {
                 return getResult(dbRange, field, criteriaRange, this, function (numbers, sum) {
@@ -474,7 +474,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/databasefuncs', [
             category: 'database',
             minParams: 3,
             maxParams: 3,
-            type: 'val',
+            type: 'val:num',
             signature: 'ref:single val ref:single',
             resolve: function (dbRange, field, criteriaRange) {
                 return getResult(dbRange, field, criteriaRange, this, function (numbers, sum) {
@@ -487,7 +487,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/databasefuncs', [
             category: 'database',
             minParams: 3,
             maxParams: 3,
-            type: 'val',
+            type: 'val:num',
             signature: 'ref:single val ref:single',
             resolve: function (dbRange, field, criteriaRange) {
                 return getResult(dbRange, field, criteriaRange, this, function (numbers, sum) {
