@@ -346,7 +346,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/datetimefuncs', [
             category: 'datetime',
             minParams: 3,
             maxParams: 3,
-            type: 'val',
+            type: 'val:date',
             format: 'date',
             signature: 'val:int val:int val:int',
             resolve: function (year, month, day) {
@@ -362,14 +362,14 @@ define('io.ox/office/spreadsheet/model/formula/funcs/datetimefuncs', [
             hidden: true,
             minParams: 3,
             maxParams: 3,
-            type: 'val'
+            type: 'val:num'
         },
 
         DATEVALUE: {
             category: 'datetime',
             minParams: 1,
             maxParams: 1,
-            type: 'val',
+            type: 'val:num',
             signature: 'val:str',
             resolve: function (dateText) {
                 return Math.floor(parseDateTime(this, dateText));
@@ -380,7 +380,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/datetimefuncs', [
             category: 'datetime',
             minParams: 1,
             maxParams: 1,
-            type: 'val',
+            type: 'val:num',
             signature: 'val:day',
             resolve: function (date) { return date.getUTCDate(); }
         },
@@ -390,7 +390,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/datetimefuncs', [
             name: { ooxml: '_xlfn.DAYS' },
             minParams: 2,
             maxParams: 2,
-            type: 'val',
+            type: 'val:num',
             signature: 'val:day val:day',
             resolve: function (endDate, startDate) {
                 // DAYS() expects end date before start date
@@ -402,7 +402,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/datetimefuncs', [
             category: 'datetime',
             minParams: 2,
             maxParams: 3,
-            type: 'val',
+            type: 'val:num',
             signature: 'val:day val:day val:bool',
             resolve: function (startDate, endDate, euroMode) {
                 // euroMode missing or FALSE: use 30/360 US mode
@@ -415,7 +415,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/datetimefuncs', [
             name: { ooxml: null, odf: 'ORG.OPENOFFICE.DAYSINMONTH' },
             minParams: 1,
             maxParams: 1,
-            type: 'val',
+            type: 'val:num',
             signature: 'val:day',
             resolve: function (date) {
                 return DateUtils.getDaysInMonth(date.getUTCFullYear(), date.getUTCMonth());
@@ -427,7 +427,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/datetimefuncs', [
             name: { ooxml: null, odf: 'ORG.OPENOFFICE.DAYSINYEAR' },
             minParams: 1,
             maxParams: 1,
-            type: 'val',
+            type: 'val:num',
             signature: 'val:day',
             resolve: function (date) {
                 return DateUtils.getDaysInYear(date.getUTCFullYear());
@@ -440,7 +440,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/datetimefuncs', [
             name: { ooxml: null, odf: ['ORG.OPENOFFICE.EASTERSUNDAY', 'EASTERSUNDAY'] },
             minParams: 1,
             maxParams: 1,
-            type: 'val',
+            type: 'val:date',
             format: 'date',
             signature: 'val:int',
             resolve: function (year) {
@@ -472,7 +472,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/datetimefuncs', [
             category: 'datetime',
             minParams: 2,
             maxParams: 2,
-            type: 'val',
+            type: 'val:date',
             format: 'date',
             signature: 'val:day val:int',
             resolve: function (date, months) {
@@ -485,7 +485,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/datetimefuncs', [
             category: 'datetime',
             minParams: 2,
             maxParams: 2,
-            type: 'val',
+            type: 'val:date',
             format: 'date',
             signature: 'val:day val:int',
             resolve: function (date, months) {
@@ -498,7 +498,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/datetimefuncs', [
             category: 'datetime',
             minParams: 1,
             maxParams: 1,
-            type: 'val',
+            type: 'val:num',
             signature: 'val:date',
             resolve: function (date) { return date.getUTCHours(); }
         },
@@ -508,7 +508,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/datetimefuncs', [
             name: { ooxml: null, odf: 'ORG.OPENOFFICE.ISLEAPYEAR' },
             minParams: 1,
             maxParams: 1,
-            type: 'val',
+            type: 'val:bool',
             signature: 'val:day',
             resolve: function (date) {
                 return DateUtils.isLeapYear(date.getUTCFullYear());
@@ -521,7 +521,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/datetimefuncs', [
             name: { ooxml: '_xlfn.ISOWEEKNUM' },
             minParams: { ooxml: 1, odf: 2 },
             maxParams: { ooxml: 1, odf: 2 },
-            type: 'val',
+            type: 'val:num',
             signature: 'val:day val:int',
             resolve: function (date, mode) {
                 // ODF: date mode 1 for Sunday, every other value for Monday; OOXML: always Monday
@@ -533,7 +533,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/datetimefuncs', [
             category: 'datetime',
             minParams: 1,
             maxParams: 1,
-            type: 'val',
+            type: 'val:num',
             signature: 'val:date',
             resolve: function (date) { return date.getUTCMinutes(); }
         },
@@ -542,7 +542,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/datetimefuncs', [
             category: 'datetime',
             minParams: 1,
             maxParams: 1,
-            type: 'val',
+            type: 'val:num',
             signature: 'val:day',
             resolve: function (date) { return date.getUTCMonth() + 1; } // JS Date class returns zero-based month
         },
@@ -552,7 +552,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/datetimefuncs', [
             name: { ooxml: null, odf: 'ORG.OPENOFFICE.MONTHS' },
             minParams: 3,
             maxParams: 3,
-            type: 'val',
+            type: 'val:num',
             signature: 'val:day val:day val:int',
             resolve: function (startDate, endDate, whole) {
                 return DateUtils.getMonthsDiff(startDate, endDate, whole !== 1);
@@ -563,7 +563,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/datetimefuncs', [
             category: 'datetime',
             minParams: 2,
             maxParams: 3,
-            type: 'val',
+            type: 'val:num',
             signature: 'val:day val:day any',
             resolve: function (startDate, endDate, holidays) {
                 return networkDaysIntl(this, startDate, endDate, 1, holidays);
@@ -575,7 +575,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/datetimefuncs', [
             name: { odf: 'COM.MICROSOFT.NETWORKDAYS.INTL' },
             minParams: 2,
             maxParams: 4,
-            type: 'val',
+            type: 'val:num',
             signature: 'val:day val:day val any',
             resolve: function (startDate, endDate, weekend, holidays) {
                 return networkDaysIntl(this, startDate, endDate, weekend, holidays);
@@ -586,7 +586,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/datetimefuncs', [
             category: 'datetime',
             minParams: 0,
             maxParams: 0,
-            type: 'val',
+            type: 'val:date',
             format: 'datetime',
             recalc: 'always',
             resolve: DateUtils.makeUTCNow
@@ -596,7 +596,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/datetimefuncs', [
             category: 'datetime',
             minParams: 1,
             maxParams: 1,
-            type: 'val',
+            type: 'val:num',
             signature: 'val:date',
             resolve: function (date) { return date.getUTCSeconds(); }
         },
@@ -605,7 +605,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/datetimefuncs', [
             category: 'datetime',
             minParams: 3,
             maxParams: 3,
-            type: 'val',
+            type: 'val:date',
             format: 'time',
             signature: 'val:int val:int val:int',
             resolve: function (hour, minute, second) {
@@ -625,7 +625,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/datetimefuncs', [
             category: 'datetime',
             minParams: 1,
             maxParams: 1,
-            type: 'val',
+            type: 'val:num',
             signature: 'val:str',
             resolve: function (timeText) {
                 return parseDateTime(this, timeText) % 1;
@@ -636,7 +636,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/datetimefuncs', [
             category: 'datetime',
             minParams: 0,
             maxParams: 0,
-            type: 'val',
+            type: 'val:date',
             format: 'date',
             recalc: 'always',
             resolve: DateUtils.makeUTCToday
@@ -646,7 +646,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/datetimefuncs', [
             category: 'datetime',
             minParams: 1,
             maxParams: 2,
-            type: 'val',
+            type: 'val:num',
             signature: 'val:day val:int',
             resolve: function (date, mode) {
 
@@ -673,7 +673,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/datetimefuncs', [
             category: 'datetime',
             minParams: 1,
             maxParams: 2,
-            type: 'val',
+            type: 'val:num',
             signature: 'val:day val:int',
             resolve: (function () {
 
@@ -698,7 +698,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/datetimefuncs', [
             name: { ooxml: null, odf: 'ORG.OPENOFFICE.WEEKS' },
             minParams: 3,
             maxParams: 3,
-            type: 'val',
+            type: 'val:num',
             signature: 'val:day val:day val:int',
             resolve: function (startDate, endDate, whole) {
                 return DateUtils.getWeeksDiff(startDate, endDate, whole !== 1);
@@ -710,7 +710,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/datetimefuncs', [
             name: { ooxml: null, odf: 'ORG.OPENOFFICE.WEEKSINYEAR' },
             minParams: 1,
             maxParams: 1,
-            type: 'val',
+            type: 'val:num',
             signature: 'val:day',
             resolve: function (date) {
                 // the 28th of December has always maximum week number in ISO8601 mode
@@ -722,7 +722,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/datetimefuncs', [
             category: 'datetime',
             minParams: 2,
             maxParams: 3,
-            type: 'val',
+            type: 'val:date',
             format: 'date',
             signature: 'val:day val:int any',
             resolve: function (startDate, days, holidays) {
@@ -735,7 +735,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/datetimefuncs', [
             name: { odf: 'COM.MICROSOFT.WORKDAY.INTL' },
             minParams: 2,
             maxParams: 4,
-            type: 'val',
+            type: 'val:date',
             format: 'date',
             signature: 'val:day val:int val:int any',
             resolve: function (startDate, days, weekend, holidays) {
@@ -747,7 +747,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/datetimefuncs', [
             category: 'datetime',
             minParams: 1,
             maxParams: 1,
-            type: 'val',
+            type: 'val:num',
             signature: 'val:day',
             resolve: function (date) { return date.getUTCFullYear(); }
         },
@@ -756,7 +756,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/datetimefuncs', [
             category: 'datetime',
             minParams: 2,
             maxParams: 3,
-            type: 'val',
+            type: 'val:num',
             signature: 'val:day val:day val:int',
             resolve: function (startDate, endDate, mode) {
                 return DateUtils.getYearFrac(startDate, endDate, mode);
@@ -768,7 +768,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/datetimefuncs', [
             name: { ooxml: null, odf: 'ORG.OPENOFFICE.YEARS' },
             minParams: 3,
             maxParams: 3,
-            type: 'val',
+            type: 'val:num',
             signature: 'val:day val:day val:int',
             resolve: function (startDate, endDate, whole) {
                 return DateUtils.getYearsDiff(startDate, endDate, whole !== 1);
