@@ -454,7 +454,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/engineeringfuncs', [
             category: 'engineering',
             minParams: 2,
             maxParams: 2,
-            type: 'val',
+            type: 'val:num',
             signature: 'val:num val:int',
             resolve: besselI
         },
@@ -463,7 +463,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/engineeringfuncs', [
             category: 'engineering',
             minParams: 2,
             maxParams: 2,
-            type: 'val',
+            type: 'val:num',
             signature: 'val:num val:int',
             resolve: besselJ
         },
@@ -472,7 +472,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/engineeringfuncs', [
             category: 'engineering',
             minParams: 2,
             maxParams: 2,
-            type: 'val',
+            type: 'val:num',
             signature: 'val:num val:int',
             resolve: besselK
         },
@@ -481,7 +481,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/engineeringfuncs', [
             category: 'engineering',
             minParams: 2,
             maxParams: 2,
-            type: 'val',
+            type: 'val:num',
             signature: 'val:num val:int',
             resolve: besselY
         },
@@ -491,7 +491,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/engineeringfuncs', [
             name: { ooxml: '_xlfn.BITAND' },
             minParams: 2,
             maxParams: 2,
-            type: 'val',
+            type: 'val:num',
             signature: 'val:int val:int',
             resolve: function (number1, number2) {
                 return combineBits(number1, number2, function (i1, i2) { return i1 & i2; });
@@ -503,7 +503,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/engineeringfuncs', [
             name: { ooxml: '_xlfn.BITLSHIFT' },
             minParams: 2,
             maxParams: 2,
-            type: 'val',
+            type: 'val:num',
             signature: 'val:int val:int',
             resolve: shiftBitsLeft
         },
@@ -513,7 +513,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/engineeringfuncs', [
             name: { ooxml: '_xlfn.BITOR' },
             minParams: 2,
             maxParams: 2,
-            type: 'val',
+            type: 'val:num',
             signature: 'val:int val:int',
             resolve: function (number1, number2) {
                 return combineBits(number1, number2, function (i1, i2) { return i1 | i2; });
@@ -525,7 +525,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/engineeringfuncs', [
             name: { ooxml: '_xlfn.BITRSHIFT' },
             minParams: 2,
             maxParams: 2,
-            type: 'val',
+            type: 'val:num',
             signature: 'val:int val:int',
             resolve: function (number, bits) {
                 return shiftBitsLeft(number, -bits);
@@ -537,7 +537,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/engineeringfuncs', [
             name: { ooxml: '_xlfn.BITXOR' },
             minParams: 2,
             maxParams: 2,
-            type: 'val',
+            type: 'val:num',
             signature: 'val:int val:int',
             resolve: function (number1, number2) {
                 return combineBits(number1, number2, function (i1, i2) { return i1 ^ i2; });
@@ -548,7 +548,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/engineeringfuncs', [
             category: 'engineering',
             minParams: 1,
             maxParams: 2,
-            type: 'val',
+            type: 'val:num',
             signature: 'val:num val:num',
             resolve: function (number, step) {
                 if (_.isUndefined(step)) { step = 0; }
@@ -560,7 +560,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/engineeringfuncs', [
             category: 'engineering',
             minParams: 1,
             maxParams: 2,
-            type: 'val',
+            type: 'val:num',
             signature: 'val:num val:num',
             resolve: (function () {
 
@@ -592,7 +592,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/engineeringfuncs', [
             name: { ooxml: '_xlfn.ERF.PRECISE', odf: 'COM.MICROSOFT.ERF.PRECISE' },
             minParams: 1,
             maxParams: 1,
-            type: 'val',
+            type: 'val:num',
             signature: 'val:num',
             resolve: MathUtils.erf
         },
@@ -601,7 +601,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/engineeringfuncs', [
             category: 'engineering',
             minParams: 1,
             maxParams: 1,
-            type: 'val',
+            type: 'val:num',
             signature: 'val:num',
             resolve: {
                 ooxml: function (a) {
@@ -618,7 +618,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/engineeringfuncs', [
             name: { ooxml: '_xlfn.ERFC.PRECISE', odf: 'COM.MICROSOFT.ERFC.PRECISE' },
             minParams: 1,
             maxParams: 1,
-            type: 'val',
+            type: 'val:num',
             signature: 'val:num',
             resolve: MathUtils.erfc
         },
@@ -627,7 +627,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/engineeringfuncs', [
             category: 'engineering',
             minParams: 1,
             maxParams: 2,
-            type: 'val',
+            type: 'val:num',
             signature: 'val:num val:num',
             resolve: function (number, step) {
                 if (_.isUndefined(step)) { step = 0; }
