@@ -41,7 +41,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/informationfuncs', [
             category: 'information',
             minParams: 1,
             maxParams: 2,
-            type: 'val',
+            type: 'val:any',
             recalc: 'always',
             signature: 'val:str ref:single|deps:skip',
             resolve: (function () {
@@ -166,7 +166,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/informationfuncs', [
             category: 'information',
             minParams: 1,
             maxParams: 1,
-            type: 'val',
+            type: 'val:num',
             signature: 'val:any',
             resolve: function (value) {
                 if (value instanceof ErrorCode) { return value.num; }
@@ -179,14 +179,14 @@ define('io.ox/office/spreadsheet/model/formula/funcs/informationfuncs', [
             name: { ooxml: null, odf: 'ORG.OPENOFFICE.ERRORTYPE' },
             minParams: 1,
             maxParams: 1,
-            type: 'val'
+            type: 'val:num'
         },
 
         INFO: {
             category: 'information',
             minParams: 1,
             maxParams: 1,
-            type: 'val',
+            type: 'val:str',
             recalc: 'always'
         },
 
@@ -194,7 +194,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/informationfuncs', [
             category: 'information',
             minParams: 1,
             maxParams: 1,
-            type: 'val',
+            type: 'val:bool',
             signature: 'val:any',
             resolve: _.isNull // error codes result in FALSE
         },
@@ -203,7 +203,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/informationfuncs', [
             category: 'information',
             minParams: 1,
             maxParams: 1,
-            type: 'val',
+            type: 'val:bool',
             signature: 'val:any',
             resolve: function (value) {
                 return (value instanceof ErrorCode) && (value !== ErrorCode.NA);
@@ -214,7 +214,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/informationfuncs', [
             category: 'information',
             minParams: 1,
             maxParams: 1,
-            type: 'val',
+            type: 'val:bool',
             signature: 'val:any',
             resolve: function (value) { return value instanceof ErrorCode; }
         },
@@ -223,7 +223,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/informationfuncs', [
             category: 'information',
             minParams: 1,
             maxParams: 1,
-            type: 'val',
+            type: 'val:bool',
             signature: 'val:num',
             resolve: function (number) {
                 return (floor(abs(number)) % 2) === 0;
@@ -235,7 +235,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/informationfuncs', [
             name: { ooxml: '_xlfn.ISFORMULA' },
             minParams: 1,
             maxParams: 1,
-            type: 'val',
+            type: 'val:bool',
             recalc: 'always',
             signature: 'ref:single|deps:skip',
             resolve: function (range) {
@@ -257,7 +257,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/informationfuncs', [
             category: 'information',
             minParams: 1,
             maxParams: 1,
-            type: 'val',
+            type: 'val:bool',
             signature: 'val:any',
             resolve: _.isBoolean // error codes and empty cells result in FALSE
         },
@@ -266,7 +266,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/informationfuncs', [
             category: 'information',
             minParams: 1,
             maxParams: 1,
-            type: 'val',
+            type: 'val:bool',
             signature: 'val:any',
             resolve: function (value) { return value === ErrorCode.NA; }
         },
@@ -275,7 +275,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/informationfuncs', [
             category: 'information',
             minParams: 1,
             maxParams: 1,
-            type: 'val',
+            type: 'val:bool',
             signature: 'val:any',
             resolve: function (value) {
                 return !_.isString(value); // error codes and empty cells result in TRUE
@@ -286,7 +286,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/informationfuncs', [
             category: 'information',
             minParams: 1,
             maxParams: 1,
-            type: 'val',
+            type: 'val:bool',
             signature: 'val:any',
             resolve: _.isNumber // error codes and empty cells result in FALSE
         },
@@ -295,7 +295,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/informationfuncs', [
             category: 'information',
             minParams: 1,
             maxParams: 1,
-            type: 'val',
+            type: 'val:bool',
             signature: 'val:num',
             resolve: function (number) {
                 return (floor(abs(number)) % 2) !== 0;
@@ -306,7 +306,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/informationfuncs', [
             category: 'information',
             minParams: 1,
             maxParams: 1,
-            type: 'val',
+            type: 'val:bool',
             signature: 'any|deps:skip',
             resolve: function (operator) { return operator.isReference(); } // error codes result in FALSE
         },
@@ -315,7 +315,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/informationfuncs', [
             category: 'information',
             minParams: 1,
             maxParams: 1,
-            type: 'val',
+            type: 'val:bool',
             signature: 'val:any',
             resolve: _.isString // error codes and empty cells result in FALSE
         },
@@ -324,7 +324,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/informationfuncs', [
             category: 'information',
             minParams: 0,
             maxParams: 0,
-            type: 'val',
+            type: 'val:err',
             resolve: _.constant(ErrorCode.NA)
         },
 
@@ -334,14 +334,14 @@ define('io.ox/office/spreadsheet/model/formula/funcs/informationfuncs', [
             hidden: true,
             minParams: 1,
             maxParams: 3,
-            type: 'val'
+            type: 'val:any'
         },
 
         TYPE: {
             category: 'information',
             minParams: 1,
             maxParams: 1,
-            type: 'val',
+            type: 'val:num',
             signature: 'val:any', // resolve cell references to values, accept error codes
             resolve: function (value) {
                 // array literals always result in 64 regardless of their contents
