@@ -76,7 +76,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/logicalfuncs', [
         AND: {
             category: 'logical',
             minParams: 1,
-            type: 'val',
+            type: 'val:bool',
             signature: 'any|mat:pass',
             // empty parameters count as FALSE: AND(TRUE,) = FALSE
             resolve: implementLogicalAggregation(true, function (bool1, bool2) { return bool1 && bool2; })
@@ -86,7 +86,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/logicalfuncs', [
             category: 'logical',
             minParams: 0,
             maxParams: 0,
-            type: 'val',
+            type: 'val:bool',
             resolve: _.constant(false)
         },
 
@@ -132,7 +132,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/logicalfuncs', [
             category: 'logical',
             minParams: 2,
             maxParams: 2,
-            type: 'val',
+            type: 'val:any',
             signature: 'val:any val:any', // always return scalar values (in difference to IF)
             resolve: function (value1, value2) {
                 return (value1 instanceof ErrorCode) ? value2 : value1;
@@ -144,7 +144,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/logicalfuncs', [
             name: { ooxml: '_xlfn.IFNA' },
             minParams: 2,
             maxParams: 2,
-            type: 'val',
+            type: 'val:any',
             signature: 'val:any val:any', // always return scalar values (in difference to IF)
             resolve: function (value1, value2) {
                 return (value1 === ErrorCode.NA) ? value2 : value1;
@@ -170,7 +170,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/logicalfuncs', [
             category: 'logical',
             minParams: 1,
             maxParams: 1,
-            type: 'val',
+            type: 'val:bool',
             signature: 'val:bool',
             resolve: function (value) { return !value; }
         },
@@ -178,7 +178,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/logicalfuncs', [
         OR: {
             category: 'logical',
             minParams: 1,
-            type: 'val',
+            type: 'val:bool',
             signature: 'any|mat:pass',
             // empty parameters count as FALSE (but do not skip to catch empty-only parameters)
             resolve: implementLogicalAggregation(false, function (bool1, bool2) { return bool1 || bool2; })
@@ -188,7 +188,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/logicalfuncs', [
             category: 'logical',
             minParams: 0,
             maxParams: 0,
-            type: 'val',
+            type: 'val:bool',
             resolve: _.constant(true)
         },
 
@@ -196,7 +196,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/logicalfuncs', [
             category: 'logical',
             name: { ooxml: '_xlfn.XOR' },
             minParams: 1,
-            type: 'val',
+            type: 'val:bool',
             signature: 'any|mat:pass',
             // empty parameters count as FALSE (but do not skip to catch empty-only parameters)
             resolve: implementLogicalAggregation(false, function (bool1, bool2) { return bool1 !== bool2; })
