@@ -136,7 +136,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/mathfuncs', [
             category: 'math',
             minParams: 1,
             maxParams: 1,
-            type: 'val',
+            type: 'val:num',
             signature: 'val:num',
             resolve: abs
         },
@@ -145,7 +145,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/mathfuncs', [
             category: 'math',
             minParams: 1,
             maxParams: 1,
-            type: 'val',
+            type: 'val:num',
             signature: 'val:num',
             resolve: Math.acos
         },
@@ -154,7 +154,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/mathfuncs', [
             category: 'math',
             minParams: 1,
             maxParams: 1,
-            type: 'val',
+            type: 'val:num',
             signature: 'val:num',
             resolve: MathUtils.acosh
         },
@@ -164,7 +164,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/mathfuncs', [
             name: { ooxml: '_xlfn.ACOT' },
             minParams: 1,
             maxParams: 1,
-            type: 'val',
+            type: 'val:num',
             signature: 'val:num',
             resolve: function (number) {
                 return PI_2 - atan(number);
@@ -176,7 +176,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/mathfuncs', [
             name: { ooxml: '_xlfn.ACOTH' },
             minParams: 1,
             maxParams: 1,
-            type: 'val',
+            type: 'val:num',
             signature: 'val:num',
             resolve: MathUtils.acoth
         },
@@ -185,7 +185,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/mathfuncs', [
             category: 'math',
             name: { ooxml: '_xlfn.AGGREGATE', odf: 'COM.MICROSOFT.AGGREGATE' },
             minParams: 3,
-            type: 'val',
+            type: 'val:num',
             recalc: 'always', // function result depends on hidden state of rows
             signature: 'val:int val:int any any ref',
             resolve: (function () {
@@ -243,7 +243,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/mathfuncs', [
             category: 'math',
             minParams: 1,
             maxParams: 1,
-            type: 'val',
+            type: 'val:num',
             signature: 'val:num',
             resolve: Math.asin
         },
@@ -252,7 +252,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/mathfuncs', [
             category: 'math',
             minParams: 1,
             maxParams: 1,
-            type: 'val',
+            type: 'val:num',
             signature: 'val:num',
             resolve: MathUtils.asinh
         },
@@ -261,7 +261,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/mathfuncs', [
             category: 'math',
             minParams: 1,
             maxParams: 1,
-            type: 'val',
+            type: 'val:num',
             signature: 'val:num',
             resolve: atan
         },
@@ -270,7 +270,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/mathfuncs', [
             category: 'math',
             minParams: 2,
             maxParams: 2,
-            type: 'val',
+            type: 'val:num',
             signature: 'val:num val:num',
             resolve: MathUtils.atan2 // parameter order is (x,y), Math.atan2 expects (y,x)
         },
@@ -279,7 +279,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/mathfuncs', [
             category: 'math',
             minParams: 1,
             maxParams: 1,
-            type: 'val',
+            type: 'val:num',
             signature: 'val:num',
             resolve: MathUtils.atanh
         },
@@ -290,7 +290,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/mathfuncs', [
             // TODO: change to fixed-2-parameters
             minParams: { ooxml: 2, odf: 1 },
             maxParams: { ooxml: 2, odf: 3 },
-            type: 'val',
+            type: 'val:num',
             signature: 'val:num val:num val:int',
             resolve: 'CEILING.MATH'
         },
@@ -300,7 +300,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/mathfuncs', [
             name: { ooxml: '_xlfn.CEILING.MATH', odf: 'COM.MICROSOFT.CEILING.MATH' },
             minParams: 1,
             maxParams: 3,
-            type: 'val',
+            type: 'val:num',
             signature: 'val:num val:num val:int',
             resolve: function (number, significance, mode) {
                 var result, modulo, minBorder = 1e-16;
@@ -339,7 +339,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/mathfuncs', [
             name: { ooxml: null, odf: 'CEILING' },
             minParams: 1,
             maxParams: 3,
-            type: 'val',
+            type: 'val:num',
             signature: 'val:num val:num val:int',
             resolve: 'CEILING.MATH'
         },
@@ -350,7 +350,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/mathfuncs', [
             hidden: true, // replaced by CEILING.MATH in XL2013
             minParams: 1,
             maxParams: 2,
-            type: 'val',
+            type: 'val:num',
             signature: 'val:num val:num',
             resolve: 'CEILING.MATH'
         },
@@ -359,7 +359,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/mathfuncs', [
             category: 'math',
             minParams: 2,
             maxParams: 2,
-            type: 'val',
+            type: 'val:num',
             signature: 'val:int val:int',
             resolve: MathUtils.binomial
         },
@@ -369,7 +369,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/mathfuncs', [
             name: { ooxml: '_xlfn.COMBINA' },
             minParams: 2,
             maxParams: 2,
-            type: 'val',
+            type: 'val:num',
             signature: 'val:int val:int',
             resolve: function (number1, number2) {
                 return MathUtils.binomial(number1 + number2 - 1, number2);
@@ -380,7 +380,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/mathfuncs', [
             category: 'math',
             minParams: 1,
             maxParams: 1,
-            type: 'val',
+            type: 'val:num',
             signature: 'val:num',
             resolve: cos
         },
@@ -389,7 +389,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/mathfuncs', [
             category: 'math',
             minParams: 1,
             maxParams: 1,
-            type: 'val',
+            type: 'val:num',
             signature: 'val:num',
             resolve: cosh
         },
@@ -399,7 +399,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/mathfuncs', [
             name: { ooxml: '_xlfn.COT' },
             minParams: 1,
             maxParams: 1,
-            type: 'val',
+            type: 'val:num',
             signature: 'val:num',
             resolve: function (number) {
                 return div(1, tan(number));
@@ -411,7 +411,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/mathfuncs', [
             name: { ooxml: '_xlfn.COTH' },
             minParams: 1,
             maxParams: 1,
-            type: 'val',
+            type: 'val:num',
             signature: 'val:num',
             resolve: function (number) {
                 return div(1, tanh(number));
@@ -423,7 +423,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/mathfuncs', [
             name: { ooxml: '_xlfn.CSC' },
             minParams: 1,
             maxParams: 1,
-            type: 'val',
+            type: 'val:num',
             signature: 'val:num',
             resolve: function (number) {
                 return div(1, sin(number));
@@ -435,7 +435,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/mathfuncs', [
             name: { ooxml: '_xlfn.CSCH' },
             minParams: 1,
             maxParams: 1,
-            type: 'val',
+            type: 'val:num',
             signature: 'val:num',
             resolve: function (number) {
                 return div(2 * exp(-number), 1 - exp(-2 * number));
@@ -446,7 +446,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/mathfuncs', [
             category: 'math',
             minParams: 1,
             maxParams: 1,
-            type: 'val',
+            type: 'val:num',
             signature: 'val:num',
             resolve: function (number) {
                 return number / PI_180;
@@ -457,7 +457,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/mathfuncs', [
             category: 'math',
             minParams: 1,
             maxParams: 1,
-            type: 'val',
+            type: 'val:num',
             signature: 'val:num',
             resolve: function (number) {
                 var result = 2 * ceil(abs(number) / 2);
@@ -469,7 +469,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/mathfuncs', [
             category: 'math',
             minParams: 1,
             maxParams: 1,
-            type: 'val',
+            type: 'val:num',
             signature: 'val:num',
             resolve: exp
         },
@@ -478,7 +478,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/mathfuncs', [
             category: 'math',
             minParams: 1,
             maxParams: 1,
-            type: 'val',
+            type: 'val:num',
             signature: 'val:int',
             resolve: MathUtils.factorial
         },
@@ -487,15 +487,9 @@ define('io.ox/office/spreadsheet/model/formula/funcs/mathfuncs', [
             category: 'math',
             minParams: 1,
             maxParams: 1,
-            type: 'val',
+            type: 'val:num',
             signature: 'val:int',
-            resolve: (function () {
-                var FACTS = [1, 1];
-                while (isFinite(_.last(FACTS))) { FACTS.push(FACTS[FACTS.length - 2] * FACTS.length); }
-                return function (number) {
-                    return (number in FACTS) ? FACTS[number] : ErrorCode.NUM;
-                };
-            }())
+            resolve: MathUtils.factorial2
         },
 
         FLOOR: {
@@ -504,7 +498,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/mathfuncs', [
             // TODO: change to fixed-2-parameters
             minParams: { ooxml: 2, odf: 1 },
             maxParams: { ooxml: 2, odf: 3 },
-            type: 'val',
+            type: 'val:num',
             signature: 'val:num val:num val:int',
             resolve: 'FLOOR.MATH'
         },
@@ -514,7 +508,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/mathfuncs', [
             name: { ooxml: '_xlfn.FLOOR.MATH', odf: 'COM.MICROSOFT.FLOOR.MATH' },
             minParams: 1,
             maxParams: 3,
-            type: 'val',
+            type: 'val:num',
             signature: 'val:num val:num val:int',
             resolve: function (number, significance, mode) {
                 var result, modulo, minBorder = 1e-16;
@@ -550,7 +544,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/mathfuncs', [
             name: { ooxml: null, odf: 'FLOOR' },
             minParams: 1,
             maxParams: 3,
-            type: 'val',
+            type: 'val:num',
             signature: 'val:num val:num val:int',
             resolve: 'FLOOR.MATH'
         },
@@ -561,7 +555,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/mathfuncs', [
             hidden: true, // replaced by FLOOR.MATH in XL2013
             minParams: 1,
             maxParams: 2,
-            type: 'val',
+            type: 'val:num',
             signature: 'val:num val:num',
             resolve: 'FLOOR.MATH'
         },
@@ -569,7 +563,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/mathfuncs', [
         GCD: {
             category: 'math',
             minParams: 1,
-            type: 'val',
+            type: 'val:num',
             signature: 'any|mat:pass',
             resolve: (function () {
 
@@ -601,7 +595,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/mathfuncs', [
             category: 'math',
             minParams: 1,
             maxParams: 1,
-            type: 'val',
+            type: 'val:num',
             signature: 'val:int',
             resolve: _.identity // always rounds down, e.g. INT(-1.5) = -2
         },
@@ -612,7 +606,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/mathfuncs', [
             hidden: true, // replaced by CEILING.MATH in XL2013
             minParams: 1,
             maxParams: 2,
-            type: 'val',
+            type: 'val:num',
             signature: 'val:num val:num',
             resolve: 'CEILING.PRECISE'
         },
@@ -620,7 +614,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/mathfuncs', [
         LCM: {
             category: 'math',
             minParams: 1,
-            type: 'val',
+            type: 'val:num',
             signature: 'any|mat:pass',
             resolve: (function () {
 
@@ -652,7 +646,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/mathfuncs', [
             category: 'math',
             minParams: 1,
             maxParams: 1,
-            type: 'val',
+            type: 'val:num',
             signature: 'val:num',
             resolve: log
         },
@@ -661,7 +655,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/mathfuncs', [
             category: 'math',
             minParams: 1,
             maxParams: 2,
-            type: 'val',
+            type: 'val:num',
             signature: 'val:num val:num',
             resolve: function (number, base) {
                 return this.isMissingOperand(1) ? log10(number) : (log(number) / log(base));
@@ -672,7 +666,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/mathfuncs', [
             category: 'math',
             minParams: 1,
             maxParams: 1,
-            type: 'val',
+            type: 'val:num',
             signature: 'val:num',
             resolve: log10
         },
@@ -681,7 +675,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/mathfuncs', [
             category: 'math',
             minParams: 2,
             maxParams: 2,
-            type: 'val',
+            type: 'val:num',
             signature: 'val:num val:num',
             resolve: MathUtils.mod
         },
@@ -690,7 +684,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/mathfuncs', [
             category: 'math',
             minParams: 2,
             maxParams: 2,
-            type: 'val',
+            type: 'val:num',
             signature: 'val:num val:num',
             resolve: mround
         },
@@ -698,7 +692,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/mathfuncs', [
         MULTINOMIAL: {
             category: 'math',
             minParams: 1,
-            type: 'val',
+            type: 'val:num',
             signature: 'any|mat:pass',
             resolve: (function () {
 
@@ -727,7 +721,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/mathfuncs', [
             category: 'math',
             minParams: 1,
             maxParams: 1,
-            type: 'val',
+            type: 'val:num',
             signature: 'val',
             resolve: function (value) {
                 return _.isNumber(value) ? value : (value === true) ? 1 : 0;
@@ -739,7 +733,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/mathfuncs', [
             name: { ooxml: null },
             minParams: 1,
             maxParams: 1,
-            type: 'val',
+            type: 'val:num',
             signature: 'val:num',
             resolve: function (number) { return -number; }
         },
@@ -748,7 +742,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/mathfuncs', [
             category: 'math',
             minParams: 1,
             maxParams: 1,
-            type: 'val',
+            type: 'val:num',
             signature: 'val:num',
             resolve: function (number) {
                 var result = 2 * ceil((abs(number) + 1) / 2) - 1;
@@ -760,7 +754,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/mathfuncs', [
             category: 'math',
             minParams: 0,
             maxParams: 0,
-            type: 'val',
+            type: 'val:num',
             resolve: _.constant(PI)
         },
 
@@ -768,7 +762,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/mathfuncs', [
             category: 'math',
             minParams: 2,
             maxParams: 2,
-            type: 'val',
+            type: 'val:num',
             signature: 'val:num val:num',
             resolve: MathUtils.POW
         },
@@ -776,7 +770,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/mathfuncs', [
         PRODUCT: {
             category: 'math',
             minParams: 1,
-            type: 'val',
+            type: 'val:num',
             signature: 'any|mat:pass',
             resolve: function () { return StatUtils.groupProduct(this, arguments); }
         },
@@ -785,7 +779,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/mathfuncs', [
             category: 'math',
             minParams: 2,
             maxParams: 2,
-            type: 'val',
+            type: 'val:num',
             signature: 'val:num val:num',
             resolve: function (number1, number2) {
                 return trunc(div(number1, number2));
@@ -796,7 +790,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/mathfuncs', [
             category: 'math',
             minParams: 1,
             maxParams: 1,
-            type: 'val',
+            type: 'val:num',
             signature: 'val:num',
             resolve: function (number) {
                 return number * PI_180;
@@ -807,7 +801,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/mathfuncs', [
             category: 'math',
             minParams: 0,
             maxParams: 0,
-            type: 'val',
+            type: 'val:num',
             recalc: 'always',
             resolve: Math.random
         },
@@ -816,7 +810,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/mathfuncs', [
             category: 'math',
             minParams: 2,
             maxParams: 2,
-            type: 'val',
+            type: 'val:num',
             recalc: 'always',
             signature: 'val:num val:num',
             resolve: function (min, max) {
@@ -831,7 +825,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/mathfuncs', [
             category: 'math',
             minParams: 2,
             maxParams: 2,
-            type: 'val',
+            type: 'val:num',
             signature: 'val:num val:int',
             resolve: function (number, digits) {
                 var mult = pow10(-digits);
@@ -843,7 +837,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/mathfuncs', [
             category: 'math',
             minParams: 2,
             maxParams: 2,
-            type: 'val',
+            type: 'val:num',
             signature: 'val:num val:int',
             resolve: function (number, digits) {
                 var mult = pow10(-digits),
@@ -857,7 +851,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/mathfuncs', [
             category: 'math',
             minParams: 2,
             maxParams: 2,
-            type: 'val',
+            type: 'val:num',
             signature: 'val:num val:int',
             resolve: function (number, digits) {
                 var mult = pow10(-digits),
@@ -872,7 +866,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/mathfuncs', [
             name: { ooxml: '_xlfn.SEC' },
             minParams: 1,
             maxParams: 1,
-            type: 'val',
+            type: 'val:num',
             signature: 'val:num',
             resolve: function (number) {
                 return div(1, cos(number));
@@ -884,7 +878,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/mathfuncs', [
             name: { ooxml: '_xlfn.SECH' },
             minParams: 1,
             maxParams: 1,
-            type: 'val',
+            type: 'val:num',
             signature: 'val:num',
             resolve: function (number) {
                 return div(2 * exp(-number), 1 + exp(-2 * number));
@@ -895,7 +889,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/mathfuncs', [
             category: 'math',
             minParams: 4,
             maxParams: 4,
-            type: 'val',
+            type: 'val:num',
             signature: 'val:num val:num val:num any|mat:pass',
             resolve: (function () {
 
@@ -926,7 +920,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/mathfuncs', [
             category: 'math',
             minParams: 1,
             maxParams: 1,
-            type: 'val',
+            type: 'val:num',
             signature: 'val:num',
             resolve: function (number) {
                 return (number < 0) ? -1 : (number > 0) ? 1 : 0;
@@ -937,7 +931,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/mathfuncs', [
             category: 'math',
             minParams: 1,
             maxParams: 1,
-            type: 'val',
+            type: 'val:num',
             signature: 'val:num',
             resolve: sin
         },
@@ -946,7 +940,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/mathfuncs', [
             category: 'math',
             minParams: 1,
             maxParams: 1,
-            type: 'val',
+            type: 'val:num',
             signature: 'val:num',
             resolve: sinh
         },
@@ -955,7 +949,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/mathfuncs', [
             category: 'math',
             minParams: 1,
             maxParams: 1,
-            type: 'val',
+            type: 'val:num',
             signature: 'val:num',
             resolve: sqrt
         },
@@ -964,7 +958,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/mathfuncs', [
             category: 'math',
             minParams: 1,
             maxParams: 1,
-            type: 'val',
+            type: 'val:num',
             signature: 'val:num',
             resolve: function (number) {
                 return sqrt(PI * number);
@@ -974,7 +968,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/mathfuncs', [
         SUBTOTAL: {
             category: 'math',
             minParams: 2,
-            type: 'val',
+            type: 'val:num',
             recalc: 'always', // function result depends on hidden state of rows
             signature: 'val:int any|mat:pass',
             resolve: (function () {
@@ -1016,7 +1010,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/mathfuncs', [
         SUM: {
             category: 'math',
             minParams: 1,
-            type: 'val',
+            type: 'val:num',
             signature: 'any|mat:pass',
             resolve: function () {
                 return StatUtils.groupSum(this, arguments, { collectFormats: true });
@@ -1027,7 +1021,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/mathfuncs', [
             category: 'math',
             minParams: 2,
             maxParams: 3,
-            type: 'val',
+            type: 'val:num',
             signature: 'ref:val val:any ref:val',
             resolve: function () {
                 return this.aggregateFilteredCells('single', 0, MathUtils.add);
@@ -1038,7 +1032,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/mathfuncs', [
             category: 'math',
             minParams: 3,
             repeatParams: 2,
-            type: 'val',
+            type: 'val:num',
             signature: 'ref:val ref:val val:any',
             resolve: function () {
                 return this.aggregateFilteredCells('multi', 0, MathUtils.add);
@@ -1048,7 +1042,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/mathfuncs', [
         SUMSQ: {
             category: 'math',
             minParams: 1,
-            type: 'val',
+            type: 'val:num',
             signature: 'any|mat:pass',
             resolve: function () {
                 function aggregate(result, number) { return result + number * number; }
@@ -1060,7 +1054,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/mathfuncs', [
             category: 'math',
             minParams: 1,
             maxParams: 1,
-            type: 'val',
+            type: 'val:num',
             signature: 'val:num',
             resolve: tan
         },
@@ -1069,7 +1063,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/mathfuncs', [
             category: 'math',
             minParams: 1,
             maxParams: 1,
-            type: 'val',
+            type: 'val:num',
             signature: 'val:num',
             resolve: tanh
         },
@@ -1078,7 +1072,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/mathfuncs', [
             category: 'math',
             minParams: 1,
             maxParams: 2,
-            type: 'val',
+            type: 'val:num',
             signature: 'val:num val:int',
             resolve: function (number, digits) {
 
