@@ -88,7 +88,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/matrixfuncs', [
             category: 'matrix',
             minParams: 1,
             maxParams: 1,
-            type: 'val',
+            type: 'val:num',
             signature: 'mat:num',
             resolve: function (matrix) {
 
@@ -149,9 +149,9 @@ define('io.ox/office/spreadsheet/model/formula/funcs/matrixfuncs', [
                 }
 
                 // multiply the resulting diagonal elements of the U matrix
-                return sign * luVals.reduce(function (det, rowVec, row) {
+                return luVals.reduce(function (det, rowVec, row) {
                     return det * rowVec[row];
-                }, 1);
+                }, sign);
             }
         },
 
@@ -253,7 +253,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/matrixfuncs', [
         SUMPRODUCT: {
             category: 'matrix math',
             minParams: 1,
-            type: 'val',
+            type: 'val:num',
             signature: 'any|mat:force', // bug 47280: forced matrix context also in cell formulas
             resolve: function () {
                 function aggregate(result, numbers) { return result + numbers.reduce(MathUtils.mul, 1); }
@@ -265,7 +265,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/matrixfuncs', [
             category: 'matrix math',
             minParams: 2,
             maxParams: 2,
-            type: 'val',
+            type: 'val:num',
             signature: 'any|mat:force any|mat:force',
             resolve: function () {
                 function aggregate(result, nums) { return result + nums[0] * nums[0] - nums[1] * nums[1]; }
@@ -277,7 +277,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/matrixfuncs', [
             category: 'matrix math',
             minParams: 2,
             maxParams: 2,
-            type: 'val',
+            type: 'val:num',
             signature: 'any|mat:force any|mat:force',
             resolve: function () {
                 function aggregate(result, nums) { return result + nums[0] * nums[0] + nums[1] * nums[1]; }
@@ -289,7 +289,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/matrixfuncs', [
             category: 'matrix math',
             minParams: 2,
             maxParams: 2,
-            type: 'val',
+            type: 'val:num',
             signature: 'any|mat:force any|mat:force',
             resolve: function () {
                 function aggregate(result, nums) { var diff = nums[0] - nums[1]; return result + diff * diff; }
