@@ -81,36 +81,6 @@ define('io.ox/office/spreadsheet/model/formula/funcs/referencefuncs', [
         return res;
     }
 
-    /**
-     * @returns {Number} order and {Boolean} anyString
-     *  1  is ascending
-     *  -1 is descending
-     *  0  is no order
-     */
-    function getOrderType(context, operand) {
-        var order = null;
-        var last = null;
-        var anyString = false;
-
-        IteratorUtils.some(context.createScalarIterator(operand), function (value) {
-            if (last !== null) {
-                var subOrder = context.compareScalars(last, value);
-                if (order === null) {
-                    order = subOrder;
-                } else if (subOrder !== order) {
-                    order = 0;
-                    return true;
-                }
-            }
-            last = value;
-            if (_.isString(value)) { anyString = true; }
-        });
-        return {
-            anyString: anyString,
-            order: -order
-        };
-    }
-
     function getTypeId(value) {
         return _.isNumber(value) ? 1 : _.isString(value) ? 2 : _.isBoolean(value) ? 3 : (value instanceof ErrorCode) ? 4 : 0;
     }
@@ -183,70 +153,6 @@ define('io.ox/office/spreadsheet/model/formula/funcs/referencefuncs', [
         throw ErrorCode.NA;
     }
 
-    function searchMatchInOperand(context, lookup, operand, order) {
-
-        if (_.isUndefined(lookup) || _.isNull(lookup)) { throw ErrorCode.VALUE; }
-
-        var inexact = order !== 0;
-
-        var regex = null;
-        if (!inexact && _.isString(lookup)) { regex = context.convertPatternToRegExp(lookup, true); }
-
-        var lookupType = getTypeId(lookup);
-        var last = null;
-        var lastIndex = null;
-        var resultIndex = Number.NaN;
-        var anyString = false;
-        var iterator = context.createScalarIterator(operand, SEARCHOPERANDOPTIONS);
-
-        IteratorUtils.some(iterator, function (value, result) {
-            if (value === null) { return; }
-
-            var index = result.offset;
-
-            last = value;
-            lastIndex = index;
-
-            var currentType = getTypeId(value);
-
-            if (currentType === 2) { anyString = true; }
-
-            if (currentType !== lookupType) { return; }
-
-            var compare = context.compareScalars(value, lookup);
-            if (compare === 0) {
-                resultIndex = index;
-                return true;
-            }
-
-            if (inexact) {
-                if (order === 1) {
-                    if (compare > 0) {
-                        if (index < 1) { throw ErrorCode.NA; }
-                        resultIndex = index - 1;
-                        return true;
-                    }
-                } else if (order === -1) {
-                    if (compare < 0) {
-                        if (index < 1) { throw ErrorCode.NA; }
-                        resultIndex = index - 1;
-                        return true;
-                    }
-                }
-            }
-            if (regex && regex.test(value)) {
-                resultIndex = index;
-                return true;
-            }
-        });
-
-        if (!_.isNaN(resultIndex)) { return resultIndex; }
-
-        if (!_.isNaN(lastIndex) && getTypeId(last) === lookupType && anyString) { return lastIndex; }
-
-        throw ErrorCode.NA;
-    }
-
     // exports ================================================================
 
     return {
@@ -255,7 +161,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/referencefuncs', [
             category: 'reference',
             minParams: 2,
             maxParams: 5,
-            type: 'val',
+            type: 'val:str',
             signature: 'val:int val:int val:int val:bool val:str',
             resolve: function (row, col, absMode, a1Style, sheetName) {
 
@@ -336,7 +242,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/referencefuncs', [
             category: 'reference',
             minParams: 1,
             maxParams: 1,
-            type: 'val',
+            type: 'val:num',
             signature: 'ref|deps:skip',
             resolve: function (ranges) { return ranges.length; }
         },
@@ -357,7 +263,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/referencefuncs', [
             category: 'reference',
             minParams: 0,
             maxParams: 1,
-            type: 'val',
+            type: 'val:num',
             signature: 'ref:single|deps:skip',
             resolve: function (range) {
                 // create a matrix with all column indexes in matrix context with explicit range
@@ -380,7 +286,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/referencefuncs', [
             category: 'reference',
             minParams: 1,
             maxParams: 1,
-            type: 'val',
+            type: 'val:num',
             signature: 'any|deps:skip',
             resolve: function (operand) {
                 var value = operand.getRawValue();
@@ -402,7 +308,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/referencefuncs', [
             name: { ooxml: '_xlfn.FORMULATEXT', odf: 'FORMULA' },
             minParams: 1,
             maxParams: 1,
-            type: 'val',
+            type: 'val:str',
             recalc: 'always', // changing a formula may not change the result, thus no recalculation would be triggered
             signature: 'ref:single|deps:skip',
             resolve: function (range) {
@@ -427,7 +333,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/referencefuncs', [
             hidden: true,
             minParams: 2,
             repeatParams: 2,
-            type: 'val'
+            type: 'val:any'
         },
 
         HLOOKUP: {
@@ -521,7 +427,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/referencefuncs', [
 
                 tokenArray.parseFormula(grammarId, refText, { refAddress: refAddress });
 
-                var ranges = tokenArray.resolveRangeList({ resolveNames: true, refAddress: refAddress, targetAddress: refAddress });
+                var ranges = tokenArray.resolveRangeList({ resolveNames: 'simple', refAddress: refAddress, targetAddress: refAddress });
                 if (ranges.length !== 1) { throw ErrorCode.REF; }
 
                 return ranges.first();
@@ -571,28 +477,73 @@ define('io.ox/office/spreadsheet/model/formula/funcs/referencefuncs', [
             category: 'reference',
             minParams: 2,
             maxParams: 3,
-            type: 'val',
+            type: 'val:num',
             signature: 'val any|mat:pass val:int',
-            resolve: function (lookup, searchOperand, order) {
+            resolve: function (lookupValue, searchOperand, matchType) {
+                // https://github.com/sutoiku/formula.js/blob/b1174eef1c977e464f2ef15220049a2fdbcb2184/lib/lookup-reference.js
 
                 var dim = searchOperand.getDimension({ errorCode: ErrorCode.VALUE }); // #VALUE! thrown for complex references
 
                 if (Math.min(dim.rows, dim.cols) !== 1) { throw ErrorCode.NA; }
 
-                if (_.isUndefined(order)) { order = 1; }
+                if (_.isUndefined(matchType)) { matchType = 1; }
 
-                if (order !== 0) {
-                    var orderType = getOrderType(this, searchOperand);
+                if (matchType !== -1 && matchType !== 0 && matchType !== 1) { throw ErrorCode.NA; }
 
-                    if (order !== orderType.order) {
-                        if (orderType.anyString) {
-                            order = 0;
+                var iterator = this.createScalarIterator(searchOperand, SEARCHOPERANDOPTIONS);
+                var index;
+                var indexValue;
+
+                IteratorUtils.some(iterator, function (value, result) {
+                    var idx = result.offset;
+
+                    if (matchType === 1) {
+                        if (value === lookupValue) {
+                            index = idx + 1;
+                            return true;
+                        } else if (value < lookupValue) {
+                            if (!indexValue) {
+                                index = idx + 1;
+                                indexValue = value;
+                            } else if (value > indexValue) {
+                                index = idx + 1;
+                                indexValue = value;
+                            }
+                        }
+                    } else if (matchType === 0) {
+                        if (getTypeId(lookupValue) === 2) {
+                            lookupValue = lookupValue.replace(/\?/g, '.');
+                            if (value.toLowerCase().match(lookupValue.toLowerCase())) {
+                                index = idx + 1;
+                                return true;
+                            }
                         } else {
-                            throw ErrorCode.NA;
+                            if (value === lookupValue) {
+                                index = idx + 1;
+                                return true;
+                            }
+                        }
+                    } else if (matchType === -1) {
+                        if (value === lookupValue) {
+                            index = idx + 1;
+                            return true;
+                        } else if (value > lookupValue) {
+                            if (!indexValue) {
+                                index = idx + 1;
+                                indexValue = value;
+                            } else if (value < indexValue) {
+                                index = idx + 1;
+                                indexValue = value;
+                            }
                         }
                     }
+                });
+
+                if (index) {
+                    return index;
+                } else {
+                    throw ErrorCode.NA;
                 }
-                return searchMatchInOperand(this, lookup, searchOperand, order) + 1;
             }
         },
 
@@ -628,7 +579,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/referencefuncs', [
             category: 'reference',
             minParams: 0,
             maxParams: 1,
-            type: 'val',
+            type: 'val:num',
             signature: 'ref:single|deps:skip',
             resolve: function (range) {
                 // create a matrix with all row indexes in matrix context with explicit range
@@ -651,7 +602,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/referencefuncs', [
             category: 'reference',
             minParams: 1,
             maxParams: 1,
-            type: 'val',
+            type: 'val:num',
             signature: 'any|deps:skip',
             resolve: function (operand) {
                 var value = operand.getRawValue();
@@ -673,7 +624,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/referencefuncs', [
             name: { ooxml: '_xlfn.SHEET' },
             minParams: 0,
             maxParams: 1,
-            type: 'val',
+            type: 'val:num',
             recalc: 'always', // function result depends on index of a sheet (refresh on moving sheet)
             signature: 'any|deps:skip', // string (sheet name) or reference
             resolve: function (operand) {
@@ -691,11 +642,12 @@ define('io.ox/office/spreadsheet/model/formula/funcs/referencefuncs', [
                 // convert values to strings (sheet name may look like a number or boolean)
                 if (operand.isScalar()) {
                     var sheet = this.docModel.getSheetIndex(this.convertToString(value));
-                    return (sheet < 0) ? ErrorCode.NA : (sheet + 1);
+                    if (sheet < 0) { throw ErrorCode.NA; }
+                    return sheet + 1;
                 }
 
                 // always fail for matrix operands, regardless of context
-                return ErrorCode.NA;
+                throw ErrorCode.NA;
             }
         },
 
@@ -704,7 +656,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/referencefuncs', [
             name: { ooxml: '_xlfn.SHEETS' },
             minParams: 0,
             maxParams: 1,
-            type: 'val',
+            type: 'val:num',
             recalc: 'always', // function result depends on indexes of sheets (refresh on moving sheet)
             signature: 'ref:multi|deps:skip',
             resolve: function (range) {
