@@ -33,7 +33,8 @@ define('io.ox/office/spreadsheet/model/formula/interpret/formulacompiler', [
     var OPERATOR_PRECEDENCE_CATEGORIES = {
         cmp: Utils.makeSet(['eq', 'ne', 'lt', 'le', 'gt', 'ge']),
         con: Utils.makeSet(['con']),
-        pct: Utils.makeSet(['pct']),
+        upre: Utils.makeSet(['add', 'sub']),
+        upost: Utils.makeSet(['upct']),
         add: Utils.makeSet(['add', 'sub']),
         mul: Utils.makeSet(['mul', 'div']),
         pow: Utils.makeSet(['pow']),
@@ -494,12 +495,16 @@ define('io.ox/office/spreadsheet/model/formula/interpret/formulacompiler', [
              * Compiles a unary prefix/postfix operator subexpression.
              */
             function compileUnaryTerm(token) {
-                if (isOperatorToken(token, 'add')) {
+                if (isOperatorToken(token, 'upre')) {
+                    switch (token.getValue()) {
+                        case 'add': token = new OperatorToken('uplus'); break;
+                        case 'sub': token = new OperatorToken('uminus'); break;
+                    }
                     token = compileTermAndPush(compileUnaryTerm, token, 1);
                 } else {
                     token = compileListTerm(token);
                 }
-                while (isOperatorToken(token, 'pct')) {
+                while (isOperatorToken(token, 'upost')) {
                     pushOperator(token, 1);
                     token = getNextToken();
                 }
