@@ -120,7 +120,7 @@ define('io.ox/office/spreadsheet/model/formula/interpret/formulainterpreter', [
 
         // base constructor ---------------------------------------------------
 
-        BaseObject.call(this);
+        BaseObject.call(this, docModel);
 
         // private methods ----------------------------------------------------
 
@@ -318,7 +318,7 @@ define('io.ox/office/spreadsheet/model/formula/interpret/formulainterpreter', [
                     type = 'ref';
                     break;
                 default:
-                    FormulaUtils.throwInternal('InterpreterInstance.makeTokenOperand(): unknown token type: "' + token.getType() + '"');
+                    FormulaUtils.throwInternal('InterpreterInstance.resolveOperandNode(): unknown token type: "' + token.getType() + '"');
             }
 
             // check context type (will throw 'reference' exception)
@@ -526,13 +526,19 @@ define('io.ox/office/spreadsheet/model/formula/interpret/formulainterpreter', [
                     // invoke the resolver callback function of the operator
                     var operand = getOperand(descriptor, signature, operands, 0, 0);
 
+                    // allow 'mat'-type operators to return scalars (especially error codes)
+                    if ((descriptor.type === 'mat') && operand.isScalar()) {
+                        operand = createOperand(Matrix.create(1, 1, operand.getRawValue()));
+                    }
+
                     // exit immediately if the result does not match the specified type
-                    // (in matrix context, 'val'-type functions/operands are allowed to return matrixes though)
-                    if ((descriptor.type !== 'any') &&
-                        (descriptor.type !== operand.getType()) &&
-                        !((contextType === 'mat') && (descriptor.type === 'val') && operand.isMatrix())
+                    if ((descriptor.type !== 'any') && (descriptor.type !== operand.getType()) &&
+                        // allow error codes as return values for 'ref'-type operators
+                        !((descriptor.type === 'ref') && operand.isScalar() && (operand.getRawValue() instanceof ErrorCode)) &&
+                        // in matrix context, 'val'-type functions/operands are allowed to return matrixes
+                        !((descriptor.type === 'val') && (contextType === 'mat') && operand.isMatrix())
                     ) {
-                        FormulaUtils.throwInternal('InterpreterInstance.resolveOperatorNode(): ' + descriptor.name + ': operator result type does not match operator return type');
+                        FormulaUtils.throwInternal('InterpreterInstance.resolveOperatorNode(): ' + descriptor.key + ': operator result type does not match operator return type');
                     }
 
                     // expand scalar operators to matrix results if required
