@@ -13,13 +13,29 @@
  */
 
 define('io.ox/office/spreadsheet/model/formula/parser/desccollection', [
-    'io.ox/office/tk/container/basemap'
-], function (BaseMap) {
+    'io.ox/office/tk/container/container'
+], function (Container) {
 
     'use strict';
 
-    // convenience shortcuts
-    var MapProto = BaseMap.prototype;
+    // private global functions ===============================================
+
+    /**
+     * Returns the pattern for a regular expression that maches any of the
+     * strings in the passed array.
+     *
+     * @param {Array<String>} list
+     *  The array with strings to be matched by a regular expression.
+     *
+     * @returns {String}
+     *  The pattern for a regular expression that maches any of the strings in
+     *  the passed array, enclosed in parentheses. The strings will be sorted
+     *  by length in order to create a greedy regular expression. Example: For
+     *  the strings 'a', 'b', and 'ab', the pattern '(ab|a|b)' will be created.
+     */
+    function createListPattern(list) {
+        return '(' + list.sort(function (n1, n2) { return n2.length - n1.length; }).map(_.escapeRegExp).join('|') + ')';
+    }
 
     // class Descriptor =======================================================
 
@@ -65,17 +81,29 @@ define('io.ox/office/spreadsheet/model/formula/parser/desccollection', [
      *
      * @constructor
      *
-     * @extends BaseMap
+     * @extends Container
      *
-     * @param {Object} descriptors
-     *  An object with all descriptors to be inserted into the new collection
-     *  (MUST BE instances of the class Descriptor), mapped by their unique
-     *  resource keys.
+     * @param {Object} map
+     *  The raw source data map, mapped by the resource keys to be used in the
+     *  new collection.
+     *
+     * @param {Function} generator
+     *  The generator callback function that will be invoked for each entry in
+     *  the passed data map. Receives the following parameters:
+     *  (1) {Object} data
+     *      The current entry of the map passed to this method.
+     *  (2) {String} key
+     *      The resource key of the current entry.
+     *  Can return a descriptor (instance of class Descriptor) to be inserted
+     *  into the new collection; or null or undefined to skip the map entry.
+     *
+     * @param {Object} [context]
+     *  The calling context for the callback function.
      */
-    var DescriptorCollection = BaseMap.extend({ constructor: function (descriptors) {
+    var DescriptorCollection = Container.extend({ constructor: function (map, generator, context) {
 
-        // all descriptors contained in this collection (instances of the class Descriptor), mapped by resource key
-        BaseMap.call(this, descriptors);
+        // base constructor
+        Container.call(this);
 
         // resource keys of all descriptors as map values, mapped by their names
         this._nativeKeys = {};
@@ -85,8 +113,14 @@ define('io.ox/office/spreadsheet/model/formula/parser/desccollection', [
         this._nativeNames = [];
         this._localNames = [];
 
-        // initialize the key maps from the passed map of descriptors
-        this.forEach(function (descriptor, key) {
+        // initialize the key maps from the passed list of descriptors
+        Container.forEach(map, function (data, key) {
+
+            // generator callback creates a new descriptor instance, or returns null
+            var descriptor = generator.call(context, data, key);
+            if (!(descriptor instanceof Descriptor)) { return; }
+
+            this._insert(key, descriptor);
             this._nativeKeys[descriptor.nativeName.toUpperCase()] = this._localKeys[descriptor.localName.toUpperCase()] = key;
             descriptor.altNativeNames.forEach(function (altName) { this._nativeKeys[altName.toUpperCase()] = key; }, this);
             descriptor.altLocalNames.forEach(function (altName) { this._localKeys[altName.toUpperCase()] = key; }, this);
@@ -101,8 +135,8 @@ define('io.ox/office/spreadsheet/model/formula/parser/desccollection', [
         this._localNames.sort();
 
         // regular expression patterns matching any of the supported names (sort by name length to create a greedy pattern)
-        this._nativePattern = '(' + this._nativeNames.sort(function (n1, n2) { return n2.length - n1.length; }).map(_.escapeRegExp).join('|') + ')';
-        this._localPattern = '(' + this._localNames.sort(function (n1, n2) { return n2.length - n1.length; }).map(_.escapeRegExp).join('|') + ')';
+        this._nativePattern = createListPattern(this._nativeNames);
+        this._localPattern = createListPattern(this._localNames);
 
     } }); // class DescriptorCollection
 
@@ -119,7 +153,7 @@ define('io.ox/office/spreadsheet/model/formula/parser/desccollection', [
      *  is not valid.
      */
     DescriptorCollection.prototype.get = function (key) {
-        return MapProto.get.call(this, key, null);
+        return this._get(key) || null;
     };
 
     /**
@@ -139,7 +173,7 @@ define('io.ox/office/spreadsheet/model/formula/parser/desccollection', [
      *  The value of the specified descriptor property, or the default value.
      */
     DescriptorCollection.prototype.getProperty = function (key, name, def) {
-        var descriptor = this.get(key);
+        var descriptor = this._get(key);
         return (descriptor && (name in descriptor)) ? descriptor[name] : def;
     };
 
@@ -159,7 +193,7 @@ define('io.ox/office/spreadsheet/model/formula/parser/desccollection', [
      *  the passed resource key cannot be resolved to the name of a descriptor.
      */
     DescriptorCollection.prototype.getName = function (key, localized) {
-        var descriptor = this.get(key);
+        var descriptor = this._get(key);
         return !descriptor ? null : localized ? descriptor.localName : descriptor.nativeName;
     };
 
@@ -218,64 +252,14 @@ define('io.ox/office/spreadsheet/model/formula/parser/desccollection', [
         return localized ? this._localPattern : this._nativePattern;
     };
 
-    // static methods ---------------------------------------------------------
+    // sub classes ------------------------------------------------------------
 
     /**
-     * Creates a new descriptor to be inserted into an instance of this class.
+     * The class constructor of the instances of a descriptor collection.
      *
-     * @param {String} key
-     *  The unique key of the resource object represented by the descriptor.
-     *
-     * @param {String} nativeName
-     *  The native name of the resource object.
-     *
-     * @param {String} localName
-     *  The localized name of the resource object.
-     *
-     * @returns {Descriptor}
-     *  A new descriptor containing the passed settings.
+     * @type Function
      */
-    DescriptorCollection.newDescriptor = function (key, nativeName, localName) {
-        return new Descriptor(key, nativeName, localName);
-    };
-
-    /**
-     * Creates a new descriptor collection by converting an arbitrary data map
-     * to descriptor instances using the passed generator callback function.
-     *
-     * @param {Object} map
-     *  The raw source data map, mapped by the resource keys to be used in the
-     *  new collection.
-     *
-     * @param {Function} callback
-     *  The generator callback function that will be invoked for each entry in
-     *  the passed data map. Receives the following parameters:
-     *  (1) {Object} data
-     *      The current entry of the map passed to this method.
-     *  (2) {String} key
-     *      The resource key of the current entry.
-     *  Can return a descriptor (instance of class Descriptor) to be inserted
-     *  into the new collection; or null or undefined to skip the map entry.
-     *
-     * @param {Object} [context]
-     *  The calling context for the callback function.
-     *
-     * @returns {DescriptorCollection}
-     *  The new descriptor collection.
-     */
-    DescriptorCollection.create = function (map, callback, context) {
-
-        // invoke the generator callback function for all entries in the map
-        var descriptors = _.mapObject(map, callback, context);
-
-        // filter all invalid entries from the result map
-        _.each(descriptors, function (entry, key) {
-            if (!(entry instanceof Descriptor)) { delete descriptors[key]; }
-        });
-
-        // create the new collection
-        return new DescriptorCollection(descriptors);
-    };
+    DescriptorCollection.ElementType = Descriptor;
 
     // exports ================================================================
 
