@@ -414,17 +414,32 @@ define('io.ox/office/spreadsheet/model/formula/parser/expressionparser', [
      *  The original text representation of the defined name in the parsed
      *  formula expression.
      *
+     * @param {Object} [options]
+     *  Optional parameters:
+     *  @param {Boolean} [options.resolveTable=false]
+     *      If set to true, and the passed label refers to a table range, a
+     *      table reference token will be created.
+     *
      * @returns {TokenDescriptor}
      *  The token descriptor containing a new name token, and the passed text.
      */
-    ExpressionParserBase.prototype.createNameToken = function (sheetRef, label, text) {
+    ExpressionParserBase.prototype.createNameToken = function (sheetRef, label, text, options) {
 
         // bug 40293: add sheet reference to existing sheet-local names if specified
         if (!sheetRef && this.extendSheet && this.refSheetModel && this.refSheetModel.getNameCollection().hasName(label)) {
             sheetRef = new SheetRef(this.refSheet, true);
         }
 
-        return this.createToken(new Tokens.NameToken(this.docModel, label, sheetRef), text);
+        // workaround for bugs 51203 and 52728, TODO: support for arbitrary external references
+        var globalRef = !sheetRef && /^\[0\]!/.test(text);
+        // create the name token
+        var nameToken = new Tokens.NameToken(this.docModel, label, sheetRef, globalRef ? 0 : null);
+
+        // try to find a table range model referred by the passed label
+        var tableModel = Utils.getBooleanOption(options, 'resolveTable', false) ? nameToken.resolveTableModel() : null;
+        if (tableModel) { nameToken = new Tokens.TableToken(this.docModel, label); }
+
+        return this.createToken(nameToken, text);
     };
 
     /**
@@ -632,7 +647,7 @@ define('io.ox/office/spreadsheet/model/formula/parser/expressionparser', [
         FormulaUtils.logTokens('tokenize', tokenDescs);
 
         // whether the intersection operator is a space and needs post-processing
-        var spaceAsIsect = this.grammar.getOperatorName('isect') === ' ';
+        var spaceAsIsect = this.grammar.isSpaceIntersection();
 
         // post-process the token array
         Utils.iterateArray(tokenDescs, function (tokenDesc, index) {
@@ -1260,9 +1275,9 @@ define('io.ox/office/spreadsheet/model/formula/parser/expressionparser', [
             return this.createFunctionToken(null, matches[1], matches[0]);
         }
 
-        // defined name without sheet reference
+        // defined name without sheet reference, or table reference
         if ((matches = RE.NAME_REF.exec(expr))) {
-            return this.createNameToken(null, matches[1], matches[0]);
+            return this.createNameToken(null, matches[1], matches[0], { resolveTable: true });
         }
     };
 
@@ -1337,7 +1352,7 @@ define('io.ox/office/spreadsheet/model/formula/parser/expressionparser', [
 
         // defined name without sheet reference
         if ((matches = RE.NAME_REF.exec(expr))) {
-            return this.createNameToken(null, matches[1], matches[0]);
+            return this.createNameToken(null, matches[1], matches[0], { resolveTable: true });
         }
     };
 
