@@ -214,7 +214,7 @@ define('io.ox/office/spreadsheet/model/formula/parser/formulagrammar', [
         var NA_ERROR = errorCollection.getName(ErrorCode.NA.key, localized);
 
         // a simple number formatter to generate the string representation of numbers
-        var formatter = new Formatter({ dec: DEC, group: GROUP });
+        var formatter = new Formatter(BaseObject.SINGLETON, { dec: DEC, group: GROUP });
 
         // reference syntax identifier
         var refSyntax = !odf ? 'ooxml' : localized ? 'odfui' : 'of';
@@ -268,7 +268,7 @@ define('io.ox/office/spreadsheet/model/formula/parser/formulagrammar', [
 
         // base constructor ---------------------------------------------------
 
-        BaseObject.call(this);
+        BaseObject.call(this, BaseObject.SINGLETON);
 
         // public properties --------------------------------------------------
 
@@ -500,6 +500,12 @@ define('io.ox/office/spreadsheet/model/formula/parser/formulagrammar', [
          * @param {SpreadsheetModel} docModel
          *  The document model needed to resolve sheet names.
          *
+         * @param {Number|Null} extDocRef
+         *  The index of the external document, e.g. in [1]!extname or
+         *  [1]Sheet1!A1. The value zero represents a global reference into the
+         *  own document, e.g. in [0]!globalname. If set to null, the token
+         *  represents a reference in the own document (e.g. globalname).
+         *
          * @param {SheetRef|Null} sheet1Ref
          *  The first sheet reference. If set to null, an empty string will be
          *  returned.
@@ -515,31 +521,35 @@ define('io.ox/office/spreadsheet/model/formula/parser/formulagrammar', [
          *  are invalid (deleted sheet); or an empty string, if no sheet
          *  references have been passed (sheet-local reference).
          */
-        function generateSheetRangePrefix(docModel, sheet1Ref, sheet2Ref) {
+        function generateSheetRangePrefix(docModel, extDocRef, sheet1Ref, sheet2Ref) {
+
+            // start with the external document reference
+            var result = (extDocRef !== null) ? ('[' + extDocRef + ']') : '';
 
             // empty string for missing sheet reference
-            if (!sheet1Ref) { return ''; }
+            if (sheet1Ref) {
 
-            // convert first sheet name
-            var sheet1Name = sheet1Ref.resolve(docModel);
-            if (sheet1Name === null) { return null; }
+                // convert first sheet name
+                var sheet1Name = sheet1Ref.resolve(docModel, extDocRef);
+                if (sheet1Name === null) { return null; }
 
-            // convert second sheet name
-            var sheet2Name = (sheet2Ref && !sheet1Ref.equals(sheet2Ref)) ? sheet2Ref.resolve(docModel) : '';
-            if (sheet2Name === null) { return null; }
+                // convert second sheet name
+                var sheet2Name = (sheet2Ref && !sheet1Ref.equals(sheet2Ref)) ? sheet2Ref.resolve(docModel, extDocRef) : '';
+                if (sheet2Name === null) { return null; }
 
-            // the resulting sheet names
-            var result = odf ? encodeAbsSheetName(docModel, sheet1Name, sheet1Ref.abs) : sheet1Name;
-            if (sheet2Name) {
-                result += ':' + (odf ? encodeAbsSheetName(docModel, sheet2Name, sheet2Ref.abs) : sheet2Name);
+                // the resulting sheet names
+                result += odf ? encodeAbsSheetName(docModel, sheet1Name, sheet1Ref.abs) : sheet1Name;
+                if (sheet2Name) {
+                    result += ':' + (odf ? encodeAbsSheetName(docModel, sheet2Name, sheet2Ref.abs) : sheet2Name);
+                }
+
+                // OOXML: enclose sheet range in apostrophes, if one of the sheet names is complex
+                if (!odf && (!self.isSimpleSheetName(docModel, sheet1Name) || (sheet2Name && !self.isSimpleSheetName(docModel, sheet2Name)))) {
+                    result = SheetRef.encodeComplexSheetName(result);
+                }
             }
 
-            // OOXML: enclose sheet range in apostrophes, if one of the sheet names is complex
-            if (!odf && (!self.isSimpleSheetName(docModel, sheet1Name) || (sheet2Name && !self.isSimpleSheetName(docModel, sheet2Name)))) {
-                result = SheetRef.encodeComplexSheetName(result);
-            }
-
-            return result + '!';
+            return result ? (result + '!') : '';
         }
 
         /**
@@ -565,7 +575,7 @@ define('io.ox/office/spreadsheet/model/formula/parser/formulagrammar', [
 
             // convert reference to sheet name, use the #REF! error code for invalid sheets,
             // enclose complex sheet names in apostrophes
-            var sheetName = sheetRef.resolve(docModel);
+            var sheetName = sheetRef.resolve(docModel, null);
             return sheetName ? (encodeAbsSheetName(docModel, sheetName, sheetRef.abs) + '.') : null;
         }
 
@@ -779,7 +789,7 @@ define('io.ox/office/spreadsheet/model/formula/parser/formulagrammar', [
 
             // start with all sheet names before the cell range address, e.g. Sheet1:Sheet2!A1:C3
             // (sheet reference errors will result in a simple #REF! error without anything else)
-            var sheetPrefix = generateSheetRangePrefix(docModel, sheet1Ref, sheet2Ref);
+            var sheetPrefix = generateSheetRangePrefix(docModel, null, sheet1Ref, sheet2Ref);
             return (sheetPrefix === null) ? REF_ERROR : (sheetPrefix + startStr + (endStr ? (':' + endStr) : ''));
         };
 
@@ -891,6 +901,14 @@ define('io.ox/office/spreadsheet/model/formula/parser/formulagrammar', [
          * @param {SpreadsheetModel} docModel
          *  The document model needed to resolve sheet names.
          *
+         * @param {Number|Null} extDocRef
+         *  The index of the external document, e.g. the number in the brackets
+         *  in the formula [1]!extname. The value zero represents a globally
+         *  defined name with document reference in the passed document model,
+         *  e.g. the zero in [0]!globalname. If null or undefined, the token
+         *  represents a name in the passed document without document reference
+         *  (e.g. globalname).
+         *
          * @param {SheetRef|Null} sheetRef
          *  The sheet reference (e.g. the particle 'Sheet1' in 'Sheet1!name').
          *  If set to null, no sheet name will be inserted into the returned
@@ -902,14 +920,14 @@ define('io.ox/office/spreadsheet/model/formula/parser/formulagrammar', [
          * @returns {String}
          *  The string representation of the defined name.
          */
-        this.formatName = function (docModel, sheetRef, label) {
+        this.formatName = function (docModel, extDocRef, sheetRef, label) {
 
-            // no sheet-local names in ODF files
-            if (odf && sheetRef) { return NA_ERROR; }
+            // no external or sheet-local names in ODF files
+            if (odf && (extDocRef || sheetRef)) { return NA_ERROR; }
 
             // sheet reference error will be replaced by a global workbook reference
-            var sheetPrefix = generateSheetRangePrefix(docModel, sheetRef);
-            if (sheetPrefix === null) { sheetPrefix = localized ? '' : '[0]!'; }
+            var sheetPrefix = generateSheetRangePrefix(docModel, extDocRef, sheetRef);
+            if (sheetPrefix === null) { sheetPrefix = '[' + (extDocRef || 0) + ']!'; }
             return sheetPrefix + label;
         };
 
@@ -921,6 +939,13 @@ define('io.ox/office/spreadsheet/model/formula/parser/formulagrammar', [
          * @param {SpreadsheetModel} docModel
          *  The document model needed to resolve sheet names.
          *
+         * @param {Number|Null} extDocRef
+         *  The index of the external document, e.g. the number in the brackets
+         *  in the formula [1]!macro(). The value zero represents a macro with
+         *  document reference in the passed document model, e.g. the zero in
+         *  [0]!macro(). If null or undefined, the token represents a macro in
+         *  the passed document without document reference (e.g. macro()).
+         *
          * @param {SheetRef|Null} sheetRef
          *  The sheet reference (e.g. the particle 'Sheet1' in the formula
          *  'Sheet1!macro()'). If set to null, no sheet name will be inserted
@@ -932,10 +957,10 @@ define('io.ox/office/spreadsheet/model/formula/parser/formulagrammar', [
          * @returns {String}
          *  The string representation of the macro call.
          */
-        this.formatMacro = function (docModel, sheetRef, label) {
+        this.formatMacro = function (docModel, extDocRef, sheetRef, label) {
 
-            // no sheet-local macros in ODF files
-            if (odf) { return sheetRef ? NA_ERROR : label; }
+            // no external or sheet-local macros in ODF files
+            if (odf) { return (extDocRef || sheetRef) ? NA_ERROR : label; }
 
             // OOXML: macro names equal to the internal name of a built-in function will be prefixed
             // Example: the formula '=SUMME(1)+SUM(1)' in a German UI results in the expression 'SUM(1)+_xludf.SUM(1)'
@@ -948,8 +973,8 @@ define('io.ox/office/spreadsheet/model/formula/parser/formulagrammar', [
                 label = UDF_PREFIX + label;
             }
 
-            // sheet reference error will be replaced by a global workbook reference
-            return this.formatName(docModel, sheetRef, label);
+            // format the macro call like a defined name
+            return this.formatName(docModel, extDocRef, sheetRef, label);
         };
 
         /**
@@ -1142,6 +1167,17 @@ define('io.ox/office/spreadsheet/model/formula/parser/formulagrammar', [
             return colName.replace(TABLE_COL_ESCAPE_RE, '\'$&');
         };
 
+        /**
+         * Returns whether the intersection operator is a space character, and
+         * thus needs special handling to disambiguate it from white-space.
+         *
+         * @returns {Boolean}
+         *  Whether the intersection operator is a space character.
+         */
+        this.isSpaceIntersection = function () {
+            return this.getOperatorName('isect') === ' ';
+        };
+
         /**
          * Generates the formula expression for a generic subtotal formula.
          *
