@@ -13,12 +13,12 @@
  */
 
 define('io.ox/office/spreadsheet/model/formula/parser/formulaparser', [
-    'io.ox/office/tk/container/simplemap',
+    'io.ox/office/tk/container/valuemap',
     'io.ox/office/baseframework/model/modelobject',
     'io.ox/office/spreadsheet/model/formula/formulautils',
     'io.ox/office/spreadsheet/model/formula/parser/expressionparser',
     'io.ox/office/spreadsheet/model/formula/parser/rangelistparser'
-], function (SimpleMap, ModelObject, FormulaUtils, ExpressionParser, RangeListParser) {
+], function (ValueMap, ModelObject, FormulaUtils, ExpressionParser, RangeListParser) {
 
     'use strict';
 
@@ -37,10 +37,10 @@ define('io.ox/office/spreadsheet/model/formula/parser/formulaparser', [
     var FormulaParser = ModelObject.extend({ constructor: function (docModel) {
 
         // all existing expression parsers, mapped by grammar identifiers
-        var exprParserMap = new SimpleMap();
+        var exprParserMap = new ValueMap();
 
         // all existing range list parsers, mapped by grammar identifiers
-        var listParserMap = new SimpleMap();
+        var listParserMap = new ValueMap();
 
         // base constructor ---------------------------------------------------
 
