@@ -24,6 +24,9 @@ define.async('io.ox/office/spreadsheet/model/formula/parser/formularesource', [
 
     'use strict';
 
+    // convenience shortcuts
+    var Descriptor = DescriptorCollection.ElementType;
+
     // internal implementations of all operators
     var OPERATOR_IMPL_MAP = null;
 
@@ -78,13 +81,15 @@ define.async('io.ox/office/spreadsheet/model/formula/parser/formularesource', [
 
     // maps resource keys of operators to their local names
     var LOCAL_OPERATOR_NAMES = {
+        uplus: '+',
+        uminus: '-',
+        upct: '%',
         add: '+',
         sub: '-',
         mul: '*',
         div: '/',
         pow: '^',
         con: '&',
-        pct: '%',
         lt: '<',
         le: '<=',
         gt: '>',
@@ -325,7 +330,7 @@ define.async('io.ox/office/spreadsheet/model/formula/parser/formularesource', [
         }
 
         // process all raw descriptor objects
-        var collection = DescriptorCollection.create(implementationMap, function (implementation, key) {
+        var collection = new DescriptorCollection(implementationMap, function (implementation, key) {
 
             // resolve file format dependent properties of the implementation
             var properties = Utils.mapProperties(implementation, function (value) {
@@ -358,7 +363,7 @@ define.async('io.ox/office/spreadsheet/model/formula/parser/formularesource', [
             }
 
             // create the resource descriptor with preferred native name (first array element)
-            var descriptor = DescriptorCollection.newDescriptor(key, nativeNames[0], localName);
+            var descriptor = new Descriptor(key, nativeNames[0], localName);
 
             // store the alternative native names contained in the array
             descriptor.altNativeNames = nativeNames.slice(1);
@@ -378,7 +383,9 @@ define.async('io.ox/office/spreadsheet/model/formula/parser/formularesource', [
             if (_.isNumber(properties.repeatParams)) { descriptor.repeatParams = properties.repeatParams; }
 
             // copy result type and format category
-            descriptor.type = properties.type;
+            var retType = properties.type.split(':');
+            descriptor.type = retType[0];
+            descriptor.valType = retType[1] || 'any';
             descriptor.format = properties.format;
 
             // convert signature string to an array of parameter descriptors
@@ -576,7 +583,7 @@ define.async('io.ox/office/spreadsheet/model/formula/parser/formularesource', [
 
         // base constructor ---------------------------------------------------
 
-        BaseObject.call(this);
+        BaseObject.call(this, BaseObject.SINGLETON);
 
         // private methods ----------------------------------------------------
 
@@ -696,7 +703,8 @@ define.async('io.ox/office/spreadsheet/model/formula/parser/formularesource', [
          *
          * @param {Boolean} localized
          *  Whether to return the localized decimal separator according to the
-         *  UI language (true), or the native (English) decimal separator.
+         *  locale passed to the constructor (true), or the native decimal
+         *  separator used in the file format (false).
          *
          * @returns {String}
          *  The decimal separator character.
@@ -709,8 +717,9 @@ define.async('io.ox/office/spreadsheet/model/formula/parser/formularesource', [
          * Returns the group separator for the current UI language.
          *
          * @param {Boolean} localized
-         *  Whether to return the localized group separator according to the UI
-         *  language (true), or the native (English) group separator.
+         *  Whether to return the localized group separator according to the
+         *  locale passed to the constructor (true), or the native group
+         *  separator used in the file format (false).
          *
          * @returns {String}
          *  The decimal separator character.
@@ -726,8 +735,8 @@ define.async('io.ox/office/spreadsheet/model/formula/parser/formularesource', [
          *
          * @param {Boolean} localized
          *  Whether to return the localized list separator character according
-         *  to the UI language (true), or the native (English) list separator
-         *  character.
+         *  to the locale passed to the constructor (true), or the native list
+         *  separator character used in the file format (false).
          *
          * @returns {String}
          *  The list separator character.
@@ -742,7 +751,8 @@ define.async('io.ox/office/spreadsheet/model/formula/parser/formularesource', [
          *
          * @param {Boolean} localized
          *  Whether to return the localized prefix characters according to the
-         *  UI language (true), or the native (English) prefix characters.
+         *  locale passed to the constructor (true), or the native prefix
+         *  characters used in the file format (false).
          *
          * @returns {String}
          *  The prefix characters used in R1C1 references (a string with two
@@ -853,44 +863,44 @@ define.async('io.ox/office/spreadsheet/model/formula/parser/formularesource', [
         }
 
         // create descriptors for the names of boolean values
-        booleanCollection = DescriptorCollection.create({ f: 'FALSE', t: 'TRUE' }, function (nativeName, key) {
+        booleanCollection = new DescriptorCollection({ f: 'FALSE', t: 'TRUE' }, function (nativeName, key) {
             var localName = rawResourceData[nativeName];
             if (!localName) {
                 Utils.error('\xa0 missing boolean translation: key=' + key);
                 localName = nativeName;
             }
-            return DescriptorCollection.newDescriptor(key, nativeName, localName);
+            return new Descriptor(key, nativeName, localName);
         });
 
         // create error code descriptors
-        errorCollection = DescriptorCollection.create(ErrorCode.NATIVE_CODES, function (error, key) {
+        errorCollection = new DescriptorCollection(ErrorCode.NATIVE_CODES, function (error, key) {
             var nativeName = NATIVE_ERROR_NAMES[key];
             var localName = rawResourceData.errors[key];
             if (!localName) {
                 Utils.error('\xa0 missing error code translation: key=' + key);
                 localName = nativeName;
             }
-            return DescriptorCollection.newDescriptor(key, nativeName, localName);
+            return new Descriptor(key, nativeName, localName);
         });
 
         // resolve descriptors for regions in structured table references
-        regionCollection = DescriptorCollection.create(NATIVE_REGION_NAMES, function (nativeName, key) {
+        regionCollection = new DescriptorCollection(NATIVE_REGION_NAMES, function (nativeName, key) {
             var localName = rawResourceData.regions[key];
             if (!localName) {
                 Utils.error('\xa0 missing table region translation: key=' + key);
                 localName = nativeName;
             }
-            return DescriptorCollection.newDescriptor(key, nativeName, localName);
+            return new Descriptor(key, nativeName, localName);
         });
 
         // resolve descriptors for named parameters of the function CELL
-        cellParamCollection = DescriptorCollection.create(NATIVE_CELL_PARAM_NAMES, function (nativeName, key) {
+        cellParamCollection = new DescriptorCollection(NATIVE_CELL_PARAM_NAMES, function (nativeName, key) {
             var localName = rawResourceData.cellParams[key];
             if (!localName) {
                 Utils.error('\xa0 missing CELL parameter translation: key=' + key);
                 localName = nativeName;
             }
-            return DescriptorCollection.newDescriptor(key, nativeName, localName);
+            return new Descriptor(key, nativeName, localName);
         });
 
         // function parameter separator
