@@ -6,7 +6,8 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
-  * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Daniel Rentz <daniel.rentz@open-xchange.com>
  */
@@ -14,8 +15,8 @@
 define('io.ox/office/spreadsheet/model/formula/parser/rangelistparser', [
     'io.ox/office/tk/utils',
     'io.ox/office/spreadsheet/utils/sheetutils',
-    'io.ox/office/spreadsheet/model/formula/utils/sheetref'
-], function (Utils, SheetUtils, SheetRef) {
+    'io.ox/office/spreadsheet/model/formula/formulautils'
+], function (Utils, SheetUtils, FormulaUtils) {
 
     'use strict';
 
@@ -23,6 +24,7 @@ define('io.ox/office/spreadsheet/model/formula/parser/rangelistparser', [
     var Address = SheetUtils.Address;
     var Range = SheetUtils.Range;
     var RangeArray = SheetUtils.RangeArray;
+    var SheetRef = FormulaUtils.SheetRef;
 
     // class RangeListParserBase ==============================================
 
@@ -44,7 +46,11 @@ define('io.ox/office/spreadsheet/model/formula/parser/rangelistparser', [
 
         // formula grammar settings
         this.grammar = formulaGrammar;
-        this.RE = formulaGrammar.RANGE_LIST_RE;
+
+        // reference grammar configuration
+        this.refGrammar = formulaGrammar.refGrammar;
+        this.addrConfig = this.refGrammar.addrConfig;
+        this.RE = this.refGrammar.RE;
 
     }); // class RangeListParserBase
 
@@ -87,12 +93,12 @@ define('io.ox/office/spreadsheet/model/formula/parser/rangelistparser', [
         var matches = null;
 
         // accept sequences of various white-space characters, use a SPACE as abstract separator
-        if ((matches = RE.SEP_WS.exec(expr))) {
+        if ((matches = RE.RL_SEP_WS.exec(expr))) {
             return { sep: ' ', text: matches[0] };
         }
 
         // accept other separators in extended mode only (only single characters, no sequences)
-        if (this.extSep && (matches = RE.SEP_OTHER.exec(expr))) {
+        if (this.extSep && (matches = RE.RL_SEP_OTHER.exec(expr))) {
             return { sep: matches[0], text: matches[0] };
         }
 
@@ -101,40 +107,6 @@ define('io.ox/office/spreadsheet/model/formula/parser/rangelistparser', [
 
     // protected methods ------------------------------------------------------
 
-    /**
-     * Extracts a column index from the passed matches of a regular expression.
-     *
-     * @param {Array<String>} matches
-     *  The matches of a regular expression.
-     *
-     * @param {Number} index
-     *  The array index of the column index in the passed matches.
-     *
-     * @returns {Number}
-     *  The column for the passed matches, if it is valid; otherwise -1.
-     */
-    RangeListParserBase.prototype.getCol = function (matches, index) {
-        var col = Address.parseCol(matches[index]);
-        return (col <= this.MAXCOL) ? col : -1;
-    };
-
-    /**
-     * Extracts a row index from the passed matches of a regular expression.
-     *
-     * @param {Array<String>} matches
-     *  The matches of a regular expression.
-     *
-     * @param {Number} index
-     *  The array index of the row index in the passed matches.
-     *
-     * @returns {Number}
-     *  The row for the passed matches, if it is valid; otherwise -1.
-     */
-    RangeListParserBase.prototype.getRow = function (matches, index) {
-        var row = Address.parseRow(matches[index]);
-        return (row <= this.MAXROW) ? row : -1;
-    };
-
     /**
      * Extracts a cell address from the passed matches of a regular expression.
      *
@@ -151,9 +123,7 @@ define('io.ox/office/spreadsheet/model/formula/parser/rangelistparser', [
      *  are valid; otherwise null.
      */
     RangeListParserBase.prototype.getAddress = function (matches, index) {
-        var col = this.getCol(matches, index);
-        var row = this.getRow(matches, index + 1);
-        return ((col >= 0) && (row >= 0)) ? new Address(col, row) : null;
+        return this.addrConfig.getAddress(matches, index, this.MAXCOL, this.MAXROW);
     };
 
     /**
@@ -165,12 +135,10 @@ define('io.ox/office/spreadsheet/model/formula/parser/rangelistparser', [
      *
      * @param {Number} index1
      *  The start array index of the first cell address in the passed matches.
-     *  See method RangeListParserBase.createAddress() for details.
      *
-     * @param {Number} index2
+     * @param {Number} [index2]
      *  The start array index of the second cell address in the passed matches.
-     *  See method RangeListParserBase.createAddress() for details. Can be
-     *  omitted for matches that represent a single cell address only.
+     *  If omitted, the range will be created from a single cell address.
      *
      * @returns {Range|Null}
      *  A cell range address for the passed matches, if the column and row
@@ -189,18 +157,20 @@ define('io.ox/office/spreadsheet/model/formula/parser/rangelistparser', [
      * @param {Array<String>} matches
      *  The matches of a regular expression.
      *
-     * @param {Number} index
-     *  The start array index of the column indexes in the passed matches. The
-     *  matches are expected to contain two elements for the first and second
-     *  column name, in this order.
+     * @param {Number} index1
+     *  The start array index of the first column index in the passed matches.
+     *
+     * @param {Number} [index2]
+     *  The start array index of the second column index in the passed matches.
+     *  If omitted, the range will be created from a single column index.
      *
      * @returns {Range|Null}
      *  A cell range address for the passed matches, if the column indexes are
      *  valid; otherwise null.
      */
-    RangeListParserBase.prototype.getColRange = function (matches, index) {
-        var col1 = this.getCol(matches, index);
-        var col2 = this.getCol(matches, index + 1);
+    RangeListParserBase.prototype.getColRange = function (matches, index1, index2) {
+        var col1 = this.addrConfig.getCol(matches, index1, this.MAXCOL);
+        var col2 = (typeof index2 === 'number') ? this.addrConfig.getCol(matches, index2, this.MAXCOL) : col1;
         return ((col1 >= 0) && (col2 >= 0)) ? Range.create(col1, 0, col2, this.MAXROW) : null;
     };
 
@@ -211,18 +181,20 @@ define('io.ox/office/spreadsheet/model/formula/parser/rangelistparser', [
      * @param {Array<String>} matches
      *  The matches of a regular expression.
      *
-     * @param {Number} index
-     *  The start array index of the row indexes in the passed matches. The
-     *  matches are expected to contain two elements for the first and second
-     *  row name, in this order.
+     * @param {Number} index1
+     *  The start array index of the first row index in the passed matches.
+     *
+     * @param {Number} [index2]
+     *  The start array index of the row column index in the passed matches. If
+     *  omitted, the range will be created from a single row index.
      *
      * @returns {Range|Null}
      *  A cell range address for the passed matches, if the row indexes are
      *  valid; otherwise null.
      */
-    RangeListParserBase.prototype.getRowRange = function (matches, index) {
-        var row1 = this.getRow(matches, index);
-        var row2 = this.getRow(matches, index + 1);
+    RangeListParserBase.prototype.getRowRange = function (matches, index1, index2) {
+        var row1 = this.addrConfig.getRow(matches, index1, this.MAXROW);
+        var row2 = (typeof index2 === 'number') ? this.addrConfig.getRow(matches, index2, this.MAXROW) : row1;
         return ((row1 >= 0) && (row2 >= 0)) ? Range.create(0, row1, this.MAXCOL, row2) : null;
     };
 
@@ -262,6 +234,55 @@ define('io.ox/office/spreadsheet/model/formula/parser/rangelistparser', [
 
     // public methods ---------------------------------------------------------
 
+    /**
+     * Parses the passed textual range to a cell range address. The range is
+     * expected to be in A1 notation.
+     *
+     * @param {String} formula
+     *  The text to be parsed to a cell range address.
+     *
+     * @param {Object} [options]
+     *  Optional parameters. See method FormulaParser.parseRange() for more
+     *  details.
+     *
+     * @returns {Range|Null}
+     *  The cell range address parsed from the specified range; or null on any
+     *  parser error.
+     */
+    RangeListParserBase.prototype.parseRange = function (formula, options) {
+
+        // initialize all instance properties
+        this._initOptions(options);
+
+        // try to parse the next range address from the formula expression
+        var rangeDesc = this.implParseRange(formula);
+
+        // return the range, if the formula does not contain any other garbage
+        return (rangeDesc && (formula.length === rangeDesc.text.length)) ? rangeDesc.range : null;
+    };
+
+    /**
+     * Converts the passed cell range addresss to its text representation.
+     *
+     * @param {Range} range
+     *  The cell range address to be converted.
+     *
+     * @param {Object} [options]
+     *  Optional parameters. See method FormulaParser.formatRange() for more
+     *  details.
+     *
+     * @returns {String}
+     *  The text representation of the passed cell range address.
+     */
+    RangeListParserBase.prototype.formatRange = function (range, options) {
+
+        // the sheet name to be inserted for the cell range address
+        var sheetName = Utils.getStringOption(options, 'sheetName', null);
+
+        // convert the range address
+        return this.implFormatRange(range, sheetName);
+    };
+
     /**
      * Parses the passed textual range list to an array of cell range
      * addresses. The range list is expected to contain range addresses in A1
@@ -331,8 +352,7 @@ define('io.ox/office/spreadsheet/model/formula/parser/rangelistparser', [
     };
 
     /**
-     * Converts the passed array of cell range addressses to their text
-     * representation.
+     * Converts the passed cell range addressses to their text representation.
      *
      * @param {RangeArray|Range} ranges
      *  An array of cell range addresses, or a single cell range address.
@@ -396,63 +416,63 @@ define('io.ox/office/spreadsheet/model/formula/parser/rangelistparser', [
         if (this.skipSheets) {
 
             // range address with sheet name (before cell addresses!), e.g. Sheet1!A1:C3
-            if ((matches = RE.RANGE_3D.exec(expr))) {
+            if ((matches = RE.RL_RANGE_3D_REF.exec(expr))) {
                 return this.createRangeDesc(null, this.getRange(matches, 3, 5), matches[0]);
             }
 
-            // range address with sheet range (before cell addresses!), e.g. Sheet1:Sheet2!A1:C3
-            if ((matches = RE.RANGE_CUBE.exec(expr))) {
-                return this.createRangeDesc(null, this.getRange(matches, 5, 7), matches[0]);
-            }
-
             // cell address with sheet name, e.g. Sheet1!A1
-            if ((matches = RE.CELL_3D.exec(expr))) {
+            if ((matches = RE.RL_CELL_3D_REF.exec(expr))) {
                 return this.createRangeDesc(null, this.getRange(matches, 3), matches[0]);
             }
 
-            // cell address with sheet range, e.g. Sheet1:Sheet2!A1
-            if ((matches = RE.CELL_CUBE.exec(expr))) {
-                return this.createRangeDesc(null, this.getRange(matches, 5), matches[0]);
+            // column interval with sheet name, e.g. Sheet1!A:C
+            if ((matches = RE.RL_COLS_3D_REF.exec(expr))) {
+                return this.createRangeDesc(null, this.getColRange(matches, 3, 4), matches[0]);
             }
 
-            // column interval with sheet name, e.g. Sheet1!A:C
-            if ((matches = RE.COLS_3D.exec(expr))) {
+            // single column with sheet name (R1C1 only), e.g. Sheet1!C1
+            if ((matches = RE.RL_COL_3D_REF.exec(expr))) {
                 return this.createRangeDesc(null, this.getColRange(matches, 3), matches[0]);
             }
 
-            // column interval with sheet range, e.g. Sheet1:Sheet2!A:C
-            if ((matches = RE.COLS_CUBE.exec(expr))) {
-                return this.createRangeDesc(null, this.getColRange(matches, 5), matches[0]);
-            }
-
             // row interval with sheet name, e.g. Sheet1!1:3
-            if ((matches = RE.ROWS_3D.exec(expr))) {
-                return this.createRangeDesc(null, this.getRowRange(matches, 3), matches[0]);
+            if ((matches = RE.RL_ROWS_3D_REF.exec(expr))) {
+                return this.createRangeDesc(null, this.getRowRange(matches, 3, 4), matches[0]);
             }
 
-            // row interval with sheet range, e.g. Sheet1:Sheet2!1:3
-            if ((matches = RE.ROWS_CUBE.exec(expr))) {
-                return this.createRangeDesc(null, this.getRowRange(matches, 5), matches[0]);
+            // single row with sheet name (R1C1 only), e.g. Sheet1!R1
+            if ((matches = RE.RL_ROW_3D_REF.exec(expr))) {
+                return this.createRangeDesc(null, this.getRowRange(matches, 3), matches[0]);
             }
         }
 
         // local range address (before cell addresses!), e.g. A1:C3
-        if ((matches = RE.RANGE.exec(expr))) {
+        if ((matches = RE.RL_RANGE_REF.exec(expr))) {
             return this.createRangeDesc(null, this.getRange(matches, 1, 3), matches[0]);
         }
 
         // local cell address, e.g. A1
-        if ((matches = RE.CELL.exec(expr))) {
+        if ((matches = RE.RL_CELL_REF.exec(expr))) {
             return this.createRangeDesc(null, this.getRange(matches, 1), matches[0]);
         }
 
         // local column interval, e.g. A:C
-        if ((matches = RE.COLS.exec(expr))) {
+        if ((matches = RE.RL_COLS_REF.exec(expr))) {
+            return this.createRangeDesc(null, this.getColRange(matches, 1, 2), matches[0]);
+        }
+
+        // local column (R1C1 only), e.g. C1
+        if ((matches = RE.RL_COL_REF.exec(expr))) {
             return this.createRangeDesc(null, this.getColRange(matches, 1), matches[0]);
         }
 
         // local row interval, e.g. 1:3
-        if ((matches = RE.ROWS.exec(expr))) {
+        if ((matches = RE.RL_ROWS_REF.exec(expr))) {
+            return this.createRangeDesc(null, this.getRowRange(matches, 1, 2), matches[0]);
+        }
+
+        // local row (R1C1 only), e.g. R1
+        if ((matches = RE.RL_ROW_REF.exec(expr))) {
             return this.createRangeDesc(null, this.getRowRange(matches, 1), matches[0]);
         }
     };
@@ -520,28 +540,28 @@ define('io.ox/office/spreadsheet/model/formula/parser/rangelistparser', [
         if (this.skipSheets) {
 
             // range address with sheet range (before 3D ranges!), e.g. Sheet1.A1:Sheet2.C3
-            if ((matches = RE.OF_RANGE_CUBE.exec(expr))) {
+            if ((matches = RE.RL_RANGE_CUBE_REF.exec(expr))) {
                 return this.createRangeDesc(null, this.getRange(matches, 3, 7), matches[0]);
             }
 
             // range address with sheet name (before cell addresses!), e.g. Sheet1.A1:C3
-            if ((matches = RE.OF_RANGE_3D.exec(expr))) {
+            if ((matches = RE.RL_RANGE_3D_REF.exec(expr))) {
                 return this.createRangeDesc(null, this.getRange(matches, 3, 5), matches[0]);
             }
 
             // cell address with sheet name, e.g. Sheet1.A1
-            if ((matches = RE.OF_CELL_3D.exec(expr))) {
+            if ((matches = RE.RL_CELL_3D_REF.exec(expr))) {
                 return this.createRangeDesc(null, this.getRange(matches, 3), matches[0]);
             }
         }
 
         // local range address (before cell addresses!), e.g. A1:C3
-        if ((matches = RE.RANGE.exec(expr))) {
+        if ((matches = RE.RL_RANGE_REF.exec(expr))) {
             return this.createRangeDesc(null, this.getRange(matches, 1, 3), matches[0]);
         }
 
         // local cell address, e.g. A1
-        if ((matches = RE.CELL.exec(expr))) {
+        if ((matches = RE.RL_CELL_REF.exec(expr))) {
             return this.createRangeDesc(null, this.getRange(matches, 1), matches[0]);
         }
     };
@@ -580,7 +600,8 @@ define('io.ox/office/spreadsheet/model/formula/parser/rangelistparser', [
      *
      * @param {String} grammarId
      *  The identifier of the formula grammar to be used to parse range list
-     *  expressions.
+     *  expressions. See SpreadsheetDocument.getFormulaGrammar() for more
+     *  details.
      *
      * @returns {RangeListParserBase}
      *  A new range list parser for the specified document and formula grammar.
