@@ -599,14 +599,20 @@ define('io.ox/office/spreadsheet/model/formula/parser/tokens', [
      * @param {SheetRef|Null} sheet1Ref
      *  The first sheet reference structure (e.g. 'Sheet1' in the expression
      *  Sheet1:Sheet2!A1). If null or undefined, the token represents a local
-     *  cell range reference into the passed sheet (e.g. A1:B2).
+     *  reference into the containing sheet (e.g. A1:B2).
      *
      * @param {SheetRef|Null} sheet2Ref
      *  The second sheet reference structure (e.g. 'Sheet2' in the expression
      *  Sheet1:Sheet2!A1). If null or undefined, the token represents a single
      *  sheet reference (e.g. Sheet1!A1).
+     *
+     * @param {Number|Null} extDocRef
+     *  The index of the external document, e.g. [1]!extname or [1]Sheet1!A1.
+     *  The value zero represents a global reference into the own document,
+     *  e.g. in [0]!globalname. If null or undefined, the token represents a
+     *  reference in the own document (e.g. globalname).
      */
-    var SheetRefToken = BaseToken.extend({ constructor: function (type, docModel, sheet1Ref, sheet2Ref) {
+    var SheetRefToken = BaseToken.extend({ constructor: function (type, docModel, sheet1Ref, sheet2Ref, extDocRef) {
 
         // base constructor
         BaseToken.call(this, type);
@@ -615,6 +621,7 @@ define('io.ox/office/spreadsheet/model/formula/parser/tokens', [
         this._docModel = docModel;
         this._sheet1Ref = sheet1Ref;
         this._sheet2Ref = sheet2Ref;
+        this._extDocRef = extDocRef;
 
         // swap sheet indexes (and absolute flags!), if sheet references are not in order
         if (sheet1Ref && sheet1Ref.valid() && sheet2Ref && sheet2Ref.valid() && (sheet2Ref.sheet < sheet1Ref.sheet)) {
@@ -630,6 +637,10 @@ define('io.ox/office/spreadsheet/model/formula/parser/tokens', [
 
     // protected methods ------------------------------------------------------
 
+    SheetRefToken.prototype._isOwnSheetRef = function (sheetRef) {
+        return this.isOwnDoc() && _.isObject(sheetRef);
+    };
+
     /**
      * Returns the sheet references of this token, and allows to oveeride the
      * own sheet references with arbitrary sheet reference structures, as
@@ -676,13 +687,25 @@ define('io.ox/office/spreadsheet/model/formula/parser/tokens', [
      *  sheet), null will be returned.
      */
     SheetRefToken.prototype._resolveSheetInterval = function (options) {
+        if (!this.isOwnDoc()) { return null; }
         var sheet1 = this._sheet1Ref ? this._sheet1Ref.sheet : Utils.getIntegerOption(options, 'refSheet', null);
         var sheet2 = this._sheet2Ref ? this._sheet2Ref.sheet : sheet1;
-        return (_.isNumber(sheet1) && (sheet1 >= 0) && _.isNumber(sheet2) && (sheet2 >= 0)) ? Interval.create(sheet1, sheet2) : null;
+        return ((typeof sheet1 === 'number') && (sheet1 >= 0) && (typeof sheet2 === 'number') && (sheet2 >= 0)) ? Interval.create(sheet1, sheet2) : null;
     };
 
     // public methods ---------------------------------------------------------
 
+    /**
+     * Returns whether this token refers into its own document.
+     *
+     * @returns {Boolean}
+     *  Returns whether this token refers into its own document (true), or to
+     *  another external spreadsheet document (false).
+     */
+    SheetRefToken.prototype.isOwnDoc = function () {
+        return !this._extDocRef; // either null or zero
+    };
+
     /**
      * Returns whether this token contains a sheet reference, regardless if it
      * is valid.
@@ -717,8 +740,8 @@ define('io.ox/office/spreadsheet/model/formula/parser/tokens', [
      *  from at least one unresolved sheet name to an existing sheet index.
      */
     SheetRefToken.prototype.refreshSheets = function () {
-        var changed1 = _.isObject(this._sheet1Ref) && this._sheet1Ref.refresh(this._docModel);
-        var changed2 = _.isObject(this._sheet2Ref) && this._sheet2Ref.refresh(this._docModel);
+        var changed1 = this._isOwnSheetRef(this._sheet1Ref) && this._sheet1Ref.refresh(this._docModel);
+        var changed2 = this._isOwnSheetRef(this._sheet2Ref) && this._sheet2Ref.refresh(this._docModel);
         return changed1 || changed2;
     };
 
@@ -730,8 +753,8 @@ define('io.ox/office/spreadsheet/model/formula/parser/tokens', [
      *  Whether the token has been changed.
      */
     SheetRefToken.prototype.transformSheet = function (fromSheet, toSheet) {
-        var changed1 = _.isObject(this._sheet1Ref) && this._sheet1Ref.transform(fromSheet, toSheet);
-        var changed2 = _.isObject(this._sheet2Ref) && this._sheet2Ref.transform(fromSheet, toSheet);
+        var changed1 = this._isOwnSheetRef(this._sheet1Ref) && this._sheet1Ref.transform(fromSheet, toSheet);
+        var changed2 = this._isOwnSheetRef(this._sheet2Ref) && this._sheet2Ref.transform(fromSheet, toSheet);
         return changed1 || changed2;
     };
 
@@ -740,16 +763,20 @@ define('io.ox/office/spreadsheet/model/formula/parser/tokens', [
      */
     SheetRefToken.prototype.debugSheetPrefix = function () {
 
+        // the external document refernce
+        var sheetName = (this._extDocRef === null) ? '' : ('[' + this._extDocRef + ']');
+
         // convert first sheet name
-        if (!this._sheet1Ref) { return ''; }
-        var sheetName = this._sheet1Ref.toString();
+        if (this._sheet1Ref) {
+            sheetName += this._sheet1Ref.toString();
+        }
 
         // convert second sheet name
-        if (this._sheet2Ref && !this._sheet1Ref.equals(this._sheet2Ref)) {
+        if (this._sheet1Ref && this._sheet2Ref && !this._sheet1Ref.equals(this._sheet2Ref)) {
             sheetName += ':' + this._sheet2Ref.toString();
         }
 
-        return sheetName + '!';
+        return sheetName ? (sheetName + '!') : '';
     };
 
     // 'virtual' methods ------------------------------------------------------
@@ -773,6 +800,9 @@ define('io.ox/office/spreadsheet/model/formula/parser/tokens', [
      */
     SheetRefToken.prototype.resolveDeletedSheet = function (formulaGrammar, sheet, refSheet) {
 
+        // nothing to do for external references
+        if (!this.isOwnDoc()) { return null; }
+
         // resolve the own sheet range (nothing to do on reference errors)
         var sheetInterval = this._sheet1Ref ? this._resolveSheetInterval({ refSheet: refSheet }) : null;
         if (!sheetInterval) { return null; }
@@ -821,6 +851,9 @@ define('io.ox/office/spreadsheet/model/formula/parser/tokens', [
      */
     SheetRefToken.prototype.resolveRenamedSheet = function (formulaGrammar, sheet, sheetName) {
 
+        // nothing to do for external references
+        if (!this.isOwnDoc()) { return null; }
+
         // create the string representation only if this token refers to the renamed sheet
         var sheet1Ref = (this._sheet1Ref && (this._sheet1Ref.sheet === sheet)) ? new SheetRef(sheetName, this._sheet1Ref.abs) : this._sheet1Ref;
         var sheet2Ref = (this._sheet2Ref && (this._sheet2Ref.sheet === sheet)) ? new SheetRef(sheetName, this._sheet2Ref.abs) : this._sheet2Ref;
@@ -867,7 +900,7 @@ define('io.ox/office/spreadsheet/model/formula/parser/tokens', [
     var ReferenceToken = SheetRefToken.extend({ constructor: function (docModel, cell1Ref, cell2Ref, sheet1Ref, sheet2Ref) {
 
         // base constructor
-        SheetRefToken.call(this, 'ref', docModel, sheet1Ref, sheet2Ref);
+        SheetRefToken.call(this, 'ref', docModel, sheet1Ref, sheet2Ref, null);
 
         // private properties
         this._cell1Ref = cell1Ref;
@@ -1379,7 +1412,7 @@ define('io.ox/office/spreadsheet/model/formula/parser/tokens', [
         // the original range, with sheet indexes
         var sheet       = options.sheet,
 
-            bothExists  = (this._cell1Ref && this._cell2Ref),
+            bothExist   = this._cell1Ref && this._cell2Ref,
 
             oldRange3d  = this.getRange3D(options),
             sameCol     = (sourceRange.start[0] === targetRange.start[0]),
@@ -1397,91 +1430,72 @@ define('io.ox/office/spreadsheet/model/formula/parser/tokens', [
         // to another sheet or a sheet range, or sheet reference is invalid
         if (!oldRange3d || !oldRange3d.isSheet(sheet)) { return null; }
 
-        if (
-            (bothExists && sourceRange.contains(Range.create(this._cell1Ref.col, this._cell1Ref.row, this._cell2Ref.col, this._cell2Ref.row)))
-            ||
-            (!bothExists && this._cell1Ref && sourceRange.containsAddress(new Address(this._cell1Ref.col, this._cell1Ref.row)))
+        if (bothExist ?
+            sourceRange.contains(new Range(this._cell1Ref.toAddress(), this._cell2Ref.toAddress())) :
+            (this._cell1Ref && sourceRange.containsAddress(this._cell1Ref.toAddress()))
         ) {
-            var backupCell1Ref = (this._cell1Ref) ? this._cell1Ref.clone() : null,
-                backupCell2Ref = (this._cell2Ref) ? this._cell2Ref.clone() : null;
+
+            var backupCell1Ref = this._cell1Ref ? this._cell1Ref.clone() : null;
+            var backupCell2Ref = this._cell2Ref ? this._cell2Ref.clone() : null;
 
             this.relocateRange(sourceRange.start, targetRange.start, false);
-            cell1Ref = (this._cell1Ref) ? this._cell1Ref.clone() : null;
-            cell2Ref = (this._cell2Ref) ? this._cell2Ref.clone() : null;
+            cell1Ref = this._cell1Ref ? this._cell1Ref.clone() : null;
+            cell2Ref = this._cell2Ref ? this._cell2Ref.clone() : null;
 
             this._cell1Ref = backupCell1Ref;
             this._cell2Ref = backupCell2Ref;
 
             return formulaGrammar.formatReference(this._docModel, targetRange.start, this._sheet1Ref, this._sheet2Ref, cell1Ref, cell2Ref);
+        }
 
         // one end (top, right, bottom or left) completly covered by sourceRange
-        } else if (bothExists && this._cell1Ref.getIndex(columns) >= sourceRange.start.get(columns) && this._cell2Ref.getIndex(columns) <= sourceRange.end.get(columns)) {
+        if (bothExist && (this._cell1Ref.getIndex(columns) >= sourceRange.start.get(columns)) && (this._cell2Ref.getIndex(columns) <= sourceRange.end.get(columns))) {
 
             if (!sameCol && !sameRow) { return null; }
 
-            var oldRangeArray       = new RangeArray(oldRange),
-                sourceRangeArray    = new RangeArray(sourceRange),
-                // current indexes
-                col1            = this._cell1Ref.col,
-                row1            = this._cell1Ref.row,
-                col2            = this._cell2Ref.col,
-                row2            = this._cell2Ref.row;
+            var newRefRange = new RangeArray(oldRange).difference(sourceRange).first(); // oldRange without sourceRange
+            var cutRefRange = sourceRange.intersect(oldRange);
+            if (!cutRefRange) { return null; }
 
-            var newRefRange     = oldRangeArray.difference(sourceRange).first(), // oldRange without sourceRange
-                cuttedRefRange  = sourceRangeArray.intersect(oldRange).first(),
+            // current indexes
+            var col1 = this._cell1Ref.col;
+            var row1 = this._cell1Ref.row;
+            var col2 = this._cell2Ref.col;
+            var row2 = this._cell2Ref.row;
 
-                startCutted     = null,
-                endCutted       = null,
-                startPasted     = null,
-                endPasted       = null,
+            var startCutted = sourceRange.contains(columns ? oldRange.headerRow() : oldRange.leadingCol());
+            var endCutted   = sourceRange.contains(columns ? oldRange.footerRow() : oldRange.trailingCol());
+            var startPasted = targetRange.contains(columns ? oldRange.headerRow() : oldRange.leadingCol());
+            var endPasted   = targetRange.contains(columns ? oldRange.footerRow() : oldRange.trailingCol());
 
-                xOffset         = null,
-                yOffset         = null,
-                xOver           = null,
-                yOver           = null;
-
-            if (!cuttedRefRange) { return null; }
-
-            startCutted     = (sourceRange.contains((columns ? oldRange.headerRow() : oldRange.leadingCol())));
-            endCutted       = (sourceRange.contains((columns ? oldRange.footerRow() : oldRange.trailingCol())));
-            startPasted     = (targetRange.contains((columns ? oldRange.headerRow() : oldRange.leadingCol())));
-            endPasted       = (targetRange.contains((columns ? oldRange.footerRow() : oldRange.trailingCol())));
-
-            xOffset         = cuttedRefRange.start.get(true) - sourceRange.start.get(true);
-            yOffset         = cuttedRefRange.start.get(false) - sourceRange.start.get(false);
-            xOver           = (sourceRange.size(true) - xOffset - cuttedRefRange.size(true));
-            yOver           = (sourceRange.size(false) - yOffset - cuttedRefRange.size(false));
+            var xOffset = cutRefRange.start[0] - sourceRange.start[0];
+            var yOffset = cutRefRange.start[1] - sourceRange.start[1];
+            var xOver   = sourceRange.cols() - xOffset - cutRefRange.cols();
+            var yOver   = sourceRange.rows() - yOffset - cutRefRange.rows();
 
             if (startCutted) {
                 if (endPasted) {
-                    col1 = newRefRange.start.get(true);
-                    row1 = newRefRange.start.get(false);
-
-                    col2 = targetRange.start.get(true) + xOffset + cuttedRefRange.size(true) - 1;
-                    row2 = targetRange.start.get(false) + yOffset + cuttedRefRange.size(false) - 1;
-
+                    col1 = newRefRange.start[0];
+                    row1 = newRefRange.start[1];
+                    col2 = targetRange.start[0] + xOffset + cutRefRange.cols() - 1;
+                    row2 = targetRange.start[1] + yOffset + cutRefRange.rows() - 1;
                 } else if (overlaps || !forward) {
-                    col1 = (xOffset > 0 || !forward) ? targetRange.start.get(true) + xOffset : newRefRange.start.get(true);
-                    row1 = (yOffset > 0 || !forward) ? targetRange.start.get(false) + yOffset : newRefRange.start.get(false);
-
-                    col2 = Math.max(cuttedRefRange.size(true), newRefRange.end.get(true));
-                    row2 = Math.max(cuttedRefRange.size(false), newRefRange.end.get(false));
+                    col1 = (xOffset > 0 || !forward) ? (targetRange.start[0] + xOffset) : newRefRange.start[0];
+                    row1 = (yOffset > 0 || !forward) ? (targetRange.start[1] + yOffset) : newRefRange.start[1];
+                    col2 = Math.max(cutRefRange.cols(), newRefRange.end[0]);
+                    row2 = Math.max(cutRefRange.rows(), newRefRange.end[1]);
                 }
-
             } else if (endCutted) {
                 if (startPasted) {
-                    col1 = Math.min(newRefRange.start.get(true), targetRange.start.get(true) + xOffset);
-                    row1 = Math.min(newRefRange.start.get(false), targetRange.start.get(false) + yOffset);
-
-                    col2 = (xOver > 0 && forward) ? targetRange.start.get(true) + xOffset + cuttedRefRange.size(true) - 1 : newRefRange.end.get(true);
-                    row2 = (yOver > 0 && forward) ? targetRange.start.get(false) + yOffset + cuttedRefRange.size(false) - 1 : newRefRange.end.get(false);
-
+                    col1 = Math.min(newRefRange.start[0], targetRange.start[0] + xOffset);
+                    row1 = Math.min(newRefRange.start[1], targetRange.start[1] + yOffset);
+                    col2 = (xOver > 0 && forward) ? targetRange.start[0] + xOffset + cutRefRange.cols() - 1 : newRefRange.end[0];
+                    row2 = (yOver > 0 && forward) ? targetRange.start[1] + yOffset + cutRefRange.rows() - 1 : newRefRange.end[1];
                 } else if (overlaps || forward) {
-                    col1 = Math.min(newRefRange.start.get(true), targetRange.start.get(true) + xOffset);
-                    row1 = Math.min(newRefRange.start.get(false), targetRange.start.get(false) + yOffset);
-
-                    col2 = (xOver > 0 || forward) ? targetRange.start.get(true) + xOffset + cuttedRefRange.size(true) - 1 : newRefRange.end.get(true);
-                    row2 = (yOver > 0 || forward) ? targetRange.start.get(false) + yOffset + cuttedRefRange.size(false) - 1 : newRefRange.end.get(false);
+                    col1 = Math.min(newRefRange.start[0], targetRange.start[0] + xOffset);
+                    row1 = Math.min(newRefRange.start[1], targetRange.start[1] + yOffset);
+                    col2 = (xOver > 0 || forward) ? targetRange.start[0] + xOffset + cutRefRange.cols() - 1 : newRefRange.end[0];
+                    row2 = (yOver > 0 || forward) ? targetRange.start[1] + yOffset + cutRefRange.rows() - 1 : newRefRange.end[1];
                 }
             }
 
@@ -1520,11 +1534,18 @@ define('io.ox/office/spreadsheet/model/formula/parser/tokens', [
      *  The sheet reference structure (e.g. the particle 'Sheet1' in the
      *  formula Sheet1!my_name). If null or undefined, the token represents a
      *  local name in the passed sheet, or a global name.
+     *
+     * @param {Number|Null} extDocRef
+     *  The index of the external document, e.g. the number in the brackets in
+     *  the formula [1]!extname. The value zero represents a globally defined
+     *  name with document reference in the own document, e.g. the zero in
+     *  [0]!globalname. If null or undefined, the token represents a name in
+     *  the own document without document reference (e.g. globalname).
      */
-    var NameToken = SheetRefToken.extend({ constructor: function (docModel, label, sheetRef) {
+    var NameToken = SheetRefToken.extend({ constructor: function (docModel, label, sheetRef, extDocRef) {
 
         // base constructor
-        SheetRefToken.call(this, 'name', docModel, sheetRef, null);
+        SheetRefToken.call(this, 'name', docModel, sheetRef, null, extDocRef);
 
         // private properties
         this._value = label;
@@ -1537,7 +1558,7 @@ define('io.ox/office/spreadsheet/model/formula/parser/tokens', [
      * Returns the model of a defined name from the specified sheet.
      */
     NameToken.prototype._getNameModelFromSheet = function (sheet, label) {
-        var sheetModel = _.isNumber(sheet) ? this._docModel.getSheetModel(sheet) : null;
+        var sheetModel = (typeof sheet === 'number') ? this._docModel.getSheetModel(sheet) : null;
         return sheetModel ? sheetModel.getNameCollection().getName(label) : null;
     };
 
@@ -1558,9 +1579,15 @@ define('io.ox/office/spreadsheet/model/formula/parser/tokens', [
      */
     NameToken.prototype._resolveNameModel = function (label, refSheet) {
 
+        // TODO: support for external names
+        if (!this.isOwnDoc()) { return null; }
+
         // sheet reference exists (e.g.: Sheet2!name): resolve from specified sheet, do not try global names
         if (this._sheet1Ref) { return this._getNameModelFromSheet(this._sheet1Ref.sheet, label); }
 
+        // document reference without sheet reference (e.g.: [0]!name) refers to global names
+        if (this._extDocRef === 0) { return this._docModel.getNameCollection().getName(label); }
+
         // no sheet reference: try sheet-local names first, then global names
         return this._getNameModelFromSheet(refSheet, label) || this._docModel.getNameCollection().getName(label);
     };
@@ -1576,10 +1603,13 @@ define('io.ox/office/spreadsheet/model/formula/parser/tokens', [
      */
     NameToken.prototype._resolveTableModel = function (tableName) {
 
-        // sheet reference exists (e.g.: Sheet2!Table1): resolve from specified sheet only;
+        // TODO: support for external tables
+        if (!this.isOwnDoc()) { return null; }
+
+        // sheet reference exists (e.g.: Sheet2!Table1): resolve from specified sheet only
         if (this._sheet1Ref) {
             var sheet = this._sheet1Ref.sheet;
-            var sheetModel = _.isNumber(sheet) ? this._docModel.getSheetModel(sheet) : null;
+            var sheetModel = (typeof sheet === 'number') ? this._docModel.getSheetModel(sheet) : null;
             return sheetModel ? sheetModel.getTableCollection().getTable(tableName) : null;
         }
 
@@ -1642,7 +1672,7 @@ define('io.ox/office/spreadsheet/model/formula/parser/tokens', [
     NameToken.prototype.getText = function (formulaGrammar, options) {
         var sheetRefs = this._resolveSheetRefs(options);
         var label = Utils.getStringOption(options, 'label', this._value);
-        return formulaGrammar.formatName(this._docModel, sheetRefs.s1, label);
+        return formulaGrammar.formatName(this._docModel, this._extDocRef, sheetRefs.s1, label);
     };
 
     /**
@@ -1688,7 +1718,7 @@ define('io.ox/office/spreadsheet/model/formula/parser/tokens', [
         if (!nameModel) { return; }
 
         // check if this token would resolve to the relabed name, according to the parent sheet of the changed name
-        var sheetModel = _.isNumber(sheet) ? this._docModel.getSheetModel(sheet) : null;
+        var sheetModel = (typeof sheet === 'number') ? this._docModel.getSheetModel(sheet) : null;
         if (sheetModel !== nameModel.getSheetModel()) { return null; }
 
         // generate the text representation for the new label
@@ -1718,7 +1748,7 @@ define('io.ox/office/spreadsheet/model/formula/parser/tokens', [
     var MacroToken = SheetRefToken.extend({ constructor: function (docModel, label, sheetRef) {
 
         // base constructor
-        SheetRefToken.call(this, 'macro', docModel, sheetRef, null);
+        SheetRefToken.call(this, 'macro', docModel, sheetRef, null, null);
 
         // private properties
         this._value = label;
@@ -1754,7 +1784,7 @@ define('io.ox/office/spreadsheet/model/formula/parser/tokens', [
     MacroToken.prototype.getText = function (formulaGrammar, options) {
         var sheetRefs = this._resolveSheetRefs(options);
         var label = Utils.getStringOption(options, 'label', this._value);
-        return formulaGrammar.formatMacro(this._docModel, sheetRefs.s1, label);
+        return formulaGrammar.formatMacro(this._docModel, this._extDocRef, sheetRefs.s1, label);
     };
 
     /**
@@ -1968,9 +1998,9 @@ define('io.ox/office/spreadsheet/model/formula/parser/tokens', [
         // whether the token contains leading or trailing whitespace characters
         var outerWs = this._openWs || this._closeWs;
 
-        // omit empty brackets after table name in UI mode
+        // add empty brackets after table name in OOXML operation mode
         if (!this._regionKeys && !this._col1Name) {
-            return tableName + (formulaGrammar.UI ? '' : ('[' + generateWs(outerWs) + ']'));
+            return tableName + ((!formulaGrammar.UI && (formulaGrammar.REF_SYNTAX === 'ooxml')) ? ('[' + generateWs(outerWs) + ']') : '');
         }
 
         // the key of a single table region (null for combined regions)
