@@ -14,11 +14,12 @@
 
 define('io.ox/office/spreadsheet/model/formula/tokenarray', [
     'io.ox/office/tk/utils',
-    'io.ox/office/tk/container/simplemap',
+    'io.ox/office/tk/container/valueset',
+    'io.ox/office/tk/container/valuemap',
     'io.ox/office/spreadsheet/utils/sheetutils',
     'io.ox/office/spreadsheet/model/formula/formulautils',
     'io.ox/office/spreadsheet/model/formula/parser/tokens'
-], function (Utils, SimpleMap, SheetUtils, FormulaUtils, Tokens) {
+], function (Utils, ValueSet, ValueMap, SheetUtils, FormulaUtils, Tokens) {
 
     'use strict';
 
@@ -61,9 +62,8 @@ define('io.ox/office/spreadsheet/model/formula/tokenarray', [
      *      conditional formatting range.
      *  - 'validation': The token array represents the condition value of a
      *      data validation range.
-     *  - 'drawing': The token array represents the source link in a drawing
-     *      object (e.g. data series source in a chart object, or a linked text
-     *      box).
+     *  - 'link': The token array represents the source link in a model object
+     *      (e.g. data series source in a chart object, or a linked text box).
      *  - 'custom': A custom token array without special behavior.
      */
     function TokenArray(parentModel, tokenType) {
@@ -103,7 +103,7 @@ define('io.ox/office/spreadsheet/model/formula/tokenarray', [
         // whether this token array is currently interpreted, to prevent recursion
         // (flag set by target addresses, the same token array may be used for different
         // formula cells, e.g. in shared formulas)
-        this._interpreting = new SimpleMap();
+        this._interpreting = new ValueSet('key()');
 
     } // class TokenArray
 
@@ -242,7 +242,7 @@ define('io.ox/office/spreadsheet/model/formula/tokenarray', [
      *  specified target address.
      */
     TokenArray.prototype._isInterpreting = function (targetAddress) {
-        return this._interpreting.has(targetAddress.key());
+        return this._interpreting.has(targetAddress);
     };
 
     /**
@@ -260,17 +260,26 @@ define('io.ox/office/spreadsheet/model/formula/tokenarray', [
      *  The return value of the callback function.
      */
     TokenArray.prototype._lockInterpreting = function (targetAddress, callback) {
-        var addressKey = targetAddress.key();
         try {
-            this._interpreting.insert(addressKey, true);
+            this._interpreting.insert(targetAddress);
             return callback.call(this);
         } finally {
-            this._interpreting.remove(addressKey);
+            this._interpreting.remove(targetAddress);
         }
     };
 
     // public methods ---------------------------------------------------------
 
+    /**
+     * Returns the model of the document containing this token array.
+     *
+     * @returns {SpreadsheettModel}
+     *  The document model containing this token array.
+     */
+    TokenArray.prototype.getDocModel = function () {
+        return this._docModel;
+    };
+
     /**
      * Returns the parent sheet model of this token array.
      *
@@ -421,12 +430,13 @@ define('io.ox/office/spreadsheet/model/formula/tokenarray', [
     /**
      * Resolves the token array to a list of range addresses. The formula
      * represented by this token array must be completely resolvable to a range
-     * list (single reference, a list of references separated by the list
+     * list (single reference, a list of range references separated by the list
      * operator, optionally enclosed in parentheses, defined names that resolve
      * to a range list if specified with the option 'resolveNames', also
-     * recursively, or a mixed list of defined names and references). To
-     * extract the range addresses contained in an arbitrary formula, the
-     * method TokenArray.extractRanges() can be used.
+     * recursively, table references, or a mixed list of range references,
+     * defined names, and table references). To extract the range addresses
+     * contained in an arbitrary formula, the method TokenArray.extractRanges()
+     * can be used.
      *
      * @param {Object} [options]
      *  Optional parameters:
@@ -442,9 +452,16 @@ define('io.ox/office/spreadsheet/model/formula/tokenarray', [
      *      The target reference address used to relocate reference tokens with
      *      relative column/row components. If omitted, cell A1 will be used as
      *      target reference cell.
-     *  @param {Boolean} [options.resolveNames=false]
-     *      If set to true, will return the range addresses referred by all
-     *      defined names contained in this token array.
+     *  @param {String} [options.resolveNames]
+     *      Specifies how to resolve defined names and table ranges contained
+     *      in this token array. If omitted, defined names and table ranges
+     *      will not be accepted and lead to an empty result array. If set to
+     *      the value 'simple', defined names will be resolved recursively (the
+     *      defined name may contain range references, other defined names, and
+     *      table references). If set to the value 'interpret', table
+     *      references will be resolved, and defined names will be interpreted
+     *      (they may contain arbitrary formula expressions with functions that
+     *      resolve to a reference list).
      *  @param {Boolean} [options.wrapReferences]
      *      If specified, the internal 'wrap references' state that has been
      *      set according to the formula type passed to the constructor will be
@@ -466,9 +483,9 @@ define('io.ox/office/spreadsheet/model/formula/tokenarray', [
         if (this._isInterpreting(targetAddress)) { return resultRanges; }
 
         // whether to resolve defined name tokens
-        var resolveNames = Utils.getBooleanOption(options, 'resolveNames', false);
+        var resolveNamesMode = Utils.getStringOption(options, 'resolveNames', null);
         // early exit, if this token array does not contain any reference or name tokens
-        var hasTokens = resolveNames ? this.hasRefTokens() : this.hasToken('ref');
+        var hasTokens = resolveNamesMode ? this.hasRefTokens() : this.hasToken('ref');
         if (!hasTokens) { return resultRanges; }
 
         // add more options (refSheet and wrapReferences)
@@ -494,7 +511,7 @@ define('io.ox/office/spreadsheet/model/formula/tokenarray', [
 
                 case 'name':
                     // the model of the defined name referred by the passed token
-                    var nameModel = resolveNames ? token.resolveNameModel(options.refSheet) : null;
+                    var nameModel = resolveNamesMode ? token.resolveNameModel(options.refSheet) : null;
                     if (!nameModel) { return false; }
 
                     // defined names are always defined relative to cell A1
@@ -503,9 +520,18 @@ define('io.ox/office/spreadsheet/model/formula/tokenarray', [
 
                     // prevent recursive invocation of this token array via other defined names
                     var ranges = this._lockInterpreting(targetAddress, function () {
-                        return nameModel.getTokenArray().resolveRangeList(newOptions);
+                        var tokenArray = nameModel.getTokenArray();
+                        switch (resolveNamesMode) {
+                            case 'simple':
+                                return tokenArray.resolveRangeList(newOptions);
+                            case 'interpret':
+                                var result = tokenArray.interpretFormula('ref', newOptions);
+                                return (result.value instanceof Range3DArray) ? result.value : null;
+                            default:
+                                return null;
+                        }
                     });
-                    if (ranges.empty()) { return false; }
+                    if (!ranges || ranges.empty()) { return false; }
 
                     // append the new ranges to the result
                     resultRanges.append(ranges);
@@ -514,7 +540,7 @@ define('io.ox/office/spreadsheet/model/formula/tokenarray', [
 
                 case 'table':
                     // try to resolve the table reference to a valid cell range address
-                    var tableRange = resolveNames ? token.getRange3D(targetAddress) : null;
+                    var tableRange = resolveNamesMode ? token.getRange3D(targetAddress) : null;
                     if (!tableRange) { return false; }
 
                     // append the valid range to the result
@@ -710,82 +736,95 @@ define('io.ox/office/spreadsheet/model/formula/tokenarray', [
      *      cell references after cells have been moved in a sheet. Used for
      *      change type 'moveCells' only.
      *
-     * @returns {Object|Null}
-     *  A descriptor object with the old and new formula expression, if they
-     *  differ, otherwise null. The descriptor object contains the following
-     *  properties:
-     *  - {String} old
-     *      The current text representation of this token array.
-     *  - {String} new
+     * @param {Function} callback
+     *  A callback function that will be invoked with the old and new formula
+     *  expressions if they differ. Receives the following parameters:
+     *  (1) {String} newFormula
      *      The transformed text representation of this token array.
+     *  (2) {String} oldFormula
+     *      The current text representation of this token array.
+     *
+     * @param {Object} [context]
+     *  The calling context for the callback function.
+     *
+     * @returns {TokenArray}
+     *  A reference to this instance.
      */
-    TokenArray.prototype.resolveOperation = function (grammarId, changeDesc) {
+    TokenArray.prototype.resolveOperation = function (grammarId, changeDesc, callback, context) {
 
         // the effective reference sheet of this token array
         var refSheet = this._resolveRefSheet();
-        // additional options for the token methods
-        var options = null;
 
-        switch (changeDesc.type) {
+        // resolve the old and new formula expressions according to the passed change descriptor
+        var resultDesc = (function () {
+            switch (changeDesc.type) {
 
-            case 'deleteSheet':
-                // if the formula does not contain any sheet or table references, nothing will change
-                if ((this._sheet3dTokens.length === 0) && !this.hasToken('table')) { return null; }
+                case 'deleteSheet':
+                    // if the formula does not contain any sheet or table references, nothing will change
+                    if ((this._sheet3dTokens.length === 0) && !this.hasToken('table')) { return null; }
 
-                // collect the old and new text representation of the formula
-                return this._resolveChangedFormula(grammarId, function (token, config) {
-                    return token.resolveDeletedSheet(config, changeDesc.sheet, refSheet);
-                });
+                    // collect the old and new text representation of the formula
+                    return this._resolveChangedFormula(grammarId, function (token, config) {
+                        return token.resolveDeletedSheet(config, changeDesc.sheet, refSheet);
+                    });
 
-            case 'renameSheet':
-                // if the formula does not contain any sheet or table references, nothing will change
-                if ((this._sheet3dTokens.length === 0) && !this.hasToken('table')) { return null; }
+                case 'renameSheet':
+                    // if the formula does not contain any sheet or table references, nothing will change
+                    if ((this._sheet3dTokens.length === 0) && !this.hasToken('table')) { return null; }
 
-                // collect the old and new text representation of the formula
-                return this._resolveChangedFormula(grammarId, function (token, config) {
-                    return token.resolveRenamedSheet(config, changeDesc.sheet, changeDesc.sheetName, changeDesc.tableNames);
-                });
+                    // collect the old and new text representation of the formula
+                    return this._resolveChangedFormula(grammarId, function (token, config) {
+                        return token.resolveRenamedSheet(config, changeDesc.sheet, changeDesc.sheetName, changeDesc.tableNames);
+                    });
 
-            case 'relabelName':
-                // if the formula does not contain any name tokens, nothing will change
-                if (this._nameTokens.length === 0) { return null; }
+                case 'relabelName':
+                    // if the formula does not contain any name tokens, nothing will change
+                    if (this._nameTokens.length === 0) { return null; }
 
-                // collect the old and new text representation of the formula
-                return this._resolveChangedFormula(grammarId, function (token, config) {
-                    return token.resolveRelabeledName(config, changeDesc.sheet, changeDesc.oldLabel, changeDesc.newLabel, refSheet);
-                });
+                    // collect the old and new text representation of the formula
+                    return this._resolveChangedFormula(grammarId, function (token, config) {
+                        return token.resolveRelabeledName(config, changeDesc.sheet, changeDesc.oldLabel, changeDesc.newLabel, refSheet);
+                    });
 
-            case 'moveCells':
-                // if the formula does not contain any reference tokens, nothing will change
-                if (!this.hasToken('ref') && !this.hasToken('table')) { return null; }
+                case 'moveCells':
+                    // if the formula does not contain any reference tokens, nothing will change
+                    if (!this.hasToken('ref') && !this.hasToken('table')) { return null; }
 
-                // create options for the method BaseToken.resolveMovedCells()
-                options = { refSheet: refSheet, freezeRelRefs: this._freezeRelRefs };
-                if (changeDesc.relocate) {
-                    options.refAddress = changeDesc.relocate.from;
-                    options.targetAddress = changeDesc.relocate.to;
-                }
+                    // create options for the method BaseToken.resolveMovedCells()
+                    var moveOptions = { refSheet: refSheet, freezeRelRefs: this._freezeRelRefs };
+                    if (changeDesc.relocate) {
+                        moveOptions.refAddress = changeDesc.relocate.from;
+                        moveOptions.targetAddress = changeDesc.relocate.to;
+                    }
 
-                // collect the old and new text representation of the formula
-                return this._resolveChangedFormula(grammarId, function (token, config) {
-                    return token.resolveMovedCells(config, changeDesc.sheet, changeDesc.moveDescs, options);
-                });
+                    // collect the old and new text representation of the formula
+                    return this._resolveChangedFormula(grammarId, function (token, config) {
+                        return token.resolveMovedCells(config, changeDesc.sheet, changeDesc.moveDescs, moveOptions);
+                    });
 
-            case 'cutPaste':
-                // if the formula does not contain any reference tokens, nothing will change
-                if (!this.hasToken('ref') && !this.hasToken('table')) { return null; }
+                case 'cutPaste':
+                    // if the formula does not contain any reference tokens, nothing will change
+                    if (!this.hasToken('ref') && !this.hasToken('table')) { return null; }
 
-                // create options for the method BaseToken.resolveCutPasteCells()
-                options = { refSheet: refSheet, sheet: changeDesc.sourceSheet };
+                    // create options for the method BaseToken.resolveCutPasteCells()
+                    var cutOptions = { refSheet: refSheet, sheet: changeDesc.sourceSheet };
 
-                // collect the old and new text representation of the formula
-                return this._resolveChangedFormula(grammarId, function (token, config) {
-                    return token.resolveCutPasteCells(config, changeDesc.sourceRange, changeDesc.targetRange, options);
-                });
+                    // collect the old and new text representation of the formula
+                    return this._resolveChangedFormula(grammarId, function (token, config) {
+                        return token.resolveCutPasteCells(config, changeDesc.sourceRange, changeDesc.targetRange, cutOptions);
+                    });
+            }
+
+            Utils.error('TokenArray.resolveOperation(): unknown operation type "' + changeDesc.type + '"');
+            return null;
+        }.call(this));
+
+        // invoke the callback function if the formula expression has changed
+        if (resultDesc) {
+            callback.call(context, resultDesc.new, resultDesc.old);
         }
 
-        Utils.error('TokenArray.resolveOperation(): unknown operation type "' + changeDesc.type + '"');
-        return null;
+        return this;
     };
 
     // token manipulation -----------------------------------------------------
@@ -1239,10 +1278,10 @@ define('io.ox/office/spreadsheet/model/formula/tokenarray', [
      *      these ranges will be forwarded to the name token of the parent
      *      formula expression, in order to decide how to proceed with these
      *      ranges.
-     *  - {Object<String,NameModel>} names
-     *      A map with the models of all defined names, mapped by their UIDs.
-     *  - {Object<String,TableModel>} tables
-     *      A map with the models of all table ranges, mapped by their UIDs.
+     *  - {ValueSet<NameModel>} nameSet
+     *      A set with the models of all defined names, mapped by their UIDs.
+     *  - {ValueSet<TableModel>} tableSet
+     *      A set with the models of all table ranges, mapped by their UIDs.
      *  - {Object<String,Boolean>} missingNames
      *      A flag set with the map keys of all missing defined names (as
      *      object keys) occurring in the formula expression, or in any
@@ -1262,7 +1301,16 @@ define('io.ox/office/spreadsheet/model/formula/tokenarray', [
     TokenArray.prototype.getDependencies = function (refAddress, depTarget, options) {
 
         // the result descriptor object
-        var deps = { depRanges: new Range3DArray(), rootRanges: new Range3DArray(), names: {}, tables: {}, missingNames: {}, missingFuncs: {}, recalc: null, circular: false };
+        var deps = {
+            depRanges: new Range3DArray(),
+            rootRanges: new Range3DArray(),
+            nameSet: new ValueSet('getUid()'),
+            tableSet: new ValueSet('getUid()'),
+            missingNames: {},
+            missingFuncs: {},
+            recalc: null,
+            circular: false
+        };
 
         // compile the infix tokens to a token tree (early exit, if this token array is invalid)
         var compileDesc = this.compileFormula();
@@ -1326,9 +1374,9 @@ define('io.ox/office/spreadsheet/model/formula/tokenarray', [
 
                 // add all dependencies of the defined name to the own result
                 deps.depRanges.append(nameDeps.depRanges);
-                deps.names[nameModel.getUid()] = nameModel;
-                _.extend(deps.names, nameDeps.names);
-                _.extend(deps.tables, nameDeps.tables);
+                deps.nameSet.insert(nameModel);
+                deps.nameSet.merge(nameDeps.nameSet);
+                deps.tableSet.merge(nameDeps.tableSet);
                 _.extend(deps.missingNames, nameDeps.missingNames);
                 _.extend(deps.missingFuncs, nameDeps.missingFuncs);
                 deps.recalc = FormulaUtils.getRecalcMode(deps.recalc, nameDeps.recalc);
@@ -1342,7 +1390,7 @@ define('io.ox/office/spreadsheet/model/formula/tokenarray', [
             if (token.isType('table')) {
                 var tableModel = token.resolveTableModel();
                 if (!tableModel) { return null; }
-                deps.tables[tableModel.getUid()] = tableModel;
+                deps.tableSet.insert(tableModel);
                 var tableRange = token.getRange3D(targetAddress);
                 return tableRange ? new Range3DArray(tableRange) : null;
             }
@@ -1439,7 +1487,7 @@ define('io.ox/office/spreadsheet/model/formula/tokenarray', [
 
         // get or create the result cache (do not cache results of volatile formulas)
         var cacheActive = options.cacheResult && (compileDesc.root.recalc !== 'always');
-        var resultCache = cacheActive ? (this._resultCache || (this._resultCache = new SimpleMap())) : null;
+        var resultCache = cacheActive ? (this._resultCache || (this._resultCache = new ValueMap())) : null;
 
         // Create the cache key. Depending on the existence of relative column or row references
         // in the token array, the cache can be optimized according to the reference and target
