@@ -13,13 +13,11 @@
  */
 
 define('io.ox/office/spreadsheet/model/hyperlinkcollection', [
-    'io.ox/office/tk/utils',
     'io.ox/office/tk/container/typedarray',
-    'io.ox/office/tk/object/timermixin',
     'io.ox/office/baseframework/model/modelobject',
     'io.ox/office/spreadsheet/utils/operations',
     'io.ox/office/spreadsheet/utils/sheetutils'
-], function (Utils, TypedArray, TimerMixin, ModelObject, Operations, SheetUtils) {
+], function (TypedArray, ModelObject, Operations, SheetUtils) {
 
     'use strict';
 
@@ -76,29 +74,61 @@ define('io.ox/office/spreadsheet/model/hyperlinkcollection', [
      * @constructor
      *
      * @extends ModelObject
-     * @extends TimerMixin
      *
      * @param {SheetModel} sheetModel
      *  The sheet model instance containing this collection.
      */
 
-    function HyperlinkCollection(sheetModel) {
+    var HyperlinkCollection = ModelObject.extend({ constructor: function (sheetModel) {
 
         // self reference
         var self = this;
 
-        // all hyperlink ranges
-        var linkModels = new HyperlinkModelArray();
+        // the document model instance
+        var docModel = sheetModel.getDocModel();
 
-        var app = sheetModel.getApp();
+        // all hyperlink ranges (may overlap)
+        var linkModels = new HyperlinkModelArray();
 
         // base constructor ---------------------------------------------------
 
-        ModelObject.call(this, sheetModel.getDocModel());
-        TimerMixin.call(this);
+        ModelObject.call(this, docModel);
 
         // private methods ----------------------------------------------------
 
+        /**
+         * Finds and returns specific hyperlink ranges of this collection.
+         *
+         * @param {Range} range
+         *  The range which should be scanned for hyperlink-ranges
+         *
+         * @param {String} [type='all']
+         *  Specifies how the hyperlink ranges must match the passed range. The
+         *  following values are available:
+         *  - 'all' (default): Returns all hyperlink ranges that overlap with
+         *      the passed range, or that are contained in the passed range.
+         *  - 'contain': Returns all hyperlink ranges that are completely
+         *      contained in the passed range.
+         *  - 'overlap': Returns all hyperlink ranges that overlap with the
+         *      passed range but are NOT completely contained in the range.
+         *  - 'exact': Returns all hyperlink ranges that match exactly the
+         *      passed range.
+         *
+         * @return {HyperlinkModelArray}
+         *  An array with all hyperlink ranges matching the criteria.
+         */
+        function findHyperlinks(range, type) {
+            return linkModels.filter(function (linkModel) {
+                var linkRange = linkModel.range;
+                switch (type) {
+                    case 'contain': return range.contains(linkRange);
+                    case 'overlap': return range.overlaps(linkRange) && !range.contains(linkRange);
+                    case 'exact':   return range.equals(linkRange);
+                    default:        return range.overlaps(linkRange);
+                }
+            });
+        }
+
         // generates the operations to add a new hyperlink range
         function generateInsertHyperlinkOperation(generator, range, url) {
             generator.generateRangeOperation(Operations.INSERT_HYPERLINK, range, { url: url });
@@ -106,57 +136,26 @@ define('io.ox/office/spreadsheet/model/hyperlinkcollection', [
         }
 
         // generates the operations to remove a hyperlink range
-        function generateDeleteHyperlinkOperation(generator, hyperlink) {
-            generator.generateRangeOperation(Operations.DELETE_HYPERLINK, hyperlink.range);
-            generator.generateRangeOperation(Operations.INSERT_HYPERLINK, hyperlink.range, { url: hyperlink.url }, { undo: true });
+        function generateDeleteHyperlinkOperation(generator, linkModel) {
+            generator.generateRangeOperation(Operations.DELETE_HYPERLINK, linkModel.range);
+            generator.generateRangeOperation(Operations.INSERT_HYPERLINK, linkModel.range, { url: linkModel.url }, { undo: true });
         }
 
         // generates the restore operation for 'moveCells' (only undo)
-        function generateRestoreHyperlinkOperation(generator, hyperlink) {
-            generator.generateRangeOperation(Operations.INSERT_HYPERLINK, hyperlink.range, { url: hyperlink.url }, { undo: true });
+        function generateRestoreHyperlinkOperation(generator, linkModel) {
+            generator.generateRangeOperation(Operations.INSERT_HYPERLINK, linkModel.range, { url: linkModel.url }, { undo: true });
         }
 
-        /**
-         * Returns specific hyperlink ranges from this collection.
-         *
-         * @param  {Range} range
-         *    The range which should be scanned for hyperlink-ranges
-         *
-         * @param  {Object} [options]
-         *  Optional parameters:
-         *  @param {String} [options.type='all']
-         *      Specifies hhow the hyperlink ranges must match the given range:
-         *      - 'all' (default):
-         *      'all contain overlap exact'
-         *
-         * @return {HyperlinkModelArray}
-         *  An array with all found hyperlink ranges.
-         */
-        function findHyperlinks(range, options) {
+        // generates all needed operations to split a hyperlink range
+        // (uses add and delete methods to generate the operations)
+        function splitExistingRanges(generator, range, linkModel) {
 
-            var type = Utils.getStringOption(options, 'type', 'all');
+            // DELETE old big hyperlink range (incl. undo)
+            generateDeleteHyperlinkOperation(generator, linkModel);
 
-            return linkModels.filter(function (linkModel) {
-                var linkRange = linkModel.range;
-                switch (type) {
-                    case 'all':     return range.overlaps(linkRange);
-                    case 'contain': return range.contains(linkRange);
-                    case 'overlap': return range.overlaps(linkRange) && !range.contains(linkRange);
-                    case 'exact':   return range.equals(linkRange);
-                }
-            });
-        }
-
-        // generates all needed operations to split a hyperlink-range
-        // (uses add- and delete-methods to generate the operations)
-        function splitExistingRanges(generator, range, link) {
-
-            // DELETE old big HyperlinkRange (incl. undo)
-            generateDeleteHyperlinkOperation(generator, link);
-
-            // ADD remaining parts of HyperlinkRanges (if exists)
-            new RangeArray(link.range).difference(range).forEach(function (ran) {
-                generateInsertHyperlinkOperation(generator, ran, link.url);
+            // ADD remaining parts of hyperlink ranges (if exists)
+            new RangeArray(linkModel.range).difference(range).forEach(function (remainRange) {
+                generateInsertHyperlinkOperation(generator, remainRange, linkModel.url);
             });
         }
 
@@ -325,7 +324,7 @@ define('io.ox/office/spreadsheet/model/hyperlinkcollection', [
          * Generates the operations and undo operations to insert or delete
          * hyperlinks for the specified cell ranges.
          *
-         * @param {SheetOperationsGenerator} generator
+         * @param {SheetOperationGenerator} generator
          *  The operations generator to be filled with the operations.
          *
          * @param {RangeArray|Range} ranges
@@ -352,44 +351,44 @@ define('io.ox/office/spreadsheet/model/hyperlinkcollection', [
             return this.iterateArraySliced(ranges, function (range) {
                 if (deleteHyperlinks) {
 
-                    // if only a single cell is selected, search the matching HyperlinkRange
+                    // if only a single cell is selected, search the matching hyperlink range
                     if (range.single() && self.rangeOverlapsHyperlinks(range)) {
-                        range = findHyperlinks(range)[0].range;
+                        range = findHyperlinks(range).first().range;
                     }
 
                     // if the selected range matches one or more HyperlinkRanges
                     if (self.rangeOverlapsHyperlinks(range)) {
-                        findHyperlinks(range).forEach(function (link) {
-                            splitExistingRanges(generator, range, link);
+                        findHyperlinks(range).forEach(function (linkModel) {
+                            splitExistingRanges(generator, range, linkModel);
                         });
                     }
 
                 } else {
 
-                    var covered = findHyperlinks(range, { type: 'contain' });
-                    var overlaped = findHyperlinks(range, { type: 'overlap' });
+                    var coveredModels = findHyperlinks(range, 'contain');
+                    var overlapModels = findHyperlinks(range, 'overlap');
 
                     // delete all complete covered hyperlinks
-                    covered.forEach(function (link) {
-                        generateDeleteHyperlinkOperation(generator, link);
+                    coveredModels.forEach(function (linkModel) {
+                        generateDeleteHyperlinkOperation(generator, linkModel);
                     });
 
                     // split all partly overlaped hyperlinks
-                    overlaped.forEach(function (link) {
-                        splitExistingRanges(generator, range, link);
+                    overlapModels.forEach(function (linkModel) {
+                        splitExistingRanges(generator, range, linkModel);
                     });
 
                     // add new hyperlink
                     generateInsertHyperlinkOperation(generator, range, url);
                 }
-            }, { delay: 'immediate', infoString: 'HyperlinkCollection: generateHyperlinkOperations', app: app });
+            }, 'HyperlinkCollection.generateHyperlinkOperations');
         };
 
         /**
          * Generates the operations and undo operations to insert or delete
          * hyperlinks for autofill-action
          *
-         * @param {SheetOperationsGenerator} generator
+         * @param {SheetOperationGenerator} generator
          *  The operations generator to be filled with the operations.
          *
          * @param {Range} ranges
@@ -403,7 +402,7 @@ define('io.ox/office/spreadsheet/model/hyperlinkcollection', [
          *
          * @param {Boolean} reverse
          *  If set to true, the autofill values will be genereated in reversed
-         *  order
+         *  order.
          *
          * @returns {jQuery.Promise}
          *  A promise that will be resolved when all operations have been
@@ -467,7 +466,7 @@ define('io.ox/office/spreadsheet/model/hyperlinkcollection', [
                         }
                     }
                 }
-            }, { delay: 'immediate', infoString: 'HyperlinkCollection: generateAutoFillOperations 1', app: app });
+            }, 'HyperlinkCollection.generateAutoFillOperations');
 
             // Next Step: Create new ajar Hyperlink(s)
             promise = promise.then(function () {
@@ -488,14 +487,14 @@ define('io.ox/office/spreadsheet/model/hyperlinkcollection', [
                     linkRange.setEnd(row_i_end, false);
 
                     return sheetModel.getCellCollection().generateFillOperations(generator, linkRange, { url: linkModel.url });
-                }, { delay: 'immediate', infoString: 'HyperlinkCollection: generateAutoFillOperations 2', app: app });
+                }, 'HyperlinkCollection.generateAutoFillOperations');
             });
 
             // add new (independent) single hyperlink(s)
             promise = promise.then(function () {
                 return self.iterateArraySliced(singleHyperlinks, function (linkModel) {
                     return sheetModel.getCellCollection().generateFillOperations(generator, linkModel.range, { url: linkModel.url });
-                }, { delay: 'immediate', infoString: 'HyperlinkCollection: generateAutoFillOperations 3', app: app });
+                }, 'HyperlinkCollection.generateAutoFillOperations');
             });
 
             return promise;
@@ -506,7 +505,7 @@ define('io.ox/office/spreadsheet/model/hyperlinkcollection', [
          * collection that would not be restored automatically with the reverse
          * operation of the passed move descriptor.
          *
-         * @param {SheetOperationsGenerator} generator
+         * @param {SheetOperationGenerator} generator
          *  The operations generator to be filled with the operations.
          *
          * @param {Array<MoveDescriptor>} moveDescs
@@ -531,13 +530,13 @@ define('io.ox/office/spreadsheet/model/hyperlinkcollection', [
                 if (!restoredRange || restoredRange.differs(linkModel.range)) {
                     restoreLinks.push(linkModel);
                 }
-            }, { delay: 'immediate', infoString: 'HyperlinkCollection: generateMoveCellsOperations 1', app: app });
+            }, 'HyperlinkCollection.generateMoveCellsOperations');
 
             // add all hyperlinks to the undo generator that need to be restored
             promise = promise.then(function () {
                 return self.iterateArraySliced(restoreLinks, function (linkModel) {
                     generateRestoreHyperlinkOperation(generator, linkModel);
-                }, { delay: 'immediate', infoString: 'HyperlinkCollection: generateMoveCellsOperations 2', app: app });
+                }, 'HyperlinkCollection.generateMoveCellsOperations');
             });
 
             return promise;
@@ -547,35 +546,35 @@ define('io.ox/office/spreadsheet/model/hyperlinkcollection', [
          * Generates the operations and undo operations to merge cells which
          * covers or overlaps hyperlink ranges
          *
-         * @param {SheetOperationsGenerator} generator
+         * @param {SheetOperationGenerator} generator
          *  The operations generator to be filled with the operations.
          *
          * @param {RangeArray|Range} ranges
          *  An array of cell range addresses, or a single cell range address to
          *  generate the operations for.
          *
+         * @param {MergeMode} mergeMode
+         *  The merge mode for the specified ranges.
+         *
          * @returns {jQuery.Promise}
          *  A promise that will be resolved when all operations have been
          *  generated.
          */
-        this.generateMergeCellsOperations = function (generator, ranges) {
+        this.generateMergeCellsOperations = function (generator, ranges/*, mergeMode*/) {
 
             var cellCollection = sheetModel.getCellCollection();
 
             return this.iterateArraySliced(RangeArray.get(ranges), function (range) {
 
-                var determinationAddress = cellCollection.findFirstCell(range, { type: 'value', covered: true });
-                var url = ''; // empty 'url' deletes hyperlinks
-
-                if (determinationAddress && cellCollection.getEffectiveURL(determinationAddress)) {
-                    url = cellCollection.getEffectiveURL(determinationAddress);
-                } else {
-                    var linkModel = findHyperlinks(new Range(range.start), { type: 'all' }).first();
-                    if (linkModel) { url = linkModel.url; }
-                }
+                // the address to extract a hyperlink URL from (prefer value cell that will be moved to the top-left corner)
+                var address = cellCollection.findFirstCell(range, { type: 'value', covered: true }) || range.start;
+                // use the first hyperlink covering the address
+                var linkModel = findHyperlinks(new Range(address)).first();
+                // empty string as URl deletes the hyperlinks
+                var url = linkModel ? linkModel.url : '';
 
                 return self.generateHyperlinkOperations(generator, range, url);
-            }, { delay: 'immediate', infoString: 'HyperlinkCollection: generateMergeCellsOperations', app: app });
+            }, 'HyperlinkCollection.generateMergeCellsOperations');
         };
 
         // initialization -----------------------------------------------------
@@ -585,14 +584,13 @@ define('io.ox/office/spreadsheet/model/hyperlinkcollection', [
 
         // destroy all class members on destruction
         this.registerDestructor(function () {
-            self = linkModels = app = null;
+            self = docModel = sheetModel = linkModels = null;
         });
 
-    } // class HyperlinkCollection
+    } }); // class HyperlinkCollection
 
     // exports ================================================================
 
-    // derive this class from class ModelObject
-    return ModelObject.extend({ constructor: HyperlinkCollection });
+    return HyperlinkCollection;
 
 });
