@@ -16,9 +16,8 @@ define('io.ox/office/spreadsheet/model/listcollection', [
     'io.ox/office/tk/utils',
     'io.ox/office/tk/container/typedarray',
     'io.ox/office/tk/locale/localedata',
-    'io.ox/office/tk/object/timermixin',
     'io.ox/office/baseframework/model/modelobject'
-], function (Utils, TypedArray, LocaleData, TimerMixin, ModelObject) {
+], function (Utils, TypedArray, LocaleData, ModelObject) {
 
     'use strict';
 
@@ -32,7 +31,6 @@ define('io.ox/office/spreadsheet/model/listcollection', [
      * @constructor
      *
      * @extends ModelObject
-     * @extends TimerMixin
      *
      * @param {SpreadsheetModel} docModel
      *  The spreadsheet document model.
@@ -48,7 +46,6 @@ define('io.ox/office/spreadsheet/model/listcollection', [
         // base constructor ---------------------------------------------------
 
         ModelObject.call(this, docModel);
-        TimerMixin.call(this);
 
         // public methods -----------------------------------------------------
 
