@@ -14,17 +14,17 @@
  */
 
 define('io.ox/office/spreadsheet/model/mergecollection', [
-    'io.ox/office/tk/container/simplemap',
-    'io.ox/office/tk/object/timermixin',
-    'io.ox/office/baseframework/model/modelobject',
-    'io.ox/office/spreadsheet/utils/operations',
-    'io.ox/office/spreadsheet/utils/sheetutils'
-], function (SimpleMap, TimerMixin, ModelObject, Operations, SheetUtils) {
+    'io.ox/office/tk/container/valuemap',
+    'io.ox/office/spreadsheet/utils/sheetutils',
+    'io.ox/office/spreadsheet/model/usedrangecollection'
+], function (ValueMap, SheetUtils, UsedRangeCollection) {
 
     'use strict';
 
     // convenience shortcuts
+    var MergeMode = SheetUtils.MergeMode;
     var Address = SheetUtils.Address;
+    var AddressSet = SheetUtils.AddressSet;
     var Range = SheetUtils.Range;
     var RangeArray = SheetUtils.RangeArray;
     var RangeSet = SheetUtils.RangeSet;
@@ -54,13 +54,12 @@ define('io.ox/office/spreadsheet/model/mergecollection', [
      *
      * @constructor
      *
-     * @extends ModelObject
-     * @extends TimerMixin
+     * @extends UsedRangeCollection
      *
      * @param {SheetModel} sheetModel
      *  The sheet model instance containing this collection.
      */
-    function MergeCollection(sheetModel) {
+    var MergeCollection = UsedRangeCollection.extend({ constructor: function (sheetModel) {
 
         // self reference
         var self = this;
@@ -72,24 +71,40 @@ define('io.ox/office/spreadsheet/model/mergecollection', [
         var mergedRangeSet = new RangeSet();
 
         // all merged ranges, mapped by key of their start addresses
-        var mergedRangeMap = new SimpleMap();
+        var mergedRangeMap = new ValueMap();
 
-        // the spreadsheet app
-        var app = docModel.getApp();
+        // set of start/end addresses of all merged ranges used to calculate the bounding range
+        var usedAddressSet = new AddressSet();
 
         // base constructor ---------------------------------------------------
 
-        ModelObject.call(this, docModel);
-        TimerMixin.call(this);
+        UsedRangeCollection.call(this, sheetModel, usedRangeResolver);
 
         // private methods ----------------------------------------------------
 
+        /**
+         * Calculates the used range of this collection (will be called from
+         * base class).
+         */
+        function usedRangeResolver() {
+            return usedAddressSet.boundary();
+        }
+
+        function getUsedEnd(mergedRange) {
+            var address = mergedRange.end.clone();
+            if (docModel.isColRange(mergedRange)) { address[1] = 0; }
+            if (docModel.isRowRange(mergedRange)) { address[0] = 0; }
+            return address;
+        }
+
         /**
          * Inserts the passed merged range into the internal containers.
          */
         function insertMergedRange(mergedRange) {
             mergedRangeSet.insert(mergedRange);
             mergedRangeMap.insert(mergedRange.start.key(), mergedRange);
+            usedAddressSet.insert(mergedRange.start);
+            usedAddressSet.insert(getUsedEnd(mergedRange));
         }
 
         /**
@@ -98,6 +113,8 @@ define('io.ox/office/spreadsheet/model/mergecollection', [
         function removeMergedRange(mergedRange) {
             mergedRangeSet.remove(mergedRange);
             mergedRangeMap.remove(mergedRange.start.key());
+            usedAddressSet.remove(mergedRange.start);
+            usedAddressSet.remove(getUsedEnd(mergedRange));
         }
 
         /**
@@ -139,7 +156,7 @@ define('io.ox/office/spreadsheet/model/mergecollection', [
          * row ranges into merge operations with merge type 'horizontal' or
          * 'vertical'.
          *
-         * @param {SheetOperationsGenerator} generator
+         * @param {SheetOperationGenerator} generator
          *  The operations generator to be filled with the operations.
          *
          * @param {RangeArray} ranges
@@ -150,8 +167,8 @@ define('io.ox/office/spreadsheet/model/mergecollection', [
             // generate 'vertical' or 'horizontal' merge operations for single-column/single-row ranges
             function collectAndGenerateOperations(singleRanges, columns) {
 
-                // the merge type for the generated operations
-                var mergeType = columns ? 'vertical' : 'horizontal';
+                // the merge mode for the generated operations
+                var mergeMode = columns ? MergeMode.VERTICAL : MergeMode.HORIZONTAL;
 
                 // sort the ranges according to the direction
                 var comparator = columns ? Address.compare : Address.compareVert;
@@ -174,7 +191,7 @@ define('io.ox/office/spreadsheet/model/mergecollection', [
 
                     // create one operation for all adjacent merged ranges
                     var compoundRange = columns ? range1.colRange(0, count) : range1.rowRange(0, count);
-                    generator.generateRangeOperation(Operations.MERGE_CELLS, compoundRange, { type: (count > 1) ? mergeType : 'merge' }, { undo: true });
+                    generator.generateMergeCellsOperation(compoundRange, (count > 1) ? mergeMode : MergeMode.MERGE, { undo: true });
                 }
             }
 
@@ -196,7 +213,7 @@ define('io.ox/office/spreadsheet/model/mergecollection', [
             // generate undo operations for two-dimensional ranges directly
             if (rangeGroups.range) {
                 rangeGroups.range.forEach(function (range) {
-                    generator.generateRangeOperation(Operations.MERGE_CELLS, range, { type: 'merge' }, { undo: true });
+                    generator.generateMergeCellsOperation(range, MergeMode.MERGE, { undo: true });
                 });
             }
         }
@@ -246,18 +263,20 @@ define('io.ox/office/spreadsheet/model/mergecollection', [
          */
         function moveCellsHandler(event, moveDesc) {
 
-            // the original merged ranges
-            var oldRangeSet = mergedRangeSet;
-
             // fill the containers during range transformation
+            var oldRangeSet = mergedRangeSet;
             mergedRangeSet = new RangeSet();
             mergedRangeMap.clear();
+            usedAddressSet.clear();
 
             // process all original merged ranges
             oldRangeSet.forEach(function (mergedRange) {
                 mergedRange = transformMergedRange(mergedRange, [moveDesc]);
                 if (mergedRange) { insertMergedRange(mergedRange); }
             });
+
+            // update the used range, and trigger the 'change:usedrange' event
+            self.updateUsedRange();
         }
 
         /**
@@ -300,6 +319,9 @@ define('io.ox/office/spreadsheet/model/mergecollection', [
             cloneData.mergedRangeSet.forEach(function (mergedRange) {
                 insertMergedRange(mergedRange.clone());
             });
+
+            // update the used range, and trigger the 'change:usedrange' event
+            this.updateUsedRange();
         };
 
         /**
@@ -315,7 +337,7 @@ define('io.ox/office/spreadsheet/model/mergecollection', [
             // the range covered by the operation
             var range = context.getRange();
             // the method how to merge/unmerge the operation range
-            var type = context.getOptEnum('type', /^(merge|horizontal|vertical|unmerge)$/, 'merge');
+            var mergeMode = context.getOptEnum('type', MergeMode, MergeMode.MERGE);
             // all merged ranges deleted from the collection
             var removedRanges = new RangeArray();
             // all merged ranges added to the collection
@@ -335,15 +357,15 @@ define('io.ox/office/spreadsheet/model/mergecollection', [
             });
 
             // handle the different merge types
-            switch (type) {
+            switch (mergeMode) {
 
-                case 'merge':
+                case MergeMode.MERGE:
                     if (range.cells() > 1) {
                         registerMergedRange(range);
                     }
                     break;
 
-                case 'horizontal':
+                case MergeMode.HORIZONTAL:
                     if (range.cols() > 1) {
                         for (var row = range.start[1]; row <= range.end[1]; row += 1) {
                             registerMergedRange(Range.create(range.start[0], row, range.end[0], row));
@@ -351,7 +373,7 @@ define('io.ox/office/spreadsheet/model/mergecollection', [
                     }
                     break;
 
-                case 'vertical':
+                case MergeMode.VERTICAL:
                     if (range.rows() > 1) {
                         for (var col = range.start[0]; col <= range.end[0]; col += 1) {
                             registerMergedRange(Range.create(col, range.start[1], col, range.end[1]));
@@ -359,7 +381,7 @@ define('io.ox/office/spreadsheet/model/mergecollection', [
                     }
                     break;
 
-                case 'unmerge':
+                case MergeMode.UNMERGE:
                     // all merged ranges have been removed already, see above
                     break;
             }
@@ -367,6 +389,9 @@ define('io.ox/office/spreadsheet/model/mergecollection', [
             // trigger change events with array of changed merged ranges
             triggerEvent('delete:merged', removedRanges);
             triggerEvent('insert:merged', insertedRanges);
+
+            // update the used range, and trigger the 'change:usedrange' event
+            this.updateUsedRange();
         };
 
         // public methods -----------------------------------------------------
@@ -494,7 +519,7 @@ define('io.ox/office/spreadsheet/model/mergecollection', [
             // quickly find a merged range by its start address
             var mergedRange = mergedRangeMap.get(address.key(), null);
 
-            // do not try to search in the set for search type 'reference'
+            // do not try to search in the set for search type 'reference' (start address only)
             if (type === 'reference') { return mergedRange ? mergedRange.clone() : null; }
 
             // return a found merged range (but return null if search type is 'hidden')
@@ -724,18 +749,14 @@ define('io.ox/office/spreadsheet/model/mergecollection', [
         /**
          * Generates and applies 'mergeCells' operations for all passed ranges.
          *
-         * @param {SheetOperationsGenerator} generator
+         * @param {SheetOperationGenerator} generator
          *  The operations generator to be filled with the operations.
          *
          * @param {RangeArray|Range} ranges
          *  An array of range addresses, or a single cell range address.
          *
-         * @param {String} type
-         *  The merge type. Must be one of:
-         *  - 'merge': Merges the entire ranges.
-         *  - 'horizontal': Merges the single rows in all ranges.
-         *  - 'vertical': Merges the single columns in all ranges.
-         *  - 'unmerge': Removes all merged ranges covered by the ranges.
+         * @param {MergeMode} mergeMode
+         *  The merge mode to be inserted into the generated operations.
          *
          * @returns {jQuery.Promise}
          *  A promise that will be resolved when the operations have been
@@ -744,16 +765,16 @@ define('io.ox/office/spreadsheet/model/mergecollection', [
          *  - 'merge:overlap': The passed cell ranges overlap each other.
          *  - 'merge:overflow': Tried to merge too many ranges at once.
          */
-        this.generateMergeCellsOperations = function (generator, ranges, type) {
+        this.generateMergeCellsOperations = function (generator, ranges, mergeMode) {
 
             // the cell collection of the sheet
             var cellCollection = sheetModel.getCellCollection();
             // whether to merge single columns in the passed ranges
-            var vertical = type === 'vertical';
+            var vertical = mergeMode === MergeMode.VERTICAL;
             // whether to merge single rows in the passed ranges
-            var horizontal = type === 'horizontal';
+            var horizontal = mergeMode === MergeMode.HORIZONTAL;
             // whether to unmerge the ranges
-            var unmerge = type === 'unmerge';
+            var unmerge = mergeMode === MergeMode.UNMERGE;
 
             // convert ranges to unique array
             ranges = RangeArray.get(ranges).unify();
@@ -775,8 +796,10 @@ define('io.ox/office/spreadsheet/model/mergecollection', [
             // area of the cell collection (bug 30662)
             if (!unmerge) {
 
+                // the used area of the sheet (may be null)
+                var usedRange = sheetModel.getUsedRange();
                 // the maximum used column/row index
-                var maxIndex = Math.max(0, cellCollection.getUsedCount(type !== 'horizontal') - 1);
+                var maxIndex = usedRange ? usedRange.end.get(mergeMode !== MergeMode.HORIZONTAL) : 0;
                 // the total number of created merged ranges
                 var rangeCount = 0;
 
@@ -817,13 +840,13 @@ define('io.ox/office/spreadsheet/model/mergecollection', [
 
                 // generate an 'unmerge' operation (also, if merging causes to unmerge existing merged ranges)
                 if (unmerge || rangeGroups.overlap) {
-                    generator.generateRangeOperation(Operations.MERGE_CELLS, range, { type: 'unmerge' });
+                    generator.generateMergeCellsOperation(range, MergeMode.UNMERGE);
                 }
 
                 // generate a 'merge' operation for the range, and the according 'unmerge' operation for undo
                 if (!unmerge) {
-                    generator.generateRangeOperation(Operations.MERGE_CELLS, range, { type: 'unmerge' }, { undo: true });
-                    generator.generateRangeOperation(Operations.MERGE_CELLS, range, { type: type });
+                    generator.generateMergeCellsOperation(range, MergeMode.UNMERGE, { undo: true });
+                    generator.generateMergeCellsOperation(range, mergeMode);
                 }
 
                 // all merged ranges covered by the current range need to be restored in undo (see below)
@@ -835,16 +858,16 @@ define('io.ox/office/spreadsheet/model/mergecollection', [
                 // (will become undefined, if no more merged ranges of this collection are left)
                 remainingRanges = rangeGroups.remaining;
 
-            }, { delay: 'immediate', infoString: 'MergeCollection.generateMergeCellsOperations', app: app });
+            }, 'MergeCollection.generateMergeCellsOperations');
 
             // generate the hyperlink operations
             promise = promise.then(function () {
-                return sheetModel.getHyperlinkCollection().generateMergeCellsOperations(generator, ranges);
+                return sheetModel.getHyperlinkCollection().generateMergeCellsOperations(generator, ranges, mergeMode);
             });
 
             // generate the cell operations (e.g.: move values to top-left cells, expand formatting)
             promise = promise.then(function () {
-                return cellCollection.generateMergeCellsOperations(generator, ranges, type);
+                return cellCollection.generateMergeCellsOperations(generator, ranges, mergeMode);
             });
 
             // add all merged ranges to the undo generator that need to be restored
@@ -858,7 +881,7 @@ define('io.ox/office/spreadsheet/model/mergecollection', [
          * collection that would not be restored automatically with the reverse
          * operation of the passed move descriptor.
          *
-         * @param {SheetOperationsGenerator} generator
+         * @param {SheetOperationGenerator} generator
          *  The operations generator to be filled with the operations.
          *
          * @param {Array<MoveDescriptor>} moveDescs
@@ -883,7 +906,7 @@ define('io.ox/office/spreadsheet/model/mergecollection', [
                 if (!restoredRange || restoredRange.differs(mergedRange)) {
                     restoreRanges.push(mergedRange);
                 }
-            }, { delay: 'immediate', infoString: 'MergeCellCollection.generateMoveCellsOperations', app: app });
+            }, 'MergeCollection.generateMoveCellsOperations');
 
             // add all merged ranges to the undo generator that need to be restored
             return promise.done(function () {
@@ -932,7 +955,7 @@ define('io.ox/office/spreadsheet/model/mergecollection', [
                 targetMerge--;
             }
 
-            return self.generateMergeCellsOperations(generator, op_mergedRanges, 'merge');
+            return this.generateMergeCellsOperations(generator, op_mergedRanges, MergeMode.MERGE);
         });
 
         // initialization -----------------------------------------------------
@@ -942,14 +965,17 @@ define('io.ox/office/spreadsheet/model/mergecollection', [
 
         // destroy all class members on destruction
         this.registerDestructor(function () {
-            self = docModel = sheetModel = mergedRangeSet = mergedRangeMap = app = null;
+            mergedRangeSet.clear();
+            mergedRangeMap.clear();
+            usedAddressSet.clear();
+            self = docModel = sheetModel = null;
+            mergedRangeSet = mergedRangeMap = usedAddressSet = null;
         });
 
-    } // class MergeCollection
+    } }); // class MergeCollection
 
     // exports ================================================================
 
-    // derive this class from class ModelObject
-    return ModelObject.extend({ constructor: MergeCollection });
+    return MergeCollection;
 
 });
