@@ -14,14 +14,20 @@
 
 define('io.ox/office/spreadsheet/model/modelattributesmixin', [
     'io.ox/office/tk/utils',
-    'io.ox/office/tk/container/simplemap',
+    'io.ox/office/tk/container/valuemap',
     'io.ox/office/editframework/utils/color',
     'io.ox/office/editframework/utils/border',
+    'io.ox/office/editframework/utils/attributeutils',
     'io.ox/office/drawinglayer/model/drawingstylecollection',
+    'io.ox/office/textframework/format/characterstyles',
+    'io.ox/office/spreadsheet/utils/sheetutils',
+    'io.ox/office/spreadsheet/model/pagestylecollection',
     'io.ox/office/spreadsheet/model/cellstylecollection',
     'io.ox/office/spreadsheet/model/tablestylecollection',
-    'io.ox/office/spreadsheet/model/cellautostylecollection'
-], function (Utils, SimpleMap, Color, Border, DrawingStyleCollection, CellStyleCollection, TableStyleCollection, CellAutoStyleCollection) {
+    'io.ox/office/spreadsheet/model/paragraphstylecollection',
+    'io.ox/office/spreadsheet/model/cellautostylecollection',
+    'io.ox/office/spreadsheet/model/drawing/text/fieldmanager'
+], function (Utils, ValueMap, Color, Border, AttributeUtils, DrawingStyleCollection, CharacterStyleCollection, SheetUtils, PageStyleCollection, CellStyleCollection, TableStyleCollection, ParagraphStyleCollection, CellAutoStyleCollection, FieldManager) {
 
     'use strict';
 
@@ -67,7 +73,7 @@ define('io.ox/office/spreadsheet/model/modelattributesmixin', [
          * Name of the font family used to render the cell contents. Bound to
          * the apply flag 'font'.
          */
-        fontName: { def: 'Arial', apply: 'font' },
+        fontName: { def: AttributeUtils.MINOR_FONT_KEY, apply: 'font' },
 
         /**
          * Size of the font used to render the cell contents, in points. Bound
@@ -145,10 +151,31 @@ define('io.ox/office/spreadsheet/model/modelattributesmixin', [
         formatCode: { def: 'General', apply: 'number' },
 
         /**
-         * The fill color for the cell area. Bound to the apply flag 'fill'.
+         * The fill type ('solid', 'pattern', 'gradient', or 'inherit'). Bound
+         * to the apply flag 'fill'.
+         */
+        fillType: { def: 'solid', apply: 'fill', merge: function (type1, type2) {
+            // fill type 'inherit' is used in conditional formatting to switch from 'gradient' to 'pattern', but inherit all other fill types
+            return (type2 !== 'inherit') ? type2 : (type1 === 'gradient') ? 'pattern' : type1;
+        } },
+
+        /**
+         * The fill color for the cell area, the background color of a pattern,
+         * or the start color of a gradient. Bound to the apply flag 'fill'.
          */
         fillColor: { def: Color.AUTO, apply: 'fill' },
 
+        /**
+         * The foreground color of a pattern, or the end color of a gradient.
+         * Bound to the apply flag 'fill'.
+         */
+        foreColor: { def: Color.AUTO, apply: 'fill' },
+
+        /**
+         * The identifier of a fill pattern. Bound to the apply flag 'fill'.
+         */
+        pattern: { def: 'solid', apply: 'fill' },
+
         /**
          * The style of the left border of the cell. Bound to the apply flag
          * 'border'.
@@ -463,6 +490,11 @@ define('io.ox/office/spreadsheet/model/modelattributesmixin', [
 
     var TABLE_ATTRIBUTE_DEFINITIONS = {
 
+        /**
+         * Whether the drop-down buttons of all columns will be hidden.
+         */
+        hideButtons: { def: false },
+
         /**
          * Whether the first row of the table is a header row. Header rows will
          * not be filtered or sorted.
@@ -500,11 +532,10 @@ define('io.ox/office/spreadsheet/model/modelattributesmixin', [
         bandsVert: { def: false, scope: 'element' },
 
         /**
-         * Whether the table can be filtered (this flag does not mean that the
-         * table has actual filter rules applied, but the GUI may provide
-         * visual feedback and control elements for filtering).
+         * Whether the string values in the table range will be sorted
+         * case-sensitively.
          */
-        filtered: { def: false, scope: 'element' }
+        caseSensitive: { def: false, scope: 'element' }
     };
 
     // definitions for filter attributes in table columns ---------------------
@@ -517,20 +548,23 @@ define('io.ox/office/spreadsheet/model/modelattributesmixin', [
          * - 'none': No filter rule is active.
          * - 'discrete': Discrete filter. The attribute 'entries' contains
          *      all cell entries to be shown for the table column.
+         *
+         * The property 'undo' contains the names of all attributes that need
+         * to be inserted into the undo operation that will be generated when
+         * changing this attribute.
          */
-        type: { def: 'none' },
+        type: { def: 'none', undo: 'entries' },
 
         /**
          * All entries (cell display strings) that will be shown for this table
          * column. Only used, if the filter type is 'discrete'.
          */
-        entries: { def: [], parent: { name: 'type', value: 'discrete' } },
+        entries: { def: [] },
 
         /**
-         * Whether the drop-down button of the filter column is currently
-         * hidden by a merged cell range.
+         * Whether the drop-down button of the filter column will be hidden.
          */
-        hideMergedButton: { def: false }
+        hideButton: { def: false }
     };
 
     // definitions for sorting attributes in table columns --------------------
@@ -538,9 +572,43 @@ define('io.ox/office/spreadsheet/model/modelattributesmixin', [
     var TABLE_SORT_ATTRIBUTE_DEFINITIONS = {
 
         /**
-         * Whether to sort the column entries in descending order.
+         * Specifies how to sort the values in the column.
+         * - 'none': The column will not be sorted.
+         * - 'value': The column will be sorted by the values in the cells.
+         * - 'font': The column will be sorted by the text color of the cells.
+         * - 'fill': The column will be sorted by the fill color of the cells.
+         * - 'icon': The column will be sorted by icons in the cells.
+         *
+         * The property 'undo' contains the names of all attributes that need
+         * to be inserted into the undo operation that will be generated when
+         * changing this attribute.
          */
-        descending: { def: false }
+        type: { def: 'none', undo: '*' },
+
+        /**
+         * If set to true, the values in the column will be sorted in
+         * descending order, and the selected cell color or font color will be
+         * pushed to the bottom of the table.
+         */
+        descending: { def: false },
+
+        /**
+         * The internal index of the format structure containing the font color
+         * or fill color. Only used for sort types 'font' or 'fill'.
+         */
+        dxf: { def: 0 },
+
+        /**
+         * The name of the icon set used for sorting the column. Only used for
+         * sort type 'icon'.
+         */
+        is: { def: '' },
+
+        /**
+         * The identifier of the icon in the icon set as specified by the
+         * attribute 'is'. Only used for sort type 'icon'.
+         */
+        id: { def: 0 }
     };
 
     // definitions for data validation attributes -----------------------------
@@ -550,27 +618,31 @@ define('io.ox/office/spreadsheet/model/modelattributesmixin', [
         /**
          * The type of the data validation. Supports all types used in the
          * document operation 'insertValidation'.
+         *
+         * The property 'undo' contains the names of all attributes that need
+         * to be inserted into the undo operation that will be generated when
+         * changing this attribute.
          */
-        type: { def: 'all' },
+        type: { def: 'all', undo: 'compare value1 value2' },
 
         /**
          * The comparison operator for most validation types, used together
          * with the attributes 'value1' and 'value2'.
          */
-        compare: { def: '', parent: { name: 'type', value: function (value) { return (/^(integer|number|date|time|length)$/).test(value); } } },
+        compare: { def: '' },
 
         /**
          * The first value used together with the comparison operator. Must be
          * a formula expression as string, without the leading equality sign.
          */
-        value1: { def: '', parent: { name: 'type', value: function (value) { return value !== 'all'; } } },
+        value1: { def: '' },
 
         /**
          * The second value used together with the comparison operators
          * 'between' and 'notBetween'. Must be a formula expression as string,
          * without the leading equality sign.
          */
-        value2: { def: '', parent: { name: 'type', value: function (value) { return value !== 'all'; } } },
+        value2: { def: '' },
 
         /**
          * Specifies whether to show an informational tooltip when a cell with
@@ -630,8 +702,12 @@ define('io.ox/office/spreadsheet/model/modelattributesmixin', [
         /**
          * The type of the formatting rule. Supports all types used in the
          * document operation 'insertCondFormatRule'.
+         *
+         * The property 'undo' contains the names of all attributes that need
+         * to be inserted into the undo operation that will be generated when
+         * changing this attribute.
          */
-        type: { def: 'formula' },
+        type: { def: 'formula', undo: '*' },
 
         /**
          * The first value, used by most conditional rules. Depending on the
@@ -749,6 +825,46 @@ define('io.ox/office/spreadsheet/model/modelattributesmixin', [
         endRowOffset: { def: 0, scope: 'element' }
     };
 
+    // precalculated standard row heights -------------------------------------
+
+    // effective pixel row height for different fonts and font sizes used in OOXML
+    var PIXEL_ROW_HEIGHT_MAP = _.mapObject({
+        arial:             '701120131121221222031131131131131121222122121131131131121421222122121131131131211222122131121131131221232122131112131121221231121121222221122121131242121121141131121132121131131131121222121211133131131122121221221131131131122121221131131131322122121221131131131122121221221131131122122141221131131131122121221221131131122122121221',
+        calibri:           '70112013113122122122212212212213113113113113113113122122122122212212213113113113113113113113122122122212212212213113113113113113113122122122122212212213113113113113113113113122122122212212212213113113113113113113122122122122212212213113113113113113113122122122122212212212213113113113113113113122122122122212212213113113111',
+        cambria:           '70112012212212122122113113113113112212212122122113113113113112212212122122113113113113112212212122122113113113113112212212122122113113113113112212212122122113113113113112212212122122113113113113112212212122122113113113113112212212122122113113113113112212212122122113113113113112212212122122113113113113112212212122122113113113113112211',
+        consolas:          '701120131131131131131131131131131131131131131131131131131131131131131131131131131131131131131131131131131131131131131131131131131131131131131131131131131131131131131131131131131131131131131131221221221221221221221221221221221221221221221221221221221221221221221221221221221221221221221221221221221221221221221221221221221221221',
+        'courier new':     '7011201312212212221221221311311311311312212212221221221311311311311311312212212221221311311311311311312212212221221221311311311311311312212221221221311311311311311312212212221221221311311311A113113122122213113113122122213113113122122213113113122122213113113122212213113113122212213113113122212213113113122212213113',
+        'times new roman': '70112013113113113113112212212212212212212214122122122122122122122113113113113115113113113113113113113113113112210214212212212211122122122122122122122133113113113113113113113113112113113313110122113113113112212212122122115113113112212122122113113113112212214122113113113113112212122122113113133112212212122113113113112212212122'
+    }, function (diffMap) {
+        var fontSizes = [null];
+        var fontSize = 0;
+        _.each(diffMap, function (diff) {
+            fontSize += parseInt(diff, 16);
+            fontSizes.push(fontSize);
+        });
+        return fontSizes;
+    });
+
+    // private global functions ===============================================
+
+    /**
+     * Returns the precalculated row height for the passed font settings.
+     *
+     * @param {Object} charAttributes
+     *  Character formatting attributes influencing the row height, as used in
+     *  document operations.
+     *
+     * @returns {Number|Null}
+     *  The precalculated row height for the passed font settings, in pixels;
+     *  or null, if no row height is available for the passed font settings.
+     */
+    function getPresetRowHeight(charAttributes) {
+        var presetRowHeights = PIXEL_ROW_HEIGHT_MAP[charAttributes.fontName.toLowerCase()];
+        if (!presetRowHeights) { return null; }
+        var fontSize = Math.round(charAttributes.fontSize);
+        return presetRowHeights[fontSize] || _.last(presetRowHeights);
+    }
+
     // class ModelAttributesMixin =============================================
 
     /**
@@ -766,8 +882,8 @@ define('io.ox/office/spreadsheet/model/modelattributesmixin', [
         // special behavior for OOXML files
         var ooxml = this.getApp().isOOXML();
 
-        // the font collection of the document
-        var fontCollection = this.getFontCollection();
+        // shortcut to the cell attribute pool
+        var cellAttrPool = null;
 
         // the style sheet collection for cells, columns, and rows
         var cellStyles = null;
@@ -775,8 +891,14 @@ define('io.ox/office/spreadsheet/model/modelattributesmixin', [
         // the auto-style collection for cells, columns, and rows
         var cellAutoStyles = null;
 
+        // shortcut to the drawing attribute pool
+        var drawingAttrPool = null;
+
+        // the style sheet collection for drawing objects
+        var drawingStyles = null;
+
         // cache for default digit width, mapped by different zoom factors
-        var digitWidthCache = new SimpleMap();
+        var digitWidthCache = new ValueMap();
 
         // the conversion factor for column widths (1 operation unit to 1/100 mm, initialized lazily)
         var colWidthFactor = null;
@@ -800,8 +922,39 @@ define('io.ox/office/spreadsheet/model/modelattributesmixin', [
             return rowHeightFactor || (rowHeightFactor = ooxml ? (100 * Utils.convertLength(1, 'pt', 'mm')) : 1);
         }
 
+        /**
+         * Calculates the row height in 1/100 of millimeters to be used for the
+         * passed character attributes.
+         */
+        function calculateRowHeightHmm(charAttributes) {
+
+            // the normal line height according to the font settings
+            var lineHeight = self.getRenderFont(charAttributes).getNormalLineHeight();
+
+            // use at least 125% of the font size, to compensate for browsers
+            // reporting very small line heights (especially Chrome)
+            // Bug 40718: increased 120% to 125% to cover the standard case 'Arial 11pt'.
+            lineHeight = Math.max(lineHeight, Utils.convertLength(charAttributes.fontSize, 'pt', 'px') * 1.25);
+
+            // enlarge the resulting 'normal' line height by another 10% to add top/bottom cell padding
+            return Utils.convertLengthToHmm(Math.floor(lineHeight * 1.1), 'px');
+        }
+
         // public methods -----------------------------------------------------
 
+        /**
+         * Returns the special attribute pool for cell formatting attributes
+         * used by the spreadsheet model. Used to be able to distinguish cell
+         * character attributes from drawing character attributes.
+         *
+         * @returns {AttributePool}
+         *  The attribute pool for cell formatting attributes used by the
+         *  spreadsheet model.
+         */
+        this.getCellAttributePool = function () {
+            return cellAttrPool;
+        };
+
         /**
          * Returns the cell style collection of this document.
          *
@@ -822,6 +975,75 @@ define('io.ox/office/spreadsheet/model/modelattributesmixin', [
             return cellAutoStyles;
         };
 
+        /**
+         * Returns the attribute pool for drawing formatting attributes used by
+         * the spreadsheet model. Used to be able to distinguish cell character
+         * attributes from drawing character attributes.
+         *
+         * @returns {AttributePool}
+         *  The attribute pool for drawing formatting attributes used by the
+         *  spreadsheet model.
+         */
+        this.getDrawingAttributePool = function () {
+            return drawingAttrPool;
+        };
+
+        /**
+         * Returns the maximum width of the digits in the specified font,
+         * according to the passed zoom factor.
+         *
+         * @param {Object} charAttributes
+         *  Character formatting attributes, as used in document operations.
+         *
+         * @param {Number} zoom
+         *  The zoom factor to be applied to the font size.
+         *
+         * @returns {Number}
+         *  The maximum width of the digits in the specified font, in pixels.
+         */
+        this.getDigitWidth = function (charAttributes, zoom) {
+            return this.getRenderFont(charAttributes, null, zoom).getDigitWidths().maxWidth;
+        };
+
+        /**
+         * Calculates the effective horizontal padding between cell grid lines
+         * and the text contents of the cell in pixels to be used for the
+         * passed character attributes and zoom factor.
+         *
+         * @param {Object} charAttributes
+         *  Character formatting attributes influencing the padding, as used in
+         *  document operations.
+         *
+         * @param {Number} zoom
+         *  The zoom factor used to scale the font size in the passed character
+         *  attributes.
+         *
+         * @returns {Number}
+         *  The effective horizontal text padding for the passed character
+         *  attributes, in pixels.
+         */
+        this.getTextPadding = function (charAttributes, zoom) {
+            return SheetUtils.getTextPadding(this.getDigitWidth(charAttributes, zoom));
+        };
+
+        /**
+         * Returns the total size of all horizontal padding occupied in a cell
+         * that cannot be used for the cell contents for the passed character
+         * attributes and zoom factor. This value includes the text padding
+         * (twice, for left and right border), and additional space needed for
+         * the grid lines.
+         *
+         * @param {Object} charAttributes
+         *  Character formatting attributes influencing the padding, as used in
+         *  document operations.
+         *
+         * @returns {Number}
+         *  The total size of the horizontal cell content padding, in pixels.
+         */
+        this.getTotalCellPadding = function (charAttributes, zoom) {
+            return SheetUtils.getTotalCellPadding(this.getDigitWidth(charAttributes, zoom));
+        };
+
         /**
          * Returns the maximum width of the digits in the font of the current
          * default cell style, according to the passed zoom factor.
@@ -840,7 +1062,7 @@ define('io.ox/office/spreadsheet/model/modelattributesmixin', [
                 var charAttributes = cellStyles.getDefaultStyleAttributeSet().character;
 
                 // the maximum pixel width of any of the digits of the default font
-                return fontCollection.getDigitWidths(charAttributes, { zoom: zoom }).maxWidth;
+                return self.getDigitWidth(charAttributes, zoom);
             });
         };
 
@@ -856,7 +1078,7 @@ define('io.ox/office/spreadsheet/model/modelattributesmixin', [
          */
         this.convertColWidthToUnit = function (colWidthHmm) {
             var colWidth = colWidthHmm / getColWidthFactor();
-            return ooxml ? Utils.round(colWidth, 0.01) : colWidth;
+            return ooxml ? (Math.floor(colWidth * 256) / 256) : colWidth;
         };
 
         /**
@@ -899,7 +1121,7 @@ define('io.ox/office/spreadsheet/model/modelattributesmixin', [
          *  The row height in 1/100 of millimeters.
          */
         this.convertRowHeightFromUnit = function (rowHeight) {
-            return Math.ceil(rowHeight * getRowHeightFactor());
+            return Math.round(rowHeight * getRowHeightFactor());
         };
 
         /**
@@ -954,21 +1176,17 @@ define('io.ox/office/spreadsheet/model/modelattributesmixin', [
          */
         this.getRowHeightHmm = function (charAttributes) {
 
-            // the normal line height according to the font settings
-            var lineHeight = fontCollection.getNormalLineHeight(charAttributes);
+            // bug 50743: use precalculated row heights if available, to get rid of browser-dependent 'normal line height'
+            var presetHeight = ooxml ? getPresetRowHeight(charAttributes) : null;
+            if (presetHeight) { return Utils.convertLengthToHmm(presetHeight, 'px'); }
 
-            // use at least 125% of the font size, to compensate for browsers
-            // reporting very small line heights (especially Chrome)
-            // Bug 40718: increased 120% to 125% to cover the standard case 'Arial 11pt'.
-            lineHeight = Math.max(lineHeight, Utils.convertLength(charAttributes.fontSize, 'pt', 'px') * 1.25);
-
-            // enlarge the resulting 'normal' line height by another 10% to add top/bottom cell padding
-            return Utils.convertLengthToHmm(Math.floor(lineHeight * 1.1), 'px');
+            // calculate row height in 1/100mm
+            return calculateRowHeightHmm(charAttributes);
         };
 
         /**
          * Calculates the effective scaled row height in pixels to be used for
-         * the passed character attributes.
+         * the passed character attributes and zoom factor.
          *
          * @param {Object} charAttributes
          *  Character formatting attributes influencing the line height, as
@@ -982,35 +1200,63 @@ define('io.ox/office/spreadsheet/model/modelattributesmixin', [
          *  The row height for the passed character attributes, in pixels.
          */
         this.getRowHeight = function (charAttributes, zoom) {
-            return Utils.convertHmmToLength(this.getRowHeightHmm(charAttributes) * zoom, 'px', 1);
+
+            // bug 50743: use precalculated row heights if available, to get rid of browser-dependent 'normal line height'
+            var presetHeight = ooxml ? getPresetRowHeight(charAttributes) : null;
+            if (presetHeight) { return Math.round(presetHeight * zoom); }
+
+            // calculate row height, and convert it from 1/100mm to pixels
+            return Utils.convertHmmToLength(calculateRowHeightHmm(charAttributes) * zoom, 'px', 1);
         };
 
         // initialization -----------------------------------------------------
 
-        this.registerAttributeDefinitions('document', DOCUMENT_ATTRIBUTE_DEFINITIONS);
-        this.registerAttributeDefinitions('character', CHARACTER_ATTRIBUTE_DEFINITIONS);
-        this.registerAttributeDefinitions('cell', CELL_ATTRIBUTE_DEFINITIONS);
-        this.registerAttributeDefinitions('apply', APPLY_ATTRIBUTE_DEFINITIONS);
-        this.registerAttributeDefinitions('column', COLUMN_ATTRIBUTE_DEFINITIONS);
-        this.registerAttributeDefinitions('row', ROW_ATTRIBUTE_DEFINITIONS);
-        this.registerAttributeDefinitions('group', GROUP_ATTRIBUTE_DEFINITIONS);
-        this.registerAttributeDefinitions('sheet', SHEET_ATTRIBUTE_DEFINITIONS);
-        this.registerAttributeDefinitions('table', TABLE_ATTRIBUTE_DEFINITIONS);
-        this.registerAttributeDefinitions('filter', TABLE_FILTER_ATTRIBUTE_DEFINITIONS);
-        this.registerAttributeDefinitions('sort', TABLE_SORT_ATTRIBUTE_DEFINITIONS);
-        this.registerAttributeDefinitions('validation', VALIDATION_ATTRIBUTE_DEFINITIONS);
-        this.registerAttributeDefinitions('rule', FORMAT_RULE_ATTRIBUTE_DEFINITIONS);
-        this.registerAttributeDefinitions('drawing', DRAWING_ATTRIBUTE_DEFINITIONS);
+        // global document attributes registration
+        this.registerDocumentAttributes(DOCUMENT_ATTRIBUTE_DEFINITIONS);
 
+        // formatting attributes registration with a dedicated spreadsheet attribute pool
+        this.registerAttributes('character', CHARACTER_ATTRIBUTE_DEFINITIONS, { poolId: SheetUtils.CELL_POOL_ID });
+        this.registerAttributes('cell', CELL_ATTRIBUTE_DEFINITIONS, { poolId: SheetUtils.CELL_POOL_ID });
+        this.registerAttributes('apply', APPLY_ATTRIBUTE_DEFINITIONS, { poolId: SheetUtils.CELL_POOL_ID });
+        this.registerAttributes('table', TABLE_ATTRIBUTE_DEFINITIONS, { poolId: SheetUtils.CELL_POOL_ID });
+        this.registerAttributes('filter', TABLE_FILTER_ATTRIBUTE_DEFINITIONS/*, { poolId: SheetUtils.CELL_POOL_ID }*/);
+        this.registerAttributes('sort', TABLE_SORT_ATTRIBUTE_DEFINITIONS/*, { poolId: SheetUtils.CELL_POOL_ID }*/);
+
+        // formatting attributes registration used by text framework (default attribute ppol)
+        this.registerAttributes('column', COLUMN_ATTRIBUTE_DEFINITIONS);
+        this.registerAttributes('row', ROW_ATTRIBUTE_DEFINITIONS);
+        this.registerAttributes('group', GROUP_ATTRIBUTE_DEFINITIONS);
+        this.registerAttributes('sheet', SHEET_ATTRIBUTE_DEFINITIONS);
+        this.registerAttributes('validation', VALIDATION_ATTRIBUTE_DEFINITIONS);
+        this.registerAttributes('rule', FORMAT_RULE_ATTRIBUTE_DEFINITIONS);
+        this.registerAttributes('drawing', DRAWING_ATTRIBUTE_DEFINITIONS);
+
+        // style sheet collections
         this.addStyleCollection(cellStyles = new CellStyleCollection(this));
+        this.addStyleCollection(drawingStyles = new DrawingStyleCollection(this));
+        this.addStyleCollection(new PageStyleCollection(this));
         this.addStyleCollection(new TableStyleCollection(this));
-        this.addStyleCollection(new DrawingStyleCollection(this));
 
+        // style collections needed for text in shapes
+        this.addStyleCollection(new CharacterStyleCollection(this));
+        this.addStyleCollection(new ParagraphStyleCollection(this));
+
+        // auto-style collections
         this.addAutoStyleCollection(cellAutoStyles = new CellAutoStyleCollection(this));
 
+        // shortcuts to attribute pools
+        cellAttrPool = cellStyles.getAttributePool();
+        drawingAttrPool = drawingStyles.getAttributePool();
+
+        // further helper classes expected by the text framework used for text in shapes
+        this.setFieldManager(new FieldManager(this));
+
+        // setting the handler function for updating lists
+        this.setUpdateLists(this.getUpdateListsHandler());
+
         // OOXML: listen to changes of the default style sheet, invalidate cached font measures for column width
         if (ooxml) {
-            this.listenTo(cellStyles, 'triggered', function (event, styleId) {
+            this.listenTo(cellStyles, 'triggered', function (event, type, styleId) {
                 if (styleId === cellStyles.getDefaultStyleId()) {
                     digitWidthCache.clear();
                     colWidthFactor = maxColWidthHmm = null;
@@ -1020,7 +1266,7 @@ define('io.ox/office/spreadsheet/model/modelattributesmixin', [
 
         // destroy class members on destruction
         this.registerDestructor(function () {
-            self = fontCollection = cellStyles = cellAutoStyles = null;
+            self = cellAttrPool = cellStyles = cellAutoStyles = drawingStyles = drawingAttrPool = null;
         });
 
     } // class ModelAttributesMixin
