@@ -14,13 +14,12 @@
 
 define('io.ox/office/spreadsheet/model/namecollection', [
     'io.ox/office/tk/utils',
-    'io.ox/office/tk/container/simplemap',
-    'io.ox/office/tk/object/timermixin',
+    'io.ox/office/tk/container/valuemap',
     'io.ox/office/baseframework/model/modelobject',
     'io.ox/office/spreadsheet/utils/operations',
     'io.ox/office/spreadsheet/utils/sheetutils',
     'io.ox/office/spreadsheet/model/formula/tokenarray'
-], function (Utils, SimpleMap, TimerMixin, ModelObject, Operations, SheetUtils, TokenArray) {
+], function (Utils, ValueMap, ModelObject, Operations, SheetUtils, TokenArray) {
 
     'use strict';
 
@@ -28,6 +27,96 @@ define('io.ox/office/spreadsheet/model/namecollection', [
     var Address = SheetUtils.Address;
     var Range = SheetUtils.Range;
 
+    // private global functions ===============================================
+
+    /**
+     * Validates the passed label for a defined name. Returns a rejected
+     * promise if the label is not valid.
+     *
+     * @param {String} label
+     *  The label for a defined name to be checked.
+     *
+     * @returns {jQuery.Promise|Null}
+     *  A rejected promise with a specific error code, if the label is not
+     *  valid (see method FormulaGrammar.validateNameLabel() for a list of
+     *  error codes); or the value null, if the passed label is valid.
+     */
+    function validateNameLabel(docModel, label) {
+        var labelError = docModel.getFormulaGrammar('ui').validateNameLabel(docModel, label);
+        return labelError ? SheetUtils.makeRejected(labelError) : null;
+    }
+
+    /**
+     * Internal helper function for the ODF file format. Returns whether the
+     * passed formula array contains a complex expression, or a simple cell
+     * reference.
+     *
+     * @param {TokenArray} tokenArray
+     *  A token array with a formula.
+     *
+     * @returns {Boolean}
+     *  Whether the passed token array represents a complex formula expression
+     *  (true), or a simple cell reference (false).
+     */
+    function isComplexExpression(tokenArray) {
+        var ranges = tokenArray.resolveRangeList();
+        return !ranges || (ranges.length !== 1);
+    }
+
+    /**
+     * Creates the operation properties for the passed formula expression,
+     * intended to be used in the document operations 'insertName', and
+     * 'changeName'. The formula expression will be checked for syntax and
+     * semantic errors, and it will be relocated for usage in document
+     * operations.
+     *
+     * @param {SpreadsheetModel|SheetModel} parentModel
+     *  The spreadsheet document model for globally defined names, or the sheet
+     *  model for sheet-local names.
+     *
+     * @param {Object} formulaDesc
+     *  The descriptor of the formula expression. See public method
+     *  NameCollection.generateInsertNameOperations() for details about the
+     *  properties.
+     *
+     * @param {Boolean} ooxml
+     *  Whether the defined name is contained in an OOXML document.
+     *
+     * @returns {Object|Null}
+     *  On success, an object with the property 'formula' containing the
+     *  relocated formula expression, and an optional property 'ref' with
+     *  the passed reference address (as formula expression) for ODF
+     *  documents.
+     */
+    function getFormulaProperties(parentModel, formulaDesc, ooxml) {
+
+        // the resulting operation properties
+        var properties = null;
+
+        // parse the formula; bug 40293: add sheet name to references without sheet (OOXML only) (TODO: sheet-local names)
+        var tokenArray = new TokenArray(parentModel, 'name');
+        tokenArray.parseFormula(formulaDesc.grammarId, formulaDesc.formula, { autoCorrect: true, refSheet: formulaDesc.refSheet, extendSheet: ooxml });
+
+        // interpret the formula to find syntax errors or semantic errors
+        var formulaResult = tokenArray.interpretFormula('any');
+        if (formulaResult.type !== 'error') {
+
+            // OOXML: relocate the formula expression from reference cell to A1
+            // ODF: leave formula expression unmodified, pass reference cell with operation
+            if (ooxml) {
+                properties = { formula: tokenArray.getFormula('op', { refAddress: formulaDesc.refAddress, targetAdddress: Address.A1 }) };
+            } else {
+                properties = { formula: tokenArray.getFormula('op'), isExpr: isComplexExpression(tokenArray) };
+                // store reference cell as formula expression with sheet name
+                tokenArray.clearTokens();
+                tokenArray.appendRange(new Range(formulaDesc.refAddress), { sheet: formulaDesc.refSheet, abs: true });
+                properties.ref = tokenArray.getFormula('op');
+            }
+        }
+
+        return properties;
+    }
+
     // class NameModel ========================================================
 
     /**
@@ -194,6 +283,18 @@ define('io.ox/office/spreadsheet/model/namecollection', [
             return sheetModel;
         };
 
+        /**
+         * Returns the zero-based index of the parent sheet model of a
+         * sheet-locally defined name.
+         *
+         * @returns {Number|Null}
+         *  The zero-based index of the parent sheet model of a sheet-locally
+         *  defined name; or null for a globally defined name.
+         */
+        this.getSheetIndex = function () {
+            return sheetModel ? sheetModel.getIndex() : null;
+        };
+
         /**
          * Returns the exact label of this name model, with correct character
          * case as used in formula expressions.
@@ -277,11 +378,142 @@ define('io.ox/office/spreadsheet/model/namecollection', [
 
         // operation generators -----------------------------------------------
 
+        /**
+         * Generates the operations, and the undo operations, to delete this
+         * defined name.
+         *
+         * @param {SheetOperationGenerator} generator
+         *  The operations generator to be filled with the operations.
+         *
+         * @returns {jQuery.Promise}
+         *  A promise that will be resolved when the generated operations have
+         *  been applied successfully.
+         */
+        this.generateDeleteOperations = function (generator) {
+
+            // the properties for the operation, and the undo operation
+            var properties = { label: label };
+            var undoProperties = {
+                label: label,
+                formula: this.getFormula('op', Address.A1),
+                hidden: hidden
+            };
+
+            // add special undo properties for ODF
+            if (!ooxml) {
+                undoProperties.isExpr = isComplexExpression(defTokenArray);
+                undoProperties.ref = this.getRefFormula('op');
+            }
+
+            // add the sheet index to the operation properties
+            if (sheetModel) { properties.sheet = undoProperties.sheet = sheetModel.getIndex(); }
+
+            // generate the 'deleteName' operation, and the undo operation
+            generator.generateOperation(Operations.INSERT_NAME, undoProperties, { undo: true });
+            generator.generateOperation(Operations.DELETE_NAME, properties);
+            return $.when();
+        };
+
+        /**
+         * Generates the operations, and the undo operations, to change the
+         * label or formula definition of this defined name.
+         *
+         * @param {SheetOperationGenerator} generator
+         *  The operations generator to be filled with the operations.
+         *
+         * @param {String|Null} newLabel
+         *  The new label for the defined name. If set to null, the label of
+         *  the defined name will not be changed.
+         *
+         * @param {Object|Null} formulaDesc
+         *  The descriptor of the formula expression to be bound to the defined
+         *  name. If omitted, the formula expression of the defined name will
+         *  not be changed (an invalid formula expression in the defined name
+         *  will be retained). See description of the public method
+         *  NameCollection.generateInsertNameOperations() for details about the
+         *  expected properties.
+         *
+         * @returns {jQuery.Promise}
+         *  A promise that will be resolved when the generated operations have
+         *  been applied successfully, or that will be rejected with an object
+         *  with 'cause' property set to one of the following error codes:
+         *  - 'name:used': A defined name, or a table range, with the passed
+         *      label exists already.
+         *  - 'name:empty': The new label is empty.
+         *  - 'name:invalid': The new label contains invalid characters.
+         *  - 'name:address': The new label would be valid, but conflicts with
+         *      the representation of a relative cell reference in A1 notation,
+         *      or a cell reference in R1C1 notation (either English, e.g.
+         *      'R1C1', or according to current UI language, e.g. 'Z1S1' in
+         *      German).
+         *  - 'formula:invalid': The passed formula expression is invalid.
+         *  - 'operation': Internal error while creating the operations.
+         */
+        this.generateChangeOperations = function (generator, newLabel, formulaDesc) {
+
+            // the properties for the 'changeName' operation
+            var properties = {};
+            var undoProperties = {};
+
+            // check the passed new label (ignore unchanged existing invalid labels, e.g. from import filter)
+            newLabel = (_.isString(newLabel) && (label !== newLabel)) ? newLabel : null;
+            if (newLabel) {
+
+                // the label must be valid (method validateNameLabel() returns null, or a rejected promise)
+                var labelError = validateNameLabel(docModel, newLabel);
+                if (labelError) { return labelError; }
+
+                // new label must not exist yet in the document (but allow to change case of an existing label)
+                var nameCollection = parentModel.getNameCollection();
+                if ((SheetUtils.getNameKey(label) !== SheetUtils.getNameKey(newLabel)) && nameCollection.isLabelUsed(newLabel)) {
+                    return SheetUtils.makeRejected('name:used');
+                }
+
+                // add the new label to the operation properties
+                properties.newLabel = newLabel;
+                undoProperties.newLabel = label;
+            }
+
+            // parse and validate the formula expression
+            if (_.isObject(formulaDesc)) {
+                _.extend(properties, getFormulaProperties(parentModel, formulaDesc, ooxml));
+                if (!('formula' in properties)) { return SheetUtils.makeRejected('formula:invalid'); }
+
+                // add the current formula expression to the undo properties (ODF: current reference address as formula too)
+                undoProperties.formula = this.getFormula('op');
+                if (!ooxml) {
+                    undoProperties.isExpr = isComplexExpression(defTokenArray);
+                    undoProperties.ref = this.getRefFormula('op');
+                }
+            }
+
+            // nothing to do without any changed properties
+            if (_.isEmpty(properties)) { return $.when(); }
+
+            // add the label to the operation properties (use new label to address the name in undo)
+            var oldLabel = properties.label = label;
+            undoProperties.label = (newLabel === null) ? oldLabel : newLabel;
+
+            // add the sheet index to the operation properties
+            if (sheetModel) { properties.sheet = undoProperties.sheet = sheetModel.getIndex(); }
+
+            // generate the 'changeName' operation, and the undo operation
+            generator.generateOperation(Operations.CHANGE_NAME, undoProperties, { undo: true });
+            generator.generateOperation(Operations.CHANGE_NAME, properties);
+
+            // nothing more to do, if the label has not been changed
+            if (!newLabel) { return $.when(); }
+
+            // update all formula expressions in the document
+            var changeDesc = { type: 'relabelName', sheet: this.getSheetIndex(), oldLabel: oldLabel, newLabel: newLabel };
+            return docModel.generateUpdateFormulaOperations(generator, changeDesc);
+        };
+
         /**
          * Generates the operations and undo operations to update or restore
          * the formula expression of this defined name.
          *
-         * @param {SheetOperationsGenerator} generator
+         * @param {SheetOperationGenerator} generator
          *  The operations generator to be filled with the operations.
          *
          * @param {Object} changeDesc
@@ -300,20 +532,18 @@ define('io.ox/office/spreadsheet/model/namecollection', [
             var undoProperties = {};
 
             // resolve the formula expression for the definition of this name
-            var defResult = defTokenArray.resolveOperation('op', changeDesc);
-            if (defResult) {
-                properties.formula = defResult.new;
-                undoProperties.formula = defResult.old;
-            }
+            defTokenArray.resolveOperation('op', changeDesc, function (newFormula, oldFormula) {
+                properties.formula = newFormula;
+                undoProperties.formula = oldFormula;
+            });
 
             // ODF only: update the formula expression for the reference address for renamed sheets
             // TODO: move reference address to another existing sheet when deleting a sheet
             if (!ooxml && (changeDesc.type === 'renameSheet')) {
-                var refResult = refTokenArray.resolveOperation('op', changeDesc);
-                if (refResult) {
-                    properties.ref = refResult.new;
-                    undoProperties.ref = refResult.old;
-                }
+                refTokenArray.resolveOperation('op', changeDesc, function (newFormula, oldFormula) {
+                    properties.ref = newFormula;
+                    undoProperties.ref = oldFormula;
+                });
             }
 
             // generate the operation to change this name model
@@ -382,36 +612,28 @@ define('io.ox/office/spreadsheet/model/namecollection', [
      * @constructor
      *
      * @extends ModelObject
-     * @extends TimerMixin
      *
      * @param {SpreadsheetModel|SheetModel} parentModel
      *  The spreadsheet document model (for globally defined names), or the
      *  sheet model (for sheet-local names) containing this instance.
      */
-    function NameCollection(parentModel) {
-
-        // self reference
-        var self = this;
+    var NameCollection = ModelObject.extend({ constructor: function (parentModel) {
 
         // the document model
         var docModel = parentModel.getDocModel();
 
-        // the spreadsheet app
-        var app = docModel.getApp();
-
         // the sheet model, if this collection is part of a worksheet
         var sheetModel = (parentModel === docModel) ? null : parentModel;
 
         // the models of all defined names, mapped by upper-case name
-        var nameModelMap = new SimpleMap();
+        var nameModelMap = new ValueMap();
 
         // whether the current file format is OOXML
         var ooxml = docModel.getApp().isOOXML();
 
         // base constructor ---------------------------------------------------
 
-        ModelObject.call(this, parentModel.getDocModel());
-        TimerMixin.call(this);
+        ModelObject.call(this, docModel);
 
         // private methods ----------------------------------------------------
 
@@ -464,102 +686,6 @@ define('io.ox/office/spreadsheet/model/namecollection', [
             return { label: label, key: nameKey, model: nameModel };
         }
 
-        /**
-         * Validates the passed label for a defined name. Returns a rejected
-         * promise if the label is not valid.
-         *
-         * @param {String} label
-         *  The label for a defined name to be checked.
-         *
-         * @returns {jQuery.Promise|Null}
-         *  A rejected promise with a specific error code, if the label is not
-         *  valid (see method FormulaGrammar.validateNameLabel() for a list of
-         *  error codes); or the value null, if the passed label is valid.
-         */
-        function validateNameLabel(label) {
-            var labelError = docModel.getFormulaGrammar('ui').validateNameLabel(docModel, label);
-            return labelError ? SheetUtils.makeRejected(labelError) : null;
-        }
-
-        /**
-         * Returns whether the passed label exists already, either as defined
-         * name in this collection, or as name of a table range anywhere in the
-         * document.
-         *
-         * @param {String} label
-         *  The label for a defined name to be checked.
-         *
-         * @returns {Boolean}
-         *  Whether the passed label exists already.
-         */
-        function isNameLabelUsed(label) {
-            return self.hasName(label) || docModel.hasTable(label);
-        }
-
-        /**
-         * Internal helper function for the ODF file format. Returns whether
-         * the passed formula array contains a complex expression, or a simple
-         * cell reference.
-         *
-         * @param {TokenArray} tokenArray
-         *  A token array with a formula.
-         *
-         * @returns {Boolean}
-         *  Whether the passed token array represents a complex formula
-         *  expression (true), or a simple cell reference (false).
-         */
-        function isComplexExpression(tokenArray) {
-            var ranges = tokenArray.resolveRangeList();
-            return !ranges || (ranges.length !== 1);
-        }
-
-        /**
-         * Creates the operation properties for the passed formula expression,
-         * intended to be used in the document operations 'insertName', and
-         * 'changeName'. The formula expression will be checked for syntax and
-         * semantic errors, and it will be relocated for usage in document
-         * operations.
-         *
-         * @param {Object} formulaDesc
-         *  The descriptor of the formula expression. See public method
-         *  NameCollection.generateInsertNameOperations() for details about the
-         *  properties.
-         *
-         * @returns {Object|Null}
-         *  On success, an object with the property 'formula' containing the
-         *  relocated formula expression, and an optional property 'ref' with
-         *  the passed reference address (as formula expression) for ODF
-         *  documents.
-         */
-        function getFormulaProperties(formulaDesc) {
-
-            // the resulting operation properties
-            var properties = null;
-
-            // parse the formula; bug 40293: add sheet name to references without sheet (OOXML only) (TODO: sheet-local names)
-            var tokenArray = new TokenArray(parentModel, 'name');
-            tokenArray.parseFormula(formulaDesc.grammarId, formulaDesc.formula, { autoCorrect: true, refSheet: formulaDesc.refSheet, extendSheet: ooxml });
-
-            // interpret the formula to find syntax errors or semantic errors
-            var formulaResult = tokenArray.interpretFormula('any');
-            if (formulaResult.type !== 'error') {
-
-                // OOXML: relocate the formula expression from reference cell to A1
-                // ODF: leave formula expression unmodified, pass reference cell with operation
-                if (ooxml) {
-                    properties = { formula: tokenArray.getFormula('op', { refAddress: formulaDesc.refAddress, targetAdddress: Address.A1 }) };
-                } else {
-                    properties = { formula: tokenArray.getFormula('op'), isExpr: isComplexExpression(tokenArray) };
-                    // store reference cell as formula expression with sheet name
-                    tokenArray.clearTokens();
-                    tokenArray.appendRange(new Range(formulaDesc.refAddress), { sheet: formulaDesc.refSheet, abs: true });
-                    properties.ref = tokenArray.getFormula('op');
-                }
-            }
-
-            return properties;
-        }
-
         /**
          * Returns the internal contents of this collection, needed for cloning
          * into another collection.
@@ -739,19 +865,34 @@ define('io.ox/office/spreadsheet/model/namecollection', [
 
             // skip hidden names if specified
             if (Utils.getBooleanOption(options, 'skipHidden', false)) {
-                return nameModelMap.reject(function (nameModel) { return nameModel.isHidden(); });
+                return nameModelMap.reject('isHidden');
             }
 
             return nameModelMap.values();
         };
 
+        /**
+         * Returns whether the passed label exists already, either as defined
+         * name in this collection, or as name of a table range anywhere in the
+         * document.
+         *
+         * @param {String} label
+         *  The label for a defined name to be checked.
+         *
+         * @returns {Boolean}
+         *  Whether the passed label exists already.
+         */
+        this.isLabelUsed = function (label) {
+            return this.hasName(label) || docModel.hasTable(label);
+        };
+
         // operation generators -----------------------------------------------
 
         /**
          * Generates the operations, and the undo operations, to insert a new
          * defined name into this name collection.
          *
-         * @param {SheetOperationsGenerator} generator
+         * @param {SheetOperationGenerator} generator
          *  The operations generator to be filled with the operations.
          *
          * @param {String} label
@@ -789,14 +930,14 @@ define('io.ox/office/spreadsheet/model/namecollection', [
         this.generateInsertNameOperations = function (generator, label, formulaDesc) {
 
             // the label must be valid (method validateNameLabel() returns null, or a rejected promise)
-            var labelError = validateNameLabel(label);
+            var labelError = validateNameLabel(docModel, label);
             if (labelError) { return labelError; }
 
             // check that the defined name does not exist yet (check table ranges in the entire document too)
-            if (isNameLabelUsed(label)) { return SheetUtils.makeRejected('name:used'); }
+            if (this.isLabelUsed(label)) { return SheetUtils.makeRejected('name:used'); }
 
             // parse and validate the formula expression
-            var properties = getFormulaProperties(formulaDesc);
+            var properties = getFormulaProperties(parentModel, formulaDesc, ooxml);
             if (!properties) { return SheetUtils.makeRejected('formula:invalid'); }
             var undoProperties = {};
 
@@ -814,7 +955,7 @@ define('io.ox/office/spreadsheet/model/namecollection', [
          * Generates the operations, and the undo operations, to delete an
          * existing defined name from this name collection.
          *
-         * @param {SheetOperationsGenerator} generator
+         * @param {SheetOperationGenerator} generator
          *  The operations generator to be filled with the operations.
          *
          * @param {String} label
@@ -832,27 +973,8 @@ define('io.ox/office/spreadsheet/model/namecollection', [
             var nameModel = this.getName(label);
             if (!nameModel) { return SheetUtils.makeRejected('operation'); }
 
-            // the properties for the operation, and the undo operation
-            var properties = { label: label };
-            var undoProperties = {
-                label: label,
-                formula: nameModel.getFormula('op', Address.A1),
-                hidden: nameModel.isHidden()
-            };
-
-            // add special undo properties for ODF
-            if (!ooxml) {
-                undoProperties.isExpr = isComplexExpression(nameModel.getTokenArray());
-                undoProperties.ref = nameModel.getRefFormula('op');
-            }
-
-            // add the sheet index to the operation properties
-            if (sheetModel) { properties.sheet = undoProperties.sheet = sheetModel.getIndex(); }
-
             // generate the 'deleteName' operation, and the undo operation
-            generator.generateOperation(Operations.INSERT_NAME, undoProperties, { undo: true });
-            generator.generateOperation(Operations.DELETE_NAME, properties);
-            return $.when();
+            return nameModel.generateDeleteOperations(generator);
         };
 
         /**
@@ -860,7 +982,7 @@ define('io.ox/office/spreadsheet/model/namecollection', [
          * label or formula definition of an existing defined name in this name
          * collection.
          *
-         * @param {SheetOperationsGenerator} generator
+         * @param {SheetOperationGenerator} generator
          *  The operations generator to be filled with the operations.
          *
          * @param {String} label
@@ -900,85 +1022,15 @@ define('io.ox/office/spreadsheet/model/namecollection', [
             var nameModel = this.getName(label);
             if (!nameModel) { return SheetUtils.makeRejected('operation'); }
 
-            // the properties for the 'changeName' operation
-            var properties = {};
-            var undoProperties = {};
-
-            // check the passed new label (ignore unchanged existing invalid labels, e.g. from import filter)
-            newLabel = (_.isString(newLabel) && (label !== newLabel)) ? newLabel : null;
-            if (newLabel) {
-
-                // the label must be valid (method validateNameLabel() returns null, or a rejected promise)
-                var labelError = validateNameLabel(newLabel);
-                if (labelError) { return labelError; }
-
-                // new label must not exist yet in the document (but allow to change case of an existing label)
-                if ((SheetUtils.getNameKey(label) !== SheetUtils.getNameKey(newLabel)) && isNameLabelUsed(newLabel)) {
-                    return SheetUtils.makeRejected('name:used');
-                }
-
-                // add the new label to the operation properties
-                properties.newLabel = newLabel;
-                undoProperties.newLabel = label;
-            }
-
-            // parse and validate the formula expression
-            if (_.isObject(formulaDesc)) {
-                _.extend(properties, getFormulaProperties(formulaDesc));
-                if (!('formula' in properties)) { return SheetUtils.makeRejected('formula:invalid'); }
-
-                // add the current formula expression to the undo properties (ODF: current reference address as formula too)
-                undoProperties.formula = nameModel.getFormula('op');
-                if (!ooxml) {
-                    undoProperties.isExpr = isComplexExpression(nameModel.getTokenArray());
-                    undoProperties.ref = nameModel.getRefFormula('op');
-                }
-            }
-
-            // nothing to do without any changed properties
-            if (_.isEmpty(properties)) { return $.when(); }
-
-            // add the label to the operation properties (use new label to address the name in undo)
-            properties.label = label;
-            undoProperties.label = (newLabel === null) ? label : newLabel;
-
-            // add the sheet index to the operation properties
-            if (sheetModel) { properties.sheet = undoProperties.sheet = sheetModel.getIndex(); }
-
             // generate the 'changeName' operation, and the undo operation
-            generator.generateOperation(Operations.CHANGE_NAME, undoProperties, { undo: true });
-            generator.generateOperation(Operations.CHANGE_NAME, properties);
-
-            // nothing more to do, if the label has not been changed
-            if (!newLabel) { return $.when(); }
-
-            // the change descriptor to be passed to the generator methods of the collections
-            var changeDesc = { type: 'relabelName', sheet: sheetModel ? sheetModel.getIndex() : null, oldLabel: label, newLabel: newLabel };
-
-            // update the formulas of all globally defined names
-            var promise = docModel.getNameCollection().generateUpdateFormulaOperations(generator, changeDesc);
-
-            // update the formula expressions for all sheet collections in the document
-            promise = promise.then(function () {
-                return docModel.generateOperationsForAllSheets(generator, function (sheetModel) {
-                    return Utils.invokeChainedAsync(
-                        function () { return sheetModel.getCellCollection().generateUpdateFormulaOperations(generator, changeDesc); },
-                        function () { return sheetModel.getNameCollection().generateUpdateFormulaOperations(generator, changeDesc); },
-                        function () { return sheetModel.getValidationCollection().generateUpdateFormulaOperations(generator, changeDesc); },
-                        function () { return sheetModel.getCondFormatCollection().generateUpdateFormulaOperations(generator, changeDesc); },
-                        function () { return sheetModel.getDrawingCollection().generateUpdateFormulaOperations(generator, changeDesc); }
-                    );
-                });
-            });
-
-            return promise;
+            return nameModel.generateChangeOperations(generator, newLabel, formulaDesc);
         };
 
         /**
          * Generates the operations and undo operations to update or restore
          * the formula expressions of the defined names in this collection.
          *
-         * @param {SheetOperationsGenerator} generator
+         * @param {SheetOperationGenerator} generator
          *  The operations generator to be filled with the operations.
          *
          * @param {Object} changeDesc
@@ -994,7 +1046,7 @@ define('io.ox/office/spreadsheet/model/namecollection', [
         this.generateUpdateFormulaOperations = function (generator, changeDesc) {
             return this.iterateSliced(nameModelMap.iterator(), function (nameModel) {
                 nameModel.generateUpdateFormulaOperations(generator, changeDesc);
-            }, { delay: 'immediate', infoString: 'NameCollection: generateFormulaOperations', app: app });
+            }, 'NameCollection.generateFormulaOperations');
         };
 
         // initialization -----------------------------------------------------
@@ -1020,15 +1072,14 @@ define('io.ox/office/spreadsheet/model/namecollection', [
 
         // destroy all class members on destruction
         this.registerDestructor(function () {
-            nameModelMap.forEach(function (nameModel) { nameModel.destroy(); });
-            self = parentModel = docModel = sheetModel = nameModelMap = app = null;
+            nameModelMap.forEach('destroy').clear();
+            parentModel = docModel = sheetModel = nameModelMap = null;
         });
 
-    } // class NameCollection
+    } }); // class NameCollection
 
     // exports ================================================================
 
-    // derive this class from class ModelObject
-    return ModelObject.extend({ constructor: NameCollection });
+    return NameCollection;
 
 });
