@@ -14,7 +14,7 @@
 
 define.async('io.ox/office/spreadsheet/model/numberformatter', [
     'io.ox/office/tk/utils',
-    'io.ox/office/tk/container/simplemap',
+    'io.ox/office/tk/container/valuemap',
     'io.ox/office/tk/locale/localedata',
     'io.ox/office/tk/locale/parser',
     'io.ox/office/tk/locale/formatter',
@@ -23,7 +23,7 @@ define.async('io.ox/office/spreadsheet/model/numberformatter', [
     'io.ox/office/spreadsheet/utils/sheetutils',
     'io.ox/office/spreadsheet/model/presetformattable',
     'io.ox/office/spreadsheet/model/formula/formulautils'
-], function (Utils, SimpleMap, LocaleData, Parser, Formatter, AppObjectMixin, Operations, SheetUtils, PresetFormatTable, FormulaUtils) {
+], function (Utils, ValueMap, LocaleData, Parser, Formatter, AppObjectMixin, Operations, SheetUtils, PresetFormatTable, FormulaUtils) {
 
     'use strict';
 
@@ -186,16 +186,16 @@ define.async('io.ox/office/spreadsheet/model/numberformatter', [
         var presetTable = PresetFormatTable.create(LocaleData.LOCALE);
 
         // the user-defined format codes, and the overridden preset codes, mapped by identifiers
-        var formatTable = new SimpleMap();
+        var formatTable = new ValueMap();
 
         // the number format identifiers, mapped by format codes
-        var reverseTable = new SimpleMap();
+        var reverseTable = new ValueMap();
 
         // the first unused number format identifier (as used in OOXML)
         var firstFreeId = PresetFormatTable.FIRST_USER_FORMAT_ID;
 
         // predefined number formats, as arrays mapped by categories
-        var predefFormatsMap = new SimpleMap();
+        var predefFormatsMap = new ValueMap();
 
         // the format code of the standard number format
         var standardCode = presetTable.getFormatCode(PresetFormatTable.GENERAL_ID);
@@ -205,7 +205,7 @@ define.async('io.ox/office/spreadsheet/model/numberformatter', [
 
         // base constructors --------------------------------------------------
 
-        Formatter.call(this, {
+        Formatter.call(this, docModel, {
             nullDate: Date.UTC(1899, 11, 30),
             negativeDates: fileFormat === 'odf',
             leapYearBug: fileFormat === 'ooxml',
@@ -1001,9 +1001,10 @@ define.async('io.ox/office/spreadsheet/model/numberformatter', [
         this.convertScalarToNumber = function (value, floor) {
 
             // convert strings and booleans to numbers
-            if (_.isString(value)) {
+            var type = typeof value;
+            if (type === 'string') {
                 value = this.parseValue(value);
-            } else if (_.isBoolean(value)) {
+            } else if (type === 'boolean') {
                 value = value ? 1 : 0;
             } else if (value instanceof Date) {
                 value = this.convertDateToNumber(value); // returns null for invalid dates
@@ -1012,7 +1013,7 @@ define.async('io.ox/office/spreadsheet/model/numberformatter', [
             }
 
             // the resulting value must be a finite floating-point number
-            return ((typeof value === 'number') && isFinite(value)) ? (floor ? Math.floor(value) : value) : null;
+            return Utils.isFiniteNumber(value) ? (floor ? Math.floor(value) : value) : null;
         };
 
         /**
@@ -1082,9 +1083,9 @@ define.async('io.ox/office/spreadsheet/model/numberformatter', [
             }
 
             // convert numbers and booleans to strings
-            if ((typeof value === 'number') && isFinite(value)) {
+            if (Utils.isFiniteNumber(value)) {
                 value = this.formatStandardNumber(value, maxLength);
-            } else if (_.isBoolean(value)) {
+            } else if (typeof value === 'boolean') {
                 value = formulaGrammar.getBooleanName(value); // always localized
             } else if (value === null) {
                 value = '';
@@ -1121,9 +1122,9 @@ define.async('io.ox/office/spreadsheet/model/numberformatter', [
             }
 
             // convert numbers and strings to booleans
-            if ((typeof value === 'number') && isFinite(value)) {
+            if (Utils.isFiniteNumber(value)) {
                 value = !isZero(value);
-            } else if (_.isString(value)) {
+            } else if (typeof value === 'string') {
                 // always localized, returns null on failure
                 value = formulaGrammar.getBooleanValue(value);
             } else if (value === null) {
@@ -1142,7 +1143,7 @@ define.async('io.ox/office/spreadsheet/model/numberformatter', [
          * generated that defines a new user-defined number format, according
          * to the current file format.
          *
-         * @param {SheetOperationsGenerator} generator
+         * @param {SheetOperationGenerator} generator
          *  The operations generator to be filled with the operation.
          *
          * @param {Number|String} format
@@ -1329,8 +1330,11 @@ define.async('io.ox/office/spreadsheet/model/numberformatter', [
 
         // destroy all class members on destruction
         this.registerDestructor(function () {
+            formatTable.clear();
+            reverseTable.clear();
+            predefFormatsMap.clear();
             self = docModel = formulaGrammar = null;
-            presetTable = formatTable = reverseTable = null;
+            presetTable = formatTable = reverseTable = predefFormatsMap = null;
         });
 
     } }); // class NumberFormatter
