@@ -14,9 +14,9 @@
 
 define('io.ox/office/spreadsheet/model/presetformattable', [
     'io.ox/office/tk/utils',
-    'io.ox/office/tk/container/simplemap',
+    'io.ox/office/tk/container/valuemap',
     'io.ox/office/tk/locale/localedata'
-], function (Utils, SimpleMap, LocaleData) {
+], function (Utils, ValueMap, LocaleData) {
 
     'use strict';
 
@@ -432,7 +432,7 @@ define('io.ox/office/spreadsheet/model/presetformattable', [
         this._lcData = LocaleData.get(localeId);
         this._baseEntries = null;
         this._formatCodes = null;
-        this._invMap = new SimpleMap();
+        this._invMap = new ValueMap();
 
         // initialization -----------------------------------------------------
 
