@@ -13,15 +13,14 @@
  */
 
 define('io.ox/office/spreadsheet/model/validationcollection', [
-    'io.ox/office/tk/container/simplemap',
+    'io.ox/office/tk/container/valuemap',
     'io.ox/office/tk/container/typedarray',
-    'io.ox/office/tk/object/timermixin',
     'io.ox/office/baseframework/model/modelobject',
     'io.ox/office/editframework/model/attributedmodel',
     'io.ox/office/spreadsheet/utils/operations',
     'io.ox/office/spreadsheet/utils/sheetutils',
     'io.ox/office/spreadsheet/model/formula/tokenarray'
-], function (SimpleMap, TypedArray, TimerMixin, ModelObject, AttributedModel, Operations, SheetUtils, TokenArray) {
+], function (ValueMap, TypedArray, ModelObject, AttributedModel, Operations, SheetUtils, TokenArray) {
 
     'use strict';
 
@@ -90,7 +89,7 @@ define('io.ox/office/spreadsheet/model/validationcollection', [
         var refAddress = null;
 
         // the token arrays representing the validation attributes 'value1' and 'value2'
-        var tokenArrayMap = new SimpleMap();
+        var tokenArrayMap = new ValueMap();
 
         // base constructor ---------------------------------------------------
 
@@ -277,7 +276,7 @@ define('io.ox/office/spreadsheet/model/validationcollection', [
          * Generates the operations and undo operations to update or restore
          * the formula expressions of this data validation model.
          *
-         * @param {SheetOperationsGenerator} generator
+         * @param {SheetOperationGenerator} generator
          *  The operations generator to be filled with the operations.
          *
          * @param {Number} index
@@ -327,11 +326,10 @@ define('io.ox/office/spreadsheet/model/validationcollection', [
 
             // calculate the new formula expressions for the validation model
             tokenArrayMap.forEach(function (tokenArray, propName) {
-                var result = tokenArray.resolveOperation('op', changeDesc);
-                if (result) {
-                    properties[propName] = result.new;
-                    undoProperties[propName] = result.old;
-                }
+                tokenArray.resolveOperation('op', changeDesc, function (newFormula, oldFormula) {
+                    properties[propName] = newFormula;
+                    undoProperties[propName] = oldFormula;
+                });
             });
 
             // generate the change operation with the new formula expressions
@@ -368,6 +366,7 @@ define('io.ox/office/spreadsheet/model/validationcollection', [
 
         // destroy all class members
         this.registerDestructor(function () {
+            tokenArrayMap.clear();
             self = docModel = sheetModel = tokenArrayMap = null;
         });
 
@@ -387,18 +386,15 @@ define('io.ox/office/spreadsheet/model/validationcollection', [
      * @constructor
      *
      * @extends ModelObject
-     * @extends TimerMixin
      *
      * @param {SheetModel} sheetModel
      *  The sheet model instance containing this collection.
      */
-    function ValidationCollection(sheetModel) {
+    var ValidationCollection = ModelObject.extend({ constructor: function (sheetModel) {
 
         // the spreadsheet document model
         var docModel = sheetModel.getDocModel();
 
-        var app = docModel.getApp();
-
         // all model instances with validation settings, as array (in operation order)
         var valModels = new ValidationModelArray();
 
@@ -408,7 +404,6 @@ define('io.ox/office/spreadsheet/model/validationcollection', [
         // base constructor ---------------------------------------------------
 
         ModelObject.call(this, docModel);
-        TimerMixin.call(this);
 
         // private methods ----------------------------------------------------
 
@@ -707,7 +702,7 @@ define('io.ox/office/spreadsheet/model/validationcollection', [
          * Generates the operations and undo operations to update or restore
          * the formula expressions of the data validations in this collection.
          *
-         * @param {SheetOperationsGenerator} generator
+         * @param {SheetOperationGenerator} generator
          *  The operations generator to be filled with the operations.
          *
          * @param {Object} changeDesc
@@ -723,7 +718,7 @@ define('io.ox/office/spreadsheet/model/validationcollection', [
         this.generateUpdateFormulaOperations = function (generator, changeDesc) {
             return this.iterateArraySliced(valModels, function (valModel, index) {
                 valModel.generateUpdateFormulaOperations(generator, index, changeDesc);
-            }, { delay: 'immediate', infoString: 'ValidationCollection: generateFormulaOperations', app: app });
+            }, 'ValidationCollection.generateFormulaOperations');
         };
 
         // initialization -----------------------------------------------------
@@ -756,11 +751,10 @@ define('io.ox/office/spreadsheet/model/validationcollection', [
             docModel = sheetModel = valModels = targetRangeSet = null;
         });
 
-    } // class ValidationCollection
+    } }); // class ValidationCollection
 
     // exports ================================================================
 
-    // derive this class from class ModelObject
-    return ModelObject.extend({ constructor: ValidationCollection });
+    return ValidationCollection;
 
 });
