@@ -13,8 +13,10 @@
  */
 
 define('io.ox/office/spreadsheet/utils/address', [
-    'io.ox/office/tk/utils'
-], function (Utils) {
+    'io.ox/office/tk/utils',
+    'io.ox/office/tk/locale/parser',
+    'io.ox/office/tk/locale/formatter'
+], function (Utils, Parser, Formatter) {
 
     'use strict';
 
@@ -30,9 +32,6 @@ define('io.ox/office/spreadsheet/utils/address', [
     // regular expression pattern matching a row name (1 to 99,999,999)
     var ROW_PATTERN = '0*[1-9][0-9]{0,7}';
 
-    // regular expression object matching a column name only
-    var RE_COL_NAME = new RegExp('^' + COL_PATTERN + '$', 'i');
-
     // regular expression object matching a row name only
     var RE_ROW_NAME = new RegExp('^' + ROW_PATTERN + '$');
 
@@ -112,11 +111,7 @@ define('io.ox/office/spreadsheet/utils/address', [
      *  The upper-case string representation of the column index.
      */
     Address.stringifyCol = function (col) {
-        var name = '';
-        for (; col >= 0; col = Math.floor(col / 26) - 1) {
-            name = String.fromCharCode(65 + col % 26) + name;
-        }
-        return name;
+        return Formatter.formatAlphabetic(col + 1, 'digit');
     };
 
     /**
@@ -164,13 +159,7 @@ define('io.ox/office/spreadsheet/utils/address', [
      *  the value -1.
      */
     Address.parseCol = function (str, max) {
-        var col = -1;
-        if (RE_COL_NAME.test(str)) {
-            str = str.toUpperCase();
-            for (var ichar = 0; ichar < str.length; ichar += 1) {
-                col = (col + 1) * 26 + str.charCodeAt(ichar) - 65;
-            }
-        }
+        var col = (Parser.parseAlphabetic(str, 'digit') || 0) - 1;
         return ((typeof max === 'number') ? (col <= max) : (col < MAX_COL_COUNT)) ? col : -1;
     };
 
@@ -386,8 +375,8 @@ define('io.ox/office/spreadsheet/utils/address', [
     };
 
     /**
-     * Sets contents of this cell address to the contents of the passed cell
-     * address.
+     * Sets the contents of this cell address to the contents of the passed
+     * cell address.
      *
      * @param {Address} address
      *  The cell address to be copied into this cell address.
