@@ -14,20 +14,33 @@
 
 define('io.ox/office/spreadsheet/utils/addressset', [
     'io.ox/office/tk/utils/iteratorutils',
-    'io.ox/office/tk/container/basemap',
+    'io.ox/office/tk/container/valueset',
     'io.ox/office/tk/container/sortedarray',
     'io.ox/office/spreadsheet/utils/interval',
     'io.ox/office/spreadsheet/utils/range',
     'io.ox/office/spreadsheet/utils/addressarray'
-], function (IteratorUtils, BaseMap, SortedArray, Interval, Range, AddressArray) {
+], function (IteratorUtils, ValueSet, SortedArray, Interval, Range, AddressArray) {
 
     'use strict';
 
     // convenience shortcuts
-    var MapProto = BaseMap.prototype;
+    var SetProto = ValueSet.prototype;
 
     // private global functions ===============================================
 
+    /**
+     * Returns the key of the passed cell address.
+     *
+     * @param {Address} address
+     *  A cell address.
+     *
+     * @returns {String}
+     *  The key of the passed cell address.
+     */
+    function getKey(address) {
+        return address.key();
+    }
+
     function colVectorSorter(vector) {
         return vector.first()[0];
     }
@@ -174,12 +187,12 @@ define('io.ox/office/spreadsheet/utils/addressset', [
      *
      * @constructor
      *
-     * @extends BaseMap
+     * @extends ValueSet
      */
-    var AddressSet = BaseMap.extend({ constructor: function () {
+    var AddressSet = ValueSet.extend({ constructor: function () {
 
-        // base constructor (stores all addresses by their keys, for fast direct access)
-        BaseMap.call(this);
+        // base constructor
+        ValueSet.call(this, getKey);
 
         // the address matrix containing column vectors
         this._colMatrix = new AddressMatrix(true);
@@ -197,7 +210,7 @@ define('io.ox/office/spreadsheet/utils/addressset', [
      *  A reference to this instance.
      */
     AddressSet.prototype.clear = function () {
-        MapProto.clear.call(this);
+        SetProto.clear.call(this);
         this._colMatrix.clear();
         this._rowMatrix.clear();
         return this;
@@ -220,13 +233,13 @@ define('io.ox/office/spreadsheet/utils/addressset', [
      * Returns a shallow or deep clone of this address set.
      *
      * @param {Boolean|Function} [deep=false]
-     *  If set to true or to a function, a deep clone will be created (all
+     *  If set to true or to a function, a deep clone will be created (the cell
      *  addresses in this set will be cloned); otherwise a shallow clone will
-     *  be created (the addresses in this set will be inserted by reference
+     *  be created (the cell addresses in this set will be copied by reference
      *  into the clone). If a function has been passed, it will be invoked for
-     *  each cloned cell address, receiving the new cloned cell address
-     *  inserted into the cloned set as first parameter, and the old cell
-     *  address of this set as second parameter.
+     *  each cloned cell address, receiving the new cloned cell address that
+     *  will be inserted into the cloned set as first parameter, and the old
+     *  cell address from this set as second parameter.
      *
      * @param {Object} [context]
      *  The calling context used if the 'deep' parameter is a callback.
@@ -238,40 +251,24 @@ define('io.ox/office/spreadsheet/utils/addressset', [
 
         // start with a new empty address set
         var clone = new AddressSet();
-        // user callback for deep mode
-        var callback = _.isFunction(deep) ? deep : _.noop;
 
-        // create a shallow or deep clone of the map
-        MapProto._init.call(clone, this, deep ? function (oldAddress) {
-            var newAddress = oldAddress.clone();
-            callback.call(context, newAddress, oldAddress);
-            return newAddress;
-        } : null);
-
-        // copy the new (cloned) addresses from the map into the matrixes
-        MapProto.forEach.call(clone, function (address) {
-            clone._colMatrix.insert(address, true);
-            clone._rowMatrix.insert(address, true);
-        });
+        // create a shallow or deep clone of the set
+        if (deep) {
+            var callback = (typeof deep === 'function') ? deep : _.noop;
+            this.forEach(function (oldAddress) {
+                var newAddress = oldAddress.clone();
+                callback.call(context, newAddress, oldAddress);
+                clone.insert(newAddress, true);
+            });
+        } else {
+            this.forEach(function (address) {
+                clone.insert(address, true);
+            });
+        }
 
         return clone;
     };
 
-    /**
-     * Returns whether this set contains a cell address that has the same
-     * position as the passed address.
-     *
-     * @param {Address} address
-     *  A cell address to check.
-     *
-     * @returns {Boolean}
-     *  Whether this set contains a cell address that has the same position as
-     *  the passed address.
-     */
-    AddressSet.prototype.has = function (address) {
-        return MapProto.has.call(this, address.key());
-    };
-
     /**
      * Returns the cell address from this set that has the exact position of
      * the passed address.
@@ -284,7 +281,7 @@ define('io.ox/office/spreadsheet/utils/addressset', [
      *  address; otherwise null.
      */
     AddressSet.prototype.get = function (address) {
-        return MapProto.get.call(this, address.key(), null);
+        return this._get(address.key()) || null;
     };
 
     /**
@@ -424,7 +421,7 @@ define('io.ox/office/spreadsheet/utils/addressset', [
     AddressSet.prototype.insert = function (address, replace) {
         this._colMatrix.insert(address, replace);
         address = this._rowMatrix.insert(address, replace);
-        return MapProto.insert.call(this, address.key(), address);
+        return this._insert(address.key(), address);
     };
 
     /**
@@ -438,8 +435,10 @@ define('io.ox/office/spreadsheet/utils/addressset', [
      *  contain a cell address that is equal to the passed cell address.
      */
     AddressSet.prototype.remove = function (address) {
-        address = MapProto.remove.call(this, address.key(), null);
+        var key = address.key();
+        address = this._get(key);
         if (!address) { return null; }
+        this._remove(key);
         this._colMatrix.remove(address);
         this._rowMatrix.remove(address);
         return address;
@@ -448,19 +447,20 @@ define('io.ox/office/spreadsheet/utils/addressset', [
     /**
      * Inserts all cell addresses of the passed set into this set.
      *
-     * @param {AddressSet} addressSet
-     *  The address set to be merged into this address set.
+     * @param {Object} list
+     *  A generic data source with cell addresses as elements. See static
+     *  method Container.forEach() for details.
      *
      * @param {Boolean} [replace=false]
-     *  If set to true, cell addresses in the passed address set will replace
-     *  equal cell addresses in this set. By default, the existing cell
-     *  addresses of this set will be preferred.
+     *  If set to true, cell addresses in the passed list will replace equal
+     *  cell addresses in this set. By default, the existing cell addresses of
+     *  this set will be preferred.
      *
      * @returns {AddressSet}
      *  A reference to this instance.
      */
-    AddressSet.prototype.merge = function (addressSet, replace) {
-        addressSet.forEach(function (address) { this.insert(address, replace); }, this);
+    AddressSet.prototype.merge = function (list, replace) {
+        ValueSet.forEach(list, function (address) { this.insert(address, replace); }, this);
         return this;
     };
 
