@@ -15,12 +15,13 @@ define('io.ox/office/spreadsheet/utils/clipboard', [
     'io.ox/office/tk/io',
     'io.ox/office/tk/utils',
     'io.ox/office/tk/utils/iteratorutils',
+    'io.ox/office/tk/render/rectangle',
     'io.ox/office/tk/locale/parser',
     'io.ox/office/editframework/utils/color',
     'io.ox/office/editframework/utils/hyperlinkutils',
     'io.ox/office/spreadsheet/utils/sheetutils',
     'io.ox/office/spreadsheet/model/formula/tokenarray'
-], function (IO, Utils, IteratorUtils, Parser, Color, HyperlinkUtils, SheetUtils, TokenArray) {
+], function (IO, Utils, IteratorUtils, Rectangle, Parser, Color, HyperlinkUtils, SheetUtils, TokenArray) {
 
     'use strict';
 
@@ -53,7 +54,7 @@ define('io.ox/office/spreadsheet/utils/clipboard', [
 
         // regex to check for invalid XML characters; for UTF-16 the high surrogate and the low surrogate need to match.
         INVALID_XML_CHARS_PATTERN = // UTF-8:
-                                    '[\\u0000-\\u0008\\u000B-\\u000C\\u000E-\\u001F\\u007F-\\u0084\\u0086-\\u009F\\uFDD0-\\uFDDF]|' +
+                                    '[\\x00-\\x08\\x0B-\\x0C\\x0E-\\x1F\\x7F-\\x84\\x86-\\x9F\\uFDD0-\\uFDDF]|' +
                                     // UTF-16:
                                     // [#x1FFFE-#x1FFFF], [#x2FFFE-#x2FFFF], [#x3FFFE-#x3FFFF],
                                     '\\uD83F[\\uDFFE-\\uDFFF]|\\uD87F[\\uDFFE-\\uDFFF]|\\uD8BF[\\uDFFE-\\uDFFF]|' +
@@ -686,7 +687,7 @@ define('io.ox/office/spreadsheet/utils/clipboard', [
 
     function extractElementAttributes(docModel, attrData, element) {
 
-        docModel.extendAttributes(attrData.attrs, {
+        docModel.getCellAttributePool().extendAttributeSet(attrData.attrs, {
             character: getCharAttributes(element),
             cell: getCellAttributes(element)
         });
@@ -700,18 +701,18 @@ define('io.ox/office/spreadsheet/utils/clipboard', [
      * describing the position of the drawing object relative to the bounding
      * rectangle containing all drawing objects copied to the clipboard.
      */
-    function createDataNodeFor(drawingModel, rectangle, boundRectangle, modelData) {
+    function createDataNodeFor(drawingModel, rectangle, boundRect, modelData) {
 
         // the data node to be returned
         var dataNode = $('<div data-type="' + drawingModel.getType() + '">');
 
         // adjust rectangle relative to bounding rectangle, and the explicit attributes
         dataNode.attr({
-            'data-left': rectangle.left - boundRectangle.left,
-            'data-top': rectangle.top - boundRectangle.top,
+            'data-left': rectangle.left - boundRect.left,
+            'data-top': rectangle.top - boundRect.top,
             'data-width': rectangle.width,
             'data-height': rectangle.height,
-            'data-attrs': JSON.stringify(drawingModel.getExplicitAttributeSet())
+            'data-attrs': JSON.stringify(drawingModel.getExplicitAttributeSet(true))
         });
 
         // add passed custom JSON data
@@ -740,7 +741,7 @@ define('io.ox/office/spreadsheet/utils/clipboard', [
             imageUrl = imageAttr.imageData;
         } else if (imageAttr.imageUrl) {
 
-            if (/^(http:\/\/|ftp:)/.test(imageAttr.imageUrl)) {
+            if (/^(https?:\/\/|s?ftps?:)/.test(imageAttr.imageUrl)) {
                 imageUrl = imageAttr.imageUrl;
             } else {
                 var canvas = document.createElement('canvas'),
@@ -791,10 +792,10 @@ define('io.ox/office/spreadsheet/utils/clipboard', [
      * Creates a HTML node, containing the data, necessary to
      * reconstruct an image object later in time (e.g. at paste)
      */
-    function createDataNodeForImage(app, imageModel, rectangle, boundRectangle) {
+    function createDataNodeForImage(app, imageModel, rectangle, boundRect) {
 
         // create the DOM node representing the image object
-        var dataNode = createDataNodeFor(imageModel, rectangle, boundRectangle),
+        var dataNode = createDataNodeFor(imageModel, rectangle, boundRect),
             imageNode = $('<img>'),
             mergedAttr = imageModel.getMergedAttributeSet(true),
             lineStyle = getImageLineStyle(app, mergedAttr);
@@ -817,7 +818,9 @@ define('io.ox/office/spreadsheet/utils/clipboard', [
     /**
      *
      */
-    function createDataNodeForChart(chartModel, rectangle, boundRectangle) {
+    function createDataNodeForChart(chartModel, rectangle, boundRect) {
+
+        if (!chartModel.isSupported()) { return null; }
 
         // the JSON data to be transported in the DOM node
         var chartData = {
@@ -825,7 +828,7 @@ define('io.ox/office/spreadsheet/utils/clipboard', [
         };
 
         // create the DOM node representing the chart object
-        var dataNode = createDataNodeFor(chartModel, rectangle, boundRectangle, chartData);
+        var dataNode = createDataNodeFor(chartModel, rectangle, boundRect, chartData);
 
         // try to create a replacement image that will be used when pasting into other documents
         dataNode.append(chartModel.getReplacementNode({ mimeType: 'image/png' }));
@@ -852,28 +855,28 @@ define('io.ox/office/spreadsheet/utils/clipboard', [
      */
     Clipboard.convertDrawingModels = function (app, drawingModels) {
 
-        var // the positions of all drawing objects
-            rectangles = _.invoke(drawingModels, 'getRectangle'),
-            // the bounding rectangle of all drawings for the top-left position
-            boundRectangle = Utils.getBoundingRectangle(rectangles),
-            // the resulting container up for all drawing obejcts
-            containerNode = $('<div>');
+        // the positions of all drawing objects
+        var rectangles = drawingModels.map(function (drawingModel) { return drawingModel.getRectangle(); });
+        // the bounding rectangle of all drawings for the top-left position
+        var boundRect = rectangles.reduce(function (boundRect, rect) { return boundRect ? boundRect.boundary(rect) : rect; }, null);
+        // the resulting container up for all drawing obejcts
+        var containerNode = $('<div>');
 
         // process all drawing models
         drawingModels.forEach(function (drawingModel, index) {
 
-            var // the location of the drawing object (already calculated above)
-                rectangle = rectangles[index],
-                // the resulting data node
-                dataNode = null;
+            // the location of the drawing object (already calculated above)
+            var rectangle = rectangles[index];
+            // the resulting data node
+            var dataNode = null;
 
             // generate the DOM representation of the drawing model
             switch (drawingModel.getType()) {
                 case 'image':
-                    dataNode = createDataNodeForImage(app, drawingModel, rectangle, boundRectangle);
+                    dataNode = createDataNodeForImage(app, drawingModel, rectangle, boundRect);
                     break;
                 case 'chart':
-                    dataNode = createDataNodeForChart(drawingModel, rectangle, boundRectangle);
+                    dataNode = createDataNodeForChart(drawingModel, rectangle, boundRect);
                     break;
             }
 
@@ -1271,6 +1274,8 @@ define('io.ox/office/spreadsheet/utils/clipboard', [
 
         var // the document model
             docModel = docView.getDocModel(),
+            // the attribute pool to be used for cell attributes
+            attributePool = docModel.getCellAttributePool(),
             // a two dimensional array containing the cell contents
             contents = [],
             // an array of ranges of merged cells
@@ -1279,10 +1284,6 @@ define('io.ox/office/spreadsheet/utils/clipboard', [
             rows,
             // the number of columns
             colCount,
-            // a token array used to parse formula expressions
-            tokenArray = new TokenArray(docView.getSheetModel(), 'cell'),
-            // start address of the active range in the selection
-            targetStart = docView.getSelection().activeRange().start,
             // start address of the clipboard range
             sourceStart = null,
             sourceRange = null,
@@ -1291,8 +1292,6 @@ define('io.ox/office/spreadsheet/utils/clipboard', [
             sameDoc = false,
             // copy from (other) ox-spreadsheet
             intern = false,
-            // stores the last forumla
-            lastFormula = null,
             // stores all found merged ranges
             foundMergedRanges = {},
             // whether it is a cut-event (or a copy)
@@ -1330,7 +1329,7 @@ define('io.ox/office/spreadsheet/utils/clipboard', [
         }
 
         // the default character and cell attributes for the table
-        var tableAttrData = { attrs: docModel.getDefaultAttributeSet(['character', 'cell']), format: null, lcid: null };
+        var tableAttrData = { attrs: attributePool.getDefaultValueSet(['character', 'cell']), format: null, lcid: null };
         delete tableAttrData.attrs.cell.formatId;
         delete tableAttrData.attrs.cell.formatCode;
 
@@ -1358,7 +1357,12 @@ define('io.ox/office/spreadsheet/utils/clipboard', [
         // make sure that table header, body and footer are in the correct order
         rows = _.union(table.find('thead tr').get(), table.find('tbody tr').get(), table.find('tfoot tr').get());
 
-        colCount = _.max(_.map(rows, function (row) { return $(row).find('td,th').length; }));
+        colCount = _.max(_.map(rows, function (row) {
+            var sum = _.reduce($(row).find('td,th'), function (memo, cell) {
+                return memo + (($(cell).attr('colspan')) ? (parseInt($(cell).attr('colspan'), 10) - 1) : 0);
+            }, 0);
+            return ($(row).find('td,th').length + sum);
+        }));
 
         _.each(rows, function (row, rowId) {
 
@@ -1372,7 +1376,8 @@ define('io.ox/office/spreadsheet/utils/clipboard', [
                 colspan,
                 rowspan,
                 isMergedCell,
-                linkChild;
+                linkChild,
+                lastAttributes;
 
             row = $(row);
 
@@ -1386,11 +1391,11 @@ define('io.ox/office/spreadsheet/utils/clipboard', [
 
                 isMergedCell = mergedRanges.containsAddress(address);
 
+                cellData.v = cellData.f = null;
+
                 // nothing to do, if the cell is part of a merged collection, but not the reference cell
                 if (!isMergedCell || foundMergedRanges['col' + colId + '_row' + rowId]) {
 
-                    cellData.v = cellData.f = null;
-
                     // the cell is not merged or it is the reference cell
                     cell = $(cells.get(cellId));
                     colspan = cell.attr('colspan');
@@ -1440,14 +1445,7 @@ define('io.ox/office/spreadsheet/utils/clipboard', [
                         oxCellData = isMergedCell ? oxCellData : JSON.parse(oxCellData);
 
                         if (oxCellData.formula) {
-                            tokenArray.parseFormula('op:ooxml', oxCellData.formula, { refAddress: sourceStart });
-                            //internal clipboard
-                            if (cut) {
-                                cellData.f = tokenArray.getFormula('op');
-                            } else {
-                                cellData.f = tokenArray.getFormula('op', { refAddress: sourceStart, targetAddress: targetStart });
-                            }
-                            lastFormula = cellData.f;
+                            cellData.f = oxCellData.formula;
                         }
 
                         cellData.v = oxCellData ? oxCellData.value : null;
@@ -1464,7 +1462,7 @@ define('io.ox/office/spreadsheet/utils/clipboard', [
                         } else {
                             cellAttrData = _.copy(tableAttrData, true);
                             cellData.a = cellAttrData.attrs ? cellAttrData.attrs : {};
-                            docModel.extendAttributes(cellData.a, oxCellData.attributes);
+                            attributePool.extendAttributeSet(cellData.a, oxCellData.attributes);
                             cellData.s = ''; //set to empty string to overwrite old styleId with <Default>-StyleId
                         }
 
@@ -1492,7 +1490,7 @@ define('io.ox/office/spreadsheet/utils/clipboard', [
                     // merge in the hyperlink's character attributes that are attached to it's child span
                     linkChild = findMatchingChild(cell, 'a').children('span').first();
                     if (linkChild.length > 0) {
-                        docModel.extendAttributes(cellAttrData.attrs, { character: getCharAttributes(linkChild) });
+                        attributePool.extendAttributeSet(cellAttrData.attrs, { character: getCharAttributes(linkChild) });
                     }
 
                     if (!isMergedCell) { cellId++; }
@@ -1500,27 +1498,23 @@ define('io.ox/office/spreadsheet/utils/clipboard', [
 
                 // add the cell information to the cell contents object
                 if (cellAttrData) {
-                    if (cellAttrData.attrs) { cellData.a = cellAttrData.attrs; }
+                    if (cellAttrData.attrs) {
+                        cellData.a = cellAttrData.attrs;
+                        lastAttributes = cellAttrData.attrs; // save "last" cell-attributes for following merged cells
+                    }
                     if ('format' in cellAttrData) { cellData.format = cellAttrData.format; }
                     if ('lcid' in cellAttrData) { cellData.lcid = cellAttrData.lcid; }
                 }
 
+                // set styles for merged cells
+                if (isMergedCell && lastAttributes) {   cellData.a = lastAttributes;    }
+
                 rowData.c.push(cellData);
             }
 
             contents.push(rowData);
         });
 
-        if (lastFormula && contents.length === 1) {
-            var firstRow = contents[0];
-            if (firstRow.length === 1) {
-                tokenArray.parseFormula('ui', lastFormula.substr(1), { refAddress: targetStart });
-                var result = tokenArray.interpretFormula('val', { refAddress: targetStart, targetAddress: targetStart });
-                firstRow[0].value = result.value;
-                // TODO: handle fatal errors of interpreter, remove formula from cell data
-            }
-        }
-
         var condFormats = (function () {
             var condFormatsStr = intern ? table.attr('data-ox-cond-formats') : null;
             if ((typeof condFormatsStr === 'string') && condFormatsStr) {
@@ -1534,27 +1528,18 @@ define('io.ox/office/spreadsheet/utils/clipboard', [
             return [];
         }());
 
-        condFormats = condFormats.filter(function (condFormat) {
-
+        condFormats.forEach(function (condFormat) {
             // parse the JSON data to a range array
-            if (!_.isObject(condFormat)) { return false; }
-            var ranges = docModel.createRangeArray(condFormat.ranges);
-            if (!ranges) { return false; }
-
-            if (condFormat.attrs && condFormat.attrs.attrs && condFormat.attrs.attrs.styleId) {
-                if (docModel.getApp().isOOXML() || !sameDoc) {
-                    delete condFormat.attrs.attrs.styleId;
-                } else {
-                    // set the style Id if it is the copy document and if it is not OOXML
-                    condFormat.attrs.attrs = { styleId: condFormat.attrs.attrs.styleId };
+            if (_.isObject(condFormat)) {
+                if (condFormat.attrs && condFormat.attrs.attrs && condFormat.attrs.attrs.styleId) {
+                    if (docModel.getApp().isOOXML() || !sameDoc) {
+                        delete condFormat.attrs.attrs.styleId;
+                    } else {
+                        // set the style Id if it is the copy document and if it is not OOXML
+                        condFormat.attrs.attrs = { styleId: condFormat.attrs.attrs.styleId };
+                    }
                 }
             }
-
-            // relocate the ranges to the target address
-            condFormat.ranges = RangeArray.map(ranges, function (range) {
-                return docModel.getCroppedMovedRange(range, targetStart[0], targetStart[1]);
-            });
-            return !condFormat.ranges.empty();
         });
 
         return {
@@ -1633,16 +1618,16 @@ define('io.ox/office/spreadsheet/utils/clipboard', [
      * @param {jQuery} dataNode
      *  The DOM node containing a rectangle specification.
      *
-     * @returns {Object}
+     * @returns {Rectangle}
      *  The rectangle representing the location of the object.
      */
     Clipboard.getRectangleFromNode = function (dataNode, offsetX, offsetY) {
-        return {
-            left: offsetX + Utils.getElementAttributeAsInteger(dataNode, 'data-left', 0),
-            top: offsetY + Utils.getElementAttributeAsInteger(dataNode, 'data-top', 0),
-            width: Utils.getElementAttributeAsInteger(dataNode, 'data-width', 0) || 256,
-            height: Utils.getElementAttributeAsInteger(dataNode, 'data-height', 0) || 192
-        };
+        return new Rectangle(
+            offsetX + Utils.getElementAttributeAsInteger(dataNode, 'data-left', 0),
+            offsetY + Utils.getElementAttributeAsInteger(dataNode, 'data-top', 0),
+            Utils.getElementAttributeAsInteger(dataNode, 'data-width', 0) || 256,
+            Utils.getElementAttributeAsInteger(dataNode, 'data-height', 0) || 192
+        );
     };
 
     /**
