@@ -13,21 +13,39 @@
  */
 
 define('io.ox/office/spreadsheet/utils/intervalset', [
-    'io.ox/office/tk/container/basemap',
+    'io.ox/office/tk/container/valueset',
     'io.ox/office/tk/container/sortedarray',
     'io.ox/office/spreadsheet/utils/interval',
     'io.ox/office/spreadsheet/utils/intervalarray'
-], function (BaseMap, SortedArray, Interval, IntervalArray) {
+], function (ValueSet, SortedArray, Interval, IntervalArray) {
 
     'use strict';
 
     // convenience shortcuts
-    var MapProto = BaseMap.prototype;
+    var min = Math.min;
+    var max = Math.max;
+    var floor = Math.floor;
+    var ceil = Math.ceil;
+    var log = Math.log;
+    var SetProto = ValueSet.prototype;
 
     var ZEROS = '000000000';
 
     // private global functions ===============================================
 
+    /**
+     * Returns the key of the passed index interval.
+     *
+     * @param {Interval} interval
+     *  An index interval.
+     *
+     * @returns {String}
+     *  The key of the passed index interval.
+     */
+    function getKey(interval) {
+        return interval.key();
+    }
+
     /**
      * Converts the passed number to a 10-digit string with leading zeros.
      *
@@ -80,7 +98,7 @@ define('io.ox/office/spreadsheet/utils/intervalset', [
      * @returns {Number}
      *  The dual logarithm of the passed number.
      */
-    var log2 = Math.log2 || function (number) { return Math.log(number) / Math.LN2; };
+    var log2 = Math.log2 || function (number) { return log(number) / Math.LN2; };
 
     // class IntervalTree =====================================================
 
@@ -264,7 +282,7 @@ define('io.ox/office/spreadsheet/utils/intervalset', [
         if (interval.first < this._center) {
             // collect all intervals of the left subtree
             if (this._tree1) {
-                var last1 = Math.min(interval.last, this._center - 1);
+                var last1 = min(interval.last, this._center - 1);
                 intervals.append(this._tree1.findIntervals(new Interval(interval.first, last1)));
             }
             // collect all intervals from the first-sorted array
@@ -279,7 +297,7 @@ define('io.ox/office/spreadsheet/utils/intervalset', [
         if (this._center < interval.last) {
             // collect all intervals of the right subtree
             if (this._tree2) {
-                var first2 = Math.max(interval.first, this._center + 1);
+                var first2 = max(interval.first, this._center + 1);
                 intervals.append(this._tree2.findIntervals(new Interval(first2, interval.last)));
             }
             // collect all intervals from the last-sorted array
@@ -315,10 +333,10 @@ define('io.ox/office/spreadsheet/utils/intervalset', [
         var subtree = null;
 
         if (interval.last < this._center) {
-            subtree = this._tree1 || (this._tree1 = new IntervalTree(this._first, this._center - 1, Math.ceil((this._first + this._center - 1) / 2), null, null));
+            subtree = this._tree1 || (this._tree1 = new IntervalTree(this._first, this._center - 1, ceil((this._first + this._center - 1) / 2), null, null));
             interval = subtree.insert(interval, replace);
         } else if (this._center < interval.first) {
-            subtree = this._tree2 || (this._tree2 = new IntervalTree(this._center + 1, this._last, Math.ceil((this._center + this._last + 1) / 2), null, null));
+            subtree = this._tree2 || (this._tree2 = new IntervalTree(this._center + 1, this._last, ceil((this._center + this._last + 1) / 2), null, null));
             interval = subtree.insert(interval, replace);
         } else {
             this._sorted1.insert(interval, replace);
@@ -364,12 +382,12 @@ define('io.ox/office/spreadsheet/utils/intervalset', [
      *
      * @constructor
      *
-     * @extends BaseMap
+     * @extends ValueSet
      */
-    var IntervalSet = BaseMap.extend({ constructor: function () {
+    var IntervalSet = ValueSet.extend({ constructor: function () {
 
-        // base constructor (stores all intervals by their keys, for fast direct access)
-        BaseMap.call(this);
+        // base constructor
+        ValueSet.call(this, getKey);
 
         // the centered interval tree storing all intervals
         this._tree = null;
@@ -395,7 +413,7 @@ define('io.ox/office/spreadsheet/utils/intervalset', [
      *  A reference to this instance.
      */
     IntervalSet.prototype.clear = function () {
-        MapProto.clear.call(this);
+        SetProto.clear.call(this);
         this._tree = null;
         return this;
     };
@@ -439,15 +457,16 @@ define('io.ox/office/spreadsheet/utils/intervalset', [
         // create a shallow or deep clone of the interval tree, and the own map
         if (this._tree) {
             if (deep) {
-                // deep mode: collect the cloned intervals in the own map while cloning
-                var callback = _.isFunction(deep) ? deep : _.noop;
+                // deep mode: collect the cloned intervals in the own set while cloning the tree
+                // (cloning the tree is faster than building it with distinct element insertions)
+                var callback = (typeof deep === 'function') ? deep : _.noop;
                 clone._tree = this._tree.clone(function (newInterval, oldInterval) {
                     callback.call(context, newInterval, oldInterval);
-                    MapProto.insert.call(clone, newInterval.key(), newInterval);
+                    clone._insert(newInterval.key(), newInterval);
                 });
             } else {
-                // shallow mode: simple clones of the tree, and the map
-                MapProto._init.call(clone, this);
+                // shallow mode: simple clones of the tree and the set
+                this.forEachKey(clone._insert, clone);
                 clone._tree = this._tree.clone();
             }
         }
@@ -455,21 +474,6 @@ define('io.ox/office/spreadsheet/utils/intervalset', [
         return clone;
     };
 
-    /**
-     * Returns whether this set contains an interval that has the same position
-     * as the passed interval.
-     *
-     * @param {Interval} interval
-     *  A index interval to check.
-     *
-     * @returns {Boolean}
-     *  Whether this set contains an interval that has the same position as the
-     *  passed interval.
-     */
-    IntervalSet.prototype.has = function (interval) {
-        return MapProto.has.call(this, interval.key());
-    };
-
     /**
      * Returns the interval object from this set that has the exact position of
      * the passed index interval.
@@ -482,7 +486,7 @@ define('io.ox/office/spreadsheet/utils/intervalset', [
      *  as the passed interval; otherwise null.
      */
     IntervalSet.prototype.get = function (interval) {
-        return MapProto.get.call(this, interval.key(), null);
+        return this._get(interval.key()) || null;
     };
 
     /**
@@ -592,8 +596,8 @@ define('io.ox/office/spreadsheet/utils/intervalset', [
                 // of the interval will be reduced to the leading bits up to that bit 3 (AND with the bit mask
                 // 11111000), which results in 00011010 & 11111000 = 00011000 = 24.
                 //
-                var first = Math.max(interval.first - 1, 0);
-                var msb = Math.floor(log2(first ^ interval.last));
+                var first = max(interval.first - 1, 0);
+                var msb = floor(log2(first ^ interval.last));
                 var mask = (1 << msb) - 1;
                 treeCenter = interval.last & ~mask;
                 treeFirst = (mask + 1 === treeCenter) ? 0 : (treeCenter - mask);
@@ -623,9 +627,9 @@ define('io.ox/office/spreadsheet/utils/intervalset', [
             }
         }
 
-        // add the interval to the tree, and the map
+        // add the interval to the tree and the set
         interval = this._tree.insert(interval, replace);
-        return MapProto.insert.call(this, interval.key(), interval);
+        return this._insert(interval.key(), interval);
     };
 
     /**
@@ -640,10 +644,14 @@ define('io.ox/office/spreadsheet/utils/intervalset', [
      */
     IntervalSet.prototype.remove = function (interval) {
 
-        // remove the inerval from the map (early exit, if the inetrval does not exist)
-        interval = MapProto.remove.call(this, interval.key(), null);
+        // early exit, if the interval does not exist
+        var key = interval.key();
+        interval = this._get(key);
         if (!interval) { return null; }
 
+        // remove the interval from the set
+        this._remove(key);
+
         // remove the interval from the tree, and shrink the tree, if one subtree and the sorted arrays are empty
         this._tree.remove(interval);
         while (this._tree && this._tree._sorted1.empty() && !(this._tree._tree1 && this._tree._tree2)) {
@@ -656,19 +664,20 @@ define('io.ox/office/spreadsheet/utils/intervalset', [
     /**
      * Inserts all index intervals of the passed set into this set.
      *
-     * @param {IntervalSet} intervalSet
-     *  The interval set to be merged into this interval set.
+     * @param {Object} list
+     *  A generic data source with index intervals as elements. See static
+     *  method Container.forEach() for details.
      *
      * @param {Boolean} [replace=false]
-     *  If set to true, intervals in the passed interval set will replace equal
+     *  If set to true, intervals in the passed list will replace equal
      *  intervals in this set. By default, the existing intervals of this set
      *  will be preferred.
      *
      * @returns {IntervalSet}
      *  A reference to this instance.
      */
-    IntervalSet.prototype.merge = function (intervalSet, replace) {
-        intervalSet.forEach(function (interval) { this.insert(interval, replace); }, this);
+    IntervalSet.prototype.merge = function (list, replace) {
+        ValueSet.forEach(list, function (interval) { this.insert(interval, replace); }, this);
         return this;
     };
 
