@@ -6,7 +6,8 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
- * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Daniel Rentz <daniel.rentz@open-xchange.com>
  */
@@ -29,7 +30,7 @@ define('io.ox/office/spreadsheet/utils/movedescriptor', [
      * of a move descriptor in insertion mode.
      *
      * @param {IntervalArray} targetIntervals
-     *  The target intervals of a move descriptor in insertion mode.
+     *  The (sorted) target intervals of a move descriptor in insertion mode.
      *
      * @param {Number} index
      *  The column/row index to be transformed.
@@ -47,12 +48,14 @@ define('io.ox/office/spreadsheet/utils/movedescriptor', [
         for (var i = 0, l = targetIntervals.length; i < l; i += 1) {
             var targetInterval = targetIntervals[i];
 
-            // shift index ahead, if it is located inside or behind the target interval;
-            // exit the loop early if the index becomes invalid (moved beyond the maximum index)
-            if (targetInterval.first <= index) {
-                index += targetInterval.size();
-                if (index > maxIndex) { return null; }
-            }
+            // early exit, if the target intervals are located behind the index (array is sorted)
+            if (index < targetInterval.first) { break; }
+
+            // shift index ahead
+            index += targetInterval.size();
+
+            // early exit if the index becomes invalid (moved beyond the maximum index)
+            if (index > maxIndex) { return null; }
         }
         return index;
     }
@@ -62,7 +65,7 @@ define('io.ox/office/spreadsheet/utils/movedescriptor', [
      * of a move descriptor in deletion mode.
      *
      * @param {IntervalArray} targetIntervals
-     *  The target intervals of a move descriptor in deletion mode.
+     *  The (sorted) target intervals of a move descriptor in deletion mode.
      *
      * @param {Number} index
      *  The column/row index to be transformed.
@@ -77,13 +80,14 @@ define('io.ox/office/spreadsheet/utils/movedescriptor', [
         for (var i = targetIntervals.length - 1; i >= 0; i -= 1) {
             var targetInterval = targetIntervals[i];
 
-            // shift index back, if it is located behinbd the target interval;
+            // nothing to do, if the target intervals are located behind the index
+            if (index < targetInterval.first) { continue; }
+
             // invalidate the index, if it is contained in the target interval
-            if (targetInterval.last < index) {
-                index -= targetInterval.size();
-            } else if (targetInterval.first <= index) {
-                return null;
-            }
+            if (index <= targetInterval.last) { return null; }
+
+            // shift index back
+            index -= targetInterval.size();
         }
         return index;
     }
@@ -93,7 +97,7 @@ define('io.ox/office/spreadsheet/utils/movedescriptor', [
      * a move descriptor in insertion mode.
      *
      * @param {IntervalArray} targetIntervals
-     *  The target intervals of a move descriptor in insertion mode.
+     *  The (sorted) target intervals of a move descriptor in insertion mode.
      *
      * @param {Interval} interval
      *  The index interval to be transformed.
@@ -101,42 +105,34 @@ define('io.ox/office/spreadsheet/utils/movedescriptor', [
      * @param {Number} maxIndex
      *  The maximum column/row index in the sheet in move direction.
      *
-     * @param {Object} [options]
-     *  Optional paramaters. See method MoveDescriptor.transformRange() for
-     *  details.
+     * @param {Boolean} expandEnd
+     *  If set to true, the end position of the interval will be expanded, if
+     *  new indexes will be inserted exactly behind the interval.
      *
      * @returns {Interval|Null}
      *  The transformed index interval; or null, if the interval has been moved
      *  beyond the specified maximum column/row index in the sheet.
      */
-    function transformIntervalInsert(targetIntervals, interval, maxIndex, options) {
-
-        // whether to expand the trailing border of the range, when inserting behind the range
-        var expandEnd = Utils.getBooleanOption(options, 'expandEnd', false);
-
-        // do not transform full column/row intervals unless specified
-        if ((interval.first === 0) && (interval.last === maxIndex) && !Utils.getBooleanOption(options, 'transformFull', false)) {
-            return interval;
-        }
+    function transformIntervalInsert(targetIntervals, interval, maxIndex, expandEnd) {
 
         // transform the interval as long as it remains valid
         for (var i = 0, l = targetIntervals.length; i < l; i += 1) {
             var targetInterval = targetIntervals[i];
             var targetSize = targetInterval.size();
 
-            // shift start position ahead, if the interval starts inside or behind the target interval
+            // early exit, if the target intervals are located behind the interval (array is sorted)
+            if (interval.last + (expandEnd ? 1 : 0) < targetInterval.first) { break; }
+
+            // shift start position ahead, if the interval starts inside or behind the target interval;
             // exit the loop early if the start index becomes invalid (moved beyond the maximum index)
             if (targetInterval.first <= interval.first) {
                 interval.first += targetSize;
                 if (interval.first > maxIndex) { return null; }
             }
 
-            // shift end position ahead, if interval ends inside or after the target interval
-            // (in expand-end mode: also, if it ends exactly before the target interval)
+            // shift end position ahead (in expand-end mode: also, if it ends exactly before the target interval),
             // keep the end position inside the limits of the sheet (interval may shrink)
-            if (targetInterval.first <= interval.last + (expandEnd ? 1 : 0)) {
-                interval.last = Math.min(interval.last + targetSize, maxIndex);
-            }
+            interval.last = Math.min(interval.last + targetSize, maxIndex);
         }
         return interval;
     }
@@ -146,45 +142,33 @@ define('io.ox/office/spreadsheet/utils/movedescriptor', [
      * a move descriptor in deletion mode.
      *
      * @param {IntervalArray} targetIntervals
-     *  The target intervals of a move descriptor in deletion mode.
+     *  The (sorted) target intervals of a move descriptor in deletion mode.
      *
      * @param {Interval} interval
      *  The index interval to be transformed.
      *
-     * @param {Number} maxIndex
-     *  The maximum column/row index in the sheet in move direction.
-     *
-     * @param {Object} [options]
-     *  Optional paramaters. See method MoveDescriptor.transformRange() for
-     *  details.
-     *
      * @returns {Interval|Null}
      *  The transformed index interval; or null, if the interval was covered by
      *  a target interval and has therefore been deleted completely.
      */
-    function transformIntervalDelete(targetIntervals, interval, maxIndex, options) {
-
-        // do not transform full column/row intervals unless specified
-        if ((interval.first === 0) && (interval.last === maxIndex) && !Utils.getBooleanOption(options, 'transformFull', false)) {
-            return interval;
-        }
+    function transformIntervalDelete(targetIntervals, interval) {
 
         // transform the interval index as long as it remains valid (in reversed order!)
         for (var i = targetIntervals.length - 1; i >= 0; i -= 1) {
             var targetInterval = targetIntervals[i];
             var targetSize = targetInterval.size();
 
+            // nothing to do, if the target intervals are located behind the interval
+            if (interval.last < targetInterval.first) { continue; }
+
             // shift start position of the interval back to start of target interval
             if (targetInterval.first < interval.first) {
                 interval.first = Math.max(targetInterval.first, interval.first - targetSize);
             }
 
-            // shift end position of the interval back to start of target interval
-            if (targetInterval.first <= interval.last) {
-                interval.last = Math.max(interval.last - targetSize, targetInterval.first - 1);
-            }
-
+            // shift end position of the interval back to start of target interval;
             // exit the loop early if the interval becomes invalid
+            interval.last = Math.max(interval.last - targetSize, targetInterval.first - 1);
             if (interval.last < interval.first) { return null; }
         }
         return interval;
@@ -366,6 +350,36 @@ define('io.ox/office/spreadsheet/utils/movedescriptor', [
 
     // public methods ---------------------------------------------------------
 
+    /**
+     * Returns whether the passed cell address is contained in the cell range
+     * covered by the band interval of this move descriptor.
+     *
+     * @param {Address} address
+     *  The cell address to be checked.
+     *
+     * @returns {Boolean}
+     *  Whether the passed cell address is contained in the cell range covered
+     *  by the band interval of this move descriptor.
+     */
+    MoveDescriptor.prototype.containsAddress = function (address) {
+        return this.bandInterval.containsIndex(address.get(!this.columns));
+    };
+
+    /**
+     * Returns whether the passed range is completely contained in the cell
+     * range covered by the band interval of this move descriptor.
+     *
+     * @param {Range} range
+     *  The cell range address to be checked.
+     *
+     * @returns {Boolean}
+     *  Whether the passed range is completely contained in the cell range
+     *  covered by the band interval of this move descriptor.
+     */
+    MoveDescriptor.prototype.containsRange = function (range) {
+        return this.bandInterval.contains(range.interval(!this.columns));
+    };
+
     /**
      * Creates a cell range address located in the band interval of this move
      * descriptor, and covering a single column or row in that band.
@@ -421,20 +435,6 @@ define('io.ox/office/spreadsheet/utils/movedescriptor', [
         return RangeArray.map(intervals, this.createRange, this);
     };
 
-    /**
-     * Returns whether the passed cell address will be modified by this
-     * descriptor.
-     *
-     * @param {Address} address
-     *  The cell address to be checked.
-     *
-     * @returns {Boolean}
-     *  Whether the passed cell address will be modified by this descriptor.
-     */
-    MoveDescriptor.prototype.coversAddress = function (address) {
-        return this.dirtyRange.containsAddress(address);
-    };
-
     /**
      * Transforms the passed cell address according to the settings of this
      * move descriptor.
@@ -450,7 +450,7 @@ define('io.ox/office/spreadsheet/utils/movedescriptor', [
     MoveDescriptor.prototype.transformAddress = function (address) {
 
         // nothing to do, if the address is not covered by this descriptor
-        if (!this.coversAddress(address)) { return address.clone(); }
+        if (!this.containsAddress(address)) { return address.clone(); }
 
         // the helper function that implements transformation of an address index
         var transformFunc = this.insert ? transformIndexInsert : transformIndexDelete;
@@ -479,27 +479,6 @@ define('io.ox/office/spreadsheet/utils/movedescriptor', [
         return AddressArray.map(addresses, this.transformAddress, this);
     };
 
-    /**
-     * Returns whether the passed range will be modified by this descriptor.
-     * The range must be located in the band interval, and it must overlap with
-     * the moved cell area.
-     *
-     * @param {Range} range
-     *  The cell range address to be checked.
-     *
-     * @returns {Boolean}
-     *  Whether the passed range will be modified by this descriptor.
-     */
-    MoveDescriptor.prototype.coversRange = function (range) {
-        // The range must be located completely in the band interval, and it must adjoin to or overlap
-        // with the dirty range. Adjoining ranges must be matched too, to cover the case that cells
-        // will be inserted directly after a range with the 'expandEnd' mode.
-        // Example: Move cells in C3:E5 to the right. Dirty range of this move descriptor will be
-        // C3:XFD5, and the source range B3:B5 will be expanded at the end in 'expandEnd' mode to the
-        // target range B3:E5 although it does not overlap with the dirty range.
-        return this.bandInterval.contains(range.interval(!this.columns)) && (this.dirtyRange.getStart(this.columns) <= range.getEnd(this.columns) + 1);
-    };
-
     /**
      * Transforms the passed cell range address according to the settings of
      * this move descriptor.
@@ -509,15 +488,15 @@ define('io.ox/office/spreadsheet/utils/movedescriptor', [
      *
      * @param {Object} [options]
      *  Optional parameters:
-     *  @param {Boolean} [options.expandEnd=false]
-     *      If set to true, the end position of the range will be expanded, if
-     *      new columns will be inserted exactly right of the range, or new
-     *      rows will be inserted exactly below the range.
      *  @param {Boolean} [options.transformFull=false]
      *      If set to true, entire column/row ranges will be transformed too.
      *      By default, entire column ranges will not be modified when moving
      *      vertically (through rows), and entire row ranges will not be
      *      modified when moving horizontally (through columns).
+     *  @param {Boolean} [options.expandEnd=false]
+     *      If set to true, the end position of the range will be expanded, if
+     *      new columns will be inserted exactly right of the range, or new
+     *      rows will be inserted exactly below the range.
      *  @param {Boolean} [options.reverse=false]
      *      Whether to transform the passed range with the reversed operation.
      *      If this move descriptor represents an 'insert' operation, the range
@@ -533,19 +512,31 @@ define('io.ox/office/spreadsheet/utils/movedescriptor', [
     MoveDescriptor.prototype.transformRange = function (range, options) {
 
         // nothing to do, if the range is not covered by this descriptor
-        if (!this.coversRange(range)) { return range.clone(); }
+        if (!this.containsRange(range)) { return range.clone(); }
 
         // the effective move operation
         var insert = this.insert !== Utils.getBooleanOption(options, 'reverse', false);
+        // whether to expand the trailing border of the range, when inserting behind the range
+        var expandEnd = insert && Utils.getBooleanOption(options, 'expandEnd', false);
         // the helper function that implements transformation of an index interval
         var transformFunc = insert ? transformIntervalInsert : transformIntervalDelete;
+        // the column/row interval of the range to be transformed
+        var interval = range.interval(this.columns);
+
+        // do not transform full column/row intervals unless specified
+        var fullInterval = (interval.first === 0) && (interval.last === this.maxIndex);
+        if (fullInterval && !Utils.getBooleanOption(options, 'transformFull', false)) {
+            return range.clone();
+        }
+
         // transform the correct interval of the passed range, according to move direction
-        var interval = transformFunc(this.targetIntervals, range.interval(this.columns), this.maxIndex, options);
+        var transformInterval = transformFunc(this.targetIntervals, interval, this.maxIndex, expandEnd);
+        if (!transformInterval) { return null; }
 
         // create a new range address
-        var colInterval = this.columns ? interval : range.colInterval();
-        var rowInterval = this.columns ? range.rowInterval() : interval;
-        return (colInterval && rowInterval) ? Range.createFromIntervals(colInterval, rowInterval) : null;
+        var colInterval = this.columns ? transformInterval : range.colInterval();
+        var rowInterval = this.columns ? range.rowInterval() : transformInterval;
+        return Range.createFromIntervals(colInterval, rowInterval);
     };
 
     /**
@@ -586,6 +577,117 @@ define('io.ox/office/spreadsheet/utils/movedescriptor', [
         }, this);
     };
 
+    // static methods ---------------------------------------------------------
+
+    /**
+     * Transforms the passed cell address according to the settings of all move
+     * descriptors.
+     *
+     * @param {Address} address
+     *  The cell address to be transformed.
+     *
+     * @param {Array<MoveDescriptor>} moveDescs
+     *  An array with move descriptors that will be used to transform the cell
+     *  address.
+     *
+     * @returns {Address|Null}
+     *  The transformed cell address. If the cell would be deleted completely
+     *  while deleting columns or rows, or would be shifted outside the sheet
+     *  while inserting columns or rows, null will be returned instead.
+     */
+    MoveDescriptor.transformAddress = function (address, moveDescs) {
+        moveDescs.every(function (moveDesc) {
+            return (address = moveDesc.transformAddress(address));
+        });
+        return address;
+    };
+
+    /**
+     * Transforms the passed cell addresses according to the settings of all
+     * move descriptors.
+     *
+     * @param {AddressArray|Address} addresses
+     *  The cell addresses to be transformed, as array of cell addresses, or as
+     *  single cell address.
+     *
+     * @param {Array<MoveDescriptor>} moveDescs
+     *  An array with move descriptors that will be used to transform the cell
+     *  addresses.
+     *
+     * @returns {AddressArray}
+     *  The transformed cell addresses. Cells that would be deleted completely
+     *  while deleting columns or rows, or would be shifted outside the sheet
+     *  while inserting columns or rows, will not be included into the result.
+     */
+    MoveDescriptor.transformAddresses = function (addresses, moveDescs) {
+        moveDescs.some(function (moveDesc) {
+            addresses = moveDesc.transformAddresses(addresses);
+            return addresses.empty();
+        });
+        return addresses;
+    };
+
+    /**
+     * Transforms the passed cell range address according to the settings of
+     * all move descriptors.
+     *
+     * @param {Range} range
+     *  The address of the cell range to be transformed.
+     *
+     * @param {Array<MoveDescriptor>} moveDescs
+     *  An array with move descriptors that will be used to transform the cell
+     *  range address.
+     *
+     * @param {Object} [options]
+     *  Optional parameters. See description of the public prototype method
+     *  MoveDescriptor.prototype.transformRange() for details.
+     *
+     * @returns {Range|Null}
+     *  The address of the transformed cell range. If the cell range would be
+     *  deleted completely while deleting columns or rows, or would be shifted
+     *  outside the sheet while inserting columns or rows, null will be
+     *  returned instead.
+     */
+    MoveDescriptor.transformRange = function (range, moveDescs, options) {
+        var reverse = Utils.getBooleanOption(options, 'reverse', false);
+        Utils.iterateArray(moveDescs, function (moveDesc) {
+            range = moveDesc.transformRange(range, options);
+            if (!range) { return Utils.BREAK; }
+        }, { reverse: reverse });
+        return range;
+    };
+
+    /**
+     * Transforms the passed cell range addresses according to the settings of
+     * all move descriptors.
+     *
+     * @param {RangeArray|Range} ranges
+     *  The cell range addresses to be transformed, as array of cell range
+     *  addresses, or as single cell range address.
+     *
+     * @param {Array<MoveDescriptor>} moveDescs
+     *  An array with move descriptors that will be used to transform the cell
+     *  range addresses.
+     *
+     * @param {Object} [options]
+     *  Optional parameters. See description of the public prototype method
+     *  MoveDescriptor.prototype.transformRanges() for details.
+     *
+     * @returns {RangeArray}
+     *  The transformed cell range addresses. Cell ranges that would be deleted
+     *  completely while deleting columns or rows, or would be shifted outside
+     *  the sheet while inserting columns or rows, will not be included into
+     *  the result.
+     */
+    MoveDescriptor.transformRanges = function (ranges, moveDescs, options) {
+        var reverse = Utils.getBooleanOption(options, 'reverse', false);
+        Utils.iterateArray(moveDescs, function (moveDesc) {
+            ranges = moveDesc.transformRanges(ranges, options);
+            if (ranges.empty()) { return Utils.BREAK; }
+        }, { reverse: reverse });
+        return ranges;
+    };
+
     // exports ================================================================
 
     return MoveDescriptor;
