@@ -13,8 +13,8 @@
  */
 
 define('io.ox/office/spreadsheet/utils/operations', [
-    'io.ox/office/editframework/utils/operations'
-], function (EditOperations) {
+    'io.ox/office/textframework/utils/operations'
+], function (BaseTextOperations) {
 
     'use strict';
 
@@ -24,9 +24,9 @@ define('io.ox/office/spreadsheet/utils/operations', [
      * Provides constants for the names of all document operations used in
      * spreadsheet documents.
      *
-     * @extends EditOperations
+     * @extends BaseTextOperations
      */
-    var SpreadsheetOperations = _.extend(EditOperations, {
+    var SpreadsheetOperations = BaseTextOperations.extend({
 
         INSERT_NUMBER_FORMAT: 'insertNumberFormat',
         DELETE_NUMBER_FORMAT: 'deleteNumberFormat',
@@ -69,7 +69,6 @@ define('io.ox/office/spreadsheet/utils/operations', [
         INSERT_CFRULE: 'insertCFRule',
         CHANGE_CFRULE: 'changeCFRule',
         DELETE_CFRULE: 'deleteCFRule'
-
     });
 
     // exports ================================================================
