@@ -293,6 +293,25 @@ define('io.ox/office/spreadsheet/utils/range', [
         return this.start.differs(range.start) || this.end.differs(range.end);
     };
 
+    /**
+     * Return whether this range fits completely into every ranges of the
+     * given range array.
+     *
+     * @param  {RangeArray} rangeArray
+     *  A range array, where the range should fit in.
+     *
+     * @return {Boolean}
+     *  True, if the range fits in every of the range array ranges.
+     *  False, if not.
+     */
+    Range.prototype.fitsIn = function (rangeArray) {
+        var cols = this.cols(),
+            rows = this.rows();
+        return rangeArray.every(function (range) {
+            return (range.cols() % cols === 0 && range.rows() % rows === 0);
+        });
+    };
+
     /**
      * Compares this cell range address with the passed cell range address. See
      * static method Range.compare() for details.
