@@ -6,7 +6,8 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
-  * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Daniel Rentz <daniel.rentz@open-xchange.com>
  */
@@ -14,11 +15,11 @@
 define('io.ox/office/spreadsheet/utils/rangearray', [
     'io.ox/office/tk/utils',
     'io.ox/office/tk/utils/iteratorutils',
-    'io.ox/office/tk/utils/arraytemplate',
+    'io.ox/office/tk/container/typedarray',
     'io.ox/office/spreadsheet/utils/interval',
     'io.ox/office/spreadsheet/utils/range',
     'io.ox/office/spreadsheet/utils/intervalarray'
-], function (Utils, IteratorUtils, ArrayTemplate, Interval, Range, IntervalArray) {
+], function (Utils, IteratorUtils, TypedArray, Interval, Range, IntervalArray) {
 
     'use strict';
 
@@ -212,7 +213,7 @@ define('io.ox/office/spreadsheet/utils/rangearray', [
      *
      * @extends Array
      */
-    var RangeArray = ArrayTemplate.create(Range);
+    var RangeArray = TypedArray.create(Range);
 
     // static methods ---------------------------------------------------------
 
@@ -321,10 +322,10 @@ define('io.ox/office/spreadsheet/utils/rangearray', [
         // create row bands with all rows that contains any cells
         addresses.forEach(function (address) {
 
-            var // the last row band in the array of all row bands
-                lastRowBand = _.last(rowBands),
-                // the last interval in the current row band
-                lastInterval = null;
+            // the last row band in the array of all row bands
+            var lastRowBand = rowBands.last();
+            // the last interval in the current row band
+            var lastInterval = null;
 
             // create a new row band on demand
             if (!lastRowBand || (lastRowBand.first !== address[1])) {
@@ -489,6 +490,8 @@ define('io.ox/office/spreadsheet/utils/rangearray', [
                 return false;
             case 2:
                 return this[0].overlaps(this[1]);
+            case 3:
+                return this[0].overlaps(this[1]) || this[0].overlaps(this[2]) || this[1].overlaps(this[2]);
         }
 
         // work on sorted clones for performance (check adjacent array elements)
