@@ -13,15 +13,30 @@
  */
 
 define('io.ox/office/spreadsheet/utils/rangeset', [
-    'io.ox/office/tk/container/basemap',
+    'io.ox/office/tk/container/valueset',
     'io.ox/office/spreadsheet/utils/rangearray',
     'io.ox/office/spreadsheet/utils/intervalset'
-], function (BaseMap, RangeArray, IntervalSet) {
+], function (ValueSet, RangeArray, IntervalSet) {
 
     'use strict';
 
     // convenience shortcuts
-    var MapProto = BaseMap.prototype;
+    var SetProto = ValueSet.prototype;
+
+    // private global functions ===============================================
+
+    /**
+     * Returns the key of the passed index interval.
+     *
+     * @param {Interval} interval
+     *  An index interval.
+     *
+     * @returns {String}
+     *  The key of the passed index interval.
+     */
+    function getKey(interval) {
+        return interval.key();
+    }
 
     // class RangeSet =========================================================
 
@@ -33,12 +48,12 @@ define('io.ox/office/spreadsheet/utils/rangeset', [
      *
      * @constructor
      *
-     * @extends BaseMap
+     * @extends ValueSet
      */
-    var RangeSet = BaseMap.extend({ constructor: function () {
+    var RangeSet = ValueSet.extend({ constructor: function () {
 
-        // base constructor (stores all ranges by their keys, for fast direct access)
-        BaseMap.call(this);
+        // base constructor
+        ValueSet.call(this, getKey);
 
         // the interval set storing the column intervals of all cell ranges in this set
         this._colSet = new IntervalSet();
@@ -54,7 +69,7 @@ define('io.ox/office/spreadsheet/utils/rangeset', [
      *  A reference to this instance.
      */
     RangeSet.prototype.clear = function () {
-        MapProto.clear.call(this);
+        SetProto.clear.call(this);
         this._colSet.clear();
         return this;
     };
@@ -94,7 +109,7 @@ define('io.ox/office/spreadsheet/utils/rangeset', [
         // start with a new empty range set
         var clone = new RangeSet();
         // user callback for deep mode
-        var callback = _.isFunction(deep) ? deep : _.noop;
+        var callback = (typeof deep === 'function') ? deep : _.noop;
 
         // create a deep clone of the interval sets (shallow mode only for the final ranges!)
         clone._colSet = this._colSet.clone(function (newColInterval, oldColInterval) {
@@ -103,28 +118,13 @@ define('io.ox/office/spreadsheet/utils/rangeset', [
                 var newRange = deep ? oldRange.clone() : oldRange;
                 callback.call(context, newRange, oldRange);
                 newRowInterval.range = newRange;
-                MapProto.insert.call(clone, newRange.key(), newRange);
+                clone._insert(newRange.key(), newRange);
             });
         });
 
         return clone;
     };
 
-    /**
-     * Returns whether this set contains a cell range address that has the same
-     * position as the passed range address.
-     *
-     * @param {Range} range
-     *  A cell range address to check.
-     *
-     * @returns {Boolean}
-     *  Whether this set contains a cell range address that has the same
-     *  position as the passed range address.
-     */
-    RangeSet.prototype.has = function (range) {
-        return MapProto.has.call(this, range.key());
-    };
-
     /**
      * Returns the cell range address from this set that has the exact position
      * of the passed range address.
@@ -137,7 +137,7 @@ define('io.ox/office/spreadsheet/utils/rangeset', [
      *  the passed range address; otherwise null.
      */
     RangeSet.prototype.get = function (range) {
-        return MapProto.get.call(this, range.key(), null);
+        return this._get(range.key()) || null;
     };
 
     /**
@@ -253,7 +253,7 @@ define('io.ox/office/spreadsheet/utils/rangeset', [
         var rowSet = colInterval.rowSet || (colInterval.rowSet = new IntervalSet());
         var rowInterval = rowSet.insert(range.rowInterval());
         if (replace || !rowInterval.range) { rowInterval.range = range; }
-        return MapProto.insert.call(this, range.key(), rowInterval.range);
+        return this._insert(range.key(), rowInterval.range);
     };
 
     /**
@@ -267,30 +267,34 @@ define('io.ox/office/spreadsheet/utils/rangeset', [
      *  contain a cell range that is equal to the passed cell range.
      */
     RangeSet.prototype.remove = function (range) {
-        range = MapProto.remove.call(this, range.key(), null);
+        var key = range.key();
+        range = this._get(key);
         if (!range) { return null; }
+        this._remove(key);
         var colInterval = this._colSet.get(range.colInterval());
-        var rowInterval = colInterval.rowSet.remove(range.rowInterval());
-        if (colInterval.rowSet.empty()) { this._colSet.remove(colInterval); }
-        return rowInterval.range;
+        var rowSet = colInterval.rowSet;
+        rowSet.remove(range.rowInterval());
+        if (rowSet.empty()) { this._colSet.remove(colInterval); }
+        return range;
     };
 
     /**
      * Inserts all cell ranges of the passed set into this set.
      *
-     * @param {RangeSet} rangeSet
-     *  The range set to be merged into this range set.
+     * @param {Object} list
+     *  A generic data source with cell range addresses as elements. See static
+     *  method Container.forEach() for details.
      *
      * @param {Boolean} [replace=false]
-     *  If set to true, cell ranges in the passed range set will replace equal
-     *  cell ranges in this set. By default, the existing cell ranges of this
-     *  set will be preferred.
+     *  If set to true, cell ranges in the passed list will replace equal cell
+     *  ranges in this set. By default, the existing cell ranges of this set
+     *  will be preferred.
      *
      * @returns {RangeSet}
      *  A reference to this instance.
      */
-    RangeSet.prototype.merge = function (rangeSet, replace) {
-        rangeSet.forEach(function (range) { this.insert(range, replace); }, this);
+    RangeSet.prototype.merge = function (list, replace) {
+        ValueSet.forEach(list, function (range) { this.insert(range, replace); }, this);
         return this;
     };
 
