@@ -14,6 +14,7 @@
 
 define('io.ox/office/spreadsheet/utils/sheetutils', [
     'io.ox/office/tk/utils',
+    'io.ox/office/tk/utils/enum',
     'io.ox/office/tk/utils/logger',
     'io.ox/office/tk/locale/localedata',
     'io.ox/office/tk/render/font',
@@ -32,7 +33,7 @@ define('io.ox/office/spreadsheet/utils/sheetutils', [
     'io.ox/office/spreadsheet/utils/changedescriptor',
     'io.ox/office/spreadsheet/utils/movedescriptor',
     'gettext!io.ox/office/spreadsheet/main'
-], function (Utils, Logger, LocaleData, Font, ErrorCode, Address, Interval, Range, Range3D, AddressArray, IntervalArray, RangeArray, Range3DArray, AddressSet, IntervalSet, RangeSet, ChangeDescriptor, MoveDescriptor, gt) {
+], function (Utils, Enum, Logger, LocaleData, Font, ErrorCode, Address, Interval, Range, Range3D, AddressArray, IntervalArray, RangeArray, Range3DArray, AddressSet, IntervalSet, RangeSet, ChangeDescriptor, MoveDescriptor, gt) {
 
     'use strict';
 
@@ -48,6 +49,24 @@ define('io.ox/office/spreadsheet/utils/sheetutils', [
         h: 'borderInsideHor'
     };
 
+    // maps horizontal alignment values used in operations to CSS text alignment values
+    var CSS_TEXT_ALIGN_VALUES = {
+        left: 'left',
+        center: 'center',
+        right: 'right',
+        justify: 'justify',
+        distribute: 'justify',
+        fillAcross: 'left',
+        centerAcross: 'center'
+    };
+
+    // private global functions ===============================================
+
+    // converts the passed text direction to left/right alignment
+    function getAlignFromDir(dir) {
+        return (dir === 'rtl') ? 'right' : 'left';
+    }
+
     // static class SheetUtils ================================================
 
     /**
@@ -83,6 +102,15 @@ define('io.ox/office/spreadsheet/utils/sheetutils', [
 
     // constants --------------------------------------------------------------
 
+    /**
+     * The identifier of the spreadsheet attribute pool for cell formatting
+     * attributes.
+     *
+     * @constant
+     * @type Number
+     */
+    SheetUtils.CELL_POOL_ID = 'cell';
+
     /**
      * Maximum length of a defined name.
      *
@@ -187,22 +215,6 @@ define('io.ox/office/spreadsheet/utils/sheetutils', [
      */
     SheetUtils.MIN_CELL_SIZE = 5;
 
-    /**
-     * Minimum allowed zoom factor in the spreadsheet view.
-     *
-     * @constant
-     * @type Number
-     */
-    SheetUtils.MIN_ZOOM = 0.5;
-
-    /**
-     * Maximum allowed zoom factor in the spreadsheet view.
-     *
-     * @constant
-     * @type Number
-     */
-    SheetUtils.MAX_ZOOM = 8;
-
     /**
      * Whether multi-selection (multiple ranges at the same time) is supported.
      *
@@ -211,6 +223,101 @@ define('io.ox/office/spreadsheet/utils/sheetutils', [
      */
     SheetUtils.MULTI_SELECTION = !Utils.TOUCHDEVICE;
 
+    // enumerations -----------------------------------------------------------
+
+    /**
+     * Enumeration for the types of sheets that can occur in a spreadsheet
+     * document. The JSON string representation of the enumeration values
+     * corresponds to the values used in the document operations 'insertSheet'.
+     *
+     * @constant
+     * @type Enum
+     *
+     * @property {SheetType} WORKSHEET
+     *  A regular sheet with value cells, formula cells, and drawing objects.
+     *
+     * @property {SheetType} CHARTSHEET
+     *  A sheet consisting of a single big chart object.
+     *
+     * @property {SheetType} MACROSHEET
+     *  A sheet consisting of formula cells with specific macro formulas. Used
+     *  for compatibility with MS Excel 4.0 only.
+     *
+     * @property {SheetType} DIALOGSHEET
+     *  A sheet consisting of a single dialog box. Used for compatibility with
+     *  MS Excel 5.0 only.
+     */
+    SheetUtils.SheetType = Enum.create('worksheet chartsheet macrosheet dialogsheet');
+
+    /**
+     * Enumeration for the split modes for a sheet. The JSON string
+     * representation of the enumeration values corresponds to the values used
+     * in the sheet formatting attribute 'splitMode'.
+     *
+     * @constant
+     * @type Enum
+     *
+     * @property {SplitMode} SPLIT
+     *  Specifies a dynamic split, with resizable view panes.
+     *
+     * @property {SplitMode} FROZEN
+     *  Specifies a frozen split, with fixed view panes.
+     *
+     * @property {SplitMode} FROZEN_SPLIT
+     *  Specifies a frozen split similar to FROZEN, but thawing the frozen
+     *  split will change split mode to SPLIT instead of removing the split
+     *  completely.
+     */
+    SheetUtils.SplitMode = Enum.create('split frozen frozenSplit');
+
+    /**
+     * Enumeration for the move modes for cell ranges. The JSON string
+     * representation of the enumeration values corresponds to the values used
+     * in the document operations 'moveCells'.
+     *
+     * @constant
+     * @type Enum
+     *
+     * @property {MoveMode} LEFT
+     *  A cell range will be deleted, the following cells right of the cell
+     *  range will be moved to the left.
+     *
+     * @property {MoveMode} RIGHT
+     *  A cell range will be made blank by moving the existing cells to the
+     *  right. Cells moved outside the sheet will be deleted.
+     *
+     * @property {MoveMode} UP
+     *  A cell range will be deleted, the following cells below the cell range
+     *  will be moved up.
+     *
+     * @property {MoveMode} DOWN
+     *  A cell range will be made blank by moving the existing cells down.
+     *  Cells moved outside the sheet will be deleted.
+     */
+    SheetUtils.MoveMode = Enum.create('left right up down');
+
+    /**
+     * Enumeration for the merge modes for cell ranges. The JSON string
+     * representation of the enumeration values corresponds to the values used
+     * in the document operations 'mergeCells'.
+     *
+     * @constant
+     * @type Enum
+     *
+     * @property {MergeMode} MERGE
+     *  Merges an entire cell range (multiple columns and rows).
+     *
+     * @property {MergeMode} HORIZONTAL
+     *  Merges the individual rows in a cell range.
+     *
+     * @property {MergeMode} VERTICAL
+     *  Merges the individual columns in a cell range.
+     *
+     * @property {MergeMode} UNMERGE
+     *  Converts the affected merged ranges to single cells.
+     */
+    SheetUtils.MergeMode = Enum.create('merge horizontal vertical unmerge');
+
     // public methods ---------------------------------------------------------
 
     /**
@@ -374,48 +481,30 @@ define('io.ox/office/spreadsheet/utils/sheetutils', [
      */
     SheetUtils.getTextOrientation = function (value, align, display) {
 
-        // converts the passed text direction to left/right alignment
-        function getAlignFromDir(dir) {
-            return (dir === 'rtl') ? 'right' : 'left';
-        }
-
         // the effective writing direction of the display text
-        var displayDir = _.isString(display) ? Font.getTextDirection(display) : LocaleData.DIR;
+        var displayDir = (typeof display === 'string') ? Font.getTextDirection(display) : LocaleData.DIR;
+
         // the effective CSS text alignment
-        var cssTextAlign = null;
-        // base alignment of the text lines in the cell box
-        var baseBoxAlign = null;
-
-        switch (align) {
-            case 'left':
-            case 'center':
-            case 'right':
-            case 'justify':
-                cssTextAlign = align;
-                break;
-
-            default: // automatic alignment
-
+        var cssTextAlign = CSS_TEXT_ALIGN_VALUES[align];
+        if (!cssTextAlign) {
+            switch (typeof value) {
                 // strings (depends on writing direction of the text result, not display string!)
-                if (_.isString(value)) {
+                case 'string':
                     cssTextAlign = getAlignFromDir((value === display) ? displayDir : Font.getTextDirection(value));
-
+                    break;
                 // numbers (always right aligned, independent from display string)
-                } else if (_.isNumber(value)) {
+                case 'number':
                     cssTextAlign = 'right';
-
-                // blank cells (depending on system writing direction)
-                } else if (_.isNull(value)) {
-                    cssTextAlign = getAlignFromDir(Font.DEFAULT_TEXT_DIRECTION);
-
-                // booleans and error codes (always centered)
-                } else {
-                    cssTextAlign = 'center';
-                }
+                    break;
+                default:
+                    // blank cells (depending on system writing direction)
+                    // booleans and error codes (always centered)
+                    cssTextAlign = (value === null) ? getAlignFromDir(Font.DEFAULT_TEXT_DIRECTION) : 'center';
+            }
         }
 
         // base box alignment in justified cells depends on writing direction of display string
-        baseBoxAlign = (cssTextAlign === 'justify') ? getAlignFromDir(displayDir) : cssTextAlign;
+        var baseBoxAlign = (cssTextAlign === 'justify') ? getAlignFromDir(displayDir) : cssTextAlign;
 
         // return the orientation descriptor object
         return { textDir: displayDir, cssTextAlign: cssTextAlign, baseBoxAlign: baseBoxAlign };
@@ -503,65 +592,36 @@ define('io.ox/office/spreadsheet/utils/sheetutils', [
 
     /**
      * Returns the effective horizontal padding between cell grid lines and the
-     * text contents of the cell, according to the passed zoom factor.
+     * text contents of the cell, according to the width of the digits of a
+     * specific font.
      *
-     * @param {Number} zoom
-     *  The zoom factor to calculate the cell content padding for.
+     * @param {Number} digitWidth
+     *  The width of the digits of a specific font, in pixels.
      *
      * @returns {Number}
      *  The effective horizontal cell content padding, in pixels.
      */
-    SheetUtils.getTextPadding = function (zoom) {
-        // 2 pixels padding for 100% zoom, rounded up early
-        return Math.floor(2 * zoom + 0.75);
+    SheetUtils.getTextPadding = function (digitWidth) {
+        // text padding is 1/4 of the digit width
+        return Math.ceil(digitWidth / 4);
     };
 
     /**
      * Returns the total size of all horizontal padding occupied in a cell that
-     * cannot be used for the cell contents, according to the passed zoom
-     * factor. This value includes the text padding (twice, for left and right
-     * border), and additional space needed for the grid lines.
+     * cannot be used for the cell contents, according to the width of the
+     * digits of a specific font. This value includes the text padding (twice,
+     * for left and right border), and additional space needed for the trailing
+     * grid line.
      *
-     * @param {Number} zoom
-     *  The zoom factor to calculate the cell content padding for.
+     * @param {Number} digitWidth
+     *  The width of the digits of a specific font, in pixels.
      *
      * @returns {Number}
      *  The total size of the horizontal cell content padding, in pixels.
      */
-    SheetUtils.getTotalCellPadding = function (zoom) {
+    SheetUtils.getTotalCellPadding = function (digitWidth) {
         // padding at left and right cell border, and 1 pixel for the grid line
-        return 2 * SheetUtils.getTextPadding(zoom) + 1;
-    };
-
-    /**
-     * Returns whether the passed split mode identifier includes the dynamic
-     * split mode. Returns also true, if the split mode is 'frozenSplit', i.e.
-     * the effective split mode is frozen but will thaw to dynamic split mode.
-     *
-     * @param {String} splitMode
-     *  A split mode identifier (one of 'split', 'frozen', or 'frozenSplit').
-     *
-     * @returns {Boolean}
-     *  Whether the passed split mode identifier includes the dynamic split
-     *  mode (either 'split' or 'frozenSplit').
-     */
-    SheetUtils.isDynamicSplit = function (splitMode) {
-        return /^(split|frozenSplit)$/.test(splitMode);
-    };
-
-    /**
-     * Returns whether the passed split mode identifier includes the frozen
-     * split mode.
-     *
-     * @param {String} splitMode
-     *  A split mode identifier (one of 'split', 'frozen', or 'frozenSplit').
-     *
-     * @returns {Boolean}
-     *  Whether the passed split mode identifier includes the frozen split
-     *  mode (either 'frozen' or 'frozenSplit').
-     */
-    SheetUtils.isFrozenSplit = function (splitMode) {
-        return /^(frozen|frozenSplit)$/.test(splitMode);
+        return 2 * SheetUtils.getTextPadding(digitWidth) + 1;
     };
 
     // exports ================================================================
