@@ -14,28 +14,30 @@
 
 define('io.ox/office/spreadsheet/view/chartcreator', [
     'io.ox/office/tk/utils',
+    'io.ox/office/tk/render/rectangle',
     'io.ox/office/spreadsheet/utils/sheetutils',
     'io.ox/office/spreadsheet/utils/operations',
     'io.ox/office/spreadsheet/model/formula/tokenarray',
+    'io.ox/office/drawinglayer/view/chartstyleutil',
     'gettext!io.ox/office/spreadsheet/main'
-], function (Utils, SheetUtils, Operations, TokenArray, gt) {
+], function (Utils, Rectangle, SheetUtils, Operations, TokenArray, ChartStyleUtil, gt) {
 
     'use strict';
 
-    var // convenience shortcuts
-        Address = SheetUtils.Address,
-        Range = SheetUtils.Range,
-        Range3D = SheetUtils.Range3D,
-        Range3DArray = SheetUtils.Range3DArray,
+    // convenience shortcuts
+    var Address = SheetUtils.Address;
+    var Range = SheetUtils.Range;
+    var Range3D = SheetUtils.Range3D;
+    var Range3DArray = SheetUtils.Range3DArray;
 
-        // default width of new chart objects
-        CHART_DEFAULT_WIDTH = Utils.convertHmmToLength(15000, 'px', 1),
+    // default width of new chart objects
+    var CHART_DEFAULT_WIDTH = Utils.convertHmmToLength(15000, 'px', 1);
 
-        // default height of new chart objects
-        CHART_DEFAULT_HEIGHT = Utils.convertHmmToLength(10000, 'px', 1);
+    // default height of new chart objects
+    var CHART_DEFAULT_HEIGHT = Utils.convertHmmToLength(10000, 'px', 1);
 
     var DEFAULT_LINECOLOR = { transformations: [{ type: 'lumMod', value: 15000 }, { type: 'lumOff', value: 85000 }], type: 'scheme', value: 'text1' };
-    var STANDARD_SHAPE = { type: 'solid', color: DEFAULT_LINECOLOR, width: 36 };
+    var STANDARD_SHAPE = { type: 'solid', color: DEFAULT_LINECOLOR, width: 50 };
     var NONE_SHAPE = { type: 'none', color: null, width: null };
     var HEAD_CHAR = { fontSize: 16, bold: false };
 
@@ -68,8 +70,34 @@ define('io.ox/office/spreadsheet/view/chartcreator', [
         };
     }());
 
-    function getFormula(docModel, sheet, from, to) {
+    function getFormula(docModel, sheet, chart, from, to) {
         var range = new Range(from, to);
+
+        if (chart) {
+            // workaround for Bug 52802
+
+            var formula = null;
+
+            _.times(chart.getSeriesCount(), function (i) {
+                var seriesData = chart.getSeriesModel(i);
+                seriesData.iterateTokenArrays(function (tokenArray, linkKey) {
+                    if (formula) { return; }
+
+                    var oldRangeList = seriesData.resolveRanges(linkKey);
+                    if (oldRangeList.empty()) { return; }
+                    var oldRange = oldRangeList.first();
+
+                    if (oldRange.start.equals(range.start) && oldRange.end.equals(range.end)) {
+                        formula = tokenArray.getFormula('op');
+                    }
+                });
+            });
+
+            if (formula) {
+                return formula;
+            }
+        }
+
         var tokenArray = new TokenArray(docModel, 'chart');
         tokenArray.appendRange(range, { sheet: sheet, abs: true });
         return tokenArray.getFormula('op');
@@ -89,40 +117,76 @@ define('io.ox/office/spreadsheet/view/chartcreator', [
         var bubbleTo = options.bubbleTo;
         var bubbleArray = options.bubbleArray;
         var lineAttrs = options.lineAttrs;
+        var seriesData = options.seriesData;
+        var colors = options.colors;
+        var sourceChart = options.sourceChart;
+
+        var insert = {};
+        insert.values = getFormula(docModel, sourceSheet, sourceChart, valueFrom, valueTo);
+        insert.type = seriesData.type;
+        insert.dataLabel = seriesData.dataLabel;
 
-        var insert = {
-            values: getFormula(docModel, sourceSheet, valueFrom, valueTo)
-        };
         if (title) {
-            insert.title = getFormula(docModel, sourceSheet, title);
+            insert.title = getFormula(docModel, sourceSheet, sourceChart, title);
         }
         if (keyFrom) {
-            insert.names = getFormula(docModel, sourceSheet, keyFrom, keyTo);
+            insert.names = getFormula(docModel, sourceSheet, sourceChart, keyFrom, keyTo);
         }
         if (bubbleFrom) {
-            insert.bubbles = getFormula(docModel, sourceSheet, bubbleFrom, bubbleTo);
+            insert.bubbles = getFormula(docModel, sourceSheet, sourceChart, bubbleFrom, bubbleTo);
         } else if (bubbleArray) {
             insert.bubbles = bubbleArray;
         }
+
         var properties = {
             series: series,
-            attrs: {
-                series: insert,
-                line: lineAttrs || { type: 'solid' },
-                fill: { type: 'solid' }
-            }
+            attrs: { series: insert, fill: { type: 'solid' } }
         };
+
+        // TODO: _.clone( should not be needed, but it is, why?!
+        if (lineAttrs) {
+            properties.attrs.line = _.clone(lineAttrs);
+        } else if (seriesData.markersOnly) {
+            properties.attrs.line = _.copy(NONE_SHAPE, true);
+        } else {
+            properties.attrs.line = _.copy(STANDARD_SHAPE, true);
+        }
+
+        if (colors) {
+            if (colors.length > 1) {
+                var dataPoints = [];
+                colors.forEach(function (color) {
+                    dataPoints.push({
+                        fill: { type: 'solid', color: color },
+                        line: { type: 'solid', color: color }
+                    });
+                });
+                properties.attrs.series.dataPoints = dataPoints;
+            }
+            properties.attrs.line.color = colors[0];
+            properties.attrs.fill.color = colors[0];
+        }
         generator.generateDrawingOperation(Operations.INSERT_CHART_DATASERIES, position, properties);
     }
 
-    function generateSeriesOperations(docModel, sourceRange, sourceSheet, generator, position, cells, axis, chart, lineAttrs) {
+    function generateSeriesOperations(options) {
 
-        if (_.isUndefined(chart.varyColors)) {
+        var docModel = options.docModel;
+        var sourceRange = options.sourceRange;
+        var sourceSheet = options.sourceSheet;
+        var generator = options.generator;
+        var position = options.position;
+        var cells = options.cells;
+        var axis = options.axis;
+        var chart = options.chart;
+        var seriesData = options.seriesData;
+        var lineAttrs = options.lineAttrs;
+        var sourceChart = options.sourceChart;
+
+        if (!seriesData.colors.length) {
             chart.varyColors = true;
         }
 
-        generator.generateDrawingOperation(Operations.SET_DRAWING_ATTRIBUTES, position, { attrs: { chart: chart } });
-
         var start = sourceRange.start;
         var end = sourceRange.end;
 
@@ -146,20 +210,15 @@ define('io.ox/office/spreadsheet/view/chartcreator', [
         }
 
         var seriesCount;
-        if (chart.type && chart.type.indexOf('bubble') === 0) {
-            seriesCount = generateBubbleSeriesOperations(docModel, sourceRange, sourceSheet, generator, position, cells, useAxis, lineAttrs);
+        if (seriesData.type.indexOf('bubble') === 0) {
+            seriesCount = generateBubbleSeriesOperations(docModel, sourceRange, sourceSheet, generator, position, cells, useAxis, seriesData, lineAttrs, sourceChart);
         } else {
-            seriesCount = generateStandardSeriesOperations(docModel, sourceRange, sourceSheet, generator, position, cells, useAxis, lineAttrs);
-        }
-        if ((seriesCount === 1 && !chart.varyColors) || (chart.type === 'scatter2d' || chart.type === 'line2d')) {
-            var send = {};
-            if (seriesCount === 1 && !chart.varyColors) {
-                send.varyColors = true;
-            }
-            //CURVED is a workaround, filter has not all the information it needs!
-            send.curved = chart.curved;
-            generator.generateDrawingOperation(Operations.SET_DRAWING_ATTRIBUTES, position, { attrs: { chart: send } });
+            seriesCount = generateStandardSeriesOperations(docModel, sourceRange, sourceSheet, generator, position, cells, useAxis, seriesData, lineAttrs, sourceChart);
         }
+
+        // because of the curved attribute it has to be sent AFTER the series
+        generator.generateDrawingOperation(Operations.CHANGE_DRAWING, position, { attrs: { chart: chart } });
+
         return seriesCount;
     }
 
@@ -173,6 +232,52 @@ define('io.ox/office/spreadsheet/view/chartcreator', [
         return address;
     }
 
+    function prepareSeriesColors(docModel, sourceColors, seriesCount, dataPointsCount, colorSetIndex, pieDonut) {
+
+        var count = 0;
+        var single = seriesCount === 1 || pieDonut;
+
+        var varyColors = true;
+        if (single) {
+            count = dataPointsCount;
+            if (count > 1 && sourceColors.length > 1 && !ChartStyleUtil.isAutoColor(sourceColors[0]) && _.isEqual(sourceColors[0], sourceColors[1])) {
+                varyColors = false;
+            }
+        } else {
+            count = seriesCount;
+        }
+
+        var colorSet = null;
+        var newColors = null;
+        if (Utils.isFiniteNumber(colorSetIndex)) {
+            colorSet = ChartStyleUtil.getColorSet()[colorSetIndex];
+            newColors = [];
+        } else {
+            colorSet = ChartStyleUtil.getColorSet()[1];
+            newColors = sourceColors.slice(0);
+        }
+
+        for (var index = newColors.length; index < count; index++) {
+            var color = null;
+            if (varyColors) {
+                color = ChartStyleUtil.getColorOfPattern('cycle', colorSet.type, index, colorSet.colors, count, docModel);
+            } else {
+                color = ChartStyleUtil.getColorOfPattern('cycle', colorSet.type, 1, colorSet.colors, 3, docModel);
+            }
+            newColors.push(color);
+        }
+
+        var result = [];
+        if (single) {
+            for (var i = 0; i < seriesCount; i++) {
+                result.push(newColors);
+            }
+        } else {
+            newColors.forEach(function (color) { result.push([color]); });
+        }
+        return result;
+    }
+
     /**
      * generate all series from start to end.
      * Depending if first row/column contains a String,
@@ -185,7 +290,7 @@ define('io.ox/office/spreadsheet/view/chartcreator', [
      * @param {Number} activeAxis
      *  [1 or 0] column or row for the direction of any series data
      */
-    function generateStandardSeriesOperations(docModel, sourceRange, sourceSheet, generator, position, cells, activeAxis, lineAttrs) {
+    function generateStandardSeriesOperations(docModel, sourceRange, sourceSheet, generator, position, cells, activeAxis, seriesData, lineAttrs, sourceChart) {
 
         var start = sourceRange.start;
         var end = sourceRange.end;
@@ -209,6 +314,8 @@ define('io.ox/office/spreadsheet/view/chartcreator', [
             keyTo = makeAddress(activeAxis, otherAxis, start[activeAxis], end[otherAxis]);
         }
 
+        var seriesColors = prepareSeriesColors(docModel, seriesData.colors, max, (end[otherAxis] - start[otherAxis]) + 1, seriesData.colorSet, /^(pie|donut)/.test(seriesData.type));
+
         for (var i = 0; i < max; i++) {
             var activeIndex = start[activeAxis] + 1 + i;
 
@@ -232,7 +339,10 @@ define('io.ox/office/spreadsheet/view/chartcreator', [
                 title: title,
                 valueFrom: valueFrom,
                 valueTo: valueTo,
-                lineAttrs: lineAttrs
+                seriesData: seriesData,
+                lineAttrs: lineAttrs,
+                colors: seriesColors[i],
+                sourceChart: sourceChart
             });
         }
         return max;
@@ -253,17 +363,12 @@ define('io.ox/office/spreadsheet/view/chartcreator', [
      * @param {Number} activeAxis
      *  [1 or 0] column or row for the direction of any series data
      */
-    function generateBubbleSeriesOperations(docModel, sourceRange, sourceSheet, generator, position, cells, activeAxis, lineAttrs) {
+    function generateBubbleSeriesOperations(docModel, sourceRange, sourceSheet, generator, position, cells, activeAxis, seriesData, lineAttrs, sourceChart) {
 
         var start = sourceRange.start;
         var end = sourceRange.end;
 
         var max = end[activeAxis] - start[activeAxis];
-        if (max === 0) {
-            //exception only for 1D - Bubbles, behaves like excel
-            activeAxis = (activeAxis - 1) * -1;
-            max = end[activeAxis] - start[activeAxis];
-        }
         var otherAxis = (activeAxis - 1) * -1;
 
         var keyFrom, keyTo;
@@ -284,6 +389,8 @@ define('io.ox/office/spreadsheet/view/chartcreator', [
 
         var size = 0;
 
+        var seriesColors = prepareSeriesColors(docModel, seriesData.colors, max / 2, (end[otherAxis] - start[otherAxis]) + 1, seriesData.colorSet);
+
         for (var i = 0; i < max; i += 2) {
             var activeIndex = start[activeAxis] + 1 + i;
 
@@ -303,10 +410,14 @@ define('io.ox/office/spreadsheet/view/chartcreator', [
             var bubbleArray = null;
 
             if (i === max - 1) {
-                bubbleArray = [];
-                var arraySize = 1 + (valueTo[otherAxis] - valueFrom[otherAxis]);
-                for (var j = 0; j < arraySize; j++) {
-                    bubbleArray.push(1);
+                if (docModel.getApp().isODF()) {
+                    // keep old bubble from (bubbleArray not supported yet in ODF)
+                } else {
+                    bubbleArray = [];
+                    var arraySize = 1 + (valueTo[otherAxis] - valueFrom[otherAxis]);
+                    for (var j = 0; j < arraySize; j++) {
+                        bubbleArray.push(1);
+                    }
                 }
             } else {
                 bubbleFrom = makeAddress(activeAxis, otherAxis, valueFrom[activeAxis] + 1, valueFrom[otherAxis]);
@@ -325,7 +436,10 @@ define('io.ox/office/spreadsheet/view/chartcreator', [
                 bubbleFrom: bubbleFrom,
                 bubbleTo: bubbleTo,
                 bubbleArray: bubbleArray,
-                lineAttrs: lineAttrs
+                seriesData: seriesData,
+                lineAttrs: lineAttrs,
+                colors: seriesColors[i / 2],
+                sourceChart: sourceChart
             });
             size++;
         }
@@ -409,10 +523,58 @@ define('io.ox/office/spreadsheet/view/chartcreator', [
                 right = forceNames;
             }
         }
-
+        if (cols === 1) {
+            bottom = false;
+        }
+        if (rows === 1) {
+            right = false;
+        }
         return $.when({ cells: [bottom, right], axis: axis });
     }
 
+    function prepareFallbackValueAttrs(docModel, attrs) {
+        if (!attrs) {
+            return;
+        }
+        prepareFallbackValueShape(docModel, attrs.line);
+        prepareFallbackValueShape(docModel, attrs.fill);
+
+        return attrs;
+    }
+
+    function prepareFallbackValueShape(docModel, shape) {
+        if (!shape) {
+            return;
+        }
+        if (shape.color && shape.color.type === 'scheme') {
+            shape.color.fallbackValue = docModel.parseAndResolveColor(shape.color, 'fill').hex;
+        }
+        return shape;
+    }
+
+    function generatePieUndoRedoOperation(generator, name, position, axis, attrs, undoAttrs) {
+        if (_.isEmpty(undoAttrs)) {
+            undoAttrs = attrs;
+        }
+        generator.generateDrawingOperation(name, position, { axis: axis, attrs: attrs });
+        generator.generateDrawingOperation(name, position, { axis: axis, attrs: undoAttrs }, { undo: true });
+    }
+
+    function generatePieAxisOperations(generator, position, axId, clonedAxes) {
+        var cloneAxis = clonedAxes[axId];
+
+        generatePieUndoRedoOperation(generator, Operations.SET_CHART_AXIS_ATTRIBUTES, position, axId, INSERT_DEFAULTS.pie[axId + 'Axis'], cloneAxis.axis);
+
+        if (!_.isEmpty(cloneAxis.grid)) {
+            generatePieUndoRedoOperation(generator, Operations.SET_CHART_GRIDLINE_ATTRIBUTES, position, axId, INSERT_DEFAULTS.pie[axId + 'Grid'], cloneAxis.grid);
+        }
+
+        if (!_.isEmpty(cloneAxis.title)) {
+            generator.generateDrawingOperation(Operations.SET_CHART_TITLE_ATTRIBUTES, position, { axis: axId, attrs: { text: { link: null } } });
+            generator.generateDrawingOperation(Operations.SET_CHART_TITLE_ATTRIBUTES, position, { axis: axId, attrs: cloneAxis.title }, { undo: true });
+        }
+    }
+
     // static class ChartCreator ==============================================
 
     var ChartCreator = {};
@@ -426,7 +588,18 @@ define('io.ox/office/spreadsheet/view/chartcreator', [
      *  A promise that will be resolved after the chart has been created and
      *  inserted successfully, or that will be rejected on any error.
      */
-    ChartCreator.createChart = function (app, chart) {
+    ChartCreator.createChart = function (app, chartData) {
+
+        var chartAttrs = {
+            stacking: chartData.stacking,
+            curved: chartData.curved
+        };
+
+        var seriesData = {
+            type: chartData.series.type,
+            markersOnly: chartData.series.markersOnly,
+            colors: []
+        };
 
         var docModel = app.getModel();
         var docView = app.getView();
@@ -436,61 +609,69 @@ define('io.ox/office/spreadsheet/view/chartcreator', [
 
         var range = docView.getActiveRange();
 
-        var promise = getContentForRange(docModel, docView, range, docView.getActiveSheet());
+        var forceNames;
+        var axis;
+
+        if (seriesData.type.indexOf('bubble') === 0 && Math.min(range.cols(), range.rows()) > 2) {
+            forceNames = true;
+            if (range.cols() > range.rows()) {
+                axis = 1;
+            } else {
+                axis = 0;
+            }
+        }
+
+        var promise = getContentForRange(docModel, docView, range, docView.getActiveSheet(), axis, undefined, forceNames);
 
         promise = promise.then(function (data) {
 
-            var rect = gridPane.getVisibleRectangle();
+            var visibleRect = gridPane.getVisibleRectangle();
 
-            var clip = {
-                left: Math.max(0, Math.round(rect.left + (rect.width - CHART_DEFAULT_WIDTH) / 2)),
-                top: Math.max(0, Math.round(rect.top + (rect.height - CHART_DEFAULT_HEIGHT) / 2)),
-                width: CHART_DEFAULT_WIDTH,
-                height: CHART_DEFAULT_HEIGHT
-            };
+            var chartRect = new Rectangle(
+                Math.max(0, Math.round(visibleRect.left + (visibleRect.width - CHART_DEFAULT_WIDTH) / 2)),
+                Math.max(0, Math.round(visibleRect.top + (visibleRect.height - CHART_DEFAULT_HEIGHT) / 2)),
+                CHART_DEFAULT_WIDTH,
+                CHART_DEFAULT_HEIGHT
+            );
 
-            var attrs = drawingCollection.getAttributeSetForRectangle(clip);
+            var drawingDesc = { type: 'chart', attrs: drawingCollection.getAttributeSetForRectangle(chartRect) };
+            drawingDesc.attrs.fill = { type: 'solid', color: { type: 'scheme', value: 'light1' } };
+            drawingDesc.attrs.line = { type: 'none' };
 
-            return docView.insertDrawing('chart', attrs, function (generator, sheet, position) {
+            return app.getController().execInsertDrawings([drawingDesc], function (generator, sheet, position) {
 
-                if (!chart.chartStyleId) {
-                    chart.chartStyleId = 2;
+                if (!chartAttrs.chartStyleId) {
+                    chartAttrs.chartStyleId = 2;
                 }
 
-                var seriesCount = generateSeriesOperations(docModel, range, sheet, generator, position, data.cells, data.axis, chart);
+                generateSeriesOperations({ docModel: docModel, sourceRange: range, sourceSheet: sheet, generator: generator, position: position, cells: data.cells, axis: data.axis, chart: chartAttrs, seriesData: seriesData });
 
-                var legendPos;
-                if (seriesCount === 1) {
-                    //TODO: title
-                    legendPos = 'off';
-                    generator.generateDrawingOperation(Operations.SET_CHART_TITLE_ATTRIBUTES, position, { axis: 'main', attrs: { character: HEAD_CHAR } });
-                } else {
-                    legendPos = 'bottom';
-                }
-                generator.generateDrawingOperation(Operations.SET_CHART_LEGEND_ATTRIBUTES, position, { attrs: { legend: { pos: legendPos } } });
+                generator.generateDrawingOperation(Operations.SET_CHART_TITLE_ATTRIBUTES, position, { axis: 'main', attrs: { character: { fontSize: 1 }, text: { link: [' '] } } });
+                generator.generateDrawingOperation(Operations.SET_CHART_LEGEND_ATTRIBUTES, position, { attrs: { legend: { pos:  'bottom' } } });
 
                 var defaults;
-                switch (chart.type) {
-                    case 'bubble2d':
-                    case 'scatter2d':
+                var type = seriesData.type.replace('2d', '').replace('3d', '');
+                switch (type) {
+                    case 'bubble':
+                    case 'scatter':
                         defaults = INSERT_DEFAULTS.xy;
                         break;
-                    case 'pie2d':
-                    case 'donut2d':
+                    case 'pie':
+                    case 'donut':
                         defaults = INSERT_DEFAULTS.pie;
                         break;
                     default:
                         defaults = INSERT_DEFAULTS.normal;
                 }
 
-                generator.generateDrawingOperation(Operations.SET_CHART_AXIS_ATTRIBUTES, position, { axis: 'x', attrs: defaults.xAxis });
-                generator.generateDrawingOperation(Operations.SET_CHART_AXIS_ATTRIBUTES, position, { axis: 'y', attrs: defaults.yAxis });
-                generator.generateDrawingOperation(Operations.SET_CHART_GRIDLINE_ATTRIBUTES, position, { axis: 'x', attrs: defaults.xGrid });
-                generator.generateDrawingOperation(Operations.SET_CHART_GRIDLINE_ATTRIBUTES, position, { axis: 'y', attrs: defaults.yGrid });
+                generator.generateDrawingOperation(Operations.SET_CHART_AXIS_ATTRIBUTES, position, { axis: 'x', attrs: prepareFallbackValueAttrs(docModel, defaults.xAxis) });
+                generator.generateDrawingOperation(Operations.SET_CHART_AXIS_ATTRIBUTES, position, { axis: 'y', attrs: prepareFallbackValueAttrs(docModel, defaults.yAxis) });
+                generator.generateDrawingOperation(Operations.SET_CHART_GRIDLINE_ATTRIBUTES, position, { axis: 'x', attrs: prepareFallbackValueAttrs(docModel, defaults.xGrid) });
+                generator.generateDrawingOperation(Operations.SET_CHART_GRIDLINE_ATTRIBUTES, position, { axis: 'y', attrs: prepareFallbackValueAttrs(docModel, defaults.yGrid) });
             });
         });
 
-        return promise;
+        return docView.yellOnFailure(promise);
     };
 
     /**
@@ -507,7 +688,7 @@ define('io.ox/office/spreadsheet/view/chartcreator', [
      *  @param {String} [options.axis]
      *      series direction
      *
-     *  @param {Object} [options.chartAttrs]
+     *  @param {Object} [options.chartData]
      *      is used for changing other attributes of the chart and for the type info (bubble or not)
      *
      *  @param {Boolean} [options.forceTitle]
@@ -527,19 +708,40 @@ define('io.ox/office/spreadsheet/view/chartcreator', [
         var sourceSheet = Utils.getOption(options, 'sourceSheet');
         var chartModel  = Utils.getOption(options, 'chartModel');
         var axis        = Utils.getOption(options, 'axis');
-        var chartAttrs  = Utils.getOption(options, 'chartAttrs');
+        var chartData   = Utils.getOption(options, 'chartData');
         var forceTitle  = Utils.getOption(options, 'forceTitle');
         var forceNames  = Utils.getOption(options, 'forceNames');
-        var typeChanged = Utils.getOption(options, 'typeChanged');
+        // var typeChanged = Utils.getOption(options, 'typeChanged');
 
-        if (!chartAttrs) {
-            var mergedAttributes = chartModel.getMergedAttributeSet(true);
+        var chartAttrs = null;
+        var seriesData = null;
+        var mergedAttributes = chartModel.getMergedAttributeSet(true);
+
+        if (!chartData) {
             //CURVED is a workaround, filter has not all the information it needs!
             chartAttrs = {
-                type: mergedAttributes.chart.type,
                 stacking: mergedAttributes.chart.stacking,
                 curved: mergedAttributes.chart.curved
             };
+            seriesData = {
+                type: chartModel.getChartType().split(' ')[0],
+                markersOnly: chartModel.isMarkerOnly()
+            };
+        } else {
+            chartAttrs = {
+                stacking: chartData.stacking,
+                curved: chartData.curved
+            };
+            seriesData = chartData.series;
+        }
+
+        seriesData.colors = chartModel.getSeriesColorInfo();
+        seriesData.dataLabel = chartModel.getDataLabel();
+        chartAttrs.chartStyleId = mergedAttributes.chart.chartStyleId;
+        if (chartAttrs.chartStyleId) {
+            seriesData.colorSet = chartModel.getColorSet().replace('cs', '') | 0;
+        } else {
+            seriesData.colorSet = null;
         }
 
         var clonedData = chartModel.getCloneData();
@@ -556,23 +758,20 @@ define('io.ox/office/spreadsheet/view/chartcreator', [
             if (data.axis === 0 || data.axis === 1) {
                 axis = data.axis;
             }
-            var position = chartModel.getSheetPosition();
+            var position = chartModel.getPosition();
             var lineAttrs = null;
-            if (!typeChanged && chartModel.isMarkerOnly()) {
-                lineAttrs = NONE_SHAPE;
-            }
 
             return chartModel.getSheetModel().createAndApplyOperations(function (generator) {
 
                 var oldCount = chartModel.getSeriesCount();
-                var seriesCount = generateSeriesOperations(docModel, sourceRange, sourceSheet, generator, position, data.cells, axis, chartAttrs, lineAttrs);
+                var seriesCount = generateSeriesOperations({ docModel: docModel, sourceRange: sourceRange, sourceSheet: sourceSheet, generator: generator, position: position, cells: data.cells, axis: axis, chart: chartAttrs, seriesData: seriesData, lineAttrs: lineAttrs, sourceChart: chartModel });
 
                 _.times(oldCount, function () {
                     generator.generateDrawingOperation(Operations.DELETE_CHART_DATASERIES, position, { series: seriesCount });
                 });
 
                 // UNDO ---
-                generator.generateDrawingOperation(Operations.SET_DRAWING_ATTRIBUTES, position, { attrs: undoAttrs }, { undo: true });
+                generator.generateDrawingOperation(Operations.CHANGE_DRAWING, position, { attrs: undoAttrs }, { undo: true });
 
                 _.each(clonedData.series, function (obj, index) {
                     generator.generateDrawingOperation(Operations.INSERT_CHART_DATASERIES, position, { series: index, attrs: obj }, { undo: true });
@@ -582,6 +781,11 @@ define('io.ox/office/spreadsheet/view/chartcreator', [
                     generator.generateDrawingOperation(Operations.DELETE_CHART_DATASERIES, position, { series: oldCount }, { undo: true });
                 });
 
+                if (/^(pie|donut)/.test(seriesData.type)) {
+                    generatePieAxisOperations(generator, position, 'x', clonedData.axes);
+                    generatePieAxisOperations(generator, position, 'y', clonedData.axes);
+                }
+
                 // callback MUST return a promise
                 return $.when();
             }, { storeSelection: true });
@@ -590,19 +794,13 @@ define('io.ox/office/spreadsheet/view/chartcreator', [
         return promise;
     };
 
-    ChartCreator.generateOperationsFromModelData = function (app, generator, position, chartModelData) {
-        var chartAttrs = {
-            chart: chartModelData.attrs.chart,
-            fill: chartModelData.attrs.fill,
-            line: chartModelData.attrs.line
-        };
+    ChartCreator.generateOperationsFromModelData = function (generator, position, chartModelData) {
+
         var axes = chartModelData.axes;
         var series = chartModelData.series;
         var title = chartModelData.title;
         var legend = chartModelData.legend;
 
-        generator.generateDrawingOperation(Operations.SET_DRAWING_ATTRIBUTES, position, { attrs: chartAttrs });
-
         _.each(series, function (serie, index) {
             var properties = {
                 series: index,
@@ -633,11 +831,11 @@ define('io.ox/office/spreadsheet/view/chartcreator', [
 
     };
 
-    ChartCreator.getStandardShape = function () {
-        return STANDARD_SHAPE;
+    ChartCreator.getStandardShape = function (docModel) {
+        return prepareFallbackValueShape(docModel, STANDARD_SHAPE);
     };
 
-    ChartCreator.getHeadChar = function () {
+    ChartCreator.getHeadChar = function (/*docModel*/) {
         return HEAD_CHAR;
     };
 
