@@ -16,11 +16,12 @@ define('io.ox/office/spreadsheet/view/control/activesheetgroup', [
     'io.ox/office/tk/utils',
     'io.ox/office/tk/forms',
     'io.ox/office/tk/utils/tracking',
+    'io.ox/office/tk/utils/iteratorutils',
     'io.ox/office/tk/control/radiogroup',
     'io.ox/office/baseframework/app/appobjectmixin',
     'io.ox/office/spreadsheet/view/popup/sheetcontextmenu',
     'gettext!io.ox/office/spreadsheet/main'
-], function (Utils, Forms, Tracking, RadioGroup, AppObjectMixin, SheetContextMenu, gt) {
+], function (Utils, Forms, Tracking, IteratorUtils, RadioGroup, AppObjectMixin, SheetContextMenu, gt) {
 
     'use strict';
 
@@ -37,11 +38,8 @@ define('io.ox/office/spreadsheet/view/control/activesheetgroup', [
      *
      * @param {SpreadsheetView} docView
      *  The spreadsheet view containing this instance.
-     *
-     * @param {Object} [initOptions]
-     *  Optional parameters. Will be passed to the base class RadioGroup.
      */
-    function ActiveSheetGroup(docView) {
+    var ActiveSheetGroup = RadioGroup.extend({ constructor: function (docView) {
 
         // self reference
         var self = this;
@@ -77,9 +75,12 @@ define('io.ox/office/spreadsheet/view/control/activesheetgroup', [
         var dndStartIndex = -1;
         var dndTargetIndex = -1;
 
+        // whether the tracking point has been moved at all (bug 50653)
+        var dndMoved = false;
+
         // base constructors --------------------------------------------------
 
-        RadioGroup.call(this, { classes: 'active-sheet-group', role: 'tablist' });
+        RadioGroup.call(this, docView, { classes: 'active-sheet-group', role: 'tablist' });
         AppObjectMixin.call(this, docView.getApp());
 
         // private methods ----------------------------------------------------
@@ -122,11 +123,12 @@ define('io.ox/office/spreadsheet/view/control/activesheetgroup', [
 
             // collect position information of all buttons (performance: once for all buttons, before manipulating DOM again)
             var leadingOffset = sheetButtons.first().offset().left;
-            var buttonPositions = sheetButtons.map(function () {
-                var buttonOffset = $(this).offset().left - leadingOffset;
+            var buttonPositions = sheetButtons.get().map(function (buttonNode) {
+                buttonNode = $(buttonNode);
+                var buttonOffset = buttonNode.offset().left - leadingOffset;
                 return {
                     offset: buttonOffset,
-                    leadingWidth: buttonOffset + $(this).outerWidth(),
+                    leadingWidth: buttonOffset + buttonNode.outerWidth(),
                     trailingWidth: buttonsWidth - buttonOffset
                 };
             });
@@ -157,7 +159,7 @@ define('io.ox/office/spreadsheet/view/control/activesheetgroup', [
 
                 // adjust button positions relative to first visible button
                 var relOffset = buttonPositions[firstIndex].offset;
-                _.each(buttonPositions, function (position) {
+                buttonPositions.forEach(function (position) {
                     position.offset -= relOffset;
                     position.leadingWidth -= relOffset;
                 });
@@ -262,8 +264,8 @@ define('io.ox/office/spreadsheet/view/control/activesheetgroup', [
         }
 
         /**
-         * Handles tracking on the scroll-back button. Stops event propagation,
-         * to not interfere with sheet move tracking.
+         * Handles tracking on the scroll-back button. Stops event propagation
+         * (to not interfere with sheet move tracking).
          */
         function prevButtonTrackingHandler(event) {
             scrollToPrev();
@@ -272,7 +274,7 @@ define('io.ox/office/spreadsheet/view/control/activesheetgroup', [
 
         /**
          * Handles tracking on the scroll-forward button. Stops event
-         * propagation, to not interfere with sheet move tracking.
+         * propagation (to not interfere with sheet move tracking).
          */
         function nextButtonTrackingHandler(event) {
             scrollToNext();
@@ -308,8 +310,8 @@ define('io.ox/office/spreadsheet/view/control/activesheetgroup', [
         function dndTrackingStartHandler(event) {
 
             // do nothing in read-only mode
-            if (!docModel.getEditMode()) {
-                Tracking.cancelTracking();
+            if (!docView.isEditable()) {
+                event.cancelTracking();
                 return;
             }
 
@@ -323,6 +325,9 @@ define('io.ox/office/spreadsheet/view/control/activesheetgroup', [
             dndSheetNode.text(Forms.getCaptionText(dndButtonNode));
             $(document.body).append(dndTrackerNode.hide());
             dndButtonNode.addClass('tracking-active');
+
+            // bug 50653: check whether the tracking point has been moved at all
+            dndMoved = false;
         }
 
         /**
@@ -335,14 +340,16 @@ define('io.ox/office/spreadsheet/view/control/activesheetgroup', [
             // all visible sheet tab buttons
             var visibleNodes = Forms.filterVisibleNodes(buttonNodes);
             // absolute position and size of all visible sheet buttons
-            var buttonRects = _.map(visibleNodes.get(), Utils.getNodePositionInPage);
+            var buttonRects = visibleNodes.get().map(Utils.getNodePositionInPage);
             // search rectangle of hovered sheet tab button in array of visible button rectangles
-            var rectIndex = Utils.findLastIndex(buttonRects, function (data) {
-                return (data.left + data.width / 2) <= event.pageX;
+            var rectIndex = Utils.findLastIndex(buttonRects, function (rect) {
+                return (rect.left + rect.width / 2) <= event.pageX;
             }, { sorted: true }) + 1;
 
             // calculate new insertion index (add number of leading hidden buttons)
             dndTargetIndex = buttonNodes.index(visibleNodes[0]) + rectIndex;
+            // bug 50653: check whether the tracking point has been moved at all
+            dndMoved = true;
 
             // hide tracking icon on invalid position (next to start button)
             if (!isValidDndTargetIndex()) {
@@ -353,7 +360,7 @@ define('io.ox/office/spreadsheet/view/control/activesheetgroup', [
             // whether to show the tracking position after the last visible button
             var trailing = rectIndex >= buttonRects.length;
             // position of the sheet tab button following the tracking position
-            var buttonRect = buttonRects[rectIndex] || _.last(buttonRects);
+            var buttonRect = trailing ? _.last(buttonRects) : buttonRects[rectIndex];
             // exact insertion position (center of the tracker node), in pixels
             var offsetX = buttonRect.left + (trailing ? buttonRect.width : 0);
 
@@ -387,27 +394,36 @@ define('io.ox/office/spreadsheet/view/control/activesheetgroup', [
          */
         function dndTrackingEndHandler() {
 
-            // leave cell edit mode before manipulating the sheet order
-            if (isValidDndTargetIndex() && docView.leaveCellEditMode()) {
+            // leave text edit mode before manipulating the sheet order
+            var promise = docView.leaveTextEditMode().done(function () {
 
-                // adjust drop position, if target position follows source position
-                if (dndStartIndex < dndTargetIndex) { dndTargetIndex -= 1; }
-
-                // the sheet tab button nodes
-                var buttonNodes = self.getOptionButtons();
                 // source sheet index for document operation
-                var fromSheet = Utils.getElementAttributeAsInteger(buttonNodes[dndStartIndex], 'data-index', -1);
-                // target sheet index for document operation
-                var toSheet = Utils.getElementAttributeAsInteger(buttonNodes[dndTargetIndex], 'data-index', -1);
+                var fromSheet = Forms.getButtonValue(dndButtonNode);
 
-                // change sheet order in the document
-                if ((fromSheet >= 0) && (toSheet >= 0)) {
-                    docView.executeControllerItem('sheet/move', { from: fromSheet, to: toSheet });
+                // move sheet only if its position will really change
+                if (isValidDndTargetIndex()) {
+
+                    // adjust drop position, if target position follows source position
+                    if (dndStartIndex < dndTargetIndex) { dndTargetIndex -= 1; }
+
+                    // the sheet tab button nodes
+                    var buttonNodes = self.getOptionButtons();
+                    // target sheet index for document operation
+                    var toSheet = Forms.getButtonValue(buttonNodes[dndTargetIndex]);
+
+                    // change sheet order in the document
+                    if (fromSheet !== toSheet) {
+                        docView.executeControllerItem('document/movesheet', { from: fromSheet, to: toSheet });
+                    }
+
+                } else if (dndMoved) {
+                    // activate the sheet that has been tracked but will not be moved
+                    self.triggerChange(fromSheet);
                 }
-            }
+            });
 
             // remove tracking icon, focus back to document
-            dndTrackingCancelHandler();
+            promise.always(dndTrackingCancelHandler);
         }
 
         /**
@@ -426,18 +442,22 @@ define('io.ox/office/spreadsheet/view/control/activesheetgroup', [
         /**
          * Recreates all sheet tabs in this radio group.
          */
-        var fillList = this.createDebouncedMethod($.noop, function () {
+        var fillList = this.createDebouncedMethod('ActiveSheetGroup.fillList', null, function () {
+
+            // remove all old option buttons
+            self.clearOptionButtons();
 
             // create buttons for all visible sheets
-            self.clearOptionButtons();
-            docView.iterateVisibleSheets(function (sheetModel, index, sheetName) {
-                self.createOptionButton(index, {
+            var iterator = docModel.createSheetIterator({ supported: true, visible: true });
+            IteratorUtils.forEach(iterator, function (sheetModel, iterResult) {
+                var sheetLabel = _.noI18n(iterResult.name);
+                self.createOptionButton(iterResult.sheet, {
                     icon: sheetModel.isLocked() ? 'fa-lock' : null,
                     iconClasses: 'small-icon',
-                    label: _.noI18n(sheetName),
+                    label: sheetLabel,
                     labelStyle: 'white-space:pre;',
-                    tooltip: _.noI18n(sheetName),
-                    attributes: { role: 'tab', 'data-index': sheetModel.getIndex() }
+                    tooltip: sheetLabel,
+                    attributes: { role: 'tab' }
                 });
             });
 
@@ -446,7 +466,7 @@ define('io.ox/office/spreadsheet/view/control/activesheetgroup', [
 
             // explicitly notify listeners, needed for reliable layout
             self.trigger('change:sheets');
-        }, { infoString: 'ActiveSheetGroup: fillList', app: docView.getApp() });
+        });
 
         // methods ------------------------------------------------------------
 
@@ -484,26 +504,25 @@ define('io.ox/office/spreadsheet/view/control/activesheetgroup', [
         // initialization -----------------------------------------------------
 
         // set tool tips for scroll buttons
-        Forms.setToolTip(prevButton, { tooltip: gt('Scroll to the previous sheet') });
-        Forms.setToolTip(nextButton, { tooltip: gt('Scroll to the next sheet') });
+        Forms.setToolTip(prevButton, gt('Scroll to the previous sheet'));
+        Forms.setToolTip(nextButton, gt('Scroll to the next sheet'));
+
+        // cancel button drag&drop when losing edit rights
+        this.listenTo(docView.getApp(), 'docs:editmode:leave', function () {
+            if (dndButtonNode) { Tracking.cancelTracking(); }
+        });
+
+        // register handler early for fast preview during import
+        this.listenTo(docView.getApp(), 'docs:preview:activesheet', fillList);
 
         // initialization after import
         this.waitForImportSuccess(function () {
             // build the list of available sheets once after import
             fillList();
             // rebuild the list of available sheets after it has been changed
-            this.listenTo(docView, 'change:sheets', fillList);
-            this.listenTo(docModel, 'change:sheet:attributes', fillList); // e.g. sheet protection
+            this.listenTo(docModel, 'transform:sheet rename:sheet change:sheet:attributes', fillList);
         }, this);
 
-        // register handler early for fast preview during import
-        this.listenTo(docView, 'preview:activesheet', fillList);
-
-        // cancel button drag&drop when losing edit rights
-        this.listenTo(docModel, 'change:editmode', function (event, editMode) {
-            if (!editMode && dndButtonNode) { Tracking.cancelTracking(); }
-        });
-
         // create the context menu
         contextMenu = new SheetContextMenu(docView, this.getNode());
 
@@ -543,11 +562,10 @@ define('io.ox/office/spreadsheet/view/control/activesheetgroup', [
             prevButton = nextButton = dndTrackerNode = dndSheetNode = null;
         });
 
-    } // class ActiveSheetGroup
+    } }); // class ActiveSheetGroup
 
     // exports ================================================================
 
-    // derive this class from class RadioGroup
-    return RadioGroup.extend({ constructor: ActiveSheetGroup });
+    return ActiveSheetGroup;
 
 });
