@@ -14,10 +14,11 @@
 
 define('io.ox/office/spreadsheet/view/control/activesheetlist', [
     'io.ox/office/tk/utils',
+    'io.ox/office/tk/utils/iteratorutils',
     'io.ox/office/tk/control/radiolist',
     'io.ox/office/baseframework/app/appobjectmixin',
     'gettext!io.ox/office/spreadsheet/main'
-], function (Utils, RadioList, AppObjectMixin, gt) {
+], function (Utils, IteratorUtils, RadioList, AppObjectMixin, gt) {
 
     'use strict';
 
@@ -37,7 +38,7 @@ define('io.ox/office/spreadsheet/view/control/activesheetlist', [
      * @param {Object} [initOptions]
      *  Optional parameters. Will be passed to the base class RadioList.
      */
-    function ActiveSheetList(docView, initOptions) {
+    var ActiveSheetList = RadioList.extend({ constructor: function (docView, initOptions) {
 
         // self reference
         var self = this;
@@ -50,7 +51,7 @@ define('io.ox/office/spreadsheet/view/control/activesheetlist', [
 
         // base constructors --------------------------------------------------
 
-        RadioList.call(this, {
+        RadioList.call(this, docView, {
             icon: showNames ? null : 'fa-bars',
             iconClasses: showNames ? 'small-icon' : null,
             tooltip: gt('Select sheet'),
@@ -65,43 +66,43 @@ define('io.ox/office/spreadsheet/view/control/activesheetlist', [
         /**
          * Recreates all sheet entries in the drop-down menu.
          */
-        var fillList = this.createDebouncedMethod($.noop, function () {
+        var fillList = this.createDebouncedMethod('ActiveSheetList.fillList', null, function () {
             self.clearMenu();
-            docView.iterateVisibleSheets(function (sheetModel, index, sheetName) {
-                self.createOptionButton(index, {
+            var iterator = docModel.createSheetIterator({ supported: true, visible: true });
+            IteratorUtils.forEach(iterator, function (sheetModel, iterResult) {
+                var sheetLabel = _.noI18n(iterResult.name);
+                self.createOptionButton(iterResult.sheet, {
                     icon: sheetModel.isLocked() ? 'fa-lock' : null,
                     iconClasses: 'small-icon',
-                    label: _.noI18n(sheetName),
+                    label: sheetLabel,
                     labelStyle: 'white-space:pre;',
-                    tooltip: _.noI18n(sheetName)
+                    tooltip: sheetLabel
                 });
             });
-        }, { infoString: 'ActiveSheetList: fillList', app: docView.getApp() });
+        });
 
         // initialization -----------------------------------------------------
 
+        // register handler early for fast preview during import
+        this.listenTo(docView.getApp(), 'docs:preview:activesheet', fillList);
+
         // initialization after import
         this.waitForImportSuccess(function () {
             // build the list of available sheets once after import
             fillList();
             // rebuild the list of available sheets after it has been changed
-            this.listenTo(docView, 'change:sheets', fillList);
-            this.listenTo(docModel, 'change:sheet:attributes', fillList); // e.g. sheet protection
+            this.listenTo(docModel, 'transform:sheet rename:sheet change:sheet:attributes', fillList);
         }, this);
 
-        // register handler early for fast preview during import
-        this.listenTo(docView, 'preview:activesheet', fillList);
-
         // destroy all class members on destruction
         this.registerDestructor(function () {
             self = docModel = docView = initOptions = null;
         });
 
-    } // class ActiveSheetList
+    } }); // class ActiveSheetList
 
     // exports ================================================================
 
-    // derive this class from class RadioList
-    return RadioList.extend({ constructor: ActiveSheetList });
+    return ActiveSheetList;
 
 });
