@@ -13,12 +13,11 @@
  */
 
 define('io.ox/office/spreadsheet/view/control/discretefiltergroup', [
-    'io.ox/office/tk/utils',
     'io.ox/office/tk/control/checkgroup',
     'io.ox/office/spreadsheet/utils/scalarset',
     'io.ox/office/spreadsheet/model/formula/formulautils',
     'gettext!io.ox/office/spreadsheet/main'
-], function (Utils, CheckGroup, ScalarSet, FormulaUtils, gt) {
+], function (CheckGroup, ScalarSet, FormulaUtils, gt) {
 
     'use strict';
 
@@ -41,22 +40,25 @@ define('io.ox/office/spreadsheet/view/control/discretefiltergroup', [
      * @param {SpreadsheetView} docView
      *  The spreadsheet view that contains this instance.
      */
-    function DiscreteFilterGroup(docView) {
+    var DiscreteFilterGroup = CheckGroup.extend({ constructor: function (docView) {
 
         // self reference
         var self = this;
 
+        // special behavior for ODF documents
+        var odf = docView.getApp().isODF();
+
         // base constructor ---------------------------------------------------
 
-        CheckGroup.call(this, { matcher: matcher, sorted: sortComparator, boxed: true, checkAll: true });
+        CheckGroup.call(this, docView, { matcher: itemMatcher, sorted: sortComparator, boxed: true, checkAll: true });
 
         // private methods ----------------------------------------------------
 
         /**
          * A case-insensitive list item matcher.
          */
-        function matcher(value, entry) {
-            return (docView.getApp().isODF() && value === entry) || (_.isString(value) && _.isString(entry) && value.toLowerCase() === entry.toLowerCase());
+        function itemMatcher(value, entry) {
+            return (odf && (value === entry)) || (_.isString(value) && _.isString(entry) && (value.toLowerCase() === entry.toLowerCase()));
         }
 
         /**
@@ -74,8 +76,8 @@ define('io.ox/office/spreadsheet/view/control/discretefiltergroup', [
          * Collects and inserts the cell entries of a table column into this
          * control.
          *
-         * @param {String} tableName
-         *  The name of the table model in the active sheet to be filtered.
+         * @param {String} tableModel
+         *  The model of the table range in the active sheet to be filtered.
          *
          * @param {Number} tableCol
          *  The zero-based column index, relative to the table range.
@@ -84,23 +86,18 @@ define('io.ox/office/spreadsheet/view/control/discretefiltergroup', [
          *  A promise that will be resolved when the control has been
          *  initialized.
          */
-        this.initialize = function (tableName, tableCol) {
+        this.initialize = function (tableModel, tableCol) {
 
             this.clearOptionButtons();
 
-            // resolve the table model from the document
-            var tableModel = docView.getTableCollection().getTable(tableName);
-
-            if (!tableModel) {
-                Utils.warn('DiscreteFilterGroup.initialize(): table model not found');
-                return $.Deferred().reject();
-            }
+            // resolve the table column model
+            var columnModel = tableModel.getColumnModel(tableCol);
 
             // unfiltered table column: show entries of all visible rows; filtered table column: show
             // entries for all data rows that are not filtered by other columns (but that may be hidden)
-            var promise = tableModel.isColumnFiltered(tableCol) ?
+            var promise = columnModel.isFiltered() ?
                 tableModel.queryFilterResult({ skipColumns: [tableCol] }) :
-                $.when(tableModel.getVisibleDataRows());
+                this.createResolvedPromise(tableModel.getVisibleDataRows());
 
             // fill the menu with the values
             promise = promise.then(function (rowIntervals) {
@@ -108,12 +105,11 @@ define('io.ox/office/spreadsheet/view/control/discretefiltergroup', [
                 // fetch cell contents of the column from the document
                 var cellArray = tableModel.getColumnContents(tableCol, rowIntervals);
                 // the filter attributes of the table column
-                var attributes = tableModel.getColumnAttributeSet(tableCol, true).filter;
+                var attributes = columnModel.getMergedAttributeSet(true).filter;
                 // each display string will be inserted once only
                 // OOXML: case-insensitive display string, always use first occurrence
                 // ODF: case-insensitive, separated by value type
                 var usedEntries = new ScalarSet();
-                var isODF = docView.getApp().isODF();
 
                 // insert the new entries into the list
                 cellArray.forEach(function (cellData) {
@@ -122,7 +118,7 @@ define('io.ox/office/spreadsheet/view/control/discretefiltergroup', [
                     // bug 36264: trim space characters but no other whitespace
                     var label = cellData.display.replace(/^ +| +$/g, '');
                     // the key used to detect duplicates
-                    var key = isODF ? cellData.value : label.toLowerCase();
+                    var key = odf ? cellData.value : label.toLowerCase();
 
                     // the case-insensitive key used to detect duplicates
                     if (usedEntries.has(key)) { return; }
@@ -149,11 +145,10 @@ define('io.ox/office/spreadsheet/view/control/discretefiltergroup', [
             self = docView = null;
         });
 
-    } // class DiscreteFilterGroup
+    } }); // class DiscreteFilterGroup
 
     // exports ================================================================
 
-    // derive this class from class CheckGroup
-    return CheckGroup.extend({ constructor: DiscreteFilterGroup });
+    return DiscreteFilterGroup;
 
 });
