@@ -37,11 +37,11 @@ define('io.ox/office/spreadsheet/view/control/formatcategorypicker', [
      * @param {Object} [initOptions]
      *  Optional parameters. Supports all options of the base class RadioList.
      */
-    function FormatCategoryPicker(docView, initOptions) {
+    var FormatCategoryPicker = RadioList.extend({ constructor: function (docView, initOptions) {
 
         // base constructors --------------------------------------------------
 
-        RadioList.call(this, Utils.extendOptions({
+        RadioList.call(this, docView, Utils.extendOptions({
             label: _.noI18n('123'),
             tooltip: gt('Number format')
         }, initOptions, {
@@ -64,11 +64,10 @@ define('io.ox/office/spreadsheet/view/control/formatcategorypicker', [
             docView = initOptions = null;
         });
 
-    } // class FormatCategoryPicker
+    } }); // class FormatCategoryPicker
 
     // exports ================================================================
 
-    // derive this class from class RadioList
-    return RadioList.extend({ constructor: FormatCategoryPicker });
+    return FormatCategoryPicker;
 
 });
