@@ -18,14 +18,17 @@ define('io.ox/office/spreadsheet/view/dialog/customsortdialog', [
     'io.ox/office/tk/dialogs',
     'io.ox/office/tk/utils/iteratorutils',
     'io.ox/office/tk/object/triggerobject',
-    'io.ox/office/tk/control/checkbox',
     'io.ox/office/spreadsheet/view/labels',
+    'io.ox/office/spreadsheet/view/controls',
     'gettext!io.ox/office/spreadsheet/main',
     'less!io.ox/office/spreadsheet/view/dialog/customsortdialog'
-], function (Utils, KeyCodes, Dialogs, IteratorUtils, TriggerObject, CheckBox, Labels, gt) {
+], function (Utils, KeyCodes, Dialogs, IteratorUtils, TriggerObject, Labels, Controls, gt) {
 
     'use strict';
 
+    // convenience shortcuts
+    var CheckBox = Controls.CheckBox;
+
     var customSortStr       = /*#. menu title: custom sort options */ gt.pgettext('sort', 'Custom sort'),
         directionStr        = /*#. sorting: the sort direction headline for 'top to bottom' or 'left to right' */ gt.pgettext('sort', 'Direction'),
         hasHeadersStr       = /*#. sorting: selected range has headers which shouldn't be sorted */ gt.pgettext('sort', 'Selection has headers'),
@@ -113,7 +116,8 @@ define('io.ox/office/spreadsheet/view/dialog/customsortdialog', [
      * @param {SortLayerMenu} SortLayerMenu
      *        The menu itselfs. Used to add/remove the html for the rule.
      */
-    var Rule = function (sortLayerMenu) {
+    var Rule = TriggerObject.extend({ constructor: function (docView, sortLayerMenu) {
+
         var self            = this,
             menu            = sortLayerMenu,
             ruleCollection  = sortLayerMenu.getRuleCollection(),
@@ -125,7 +129,7 @@ define('io.ox/office/spreadsheet/view/dialog/customsortdialog', [
             ruleLine        = null,
             remBtn          = null;
 
-        TriggerObject.call(self);
+        TriggerObject.call(this, docView);
 
         // private ---------------------------------------------
 
@@ -314,8 +318,9 @@ define('io.ox/office/spreadsheet/view/dialog/customsortdialog', [
             )
         );
 
-        // If this is not the first rule, add the 'remove-button' to the rule-line
-        if (ruleCollection.getRules().length > 0) {
+        // If this is not the first rule, add the 'remove-button' to the rule-line.
+        // For tables, we can add a remove-button everytime
+        if (ruleCollection.getRules().length > 0 || sortLayerMenu.isForTable()) {
             remBtn = $('<a href="#" tabindex="0">').addClass('trash').append($('<i>').addClass('fa fa-trash-o'));
             remBtn.on('click keydown', function (e) {
                 if ((e.type !== 'keydown') || (e.keyCode === KeyCodes.SPACE)) {
@@ -333,7 +338,7 @@ define('io.ox/office/spreadsheet/view/dialog/customsortdialog', [
 
         // return self-reference
         return self;
-    };
+    } });
 
     // class RuleCollection ===================================================
 
@@ -344,7 +349,7 @@ define('io.ox/office/spreadsheet/view/dialog/customsortdialog', [
      * @param {SortLayerMenu} sortLayerMenu
      *    The menu to which the rules should be added.
      */
-    function RuleCollection(docView, sortLayerMenu) {
+    var RuleCollection = TriggerObject.extend({ constructor: function (docView, sortLayerMenu) {
         var // self reference
             self       = this,
             // the layer-menu itselfs
@@ -352,7 +357,7 @@ define('io.ox/office/spreadsheet/view/dialog/customsortdialog', [
             // array with all rules
             arrRules   = [];
 
-        TriggerObject.call(self);
+        TriggerObject.call(this, docView);
 
         // public methods -----------------------------------------------------
 
@@ -369,7 +374,7 @@ define('io.ox/office/spreadsheet/view/dialog/customsortdialog', [
             // the count of cols/rows already
             if ((arrRules.length + 1) <= menu.getRangeSize()) {
                 // generate a new rule and push it to the rules-array of the ruleCollection
-                arrRules.push(newRule = new Rule(menu));
+                arrRules.push(newRule = new Rule(docView, menu));
                 // trigger event 'addRule' to make dependent functions work
                 self.trigger('addRule', newRule);
             }
@@ -522,16 +527,16 @@ define('io.ox/office/spreadsheet/view/dialog/customsortdialog', [
         };
 
         return self;
-    }
+    } });
 
-    // class SortLayerMenu ====================================================
+    // class CustomSortDialog =================================================
 
     /**
-     * A layer menu with options for sorting.
+     * A modal dialog with options for sorting.
      *
      * @constructor
      *
-     * @extends LayerMenu
+     * @extends ModalDialog
      *
      * @param {SpreadsheetView} docView
      *  The spreadsheet view containing this instance.
@@ -544,17 +549,23 @@ define('io.ox/office/spreadsheet/view/dialog/customsortdialog', [
 
             ruleCollection = new RuleCollection(docView, self),
 
-            hasHeadersCheckbox = null,
+            hasHeadersCheckbox = new CheckBox(docView, { label: hasHeadersStr, boxed: true }),
             directionGroup = null,
             direction = null,
             columns = null,
             labels = [],
+
             // prefill-options
-            prefill = Utils.getObjectOption(options, 'prefill', null);
+            prefill = Utils.getObjectOption(options, 'prefill', null),
+
+            // special case for tables?
+            forTable = Utils.getBooleanOption(options, 'forTable', false),
+            // tableModel
+            table = (forTable) ? docView.getTableCollection().findTable(docView.getActiveCell()) : null;
 
         // base constructor ---------------------------------------------------
 
-        Dialogs.ModalDialog.call(this, { title: customSortStr, width: 400, okLabel: 'OK' });
+        Dialogs.ModalDialog.call(this, docView, { title: customSortStr, width: 400, okLabel: 'OK' });
 
         // private methods ----------------------------------------------------
 
@@ -564,9 +575,9 @@ define('io.ox/office/spreadsheet/view/dialog/customsortdialog', [
          */
         function updateLabelStrings() {
 
-            var cellCollection = docView.getCellCollection();
-            var headerRange = range.lineRange(!columns, 0);
-            var hasHeader = hasHeadersCheckbox.getValue();
+            var hasHeader       = (forTable) ? table.hasHeaderRow() : hasHeadersCheckbox.getValue();
+            var headerRange     = (forTable && hasHeader) ? table.getHeaderRange() : range.lineRange(!columns, 0);
+            var cellCollection  = docView.getCellCollection();
 
             // collect labels
             labels = IteratorUtils.map(headerRange.iterator(), function (address) {
@@ -648,21 +659,28 @@ define('io.ox/office/spreadsheet/view/dialog/customsortdialog', [
             addBtn.toggleClass('disabled', ((self.getRangeSize() === 1) || (ruleCollection.getRules().length === self.getRangeSize())));
         };
 
+        /**
+         * Return, whether this dialog is for a table or not.
+         */
+        self.isForTable = function () {
+            return forTable;
+        };
+
         // overwrite
         self.show = _.wrap(self.show, function (show) {
             return show.call(self).then(function () {
-                // If there were a problem, reopen this dialog (with prefill-options)
+                // If there is a problem, reopen this dialog (with prefill-options)
                 if (ruleCollection.hasProblem({ final: true })) {
-                    return new CustomSortDialog(docView, { prefill: {
+                    return new CustomSortDialog(docView, { forTable: forTable, prefill: {
                         direction:  direction,
-                        headers:    hasHeadersCheckbox.getValue(),
+                        headers:    (forTable) ? false : hasHeadersCheckbox.getValue(),
                         orderRules: ruleCollection.getRules(),
                         problem:    ruleCollection.hasProblem({ final: true })
                     } }).show();
                 } else {
                     return {
                         direction:  direction,
-                        headers:    hasHeadersCheckbox.getValue(),
+                        headers:    (forTable) ? false : hasHeadersCheckbox.getValue(),
                         orderRules: ruleCollection.getRules(),
                         problem:    ruleCollection.hasProblem({ final: true })
                     };
@@ -672,13 +690,17 @@ define('io.ox/office/spreadsheet/view/dialog/customsortdialog', [
 
         // initialization -----------------------------------------------------
 
-        // add base menu items
-        hasHeadersCheckbox = new CheckBox({ label: hasHeadersStr, boxed: true });
+        // close dialog when losing edit rights
+        docView.closeDialogOnReadOnlyMode(self);
 
+        // add base menu items
         self.getPopup().addClass('io-ox-office-custom-sort-dialog');
 
-        self.getBody()
-            .append(optionsStr, hasHeadersCheckbox.getNode());
+        // for tables, leave some options away
+        if (!forTable) {
+            self.getBody()
+                .append(optionsStr, hasHeadersCheckbox.getNode());
+        }
 
         // prepare direction (vertical/horizontal) dowpdown
         directionGroup = $('<div class="dropdown-link">').append(
@@ -707,10 +729,15 @@ define('io.ox/office/spreadsheet/view/dialog/customsortdialog', [
             return false;
         });
 
+        // for tables, leave some options away
+        if (!forTable) {
+            self.getBody().append(
+                directionGroup,
+                $('<hr>')
+            );
+        }
         // add all the stuff to the layer-menu
         self.getBody().append(
-            directionGroup,
-            $('<hr>'),
             dropDownContainer,
             $('<hr>'),
             $('<div class="btnHolder">').append(addBtn)
@@ -729,7 +756,9 @@ define('io.ox/office/spreadsheet/view/dialog/customsortdialog', [
 
                 // prefill the Dialog
                 if (prefill) {
-                    if (prefill.direction) { changeDirection(prefill.direction); }
+                    if (prefill.direction) {
+                        changeDirection(prefill.direction);
+                    }
                     if (prefill.headers) {
                         hasHeadersCheckbox.setValue(prefill.headers);
                         updateLabelStrings();
@@ -739,22 +768,30 @@ define('io.ox/office/spreadsheet/view/dialog/customsortdialog', [
                             if (key > 0) {
                                 ruleCollection.addRule();
                             }
-                            var ruleObj = ruleCollection.getRule(key);
-                            ruleObj.setIndex(rule.index);
+                            var ruleObj = ruleCollection.getRule(key),
+                                startCol = (forTable) ? table.getRange().start[0] : 0;
+                            ruleObj.setIndex((rule.index + startCol));
                             ruleObj.setOrderBy(rule.orderBy);
                         });
+                        self.trigger('refresh:labels', labels);
                     }
                     ruleCollection.hasProblem();
                 }
+
+                Utils.setFocus(self.getOkButton());
             },
             // beforeshow-handler to reset/update some values
             beforeshow: function () {
-                range = docView.getSelectedRanges().first();
+                // grab the data-range of tables, or grab the first range of the selection
+                range = (forTable) ? table.getDataRange() : docView.getSelectedRanges().first();
 
                 // reset direction
                 changeDirection('vertical');
 
-                hasHeadersCheckbox.setValue(docView.getCellCollection().hasRangeHeadline(range, direction));
+                // only try to detect a headline, when it's not a table
+                if (!forTable) {
+                    hasHeadersCheckbox.setValue(docView.getCellCollection().hasRangeHeadline(range, direction));
+                }
                 updateLabelStrings();
             },
             // hide-handler to cleanup some values
@@ -788,14 +825,14 @@ define('io.ox/office/spreadsheet/view/dialog/customsortdialog', [
 
         // destroy all class members
         this.on('close', function () {
+            hasHeadersCheckbox.destroy();
             self = docView = null;
         });
 
-    } }); // class FunctionDialog
+    } }); // class CustomSortDialog
 
     // exports ================================================================
 
-    // derive this class from class LayerMenu
     return CustomSortDialog;
 
 });
