@@ -103,7 +103,7 @@ define('io.ox/office/spreadsheet/view/dialog/functiondialog', [
 
         // base constructor ---------------------------------------------------
 
-        Dialogs.ModalDialog.call(this, { title: DIALOG_TITLE, width: DIALOG_WIDTH, okLabel: DIALOG_OK_LABEL });
+        Dialogs.ModalDialog.call(this, docView, { title: DIALOG_TITLE, width: DIALOG_WIDTH, okLabel: DIALOG_OK_LABEL });
 
         // private methods ----------------------------------------------------
 
@@ -418,9 +418,24 @@ define('io.ox/office/spreadsheet/view/dialog/functiondialog', [
 
             // us 102078426: dialogs on small devices should come up w/o keyboard,
             // so the focus should not be in an input element
-            if (Utils.SMALL_DEVICE) {
-                Utils.setFocus(self.getOkButton());
+            if (Utils.SMALL_DEVICE || Utils.IOS) {
+                _.defer(function () { Utils.setFocus(self.getCancelButton()); });
+
             } else {
+                /**
+                 * Safari does NOT scroll automatically to the selected option,
+                 * so we have to calculate the position and scroll to it ourselfs.
+                 *     BUG #53227
+                 */
+                if (_.browser.Safari) {
+                    var index       = functionSelectNode.find('option[value=' + functionSelectNode.val() + ']').first().index(),
+                        size        = parseInt(functionSelectNode.attr('size'), 10),
+                        height      = functionSelectNode.height(),
+                        lineHeight  = (height / size);
+
+                    functionSelectNode.scrollTop(lineHeight * index);
+                }
+
                 Utils.setFocus(functionSelectNode);
             }
 
