@@ -18,9 +18,10 @@ define('io.ox/office/spreadsheet/view/dialog/sheetorderdialog', [
     'io.ox/office/tk/keycodes',
     'io.ox/office/tk/dialogs',
     'io.ox/office/tk/utils/iteratorutils',
+    'io.ox/office/spreadsheet/utils/sheetutils',
     'gettext!io.ox/office/spreadsheet/main',
     'less!io.ox/office/spreadsheet/view/dialog/sheetorderdialog'
-], function (Utils, Forms, KeyCodes, Dialogs, IteratorUtils, gt) {
+], function (Utils, Forms, KeyCodes, Dialogs, IteratorUtils, SheetUtils, gt) {
 
     'use strict';
 
@@ -61,7 +62,7 @@ define('io.ox/office/spreadsheet/view/dialog/sheetorderdialog', [
 
         // base constructor ---------------------------------------------------
 
-        Dialogs.ModalDialog.call(this, { title: gt('Reorder sheets'), width: 298 });
+        Dialogs.ModalDialog.call(this, docView, { title: gt('Reorder Sheets'), width: 298 });
         var self = this;
 
         // private functions --------------------------------------------------
@@ -188,16 +189,14 @@ define('io.ox/office/spreadsheet/view/dialog/sheetorderdialog', [
         // close dialog automatically after losing edit rights
         docView.closeDialogOnReadOnlyMode(this);
 
-        IteratorUtils.forEach(docModel.createSheetIterator({ visible: true }), function (sheetModel, result) {
+        IteratorUtils.forEach(docModel.createSheetIterator({ supported: true, visible: true }), function (sheetModel, iterResult) {
 
-            // ignore hidden sheets, and sheet types that are not supported
-            if (!docView.isSheetTypeSupported(sheetModel.getType())) { return; }
-
-            var sheetName = _.noI18n(Utils.escapeHTML(result.name));
-            var button = $('<button class="btn" data-index="' + result.sheet + '" title="' + sheetName + '" tabindex="0" role="button">' + sheetName + '</button>');
+            var sheet = iterResult.sheet;
+            var sheetName = _.noI18n(Utils.escapeHTML(iterResult.name));
+            var button = $('<button class="btn" data-index="' + sheet + '" title="' + sheetName + '" tabindex="0" role="button">' + sheetName + '</button>');
 
             button.on('click', selectButton);
-            if (result.sheet === currentSheet) {
+            if (sheet === currentSheet) {
                 button.addClass('btn-primary');
                 currentChosen = button;
             }
