@@ -40,22 +40,49 @@ define('io.ox/office/spreadsheet/view/labels', [
     /**
      * Header label for column/row operations.
      *
+     * @type String
      * @constant
      */
-    SpreadsheetLabels.COL_ROW_HEADER_LABEL = /* menu title: insert/delete/resize rows and columns in the sheet */ gt.pgettext('menu-title', 'Rows/Columns');
+    SpreadsheetLabels.COL_ROW_HEADER_LABEL = /*#. Header label insert/delete/resize rows and columns in a spreadsheet */ gt.pgettext('menu-title', 'Rows/Columns');
+
+    /**
+     * Header label for cell operations.
+     *
+     * @type String
+     * @constant
+     */
+    SpreadsheetLabels.CELL_HEADER_LABEL = /*#. Header label for operations to change cells in a spreadsheet */ gt.pgettext('menu-title', 'Cells');
+
+    /**
+     * Header label for generic data operations.
+     *
+     * @type String
+     * @constant
+     */
+    SpreadsheetLabels.DATA_HEADER_LABEL = /*#. Header label for sorting, filtering, and other data operations */ gt.pgettext('menu-title', 'Data');
 
     /**
      * Header label for data filter operations.
      *
+     * @type String
      * @constant
      */
     SpreadsheetLabels.FILTER_HEADER_LABEL = /*#. Header label for data filter options */ gt.pgettext('menu-title', 'Filter');
 
+    /**
+     * Header label for data sort operations.
+     *
+     * @type String
+     * @constant
+     */
+    SpreadsheetLabels.SORT_HEADER_LABEL = /*#. Header label for data sort options */ gt.pgettext('menu-title', 'Sort');
+
     // control labels ---------------------------------------------------------
 
     /**
      * Label for an 'Insert sheet' button.
      *
+     * @type String
      * @constant
      */
     SpreadsheetLabels.INSERT_SHEET_LABEL = gt('Insert sheet');
@@ -63,6 +90,7 @@ define('io.ox/office/spreadsheet/view/labels', [
     /**
      * Label for a 'Rename sheet' button.
      *
+     * @type String
      * @constant
      */
     SpreadsheetLabels.RENAME_SHEET_LABEL = gt('Rename sheet');
@@ -70,6 +98,7 @@ define('io.ox/office/spreadsheet/view/labels', [
     /**
      * Label for a 'Copy sheet' button.
      *
+     * @type String
      * @constant
      */
     SpreadsheetLabels.COPY_SHEET_LABEL = gt('Copy sheet');
@@ -77,13 +106,39 @@ define('io.ox/office/spreadsheet/view/labels', [
     /**
      * Label for a 'Delete sheet' button.
      *
+     * @type String
      * @constant
      */
     SpreadsheetLabels.DELETE_SHEET_LABEL = gt('Delete sheet');
 
+    /**
+     * Label for a 'Unprotect sheet' button.
+     *
+     * @type String
+     * @constant
+     */
+    SpreadsheetLabels.UNPROTECT_SHEET_LABEL = gt('Unprotect sheet');
+
+    /**
+     * Label for a 'Protect sheet' button.
+     *
+     * @type String
+     * @constant
+     */
+    SpreadsheetLabels.PROTECT_SHEET_LABEL = gt('Protect sheet');
+
+    /**
+     * Label for a 'Show sheet' button.
+     *
+     * @type String
+     * @constant
+     */
+    SpreadsheetLabels.SHOW_SHEET_LABEL = /*#. make a sheet visible that is currently hidden */ gt('Show sheet');
+
     /**
      * Label for a 'Hide sheet' button.
      *
+     * @type String
      * @constant
      */
     SpreadsheetLabels.HIDE_SHEET_LABEL = gt('Hide sheet');
@@ -91,6 +146,7 @@ define('io.ox/office/spreadsheet/view/labels', [
     /**
      * Label for a 'Reorder sheets' button.
      *
+     * @type String
      * @constant
      */
     SpreadsheetLabels.REORDER_SHEETS_LABEL = gt('Reorder sheets');
@@ -98,6 +154,7 @@ define('io.ox/office/spreadsheet/view/labels', [
     /**
      * Label for a 'Show all hidden sheets' button.
      *
+     * @type String
      * @constant
      */
     SpreadsheetLabels.UNHIDE_SHEETS_LABEL = gt('Unhide sheets');
@@ -105,6 +162,7 @@ define('io.ox/office/spreadsheet/view/labels', [
     /**
      * Label for a line-break toggle button.
      *
+     * @type String
      * @constant
      */
     SpreadsheetLabels.LINEBREAK_LABEL =
@@ -114,6 +172,7 @@ define('io.ox/office/spreadsheet/view/labels', [
     /**
      * A text label or tool tip for a 'Format Painter' control.
      *
+     * @type String
      * @constant
      */
     SpreadsheetLabels.FORMAT_PAINTER_LABEL =
@@ -123,6 +182,7 @@ define('io.ox/office/spreadsheet/view/labels', [
     /**
      * An map containing GUI labels for all function categories.
      *
+     * @type Object<String,String>
      * @constant
      */
     SpreadsheetLabels.FUNCTION_CATEGORY_LABELS = {
@@ -147,6 +207,7 @@ define('io.ox/office/spreadsheet/view/labels', [
      * drop-down list, which must simply be different from any valid number
      * format.
      *
+     * @type String
      * @constant
      */
     SpreadsheetLabels.CUSTOM_FORMAT_VALUE = '\x00';
@@ -155,6 +216,7 @@ define('io.ox/office/spreadsheet/view/labels', [
      * The label of the 'Custom' entry in the 'Number Format Code' drop-down
      * list.
      *
+     * @type String
      * @constant
      */
     SpreadsheetLabels.CUSTOM_FORMAT_LABEL =
@@ -188,86 +250,25 @@ define('io.ox/office/spreadsheet/view/labels', [
     };
 
     /**
-     * Standard options for a 'Insert rows' button.
+     * Standard options for 'Sort ascending' buttons.
      *
      * @constant
      */
-    SpreadsheetLabels.INSERT_ROWS_OPTIONS = {
-        label: gt('Insert rows')
+    SpreadsheetLabels.SORT_ASC_BUTTON_OPTIONS = {
+        icon: 'docs-sort-up',
+        label: gt.pgettext('sort', 'Ascending'),
+        tooltip: gt.pgettext('sort', 'Sort from smallest to largest value')
     };
 
     /**
-     * Standard options for a 'Insert row' button.
+     * Standard options for 'Sort descending' buttons.
      *
      * @constant
      */
-    SpreadsheetLabels.INSERT_ROW_OPTIONS = {
-        label: gt('Insert row')
-    };
-
-    /**
-     * Standard options for a 'Delete rows' button.
-     *
-     * @constant
-     */
-    SpreadsheetLabels.DELETE_ROWS_OPTIONS = {
-        label: gt('Delete rows')
-    };
-
-    /**
-     * Standard options for a 'Delete row' button.
-     *
-     * @constant
-     */
-    SpreadsheetLabels.DELETE_ROW_OPTIONS = {
-        label: gt('Delete row')
-    };
-
-    /**
-     * Standard options for 'Insert columns'.
-     *
-     * @constant
-     */
-    SpreadsheetLabels.INSERT_COLUMNS_OPTIONS = {
-        label: gt('Insert columns')
-    };
-
-    /**
-     * Standard options for 'Insert column'.
-     *
-     * @constant
-     */
-    SpreadsheetLabels.INSERT_COLUMN_OPTIONS = {
-        label: gt('Insert column')
-    };
-
-    /**
-     * Standard options for 'Delete columns'.
-     *
-     * @constant
-     */
-    SpreadsheetLabels.DELETE_COLUMNS_OPTIONS = {
-        label: gt('Delete columns')
-    };
-
-    /**
-     * Standard options for 'Delete column'.
-     *
-     * @constant
-     */
-    SpreadsheetLabels.DELETE_COLUMN_OPTIONS = {
-        label: gt('Delete column')
-    };
-
-    /**
-     * Standard options for 'Toggle table filter' buttons.
-     *
-     * @constant
-     */
-    SpreadsheetLabels.FILTER_OPTIONS = {
-        label: /*#. Button label: filter a cell range */ gt.pgettext('filter', 'Filter'),
-        tooltip: gt('Filter the selected cells'),
-        toggle: true
+    SpreadsheetLabels.SORT_DESC_BUTTON_OPTIONS = {
+        icon: 'docs-sort-down',
+        label: gt.pgettext('sort', 'Descending'),
+        tooltip: gt.pgettext('sort', 'Sort from largest to smallest value')
     };
 
     /**
@@ -275,9 +276,10 @@ define('io.ox/office/spreadsheet/view/labels', [
      *
      * @constant
      */
-    SpreadsheetLabels.SORT_OPTIONS = {
-        label: /*#. sorting: label of the button opening a menu with custom sort options */ gt.pgettext('sort', 'Custom'),
-        tooltip: /*#. tooltip for custom sort button */ gt.pgettext('sort', 'Settings for sorting')
+    SpreadsheetLabels.SORT_CUSTOM_BUTTON_OPTIONS = {
+        //#. sorting: label of the button opening a menu with custom sort options
+        label: gt.pgettext('sort', 'Custom'),
+        tooltip: gt.pgettext('sort', 'Settings for sorting')
     };
 
     /**
@@ -290,29 +292,6 @@ define('io.ox/office/spreadsheet/view/labels', [
         //TODO: missing tooltip
     };
 
-    // insert options ---------------------------------------------------------
-
-    /**
-     * Standard options for 'Insert sum'.
-     *
-     * @constant
-     */
-    SpreadsheetLabels.INSERT_SUM_OPTIONS = {
-        label: gt('Sum'),
-        tooltip: /*#. automatically create a SUM function for selected cells */ gt('Sum automatically'),
-        value: 'SUM'
-    };
-
-    /**
-     * Standard options for 'Insert function'.
-     *
-     * @constant
-     */
-    SpreadsheetLabels.INSERT_FUNCTION_OPTIONS = {
-        label: gt('Function'),
-        tooltip: /*#. Insert a function at the current cursor location */ gt('Insert function at cursor location')
-    };
-
     // style sets for list controls -------------------------------------------
 
     /**
@@ -415,6 +394,26 @@ define('io.ox/office/spreadsheet/view/labels', [
             gt('Row %1$s', _.noI18n(Address.stringifyRow(row))));
     };
 
+    /**
+     * Returns the name of the passed series together with the word 'Series', e.g.
+     * 'Series 1'.
+     *
+     * @param {Number} seriesIndex
+     *  The zero-based series index to be converted to a series label.
+     *
+     * @returns {String}
+     *  The label for the specified series.
+     */
+    SpreadsheetLabels.getSeriesLabel = function (seriesIndex) {
+        return (
+            //#. A data series in a chart object (a sequence of multiple data points with a title)
+            //#. %1$d is the numeric index of the series (e.g. "Series 1", "Series 2", etc.)
+            //#. This label should match the default title for data series in other spreadsheet
+            //#. applications (OpenOffice/LibreOffice Calc, Microsoft Excel).
+            //#, c-format
+            gt('Series %1$d', _.noI18n(seriesIndex + 1)));
+    };
+
     /**
      * Returns the name of the passed column or row together with the word
      * 'Column' or 'Row' respectively, e.g. 'Column A', or 'Row 1'.
