@@ -48,7 +48,7 @@ define('io.ox/office/spreadsheet/view/popup/namedrangeslayermenu', [
         LayerMenu.call(this, docView, /*#. dialog title */ gt.pgettext('named ranges', 'Named ranges'), {
             classes: 'defined-names',
             rootContainerNode: docView.getApp().getWindowNode(),
-            refreshNodeRepeatedDelayed: false
+            backgroundRefresh: false
         });
 
         // private methods ----------------------------------------------------
@@ -62,20 +62,20 @@ define('io.ox/office/spreadsheet/view/popup/namedrangeslayermenu', [
 
             // add a special entry, if no names are available at all
             if (nameModels.length === 0) {
-                self.addGroup(null, new Label({ label: gt.pgettext('named ranges', 'No named ranges defined.') }));
+                self.addGroup(null, new Label(docView, { label: gt.pgettext('named ranges', 'No named ranges defined.') }));
                 self.addSeparator();
             } else {
-                nameModels.forEach(function addListEntry(nameModel) {
+                nameModels.forEach(function (nameModel) {
                     self.addGroup(null, new NamedRangeItem(docView, nameModel));
                     self.addSeparator();
                 });
             }
 
             // add an extra button to define new named ranges
-            self.addGroup('name/insert/dialog', new Button({ icon: 'fa-plus', label: gt.pgettext('named ranges', 'Add new named range') }));
+            self.addGroup('name/insert/dialog', new Button(docView, { icon: 'fa-plus', label: gt.pgettext('named ranges', 'Add new named range') }));
         }
 
-        var createAllGroupsDebounced = this.createDebouncedMethod(_.noop, createAllGroups, { delay: 10, infoString: 'NamedRangesLayerMenu: createAllGroups', app: docView.getApp() });
+        var createAllGroupsDebounced = this.createDebouncedMethod('NamedRangesLayerMenu.createAllGroupsDebounced', null, createAllGroups, { delay: 10 });
 
         /**
          * Moves the menu to a default position when it has been shown for the
@@ -107,9 +107,7 @@ define('io.ox/office/spreadsheet/view/popup/namedrangeslayermenu', [
         this.one('popup:show', setDefaultPosition);
 
         // hide the menu automatically in read-only mode
-        this.listenTo(docModel, 'change:editmode', function (event, editMode) {
-            if (!editMode) { self.hide(); }
-        });
+        this.listenTo(docView.getApp(), 'docs:editmode:leave', function () { self.hide(); });
 
         // destroy all class members
         this.registerDestructor(function () {
