@@ -14,10 +14,8 @@
 
 define('io.ox/office/spreadsheet/view/popup/sheetcontextmenu', [
     'io.ox/office/tk/forms',
-    'io.ox/office/tk/control/button',
-    'io.ox/office/baseframework/view/popup/contextmenu',
-    'io.ox/office/spreadsheet/view/labels'
-], function (Forms, Button, ContextMenu, Labels) {
+    'io.ox/office/baseframework/view/popup/contextmenu'
+], function (Forms, ContextMenu) {
 
     'use strict';
 
@@ -36,17 +34,14 @@ define('io.ox/office/spreadsheet/view/popup/sheetcontextmenu', [
      */
     function SheetContextMenu(docView, rootNode) {
 
-        var // self reference
-            self = this,
-            // app reference
-            app = docView.getApp();
+        // self reference
+        var self = this;
 
         // base constructor ---------------------------------------------------
 
         ContextMenu.call(this, docView, rootNode, {
             selector: Forms.OPTION_BUTTON_SELECTOR,
-            // do not show context menu in read-only mode, or during cell edit mode
-            enableKey: ['document/editable', 'view/cell/editmode/off'],
+            enableKey: 'document/editable', // do not show context menu in read-only mode
             delay: 200,
             lazyInitHandler: initMenu,
             autoHideGroups: false
@@ -57,8 +52,9 @@ define('io.ox/office/spreadsheet/view/popup/sheetcontextmenu', [
          * Activate the clicked sheet, before the context menu will be shown.
          */
         function contextMenuPrepareHandler(event) {
-            var // the clicked button element
-                sheetButton = $(event.sourceEvent.target);
+
+            // the clicked button element
+            var sheetButton = $(event.sourceEvent.target);
 
             // click the button if it is not selected (activate the sheet)
             if (!Forms.isCheckedButtonNode(sheetButton)) {
@@ -67,22 +63,11 @@ define('io.ox/office/spreadsheet/view/popup/sheetcontextmenu', [
         }
 
         function initMenu() {
-            self.addGroup('sheet/insert', new Button({ label: Labels.INSERT_SHEET_LABEL }))
-                .addSeparator()
-                .addGroup('sheet/rename/dialog', new Button({ label: Labels.RENAME_SHEET_LABEL }));
-
-            if (app.isOOXML()) {
-                self.addGroup('sheet/copy/dialog', new Button({ label: Labels.COPY_SHEET_LABEL }));
-            }
-
-            self.addGroup('sheet/delete', new Button({ label: Labels.DELETE_SHEET_LABEL }))
-                .addGroup('sheet/visible', new Button({ label: Labels.HIDE_SHEET_LABEL, value: false }))
-                .addSeparator()
-                .addGroup('sheet/reorder/dialog', new Button({ label: Labels.REORDER_SHEETS_LABEL }))
-                .addGroup('sheet/unhide', new Button({ label: Labels.UNHIDE_SHEETS_LABEL }));
+            docView.addSheetActionButtons(self, { insertSheet: true });
         }
 
         // public methods -----------------------------------------------------
+
         this.getXY = function (event) {
             return {
                 pageX: event.sourceEvent.pageX,
