@@ -32,10 +32,10 @@ define('io.ox/office/spreadsheet/view/popup/signaturetooltip', [
      * @param {SpreadsheetView} docView
      *  The spreadsheet view containing this instance.
      *
-     * @param {jQuery} textAreaNode
-     *  The <textarea> element used as anchor for the tooltip node.
+     * @param {HTMLElement|jQuery|Function} anchorSpec
+     *  The element used as anchor for the tooltip node.
      */
-    function SignatureToolTip(docView, textAreaNode) {
+    function SignatureToolTip(docView, anchorSpec) {
 
         // localized formula resource data
         var resource = docView.getDocModel().getFormulaResource();
@@ -45,7 +45,7 @@ define('io.ox/office/spreadsheet/view/popup/signaturetooltip', [
 
         // base constructor ---------------------------------------------------
 
-        ToolTip.call(this, { anchor: textAreaNode, classes: 'signature-tooltip', maxSize: 600 });
+        ToolTip.call(this, docView, { anchor: anchorSpec, classes: 'signature-tooltip', maxSize: 600 });
 
         // private methods ----------------------------------------------------
 
@@ -233,7 +233,7 @@ define('io.ox/office/spreadsheet/view/popup/signaturetooltip', [
 
         // destroy all class members on destruction
         this.registerDestructor(function () {
-            docView = resource = textAreaNode = null;
+            docView = resource = anchorSpec = null;
         });
 
     } // class SignatureToolTip
