@@ -13,11 +13,12 @@
  */
 
 define('io.ox/office/spreadsheet/view/popup/tablecolumnmenu', [
+    'io.ox/office/tk/control/radiogroup',
     'io.ox/office/baseframework/view/popup/compoundmenu',
     'io.ox/office/spreadsheet/view/labels',
     'io.ox/office/spreadsheet/view/control/discretefiltergroup',
     'gettext!io.ox/office/spreadsheet/main'
-], function (CompoundMenu, Labels, DiscreteFilterGroup, gt) {
+], function (RadioGroup, CompoundMenu, Labels, DiscreteFilterGroup, gt) {
 
     'use strict';
 
@@ -34,16 +35,22 @@ define('io.ox/office/spreadsheet/view/popup/tablecolumnmenu', [
      * @param {SpreadsheetView} docView
      *  The spreadsheet view that contains this instance.
      */
-    function TableColumnMenu(docView) {
+    var TableColumnMenu = CompoundMenu.extend({ constructor: function (docView) {
 
-        var // the check list control for discrete filters
-            filterGroup = null,
+        // self reference
+        var self = this;
 
-            // the name of the table range represented by this menu
-            tableName = null,
+        // the model of the table range represented by this menu
+        var tableModel = null;
+        // the table column model represented by this menu
+        var columnModel = null;
+        // the column index in the table range
+        var tableCol = 0;
 
-            // the column index in the table range
-            tableCol = 0;
+        // the radio group for sorting in ascending/descending order
+        var sortGroup = null;
+        // the check list control for discrete filters
+        var filterGroup = null;
 
         // base constructor ---------------------------------------------------
 
@@ -73,20 +80,37 @@ define('io.ox/office/spreadsheet/view/popup/tablecolumnmenu', [
          */
         function getActionValue() {
 
-            // the selected entries for a discrete filter (null, if all entries are selected)
-            var entries = filterGroup.getValue();
-            if (entries.length === filterGroup.getOptionButtons().length) { entries = null; }
+            // the attribute set to be sent as result value
+            var attrSet = {};
 
             // create discrete filter, or clear filter (for undefined entries)
-            var filterAttrs = entries ? { type: 'discrete', entries: entries } : { type: 'none' };
+            var filterEntries = filterGroup.getValue();
+            if (!filterEntries || (filterEntries.length === filterGroup.getOptionButtons().length)) {
+                attrSet.filter = { type: 'none', entries: [] };
+            } else {
+                attrSet.filter = { type: 'discrete', entries: filterEntries };
+            }
+
+            // create the sorting attributes
+            switch (sortGroup.getValue()) {
+                case 'ascending':
+                    attrSet.sort = { type: 'value', descending: false };
+                    break;
+                case 'descending':
+                    attrSet.sort = { type: 'value', descending: true };
+                    break;
+                default:
+                    attrSet.sort = { type: 'none',  descending: false };
+            }
 
             // return the entire action value
-            return { tableName: tableName, tableCol: tableCol, attributes: { filter: filterAttrs } };
+            return { tableName: tableModel.getName(), tableCol: tableCol, attributes: attrSet };
         }
 
         /**
-         * Returns whether the OK button is currently enabled. It is not
-         * allowed to apply a discrete filter without any visible entries.
+         * Returns whether the OK button of this drop-down menu is currently
+         * enabled (it is not allowed to apply a discrete filter without any
+         * visible entries).
          */
         function isActionEnabled() {
             var entries = filterGroup.getValue();
@@ -113,22 +137,46 @@ define('io.ox/office/spreadsheet/view/popup/tablecolumnmenu', [
          *  A promise that will be resolved when the menu has been initialized.
          */
         this.initialize = function (address, userData) {
-            tableName = userData.tableName;
+
+            // store the table model and table column model for usage in private methods
+            tableModel = userData.tableModel;
             tableCol = userData.tableCol;
-            return filterGroup.initialize(tableName, tableCol);
+            columnModel = tableModel.getColumnModel(tableCol);
+
+            // create the secton wth the sorting controls
+            this.addSectionLabel(Labels.SORT_HEADER_LABEL);
+            this.addGroup(null, sortGroup = new RadioGroup(docView, { toggleValue: 'none' })
+                .createOptionButton('ascending',  Labels.SORT_ASC_BUTTON_OPTIONS)
+                .createOptionButton('descending', Labels.SORT_DESC_BUTTON_OPTIONS)
+            );
+            sortGroup.setValue(!columnModel.isSorted() ? 'none' : columnModel.isDescending() ? 'descending' : 'ascending');
+
+            // create the secton with the filtering controls
+            this.addSectionLabel(Labels.FILTER_HEADER_LABEL);
+            this.addGroup(null, filterGroup = new DiscreteFilterGroup(docView));
+
+            // intitialize the filter entries in a background loop (shows a busy spinner for large lists)
+            return filterGroup.initialize(tableModel, tableCol);
         };
 
         // initialization -----------------------------------------------------
 
-        this.addSectionLabel(Labels.FILTER_HEADER_LABEL)
-            .addGroup(null, filterGroup = new DiscreteFilterGroup(docView));
+        this.on('popup:beforeshow', function () {
+            self.registerFocusableNodes($('.clipboard'));
+        });
+
+        this.on('popup:hide', function () {
+            self.destroyAllGroups();
+            filterGroup = sortGroup = null;
+        });
 
         // destroy all class members on destruction
         this.registerDestructor(function () {
-            docView = filterGroup = null;
+            self = docView = tableModel = columnModel = null;
+            filterGroup = sortGroup = null;
         });
 
-    } // class TableColumnMenu
+    } }); // class TableColumnMenu
 
     // constants --------------------------------------------------------------
 
@@ -138,11 +186,10 @@ define('io.ox/office/spreadsheet/view/popup/tablecolumnmenu', [
      *
      * @constant
      */
-    TableColumnMenu.BUTTON_TOOLTIP = gt.pgettext('filter', 'Select values for filtering');
+    TableColumnMenu.BUTTON_TOOLTIP = gt.pgettext('filter', 'Select values for filtering or sorting');
 
     // exports ================================================================
 
-    // derive this class from class CompoundMenu
-    return CompoundMenu.extend({ constructor: TableColumnMenu });
+    return TableColumnMenu;
 
 });
