@@ -13,12 +13,12 @@
  */
 
 define('io.ox/office/spreadsheet/view/popup/validationlistmenu', [
-    'io.ox/office/tk/keycodes',
     'io.ox/office/tk/forms',
     'io.ox/office/tk/popup/listmenu',
     'io.ox/office/spreadsheet/utils/sheetutils',
+    'io.ox/office/spreadsheet/utils/paneutils',
     'gettext!io.ox/office/spreadsheet/main'
-], function (KeyCodes, Forms, ListMenu, SheetUtils, gt) {
+], function (Forms, ListMenu, SheetUtils, PaneUtils, gt) {
 
     'use strict';
 
@@ -42,7 +42,7 @@ define('io.ox/office/spreadsheet/view/popup/validationlistmenu', [
 
         // base constructor ---------------------------------------------------
 
-        ListMenu.call(this, { autoFocus: false, anchorAlign: 'trailing', expandWidth: true });
+        ListMenu.call(this, docView, { autoFocus: false, anchorAlign: 'trailing', expandWidth: true });
 
         // private methods ----------------------------------------------------
 
@@ -61,7 +61,7 @@ define('io.ox/office/spreadsheet/view/popup/validationlistmenu', [
             // insert the value into the cell (via controller for busy screen etc.)
             if (entry) {
                 if ('value' in entry) {
-                    docView.executeControllerItem('cell/active/contents', { v: entry.value });
+                    docView.executeControllerItem('cell/active/contents', { v: entry.value, f: null });
                 } else if (_.isString(entry.display)) {
                     docView.executeControllerItem('cell/active/parse', entry.display);
                 }
@@ -118,9 +118,10 @@ define('io.ox/office/spreadsheet/view/popup/validationlistmenu', [
             var itemNode = this.getSelectedItemNodes().first();
 
             // apply the selected value on TAB or ENTER (optionally with SHIFT)
-            if (KeyCodes.matchKeyCode(event, 'TAB', { shift: null }) || KeyCodes.matchKeyCode(event, 'ENTER', { shift: null })) {
-                // let event bubble up for selection change
+            var moveDir = PaneUtils.getCellMoveDirection(event);
+            if (moveDir) {
                 applyListValue(itemNode);
+                docView.moveActiveCell(moveDir);
                 return true;
             }
 
@@ -128,9 +129,6 @@ define('io.ox/office/spreadsheet/view/popup/validationlistmenu', [
             itemNode = this.getItemNodeForKeyEvent(event, itemNode);
             if (itemNode.length > 0) {
                 this.selectItemNode(itemNode, { scroll: true });
-                // suppress propagation and default action of the key event
-                event.stopPropagation();
-                event.preventDefault();
                 return true;
             }
 
