@@ -14,15 +14,13 @@
 
 define('io.ox/office/spreadsheet/view/render/autostylecache', [
     'io.ox/office/tk/utils',
-    'io.ox/office/tk/container/simplemap',
+    'io.ox/office/tk/container/valuemap',
     'io.ox/office/tk/object/baseobject',
-    'io.ox/office/tk/object/timermixin',
     'io.ox/office/baseframework/app/appobjectmixin',
     'io.ox/office/editframework/utils/color',
     'io.ox/office/spreadsheet/utils/sheetutils',
-    'io.ox/office/spreadsheet/utils/paneutils',
     'io.ox/office/spreadsheet/view/render/renderutils'
-], function (Utils, SimpleMap, BaseObject, TimerMixin, AppObjectMixin, Color, SheetUtils, PaneUtils, RenderUtils) {
+], function (Utils, ValueMap, BaseObject, AppObjectMixin, Color, SheetUtils, RenderUtils) {
 
     'use strict';
 
@@ -38,12 +36,11 @@ define('io.ox/office/spreadsheet/view/render/autostylecache', [
      * @constructor
      *
      * @extends BaseObject
-     * @extends TimerMixin
      *
      * @param {SpreadsheetView} docView
      *  The document view that contains this cache instance.
      */
-    function AutoStyleCache(docView) {
+    var AutoStyleCache = BaseObject.extend({ constructor: function (docView) {
 
         // self reference
         var self = this;
@@ -54,11 +51,14 @@ define('io.ox/office/spreadsheet/view/render/autostylecache', [
         // the number formatter of the spreadsheet document
         var numberFormatter = docModel.getNumberFormatter();
 
+        // the attribute pool for cell attribute handling
+        var attributePool = docModel.getCellAttributePool();
+
         // the cell auto-style collection of the document
         var autoStyles = docModel.getCellAutoStyles();
 
         // map of all style descriptor caches (separate caches per zoom factor, and grid color)
-        var styleCacheMap = new SimpleMap();
+        var styleCacheMap = new ValueMap();
 
         // the current style descriptor cache (according to grid color and zoom)
         var styleCache = null;
@@ -71,9 +71,8 @@ define('io.ox/office/spreadsheet/view/render/autostylecache', [
 
         // base constructors --------------------------------------------------
 
-        BaseObject.call(this);
-        TimerMixin.call(this);
-        AppObjectMixin.call(this, docModel.getApp());
+        BaseObject.call(this, docView);
+        AppObjectMixin.call(this, docView.getApp());
 
         // private methods ----------------------------------------------------
 
@@ -100,7 +99,7 @@ define('io.ox/office/spreadsheet/view/render/autostylecache', [
                 _.each(counts, function (count, key) { counts[key] = 0; });
             }
 
-            return self.createDebouncedMethod(collect, flush, { delay: 500, infoString: 'AutoStyleCache: logUsage', app: docView.getApp() });
+            return self.createDebouncedMethod('AutoStyleCache.logUsage', collect, flush, { delay: 500 });
         }()) : _.noop;
 
         /**
@@ -146,44 +145,75 @@ define('io.ox/office/spreadsheet/view/render/autostylecache', [
          *  resolve the style settings of all outer border attributes; or null
          *  to use the border attributes of the real auto-style.
          *
-         * @param {Object|Null} attributeSet
-         *  A non-empty incomplete attribute set with formatting attributes to
-         *  be merged over the attributes of the auto-style; or null, if no
-         *  explicit attributes will be merged over the auto-style.
+         * @param {Object|Null} condAttrSet
+         *  A non-empty incomplete attribute set with formatting attributes of
+         *  one or more conditional formatting rules to be merged over the
+         *  attributes of the auto-style; or null, if no explicit attributes
+         *  will be merged over the auto-style.
+         *
+         * @param {Object|Null} tableAttrSet
+         *  An incomplete attribute set with formatting attributes from a table
+         *  style sheet to be merged with the attributes of the auto-style; or
+         *  null, if no table attributes will be merged over the auto-style.
          *
          * @returns {StyleDescriptor}
          *  The new style descriptor for the passed column, row, or cell.
          */
-        function createStyleDescriptor(styleId, borderStyleId, attributeSet) {
+        function createStyleDescriptor(styleId, borderStyleId, condAttrSet, tableAttrSet) {
 
             // the merged attribute set of the auto-style
-            var mergedAttributeSet = autoStyles.getMergedAttributeSet(styleId);
+            var mergedAttrSet = autoStyles.getMergedAttributeSet(styleId);
             // whether the number format of the auto-style has been overridden by explicit attributes
             var formatChanged = false;
             // whether the text color has been set by an explicit formatting attribute
             var explicitTextColor = false;
 
+            // creates a deep clone of the merged attribute set on first call
+            var ensureClonedAttributeSet = _.once(function () {
+                mergedAttrSet = _.copy(mergedAttrSet, true);
+            });
+
             // merge the outer borders of another auto-style
             if (_.isString(borderStyleId)) {
-                var borderAttributeSet = autoStyles.getMergedAttributeSet(borderStyleId);
-                mergedAttributeSet = _.copy(mergedAttributeSet, true);
+                var borderAttrSet = autoStyles.getMergedAttributeSet(borderStyleId);
+                ensureClonedAttributeSet();
                 _.each('tblr', function (borderKey) {
                     var borderName = SheetUtils.getBorderName(borderKey);
-                    mergedAttributeSet.cell[borderName] = borderAttributeSet.cell[borderName];
+                    mergedAttrSet.cell[borderName] = borderAttrSet.cell[borderName];
                 });
             }
 
             // merge the passed explicit attributes over the resulting attributes
-            if (attributeSet) {
+            if (condAttrSet) {
 
                 // special handling for number formats: detect whether the format has been changed by the explicit attributes
                 var oldParsedFormat = autoStyles.getParsedFormat(styleId);
-                mergedAttributeSet = docModel.extendAttributes(mergedAttributeSet, attributeSet, { clone: true });
-                var newParsedFormat = numberFormatter.getParsedFormatForAttributes(mergedAttributeSet.cell);
+                ensureClonedAttributeSet();
+                attributePool.extendAttributeSet(mergedAttrSet, condAttrSet);
+                var newParsedFormat = numberFormatter.getParsedFormatForAttributes(mergedAttrSet.cell);
                 formatChanged = oldParsedFormat !== newParsedFormat;
 
                 // detect whether the text color has been set explicitly
-                explicitTextColor = hasExplicitTextColor(attributeSet);
+                explicitTextColor = hasExplicitTextColor(condAttrSet);
+            }
+
+            // merge the passed table attributes over the resulting attributes
+            if (tableAttrSet) {
+                var defaultAttrSet = autoStyles.getDefaultAttributeSet();
+                ensureClonedAttributeSet();
+                _.each(tableAttrSet, function (attrs, family) {
+                    if (family in mergedAttrSet) {
+                        var mergedAttrs = mergedAttrSet[family];
+                        var defaultAttrs = defaultAttrSet[family];
+                        _.each(attrs, function (value, name) {
+                            if ((name in mergedAttrs) && _.isEqual(mergedAttrs[name], defaultAttrs[name])) {
+                                mergedAttrs[name] = value;
+                            }
+                        });
+                    } else {
+                        mergedAttrSet[family] = attrs;
+                    }
+                });
             }
 
             // if the text color has not been set explicitly by the passed attributes, it may be part of the auto-style itself
@@ -192,7 +222,7 @@ define('io.ox/office/spreadsheet/view/render/autostylecache', [
             }
 
             // create a new style descriptor
-            var styleDesc = new StyleDescriptor(mergedAttributeSet, formatChanged, explicitTextColor);
+            var styleDesc = new StyleDescriptor(mergedAttrSet, formatChanged, explicitTextColor);
             styleDesc.age = 0;
 
             // update the formatting information of the style descriptor
@@ -229,10 +259,15 @@ define('io.ox/office/spreadsheet/view/render/autostylecache', [
          *  @param {String} [options.borderStyleId]
          *      The identifier of an additional auto-style that will be used to
          *      resolve the style settings of all outer border attributes.
-         *  @param {Object} [options.attributeSet]
-         *      An incomplete attribute set with formatting attributes to be
-         *      merged over the attributes of the auto-style. MUST NOT contain
-         *      a style sheet identifier.
+         *  @param {Object} [options.condAttrSet]
+         *      An incomplete attribute set with formatting attributes of one
+         *      or more conditional formatting rules to be merged over the
+         *      attributes of the auto-style. MUST NOT contain a style sheet
+         *      identifier.
+         *  @param {Object} [options.tableAttrSet]
+         *      An incomplete attribute set with formatting attributes from a
+         *      table style sheet to be merged with the attributes of the
+         *      auto-style. MUST NOT contain a style sheet identifier.
          *
          * @returns {StyleDescriptor}
          *  The style descriptor for the specified auto-style.
@@ -246,12 +281,16 @@ define('io.ox/office/spreadsheet/view/render/autostylecache', [
             var borderStyleId = Utils.getStringOption(options, 'borderStyleId', null);
             if (autoStyles.areEqualStyleIds(styleId, borderStyleId)) { borderStyleId = null; }
 
-            // an optional attribute set to be merged over the auto-style
-            var attributeSet = Utils.getObjectOption(options, 'attributeSet', null);
-            if (_.isEmpty(attributeSet)) { attributeSet = null; }
+            // conditional attributes to be merged over the auto-style
+            var condAttrSet = Utils.getObjectOption(options, 'condAttrSet', null);
+            if (_.isEmpty(condAttrSet)) { condAttrSet = null; }
+
+            // table style attributes to be merged with the auto-style
+            var tableAttrSet = Utils.getObjectOption(options, 'tableAttrSet', null);
+            if (_.isEmpty(tableAttrSet)) { tableAttrSet = null; }
 
             // the cache key for the auto-style, and the explicit attributes
-            var styleKey = Utils.stringifyJSON([styleId, borderStyleId, attributeSet]);
+            var styleKey = Utils.stringifyJSON([styleId, borderStyleId, condAttrSet, tableAttrSet]);
 
             // if style descriptor exists already in the cache, update it on demand
             var styleDesc = styleCache.map[styleKey];
@@ -263,7 +302,7 @@ define('io.ox/office/spreadsheet/view/render/autostylecache', [
             if (_.isString(borderStyleId)) { storeStyleKey(borderStyleId, styleKey); }
 
             // create a new style descriptor for an auto-style, and store it in the cache
-            return (styleCache.map[styleKey] = createStyleDescriptor(styleId, borderStyleId, attributeSet));
+            return (styleCache.map[styleKey] = createStyleDescriptor(styleId, borderStyleId, condAttrSet, tableAttrSet));
         };
 
         /**
@@ -304,8 +343,8 @@ define('io.ox/office/spreadsheet/view/render/autostylecache', [
 
             // use permanent cache for simple grid colors
             var permColorKey = /^#(00|FF){3}$/i.test(newCssColor) ? newCssColor.toUpperCase() : '';
-            // use permanent cache for predefined zoom factors
-            var permZoomKey = _.contains(PaneUtils.ZOOM_FACTORS, sheetZoom) ? Math.round(sheetZoom * 100) : '';
+            // use permanent cache for all zoom factors that are a whole multiple of 5%
+            var permZoomKey = (sheetZoom === Utils.round(sheetZoom, 0.05)) ? Math.round(sheetZoom * 100) : '';
             // key of the current style descriptor cache
             var cacheKey = permColorKey + ':' + permZoomKey;
 
@@ -339,13 +378,13 @@ define('io.ox/office/spreadsheet/view/render/autostylecache', [
         // destroy all class members on destruction
         this.registerDestructor(function () {
             self = docView = docModel = numberFormatter = null;
-            autoStyles = styleCacheMap = styleCache = null;
+            attributePool = autoStyles = styleCacheMap = styleCache = null;
         });
 
-    } // class AutoStyleCache
+    } }); // class AutoStyleCache
 
     // exports ================================================================
 
-    return BaseObject.extend({ constructor: AutoStyleCache });
+    return AutoStyleCache;
 
 });
