@@ -15,14 +15,14 @@
 define('io.ox/office/spreadsheet/view/render/rendercache', [
     'io.ox/office/tk/utils',
     'io.ox/office/tk/utils/iteratorutils',
-    'io.ox/office/tk/container/simplemap',
+    'io.ox/office/tk/container/valueset',
+    'io.ox/office/tk/container/valuemap',
     'io.ox/office/tk/object/triggerobject',
-    'io.ox/office/tk/object/timermixin',
     'io.ox/office/spreadsheet/utils/sheetutils',
     'io.ox/office/spreadsheet/utils/paneutils',
     'io.ox/office/spreadsheet/view/render/renderutils',
     'io.ox/office/spreadsheet/view/render/autostylecache'
-], function (Utils, IteratorUtils, SimpleMap, TriggerObject, TimerMixin, SheetUtils, PaneUtils, RenderUtils, AutoStyleCache) {
+], function (Utils, IteratorUtils, ValueSet, ValueMap, TriggerObject, SheetUtils, PaneUtils, RenderUtils, AutoStyleCache) {
 
     'use strict';
 
@@ -54,27 +54,29 @@ define('io.ox/office/spreadsheet/view/render/rendercache', [
      * @constructor
      *
      * @extends TriggerObject
-     * @extends TimerMixin
      *
      * @param {SpreadsheetView} docView
      *  The document view that contains this cache instance.
      */
-    function RenderCache(docView) {
+    var RenderCache = TriggerObject.extend({ constructor: function (docView) {
 
         // self reference
         var self = this;
 
+        // the application instance
+        var app = docView.getApp();
+
         // the spreadsheet model and its containers
         var docModel = docView.getDocModel();
 
-        // the spreadsheet app
-        var app = docView.getApp();
+        // the collection of table style sheets
+        var tableStyles = docModel.getStyleCollection('table');
 
         // the cache for all auto style descriptors
         var styleCache = new AutoStyleCache(docView);
 
         // all cell elements of the rendering matrix, mapped by cell key
-        var cellMatrix = new SimpleMap();
+        var cellMatrix = new ValueSet('key');
 
         // column headers in the rendering matrix (as sorted array, and mapped by column index)
         var colHeader = new RenderUtils.MatrixHeaderCache(true);
@@ -83,7 +85,7 @@ define('io.ox/office/spreadsheet/view/render/rendercache', [
         var rowHeader = new RenderUtils.MatrixHeaderCache(false);
 
         // the current bounding ranges and rectangles, per pane position (missing entry: hidden)
-        var boundaryMap = new SimpleMap();
+        var boundaryMap = new ValueMap();
 
         // the unified bounding ranges covered by this cache
         var boundRanges = new RangeArray();
@@ -103,13 +105,13 @@ define('io.ox/office/spreadsheet/view/render/rendercache', [
         // timer for the current asynchronous update cycle
         var updateTimer = null;
 
-        // special behavior for ODF files
-        var odf = docModel.getApp().isODF();
+        // special behavior for OOXML and ODF files
+        var ooxml = app.isOOXML();
+        var odf = app.isODF();
 
-        // base constructors --------------------------------------------------
+        // base constructor ---------------------------------------------------
 
-        TriggerObject.call(this);
-        TimerMixin.call(this);
+        TriggerObject.call(this, docView);
 
         // private methods ----------------------------------------------------
 
@@ -299,7 +301,7 @@ define('io.ox/office/spreadsheet/view/render/rendercache', [
                 // delete all matrix cell elements attached to the header element
                 while (cellElement) {
                     var nextElement = cellElement[nextProp];
-                    cellMatrix.remove(cellElement.key);
+                    cellMatrix.remove(cellElement);
                     cellElement.unlink();
                     cellElement = nextElement;
                 }
@@ -354,7 +356,7 @@ define('io.ox/office/spreadsheet/view/render/rendercache', [
                         var cellElement = new RenderUtils.MatrixCellElement(address, colElement, rowElement, l, r, t, b);
 
                         // insert the new cell element into the rendering matrix
-                        cellMatrix.insert(cellElement.key, cellElement);
+                        cellMatrix.insert(cellElement);
                     });
                 }
                 nextIndex += 1;
@@ -381,14 +383,14 @@ define('io.ox/office/spreadsheet/view/render/rendercache', [
          *
          * @param {Object} [options]
          *  Optional parameters:
-         *  @param {Boolean} [options.columns=false]
+         *  - {Boolean} [options.columns=false]
          *      If set to true, the cells in the passed ranges will be visited
          *      in vertical orientation (all cells top-down in first column,
          *      then all cells top-down in second column, etc.). By default,
          *      the cells will be visited in horizontal orientation (all cells
          *      left-to-right in first row, then all cells left-to-right in
          *      second row, etc.).
-         *  @param {Boolean} [options.first=false]
+         *  - {Boolean} [options.first=false]
          *      If set to true, only the matrix elements of the first visible
          *      row (or the first visible column in vertical mode, see option
          *      'columns') of each range will be visited.
@@ -404,9 +406,9 @@ define('io.ox/office/spreadsheet/view/render/rendercache', [
             // iteration direction (true for columns instead of rows)
             var columns = Utils.getBooleanOption(options, 'columns', false);
             // descriptors of all visited merged ranges
-            var visitedMergedMap = new SimpleMap();
+            var visitedMergedSet = new ValueSet('originKey');
             // descriptors of all visited merged ranges whose visible origin has been visited
-            var visitedOriginsMap = new SimpleMap();
+            var visitedOriginsSet = new ValueSet('originKey');
 
             function invokeCallback(element, range) {
 
@@ -416,9 +418,9 @@ define('io.ox/office/spreadsheet/view/render/rendercache', [
                 // collect origin cells of all merged ranges covering the visited cells (value false
                 // for cells covered by the merged range, value true for top-left visible cells)
                 if (element.isMergedOrigin()) {
-                    visitedOriginsMap.insert(element.merged.originKey, element.merged);
+                    visitedOriginsSet.insert(element.merged);
                 } else if (element.isMerged()) {
-                    visitedMergedMap.insert(element.merged.originKey, element.merged);
+                    visitedMergedSet.insert(element.merged);
                 }
             }
 
@@ -471,9 +473,7 @@ define('io.ox/office/spreadsheet/view/render/rendercache', [
             });
 
             // collect and return descriptors of all merged ranges whose top-left cell has NOT been visited
-            return visitedMergedMap.reject(function (mergeDesc, originKey) {
-                return visitedOriginsMap.has(originKey);
-            });
+            return visitedMergedSet.reject(visitedOriginsSet.has, visitedOriginsSet);
         }
 
         function abortUpdateCycle() {
@@ -509,19 +509,60 @@ define('io.ox/office/spreadsheet/view/render/rendercache', [
                 var hyperlinkCollection = sheetModel.getHyperlinkCollection();
                 // the conditional formatting collection of the passed sheet
                 var condFormatCollection = sheetModel.getCondFormatCollection();
+                // the table collection of the active sheet
+                var tableCollection = sheetModel.getTableCollection();
+
+                // the cell attributes of active conditional formatting rules (cached by address for repeated usage in merged ranges)
+                var condFormatResultMap = new ValueMap();
+                // the settings needed to render the cells of a table range (cached by table model UID for repeated usage)
+                var tableSettingsMap = new ValueMap();
+                // the cell attributes of a table style sheet covered by the cell (cached by address for repeated usage in merged ranges)
+                var tableAttrSetMap = new ValueMap();
+
                 // the ranges to be updated and rendered
                 var updateRanges = new RangeArray();
                 // all matrix cell elements with overflowing text, mapped by cell key, for second-step-update
-                var overflowElementMap = new SimpleMap();
+                var overflowElementMap = new ValueMap();
                 // all matrix cell elements whose overflowing neighbors need to be updated
-                var neighborElementMap = new SimpleMap();
-                // whether to use the top-left cell to render the border of an entire merged range
-                var expandMergedBorders = docModel.getApp().isODF();
+                var neighborElementSet = new ValueSet('key');
 
-                // returns the cell attributes of active conditional formatting rules (cached for repeated usage in merged ranges)
-                var getCondFormatResult = _.memoize(function (address) {
-                    return condFormatCollection.resolveRules(address);
-                }, function (address) { return address.key(); });
+                // returns the cell attributes of active conditional formatting rules
+                function getCondFormatResult(address) {
+                    return condFormatResultMap.getOrCreate(address.key(), function () {
+                        return condFormatCollection.resolveRules(address);
+                    });
+                }
+
+                // returns the settings needed to render the cells of a table range (cached for repeated usage)
+                function getTableSettings(tableModel) {
+                    return tableSettingsMap.getOrCreate(tableModel.getUid(), function () {
+                        var styleId = tableModel.getStyleId();
+                        var rawAttrSet = styleId ? tableStyles.getStyleSheetAttributeMap(styleId, true) : null;
+                        return _.isEmpty(rawAttrSet) ? null : {
+                            range: tableModel.getRange(),
+                            attrs: rawAttrSet,
+                            flags: tableModel.getStyleFlags()
+                        };
+                    });
+                }
+
+                // returns the cell attributes of a table style sheet covered by the cell
+                function getTableAttrSet(address) {
+                    return tableAttrSetMap.getOrCreate(address.key(), function () {
+                        // resolve the table style settings
+                        var tableModel = tableCollection.findTable(address);
+                        var settings = tableModel ? getTableSettings(tableModel) : null;
+                        if (!settings) { return null; }
+                        // resolve the formatting attributes for the current cell address
+                        var range = settings.range;
+                        var colInterval = { start: address[0] - range.start[0], end: address[0] - range.start[0] };
+                        var rowInterval = { start: address[1] - range.start[1], end: address[1] - range.start[1] };
+                        var attrSet = tableStyles.resolveCellAttributeSet(settings.attrs, colInterval, rowInterval, range.cols(), range.rows(), settings.flags);
+                        // remove the table attributes (prevent to use them in auto-style cache)
+                        delete attrSet.table;
+                        return attrSet;
+                    });
+                }
 
                 // updates cell formatting and all text settings of a single matrix cell element
                 function updateCellElement(element) {
@@ -532,19 +573,26 @@ define('io.ox/office/spreadsheet/view/render/rendercache', [
                     var cellModel = cellCollection.getCellModel(address);
                     // the identifier of the initial auto-style (bug 40429: always set a style descriptor to (blank) merged ranges)
                     var baseStyleId = cellModel ? cellModel.s : element.isMergedOrigin() ? cellCollection.getDefaultStyleId(address) : null;
-                    // result descriptor for conditional formatting to be rendered over the auto-style of the cell
+
+                    // OOXML: use the auto-style of current cell (not merged origin) for outer borders in merged ranges
+                    // ODF: expand the borders of the top-left auto-style in merged ranges
+                    var borderStyleId = (ooxml && element.isMergedBorder()) ? cellCollection.getStyleId(element.address) : null;
+
+                    // result descriptor for conditional formatting
                     var condFormatResult = getCondFormatResult(address);
                     // explicit attributes of conditional formatting to be rendered over the auto-style of the cell
-                    var attributeSet = condFormatResult ? condFormatResult.attributeSet : null;
-                    // an alternative auto-style identifier for outer borders in merged ranges (use current address not shifted to merged origin!)
-                    var borderStyleId = (!expandMergedBorders && element.isMergedBorder()) ? cellCollection.getStyleId(element.address) : null;
-                    // the auto-style identifier of the source cell (resolve default style for undefined cells with conditional formatting)
-                    var styleId = (baseStyleId !== null) ? baseStyleId : (attributeSet || _.isString(borderStyleId)) ? cellCollection.getDefaultStyleId(address) : null;
-                    // the rendering style descriptor; or null for undefined cells without any special settings
-                    var styleDesc = _.isString(styleId) ? styleCache.getStyle(styleId, { borderStyleId: borderStyleId, attributeSet: attributeSet }) : null;
+                    var condAttrSet = condFormatResult ? condFormatResult.attributeSet : null;
                     // additional rendering properties returned by conditional formattings
                     var renderProps = condFormatResult ? condFormatResult.renderProps : null;
 
+                    // explicit attributes of a table style to be rendered over the auto-style of the cell
+                    var tableAttrSet = getTableAttrSet(address);
+
+                    // the auto-style identifier of the source cell (resolve default style for undefined cells with conditional formatting)
+                    var styleId = (baseStyleId !== null) ? baseStyleId : ((borderStyleId !== null) || condAttrSet || tableAttrSet) ? cellCollection.getDefaultStyleId(address) : null;
+                    // the rendering style descriptor; or null for undefined cells without any special settings
+                    var styleDesc = (styleId !== null) ? styleCache.getStyle(styleId, { borderStyleId: borderStyleId, condAttrSet: condAttrSet, tableAttrSet: tableAttrSet }) : null;
+
                     // hyperlinks in ODF files will be drawn with blue text color by default
                     if (odf && hyperlinkCollection.getCellURL(address)) {
                         (renderProps || (renderProps = {})).hyperlink = true;
@@ -556,7 +604,7 @@ define('io.ox/office/spreadsheet/view/render/rendercache', [
                 // returns the pixel position of the next available adjacent merged range
                 function findNextMergedRectangle(element, forward) {
                     var mergeDesc = findNextMergeDesc(element.address, forward);
-                    return mergeDesc ? sheetModel.getRangeRectangle(mergeDesc.mergedRange) : null;
+                    return mergeDesc ? docView.getRangeRectangle(mergeDesc.mergedRange) : null;
                 }
 
                 // finds the content cell next to the passed cell element
@@ -689,23 +737,23 @@ define('io.ox/office/spreadsheet/view/render/rendercache', [
 
                         // update adjacent cell elements with text floating towards the updated ranges, if blank state changes
                         if (oldBlank !== newBlank) {
-                            neighborElementMap.insert(element.key, element);
+                            neighborElementSet.insert(element);
                         }
-                    }, { delay: 'immediate', infoString: 'Rendercache.updatetimer 1', app: app });
+                    }, 'Rendercache.registerDirtyRanges.updateMatrix');
                 });
 
                 // update origin cells of outer merged ranges overlapping the dirty ranges
                 updateTimer = updateTimer.then(RenderUtils.profileAsyncMethod('update origins of merged range', function () {
                     return self.iterateArraySliced(outerMergeDescs, function (mergeDesc) {
                         updateCellElement(mergeDesc.element);
-                    }, { delay: 'immediate', infoString: 'Rendercache.updatetimer 2', app: app });
+                    }, 'Rendercache.registerDirtyRanges.updateMatrix');
                 }));
 
                 // update clipping rectangles of cells with overflowing text (restrict to content cells and merged ranges)
                 updateTimer = updateTimer.then(RenderUtils.profileAsyncMethod('update text clipping rectangles', function () {
 
                     // find adjacent cells with overflowing text (left/right of changed cells)
-                    neighborElementMap.forEach(function (element) {
+                    neighborElementSet.forEach(function (element) {
                         registerAdjacentOverflowCell(element, false);
                         registerAdjacentOverflowCell(element, true);
                     });
@@ -719,7 +767,7 @@ define('io.ox/office/spreadsheet/view/render/rendercache', [
                         var innerRect = element.text.inner;
                         // the new clipping positions
                         var clipL = innerRect.left - element.text.overflowL;
-                        var clipR = innerRect.left + innerRect.width + element.text.overflowR;
+                        var clipR = innerRect.right() + element.text.overflowR;
                         // whether left or right text overflows
                         var overflowL = element.hasOverflowText(false);
                         var overflowR = element.hasOverflowText(true);
@@ -736,7 +784,7 @@ define('io.ox/office/spreadsheet/view/render/rendercache', [
                                 mergedRect = findNextMergedRectangle(element, false);
                                 contentCol = findNextContentCol(element, false);
                             }
-                            if (mergedRect) { clipL = Math.max(clipL, mergedRect.left + mergedRect.width); }
+                            if (mergedRect) { clipL = Math.max(clipL, mergedRect.right()); }
                             if (contentCol) { clipL = Math.max(clipL, contentCol.offset + contentCol.size); }
                         }
 
@@ -760,7 +808,7 @@ define('io.ox/office/spreadsheet/view/render/rendercache', [
                         if (overflowL || overflowR) {
                             addOverflowRange(element.address, overflowL, overflowR);
                         }
-                    }, { delay: 'immediate', infoString: 'Rendercache.updatetimer 3', app: app });
+                    }, 'Rendercache.registerDirtyRanges.updateMatrix');
                 }));
 
                 // notify rendering listeners
@@ -784,57 +832,9 @@ define('io.ox/office/spreadsheet/view/render/rendercache', [
 
             // the actual method RenderCache.registerDirtyRanges() to be returned from the local scope
             // (debounced version of RenderCache.registerDirtyRanges(), that waits for document operations currently applied)
-            return docView.getApp().createDebouncedActionsMethodFor(self, registerRanges, updateMatrix);
+            return app.createDebouncedActionsMethodFor(self, 'RenderCache.registerDirtyRanges', registerRanges, updateMatrix);
         }());
 
-        /**
-         * Updates all cells in this rendering cache that have been changed in
-         * the active sheet (handler of the 'change:cells' event triggered by
-         * the cell collection of the active sheet).
-         */
-        var changeCellsHandler = RenderUtils.profileMethod('RenderCache.changeCellsHandler()', function (event, changeDesc) {
-
-            // the changed cell ranges
-            var changedRanges = changeDesc.getAllRanges();
-            registerDirtyRanges(changedRanges);
-
-            // add all merged ranges starting at the changed cells
-            registerDirtyRanges(docView.getMergeCollection().getMergedRanges(changedRanges, 'reference'));
-        });
-
-        /**
-         * Updates all cells in this rendering cache that have been changed in
-         * the active sheet (handler of the 'refresh:ranges' event triggered by
-         * the active sheet).
-         */
-        var refreshRangesHandler = RenderUtils.profileMethod('RenderCache.refreshRangesHandler()', function (event, ranges) {
-            registerDirtyRanges(ranges);
-        });
-
-        /**
-         * Updates the cached merged ranges in this rendering cache after new
-         * merged ranges have been inserted into the active sheet (handler of
-         * the 'insert:merged' event triggered by the merged ranges collection
-         * of the active sheet), or after existing merged ranges have been
-         * feleted from the active sheet (handler of  the 'delete:merged' event
-         * triggered by the active sheet).
-         */
-        var changeMergedHandler = RenderUtils.profileMethod('RenderCache.changeMergedHandler()', function () {
-            registerDirtyRanges(updateMergedRanges());
-        });
-
-        /**
-         * Updates this rendering cache, after the grid color of the active
-         * sheet has been changed (cell borders with automatic line color are
-         * using the current sheet grid color).
-         */
-        function changeSheetAttributesHandler(event, newAttributes, oldAttributes) {
-            if (!_.isEqual(newAttributes.sheet.gridColor, oldAttributes.sheet.gridColor)) {
-                styleCache.updateStyles();
-                if (totalRange) { registerDirtyRanges(totalRange); }
-            }
-        }
-
         // public methods -----------------------------------------------------
 
         /**
@@ -904,18 +904,18 @@ define('io.ox/office/spreadsheet/view/render/rendercache', [
          *
          * @param {Object} [options]
          *  Optional parameters:
-         *  @param {Boolean} [options.columns=false]
+         *  - {Boolean} [options.columns=false]
          *      If set to true, the cells in the passed range will be visited
          *      in vertical orientation (all cells top-down in first column,
          *      then all cells top-down in second column, etc.). By default,
          *      the cells will be visited in horizontal orientation (all cells
          *      left-to-right in first row, then all cells left-to-right in
          *      second row, etc.).
-         *  @param {Boolean} [options.first=false]
+         *  - {Boolean} [options.first=false]
          *      If set to true, only the matrix elements of the first visible
          *      row (or the first visible column in vertical mode, see option
          *      'columns') will be visited.
-         *  @param {Boolean} [options.origins=false]
+         *  - {Boolean} [options.origins=false]
          *      If set to true, the origin cells of all merged ranges covering
          *      the passed range will be visited, regardless if they are inside
          *      the passed range; and the cells in the passed range that are
@@ -1068,7 +1068,7 @@ define('io.ox/office/spreadsheet/view/render/rendercache', [
          * passed bounding intervals, and returns descriptors for all changed
          * layer ranges.
          *
-         * @param {SimpleMap<HeaderBoundary>} headerBoundaryMap
+         * @param {ValueMap<HeaderBoundary>} headerBoundaryMap
          *  All changed bounding intervals, mapped by pane side identifiers.
          *  The boundary intervals of pane sides missing in this map will not
          *  be changed. If a boundary in this map exists and is invalid (all of
@@ -1080,7 +1080,7 @@ define('io.ox/office/spreadsheet/view/render/rendercache', [
          *  that must be recalculated and repainted (e.g. after one or more
          *  document operations such as inserting or deleting columns or rows).
          *
-         * @returns {SimpleMap<RangeBoundary>}
+         * @returns {ValueMap<RangeBoundary>}
          *  A map containing descriptors for all changed layer ranges, mapped
          *  by pane position identifier. The boundary ranges of pane positions
          *  missing in this map have not been changed. If a descriptor in this
@@ -1103,7 +1103,7 @@ define('io.ox/office/spreadsheet/view/render/rendercache', [
             // all cell ranges to be refreshed in the rendering matrix
             var refreshRanges = new RangeArray();
             // the changed range boundaries returned to caller
-            var resultBoundaryMap = new SimpleMap();
+            var resultBoundaryMap = new ValueMap();
 
             headerBoundaryMap.forEach(function (boundary, paneSide) {
 
@@ -1210,13 +1210,57 @@ define('io.ox/office/spreadsheet/view/render/rendercache', [
 
         // initialization -----------------------------------------------------
 
-        // update rendering matrix after any cells or merged ranges have changed in the active sheet
-        this.listenTo(docView, 'change:cells', changeCellsHandler);
-        this.listenTo(docView, 'refresh:ranges', refreshRangesHandler);
-        this.listenTo(docView, 'insert:merged delete:merged', changeMergedHandler);
+        // update all cells that have been changed in the active sheet
+        this.listenTo(docView, 'change:cells', RenderUtils.profileMethod('RenderCache.listenTo(change:cells)', function (event, changeDesc) {
+            // the changed cell ranges
+            var changedRanges = changeDesc.getAllRanges();
+            registerDirtyRanges(changedRanges);
+            // add all merged ranges starting at the changed cells
+            registerDirtyRanges(docView.getMergeCollection().getMergedRanges(changedRanges, 'reference'));
+        }));
 
-        // update cell entries with borders after the grid color has changed
-        this.listenTo(docView, 'change:sheet:attributes', changeSheetAttributesHandler);
+        // update all cell ranges that have been invalidated in the active sheet
+        this.listenTo(docView, 'refresh:ranges', RenderUtils.profileMethod('RenderCache.listenTo(refresh:ranges)', function (event, ranges) {
+            registerDirtyRanges(ranges);
+        }));
+
+        // update the cached merged ranges after new merged ranges have been inserted into the
+        // active sheet, or after existing merged ranges have been deleted from the active sheet
+        this.listenTo(docView, 'insert:merged delete:merged', RenderUtils.profileMethod('RenderCache.listenTo(insert:merged delete:merged)', function () {
+            registerDirtyRanges(updateMergedRanges());
+        }));
+
+        // render cells of inserted and deleted table ranges (table styling)
+        this.listenTo(docView, 'insert:table delete:table', function (event, tableModel) {
+            registerDirtyRanges(tableModel.getRange());
+        });
+
+        // render table ranges with changed attributes (table styling)
+        this.listenTo(docView, 'change:table', function (event, tableModel, type) {
+            if (type === 'change:attributes') {
+                registerDirtyRanges(tableModel.getRange());
+            }
+        });
+
+        // refresh all table ranges using a changed table style sheet
+        this.listenOnceTo(docModel, 'change:activesheet', function () {
+            self.listenTo(docModel.getTableStyles(), 'triggered', function (event, type, styleId) {
+                IteratorUtils.forEach(docView.getTableCollection().createModelIterator(), function (tableModel) {
+                    if (tableModel.getStyleId() === styleId) {
+                        registerDirtyRanges(tableModel.getRange());
+                    }
+                });
+            });
+        });
+
+        // update the rendering cache, after the grid color of the active sheet has been changed
+        // (cell borders with automatic line color are using the current sheet grid color)
+        this.listenTo(docView, 'change:sheet:attributes', function (event, newAttributes, oldAttributes) {
+            if (!_.isEqual(newAttributes.sheet.gridColor, oldAttributes.sheet.gridColor)) {
+                styleCache.updateStyles();
+                if (totalRange) { registerDirtyRanges(totalRange); }
+            }
+        });
 
         // destroy all class members on destruction
         this.registerDestructor(function () {
@@ -1224,14 +1268,13 @@ define('io.ox/office/spreadsheet/view/render/rendercache', [
             self = docView = docModel = app = null;
             styleCache = cellMatrix = colHeader = rowHeader = null;
             boundaryMap = boundRanges = totalRange = null;
-            mergedRangeSet = dirtyRanges = null;
+            mergedRangeSet = dirtyRanges = pendingRanges = null;
         });
 
-    } // class RenderCache
+    } }); // class RenderCache
 
     // exports ================================================================
 
-    // derive this class from class TriggerObject
-    return TriggerObject.extend({ constructor: RenderCache });
+    return RenderCache;
 
 });
