@@ -15,13 +15,15 @@
 define('io.ox/office/spreadsheet/view/render/renderutils', [
     'io.ox/office/tk/utils',
     'io.ox/office/tk/utils/logger',
-    'io.ox/office/tk/container/simplemap',
+    'io.ox/office/tk/container/valuemap',
     'io.ox/office/tk/container/sortedarray',
     'io.ox/office/tk/render/path',
+    'io.ox/office/tk/render/rectangle',
     'io.ox/office/editframework/utils/color',
     'io.ox/office/editframework/utils/border',
+    'io.ox/office/editframework/utils/pattern',
     'io.ox/office/spreadsheet/utils/sheetutils'
-], function (Utils, Logger, SimpleMap, SortedArray, Path, Color, Border, SheetUtils) {
+], function (Utils, Logger, ValueMap, SortedArray, Path, Rectangle, Color, Border, Pattern, SheetUtils) {
 
     'use strict';
 
@@ -245,7 +247,7 @@ define('io.ox/office/spreadsheet/view/render/renderutils', [
         // the parsed format code
         this.format = null;
 
-        // effective CSS fill color
+        // effective fill style (CSS color, canvas gradient, or canvas pattern)
         this.fill = null;
 
         // style settings for all border lines
@@ -288,9 +290,16 @@ define('io.ox/office/spreadsheet/view/render/renderutils', [
         // resolve the number format descriptor
         this.format = docModel.getNumberFormatter().getParsedFormatForAttributes(cellAttrs);
 
-        // resolve fill style to color descriptor, and to resulting CSS color value
-        var colorDesc = docModel.resolveColor(Color.parseJSON(cellAttrs.fillColor), 'fill');
-        this.fill = (colorDesc.a === 0) ? null : colorDesc.css;
+        // resolve fill style (CSS color, canvas gradient, or canvas pattern)
+        switch (cellAttrs.fillType) {
+            case 'pattern':
+                this.fill = Pattern.createCanvasPattern(cellAttrs.pattern, cellAttrs.fillColor, cellAttrs.foreColor, docModel.getThemeModel());
+                break;
+            case 'gradient': // TODO
+            default:
+                var fillColorDesc = docModel.resolveColor(Color.parseJSON(cellAttrs.fillColor), 'fill');
+                this.fill = (fillColorDesc.a === 0) ? null : fillColorDesc.css;
+        }
 
         // resolve style settings for all border lines
         this.borders = Utils.makeObject('tblrdu', function (borderKey) {
@@ -299,7 +308,7 @@ define('io.ox/office/spreadsheet/view/render/renderutils', [
         });
 
         // scaled font attributes according to current sheet zoom factor
-        this.font = docModel.getFontCollection().getFont(charAttrs, { zoom: sheetZoom });
+        this.font = docModel.getRenderFont(charAttrs, null, sheetZoom);
 
         // scaled height of a single text line, in pixels (effective height of an empty cell)
         this.rowHeight = docModel.getRowHeight(charAttrs, sheetZoom);
@@ -528,12 +537,12 @@ define('io.ox/office/spreadsheet/view/render/renderutils', [
      *
      * @constructor
      *
-     * @property {Object} inner
-     *  The position of the inner cell rectangle, without trailing grid lines,
+     * @property {Rectangle} inner
+     *  The location of the inner cell rectangle, without trailing grid lines,
      *  expanded to the size of a merged range if existing.
      *
-     * @property {Object} clip
-     *  The position of the clipping rectangle needed to restrict the content
+     * @property {Rectangle} clip
+     *  The location of the clipping rectangle needed to restrict the content
      *  text to the cell area (e.g. for oversized fonts), or to clip text cells
      *  with horizontally overflowing contents at the boundaries of adjacent
      *  cells.
@@ -581,7 +590,7 @@ define('io.ox/office/spreadsheet/view/render/renderutils', [
         this.inner = innerRect;
 
         // the clipping rectangle
-        this.clip = { left: innerRect.left, top: innerRect.top, width: innerRect.width, height: innerRect.height };
+        this.clip = innerRect.clone();
 
         // text overflow width to the left
         this.overflowL = 0;
@@ -848,6 +857,19 @@ define('io.ox/office/spreadsheet/view/render/renderutils', [
      *  undefined). Can be used to determine the optimal height of the row
      *  containing this cell.
      *
+     * @property {Number} paddingLeft
+     *  The padding size between left cell border and text contents in pixels,
+     *  depending on the font size and zoom factor.
+     *
+     * @property {Number} paddingRight
+     *  The padding size between text contents and right cell border in pixels,
+     *  depending on the font size and zoom factor.
+     *
+     * @property {Number} paddingTotal
+     *  The total padding size that cannot be used for text contents. This is
+     *  the sum of left and right padding, plus one pixel for the trailing grid
+     *  line.
+     *
      * @property {Object|Null} renderProps
      *  Additional rendering properties next to the cell formatting attibutes,
      *  e.g. data bar settings from a conditional formatting rule.
@@ -881,6 +903,11 @@ define('io.ox/office/spreadsheet/view/render/renderutils', [
         // text descriptor
         this.text = null;
 
+        // size of content and padding
+        this.contentWidth = this.contentHeight = 0;
+        this.paddingLeft = this.paddingRight = 0;
+        this.paddingTotal = 1;
+
         // other rendering properties
         this.renderProps = null;
 
@@ -950,8 +977,8 @@ define('io.ox/office/spreadsheet/view/render/renderutils', [
         if (this.isMergedOrigin()) { this.merged.element = this; }
 
         // the inner cell rectangle without grid line for rendering (merged ranges may be partly out of rendering matrix, resolve from sheet model)
-        var innerRect = this.innerRect = this.merged ? sheetModel.getRangeRectangle(this.merged.mergedRange) :
-            (this.col && this.row) ? { left: this.col.offset, top: this.row.offset, width: this.col.size, height: this.row.size } :
+        var innerRect = this.innerRect = this.merged ? sheetModel.getRangeRectangle(this.merged.mergedRange, { pixel: true }) :
+            (this.col && this.row) ? new Rectangle(this.col.offset, this.row.offset, this.col.size, this.row.size) :
             sheetModel.getCellRectangle(this.address);
 
         // initialize other element properties to represent a blank cell initially
@@ -974,8 +1001,7 @@ define('io.ox/office/spreadsheet/view/render/renderutils', [
         }
 
         // exclude grid lines at trailing cell borders
-        innerRect.width -= GRID_LINE_WIDTH;
-        innerRect.height -= GRID_LINE_WIDTH;
+        innerRect.expandSelf(0, 0, -GRID_LINE_WIDTH, -GRID_LINE_WIDTH);
 
         // nothing more to do for cells without visible display text (blank cells, formulas resulting in empty string, etc.),
         // but do not exit for null values as display string (invalid number format) which will be rendered as 'railroad track error'
@@ -994,8 +1020,8 @@ define('io.ox/office/spreadsheet/view/render/renderutils', [
         // effective text orientation (alignment and writing direction)
         var textOrient = SheetUtils.getTextOrientation(cellModel.v, attributes.cell.alignHor, display);
         // the inner horizontal padding for text in cells (according to current zoom)
-        var paddingLeft = (renderProps && renderProps.iconSet) ? rowHeight : sheetModel.getEffectiveTextPadding();
-        var paddingRight = sheetModel.getEffectiveTextPadding();
+        var paddingRight = sheetModel.getTextPadding(attributes.character);
+        var paddingLeft = (renderProps && renderProps.iconSet) ? rowHeight : paddingRight;
         // the available width for the cell text (without left/right padding)
         var availableWidth = Math.max(2, innerRect.width - paddingLeft - paddingRight);
         // resolved and scaled font settings
@@ -1119,10 +1145,12 @@ define('io.ox/office/spreadsheet/view/render/renderutils', [
         // store width and height of the text box in the matrix element for external usage
         this.contentWidth = totalWidth;
         this.contentHeight = totalHeight;
+        this.paddingLeft = paddingLeft;
+        this.paddingRight = paddingRight;
+        this.paddingTotal = paddingLeft + paddingRight + 1;
 
         // initialize the clipping rectangle (text may be taller than height of cell)
-        textDesc.clip.left -= overflowL;
-        textDesc.clip.width += overflowL + overflowR;
+        textDesc.clip.expandSelf(overflowL, 0, overflowR, 0);
 
         // store text overflow width
         textDesc.overflowL = overflowL;
@@ -1150,7 +1178,7 @@ define('io.ox/office/spreadsheet/view/render/renderutils', [
                 break;
             default:
                 // bottom alignment, and fall-back for unknown alignments
-                offsetY = innerRect.top + innerRect.height - totalHeight;
+                offsetY = innerRect.bottom() - totalHeight;
         }
 
         // adjust vertical offset to font base line position (as used by canvas renderer)
@@ -1165,7 +1193,7 @@ define('io.ox/office/spreadsheet/view/render/renderutils', [
                     lineDesc.x = innerRect.left + paddingLeft + (availableWidth - lineDesc.width) / 2;
                     break;
                 case 'right':
-                    lineDesc.x = innerRect.left + innerRect.width - paddingRight - lineDesc.width;
+                    lineDesc.x = innerRect.right() - paddingRight - lineDesc.width;
                     break;
                 default:
                     // left alignment, and fall-back for unknown alignments
@@ -1183,7 +1211,7 @@ define('io.ox/office/spreadsheet/view/render/renderutils', [
         if (section && section.rgbColor) {
             textColor = '#' + section.rgbColor;
         } else if (renderProps && renderProps.hyperlink && !styleDesc.explicitTextColor) {
-            textColor = '#' + docModel.getTheme().getSchemeColor('hyperlink', '00f');
+            textColor = '#' + docModel.getThemeModel().getSchemeColor('hyperlink', '00f');
         }
 
         // the fill style for canvas rendering (text will be rendered in fill mode, without outline)
@@ -1362,7 +1390,7 @@ define('io.ox/office/spreadsheet/view/render/renderutils', [
      *  Whether this instance represents the column header of a rendering
      *  matrix (true), or the row header (false).
      *
-     * @property {SimpleMap<HeaderBoundary>} boundaries
+     * @property {ValueMap<HeaderBoundary>} boundaries
      *  All column/row boundaries represented by this matrix header, mapped by
      *  pane side identifier ('left' and 'right' for the column header; 'top'
      *  and 'bottom' for the row header of the rendering matrix).
@@ -1373,7 +1401,7 @@ define('io.ox/office/spreadsheet/view/render/renderutils', [
      * @property {SortedArray<MatrixHeaderElement>} array
      *  An array of matrix header elements, sorted by column/row index.
      *
-     * @property {SimpleMap<MatrixHeaderElement>} map
+     * @property {ValueMap<MatrixHeaderElement>} map
      *  A map with all matrix header elements contained in the cache, mapped by
      *  column/row index.
      */
@@ -1383,7 +1411,7 @@ define('io.ox/office/spreadsheet/view/render/renderutils', [
         this.columns = columns;
 
         // bounding intervals and pixel positions
-        this.boundaries = new SimpleMap();
+        this.boundaries = new ValueMap();
 
         // shrunken and merged bounding intervals
         this.intervals = new IntervalArray();
@@ -1392,7 +1420,7 @@ define('io.ox/office/spreadsheet/view/render/renderutils', [
         this.array = new SortedArray(function (element) { return element.index; });
 
         // map of header elements, mapped by column/row index
-        this.map = new SimpleMap();
+        this.map = new ValueMap();
 
     } // class MatrixHeaderCache
 
