@@ -15,13 +15,12 @@
 
 define('io.ox/office/spreadsheet/view/render/selectionrenderer', [
     'io.ox/office/tk/utils',
-    'io.ox/office/tk/object/triggerobject',
-    'io.ox/office/tk/object/timermixin',
     'io.ox/office/spreadsheet/utils/config',
     'io.ox/office/spreadsheet/utils/sheetutils',
     'io.ox/office/spreadsheet/utils/paneutils',
-    'io.ox/office/spreadsheet/view/render/renderutils'
-], function (Utils, TriggerObject, TimerMixin, Config, SheetUtils, PaneUtils, RenderUtils) {
+    'io.ox/office/spreadsheet/view/render/renderutils',
+    'io.ox/office/spreadsheet/view/render/rendererbase'
+], function (Utils, Config, SheetUtils, PaneUtils, RenderUtils, RendererBase) {
 
     'use strict';
 
@@ -48,13 +47,12 @@ define('io.ox/office/spreadsheet/view/render/selectionrenderer', [
      *
      * @constructor
      *
-     * @extends TriggerObject
-     * @extends TimerMixin
+     * @extends RendererBase
      *
      * @param {GridPane} gridPane
      *  The grid pane instance that owns this selection layer renderer.
      */
-    function SelectionRenderer(gridPane) {
+    var SelectionRenderer = RendererBase.extend({ constructor: function (gridPane) {
 
         // self reference
         var self = this;
@@ -72,19 +70,12 @@ define('io.ox/office/spreadsheet/view/render/selectionrenderer', [
         // the cell range and absolute position covered by the layer nodes in the sheet area
         var layerRectangle = null;
 
-        // list of drawing positions which are remotely selected
-        var selectedDrawings = [];
+        // base constructor ---------------------------------------------------
 
-        // base constructors --------------------------------------------------
-
-        TriggerObject.call(this);
-        TimerMixin.call(this);
+        RendererBase.call(this, gridPane);
 
         // private methods ----------------------------------------------------
 
-        //Debounced version of the method renderCellSelection().
-        var renderCellSelectionDebounced = this.createDebouncedMethod($.noop, renderCellSelection, { delay: 100, infoString: 'SelectionRenderer: renderCellCollection', app: docView.getApp() });
-
         /**
          * Updates the position of the auto-fill handle and the resize handles
          * for cell selection, when entire columns or rows are selected.
@@ -139,6 +130,10 @@ define('io.ox/office/spreadsheet/view/render/selectionrenderer', [
          */
         function renderCellSelection() {
 
+            // nothing to do in chart sheets etc.
+            var sheetModel = docView.getSheetModel();
+            if (!sheetModel.isCellType()) { return; }
+
             // nothing to do, if all columns/rows are hidden (method may be called debounced)
             if (!gridPane.isVisible()) {
                 selectionLayerNode.empty();
@@ -152,12 +147,12 @@ define('io.ox/office/spreadsheet/view/render/selectionrenderer', [
             // the position of the active cell, extended to the merged range
             var activeRectangle = null;
             // additional data for active auto-fill tracking
-            var autoFillData = docView.getSheetViewAttribute('autoFillData');
+            var autoFillData = sheetModel.getViewAttribute('autoFillData');
             // whether the active cell touches the borders of selection ranges
             var activeBorders = { left: false, top: false, right: false, bottom: false };
             // hide left/top border of selection ranges, if first column/row is hidden
-            var firstColHidden = !docView.getColCollection().isEntryVisible(0);
-            var firstRowHidden = !docView.getRowCollection().isEntryVisible(0);
+            var firstColHidden = !sheetModel.getColCollection().isEntryVisible(0);
+            var firstRowHidden = !sheetModel.getRowCollection().isEntryVisible(0);
             // the HTML mark-up for all selection ranges but the active range
             var rangesMarkup = '';
             // the HTML mark-up for the active selection range
@@ -225,14 +220,9 @@ define('io.ox/office/spreadsheet/view/render/selectionrenderer', [
             gridPane.iterateRangesForRendering(selection.ranges, function (range, rectangle, index) {
 
                 // hide left/top border of the range, if the first column/row is hidden
-                if (firstColHidden && (range.start[0] === 0)) {
-                    rectangle.left -= 5;
-                    rectangle.width += 5;
-                }
-                if (firstRowHidden && (range.start[1] === 0)) {
-                    rectangle.top -= 5;
-                    rectangle.height += 5;
-                }
+                var expandL = (firstColHidden && (range.start[0] === 0)) ? 5 : 0;
+                var expandT = (firstRowHidden && (range.start[1] === 0)) ? 5 : 0;
+                rectangle.expandSelf(expandL, expandT, 0, 0);
 
                 // generate the HTML mark-up for the range
                 var rangeMarkup = '<div class="range';
@@ -245,11 +235,11 @@ define('io.ox/office/spreadsheet/view/render/selectionrenderer', [
                 if (activeRectangle && range.overlaps(activeRange)) {
 
                     // initialize position of active cell, relative to selection range
-                    var relActiveRect = _.clone(activeRectangle);
+                    var relActiveRect = activeRectangle.clone();
                     relActiveRect.left -= rectangle.left;
                     relActiveRect.top -= rectangle.top;
-                    relActiveRect.right = rectangle.width - relActiveRect.left - relActiveRect.width;
-                    relActiveRect.bottom = rectangle.height - relActiveRect.top - relActiveRect.height;
+                    var rightDist = rectangle.width - relActiveRect.right();
+                    var bottomDist = rectangle.height - relActiveRect.bottom();
 
                     // insert fill element above active cell
                     if (relActiveRect.top > 0) {
@@ -262,13 +252,13 @@ define('io.ox/office/spreadsheet/view/render/selectionrenderer', [
                     }
 
                     // insert fill element right of active cell
-                    if (relActiveRect.right > 0) {
-                        rangeMarkup += '<div class="fill" style="left:' + (relActiveRect.left + relActiveRect.width) + 'px;right:0;top:' + relActiveRect.top + 'px;height:' + relActiveRect.height + 'px;"></div>';
+                    if (rightDist > 0) {
+                        rangeMarkup += '<div class="fill" style="left:' + relActiveRect.right() + 'px;right:0;top:' + relActiveRect.top + 'px;height:' + relActiveRect.height + 'px;"></div>';
                     }
 
                     // insert fill element below active cell
-                    if (relActiveRect.bottom > 0) {
-                        rangeMarkup += '<div class="fill" style="left:0;right:0;top:' + (relActiveRect.top + relActiveRect.height) + 'px;bottom:0;"></div>';
+                    if (bottomDist > 0) {
+                        rangeMarkup += '<div class="fill" style="left:0;right:0;top:' + relActiveRect.bottom() + 'px;bottom:0;"></div>';
                     }
 
                     // update border flags for the active cell
@@ -324,11 +314,16 @@ define('io.ox/office/spreadsheet/view/render/selectionrenderer', [
             self.trigger('render:cellselection');
         }
 
+        /**
+         * Debounced version of the method renderCellSelection().
+         */
+        var renderCellSelectionDebounced = this.createDebouncedMethod('SelectionRenderer.renderCellSelectionDebounced', null, renderCellSelection, { delay: 100 });
+
         /**
          * Renders selections of all remote users which have the same sheet
          * activated.
          */
-        var renderRemoteSelections = Config.SHOW_REMOTE_SELECTIONS ? function () {
+        var renderRemoteSelection = Config.SHOW_REMOTE_SELECTIONS ? function () {
 
             // nothing to do, if all columns/rows are hidden (method may be called debounced)
             if (!gridPane.isVisible()) {
@@ -336,129 +331,48 @@ define('io.ox/office/spreadsheet/view/render/selectionrenderer', [
                 return;
             }
 
-            // prepare equal mark-up in all selection ranges
-            var borderMarkup = '<div class="borders">' + _.map('lrtb', function (pos) { return '<div data-pos="' + pos + '"></div>'; }).join('') + '</div>';
             // top-left visible address of the grid pane, to detect if the name-layer outside of the view
             var firstRow = gridPane.getTopLeftAddress()[1];
             // the HTML mark-up for all user selections
             var markup = '';
 
-            // remove the classes from the last remote selected drawings
-            selectedDrawings.forEach(function (drawingPos) {
-                var drawingFrame = gridPane.getDrawingFrame(drawingPos);
-                drawingFrame.removeClass('remoteselection badge-inside');
-                drawingFrame.removeAttr('data-username');
-            });
-            selectedDrawings = [];
-
             // generate selections of all remote users on the same sheet
-            docModel.getViewAttribute('remoteClients').forEach(function (client) {
+            docView.iterateRemoteSelections(function (userName, colorIndex, ranges, drawings) {
+                if (!ranges || drawings) { return; }
 
-                // skip users that have another sheet activated
-                if (client.userData.sheet !== docModel.getActiveSheet()) { return; }
+                 // the escaped user name, ready to be inserted into HTML mark-up
+                userName = Utils.escapeHTML(_.noI18n(userName));
 
-                // the escaped user name, ready to be inserted into HTML mark-up
-                var userName = Utils.escapeHTML(_.noI18n(client.userName));
-                // the positions of all selected drawing objects
-                var newSelectedDrawings = Utils.getArrayOption(client.userData, 'drawings', null);
+                // render all ranges of the user
+                gridPane.iterateRangesForRendering(ranges, function (range, rectangle) {
 
-                // show drawing selection only, if the selection contains drawings, otherwise show the cell selection
-                if (newSelectedDrawings && (newSelectedDrawings.length > 0)) {
+                    // the CSS classes to be set at the range (bug 35604: inside range if on top of the grid pane)
+                    var classes = 'range' + ((range.start[1] === firstRow) ? '' : ' remote-badge-outside');
 
-                    // render all selected drawings of the user
-                    var drawingCollection = docView.getDrawingCollection();
-                    newSelectedDrawings.forEach(function (drawingPos) {
-
-                        var drawingModel = drawingCollection.findModel(drawingPos);
-                        var drawingFrame = gridPane.getDrawingFrame(drawingPos);
-                        if (drawingModel && drawingFrame.length > 0) {
-
-                            var rect = drawingModel.getRectangle();
-                            rect = gridPane.convertToLayerRectangle(rect);
-                            rect.top -= 2;
-                            rect.left -= 2;
-                            rect.width += 4;
-                            rect.height += 4;
-
-                            // create the mark-up for the range
-                            markup += '<div class="border" data-style="' + client.colorIndex + '"';
-                            markup += ' style="' + PaneUtils.getRectangleStyleMarkup(rect) + '"></div>';
-
-                            drawingFrame.addClass('remoteselection badge-inside');
-
-                            drawingFrame.attr('data-username', _.noI18n(client.userName));
-                            drawingFrame.attr('data-style', client.colorIndex);
-                            selectedDrawings.push(drawingPos);
-                        }
-                    });
-
-                } else { // no drawings, show cell selection
-
-                    // create the array of cell range addresses
-                    var ranges = docModel.getFormulaParser().parseRangeList('op', client.userData.ranges);
-                    if (!ranges) { return; }
-
-                    // render all ranges of the user
-                    gridPane.iterateRangesForRendering(ranges, function (range, rectangle) {
-
-                        // the CSS classes to be set at the range (bug 35604: inside range if on top of the grid pane)
-                        var classes = 'range' + ((range.start[1] === firstRow) ? ' badge-inside' : '');
-
-                        // create the mark-up for the range
-                        markup += '<div class="' + classes + '" data-style="' + client.colorIndex + '" data-username="' + userName + '"';
-                        markup += ' style="' + PaneUtils.getRectangleStyleMarkup(rectangle) + '">' + borderMarkup + '</div>';
-                    }, { alignToGrid: true });
-                }
+                    // create the mark-up for the range
+                    markup += '<div class="' + classes + '" data-remote-user="' + userName + '" data-remote-color="' + colorIndex + '"';
+                    markup += ' style="' + PaneUtils.getRectangleStyleMarkup(rectangle) + '"><div class="fill"></div></div>';
+                }, { alignToGrid: true });
             });
 
             // insert entire HTML mark-up into the container node
             remoteLayerNode[0].innerHTML = markup;
 
-        } : $.noop;
-
-        /**
-         * Updates the layer nodes after specific document view attributes have
-         * been changed.
-         */
-        function changeViewAttributesHandler(event, attributes) {
-
-            // display remote selections
-            if ('remoteClients' in attributes) {
-                renderRemoteSelections();
-            }
-        }
-
-        /**
-         * Updates the layer nodes after specific sheet view attributes have
-         * been changed.
-         */
-        function changeSheetViewAttributesHandler(event, attributes) {
-
-            // render cell selection (triggers a 'render:cellselection' event)
-            if (Utils.hasProperty(attributes, /^(selection$|split|autoFillData$)/)) {
-                renderCellSelection();
-            }
-
-            // trigger a 'render:cellselection' event if active pane changes
-            // (no actual rendering needed, border colors will change via CSS)
-            if ('activePane' in attributes) {
-                self.trigger('render:cellselection');
-            }
-        }
+        } : _.noop;
 
         // protected methods --------------------------------------------------
 
         /**
          * Changes the layers according to the passed layer range.
          */
-        this.setLayerRange = RenderUtils.profileMethod('SelectionRenderer.setLayerRange()', function (newLayerRange, newLayerRectangle) {
+        this.setLayerRange = RenderUtils.profileMethod('SelectionRenderer.setLayerRange()', function (layerSettings) {
 
             // store new layer range and rectangle for convenience
-            layerRectangle = newLayerRectangle;
+            layerRectangle = layerSettings.rectangle;
 
             // render own selection, and selections of all remote editors
             renderCellSelection();
-            renderRemoteSelections();
+            renderRemoteSelection();
         });
 
         /**
@@ -473,32 +387,46 @@ define('io.ox/office/spreadsheet/view/render/selectionrenderer', [
         // initialization -----------------------------------------------------
 
         // render cell selection again when document edit mode changes
-        gridPane.listenToWhenVisible(this, docModel, 'change:editmode', renderCellSelection);
+        this.listenToWhenVisible(docView.getApp(), 'docs:editmode', renderCellSelection);
 
         // render cell selection after merging/unmerging cell ranges (size of active cell may change)
-        gridPane.listenToWhenVisible(this, docView, 'insert:merged delete:merged', renderCellSelectionDebounced);
+        this.listenToWhenVisible(docView, 'insert:merged delete:merged', renderCellSelectionDebounced);
 
-        // update layers according to changed view attributes (only, if this grid pane is visible)
-        gridPane.listenToWhenVisible(this, docView, 'change:viewattributes', changeViewAttributesHandler);
-        gridPane.listenToWhenVisible(this, docView, 'change:sheet:viewattributes', changeSheetViewAttributesHandler);
+        // update layers according to changed document view attributes
+        this.listenToWhenVisible(docView, 'change:viewattributes', function (event, attributes) {
+            if ('remoteClients' in attributes) {
+                renderRemoteSelection();
+            }
+        });
 
-        // post-processing after scrolling, or after selection has been rendered
+        // update the layer nodes after specific sheet view attributes have been changed
+        this.listenToWhenVisible(docView, 'change:sheet:viewattributes', function (event, attributes) {
+
+            // render cell selection (triggers a 'render:cellselection' event)
+            if (Utils.hasProperty(attributes, /^(selection$|split|autoFillData$)/)) {
+                renderCellSelection();
+            }
+
+            // trigger a 'render:cellselection' event if active pane changes
+            // (no actual rendering needed, border colors will change via CSS)
+            if ('activePane' in attributes) {
+                self.trigger('render:cellselection');
+            }
+        });
+
+        // post-processing after scrolling
         this.listenTo(gridPane, 'change:scrollpos', updateResizeHandlePositions);
 
-        // repaint the remote drawing selections after manipulating the drawing collection
-        gridPane.listenToWhenVisible(this, docView, 'insert:drawing delete:drawing change:drawing', renderRemoteSelections);
-
         // destroy all class members on destruction
         this.registerDestructor(function () {
             self = gridPane = docModel = docView = null;
             remoteLayerNode = selectionLayerNode = null;
         });
 
-    } // class SelectionRenderer
+    } }); // class SelectionRenderer
 
     // exports ================================================================
 
-    // derive this class from class TriggerObject
-    return TriggerObject.extend({ constructor: SelectionRenderer });
+    return SelectionRenderer;
 
 });
