@@ -23,6 +23,10 @@ define('io.ox/office/spreadsheet/view/statuspane', [
 
     'use strict';
 
+    // convenience shortcuts
+    var Button = Controls.Button;
+    var CompoundButton = Controls.CompoundButton;
+
     // class StatusPane =======================================================
 
     /**
@@ -36,25 +40,22 @@ define('io.ox/office/spreadsheet/view/statuspane', [
      * @param {SpreadsheetView} docView
      *  The spreadsheet view containing this instance.
      */
-    function StatusPane(docView) {
+    var StatusPane = ToolPane.extend({ constructor: function (docView) {
 
-        var // self reference
-            self = this,
+        // self reference
+        var self = this;
 
-            // the application instance
-            app = docView.getApp(),
+        // the application instance
+        var app = docView.getApp();
 
-            // the tool bar for all sheet controls
-            sheetToolBar = null,
+        // the tool bar for all sheet controls
+        var sheetToolBar = null;
 
-            // the sheet selector controls
-            sheetGroup = null,
-            largeSheetList = null,
-            smallSheetList = null,
-            moreMenuGroup = null,
-
-            // label control for the formula in the active cell
-            formulaLabel = null;
+        // the sheet selector controls
+        var sheetGroup = null;
+        var largeSheetList = null;
+        var smallSheetList = null;
+        var moreMenuGroup = null;
 
         // base constructor ---------------------------------------------------
 
@@ -68,18 +69,13 @@ define('io.ox/office/spreadsheet/view/statuspane', [
          */
         function refreshSheetToolBar() {
 
-            var // the node of the pane
-                paneNode = self.getNode(),
-                // total width of pane
-                paneWidth = paneNode.width(),
+            // the node of the sheet tool bar
+            var sheetNode = sheetToolBar.getNode();
+            // the width of the center node
+            var avaSheetWidth = Utils.getFloorNodeSize(sheetNode.closest('.float-wrapper')).width;
 
-                // the node of the sheet tool bar
-                sheetNode = sheetToolBar.getNode(),
-                // the width of the center node
-                avaSheetWidth = Utils.getFloorNodeSize(sheetNode.closest('.float-wrapper')).width,
-
-                // max width of the info node in percent
-                minSheetWidth = 240;
+            // max width of the info node in pixels
+            var minSheetWidth = 240;
 
             function getToolBarWidth() {
                 return Utils.getCeilNodeSize(sheetNode).width;
@@ -98,7 +94,7 @@ define('io.ox/office/spreadsheet/view/statuspane', [
             sheetGroup.setFullWidth();
 
             // add leading padding with the width of the row header panes
-            sheetNode.css({ width: 'auto', paddingLeft: docView.getHeaderWidth() + 'px' });
+            sheetNode.css({ width: 'auto', paddingLeft: docView.getHeaderWidth() });
 
             if (avaSheetWidth < getToolBarWidth()) {
                 sheetNode.css({ paddingLeft: '' });
@@ -108,11 +104,6 @@ define('io.ox/office/spreadsheet/view/statuspane', [
                     if (avaSheetWidth < minSheetWidth) {
                         // set fix min width for sheets
                         avaSheetWidth = minSheetWidth;
-                        // set remaining width (incl. 20px padding) to formula
-                        formulaLabel.setWidth(paneWidth - minSheetWidth - 20);
-                    } else {
-                        // reset width of formula
-                        formulaLabel.setWidth('auto');
                     }
                     // show large sheet drop-down list for small devices
                     sheetGroup.hide();
@@ -126,9 +117,6 @@ define('io.ox/office/spreadsheet/view/statuspane', [
                     // calculate and set remaining space for the sheet tabs
                     setRemainingWidth(sheetGroup);
                 }
-            } else {
-                // reset width of formula
-                formulaLabel.setWidth('auto');
             }
 
             // reset sheet component to its current width
@@ -138,16 +126,8 @@ define('io.ox/office/spreadsheet/view/statuspane', [
         // initialization -----------------------------------------------------
 
         // create the 'More' drop-down menu with all standard actions for sheets
-        moreMenuGroup = new Controls.CompoundButton(docView, { label: Labels.MORE_LABEL, tooltip: gt('More sheet operations') })
-            .addGroup('sheet/rename/dialog', new Controls.Button({ label: Labels.RENAME_SHEET_LABEL }))
-            .addGroup('sheet/copy/dialog', new Controls.Button({ label: Labels.COPY_SHEET_LABEL }));
-
-        moreMenuGroup
-            .addGroup('sheet/delete', new Controls.Button({ label: Labels.DELETE_SHEET_LABEL }))
-            .addGroup('sheet/visible', new Controls.Button({ label: Labels.HIDE_SHEET_LABEL, value: false }))
-            .addSeparator()
-            .addGroup('sheet/reorder/dialog', new Controls.Button({ label: Labels.REORDER_SHEETS_LABEL }))
-            .addGroup('sheet/unhide', new Controls.Button({ label: Labels.UNHIDE_SHEETS_LABEL }));
+        moreMenuGroup = new CompoundButton(docView, { classes: 'moreBtn', label: Labels.MORE_LABEL, tooltip: gt('More sheet operations') });
+        docView.addSheetActionButtons(moreMenuGroup);
 
         this.addViewComponent(sheetToolBar = new ToolBar(docView)
             .addGroup('view/sheet/active', largeSheetList = new Controls.ActiveSheetList(docView, { showNames: true }))
@@ -156,19 +136,26 @@ define('io.ox/office/spreadsheet/view/statuspane', [
             .addGap()
             .addGroup('view/sheet/active', sheetGroup = new Controls.ActiveSheetGroup(docView))
             .addGap()
-            .addGroup('sheet/insert', new Controls.Button({ icon: 'fa-plus', tooltip: gt('Insert sheet') }))
-            .addGroup('view/sheet/more', moreMenuGroup)
+            .addGroup('document/insertsheet', new Button(docView, { icon: 'fa-plus', tooltip: gt('Insert sheet') }))
+            .addGroup('document/editable', moreMenuGroup)
         );
 
         this.addViewComponent(new ToolBar(docView, { autoHideGroups: true })
-            .addGroup('view/status', new Controls.DynamicLabel())
-            .addGroup('view/subtotals/type', new Controls.SubtotalList(docView))
-            .addGroup('view/formula', formulaLabel = new Controls.FormulaLabel()),
-        { targetArea: 'trailing' });
+            .addGroup('view/status/label', new Controls.DynamicLabel(docView))
+            .addGroup('view/status/subtotals', new Controls.SubtotalList(docView))
+        , { targetArea: 'trailing' });
 
         // refresh sheet tool bar after sheet tabs have been inserted, deleted, or changed
         this.listenTo(sheetGroup, 'change:sheets', refreshSheetToolBar);
-        this.on('pane:layout', refreshSheetToolBar);
+
+        // handle external refresh (e.g. browser resize), but wait for an active sheet
+        this.listenOnceTo(docView, 'change:activesheet', function () {
+            refreshSheetToolBar();
+            self.on('pane:layout', refreshSheetToolBar);
+        });
+
+        // initialize visibility
+        this.toggle(app.getUserSettingsValue('showStatusBar', true));
 
         // always hide the status pane when an internal application error occurs
         this.listenTo(app, 'docs:state:error', function () { self.hide(); });
@@ -182,8 +169,7 @@ define('io.ox/office/spreadsheet/view/statuspane', [
                 var visibleOverwrite = null;
 
                 return function () {
-                    var softKeyboard = Utils.isSoftKeyboardOpen();
-                    if (softKeyboard) {
+                    if (Utils.isSoftKeyboardOpen() && (Utils.getInnerWindowHeight() / Utils.getScreenHeight()) < 0.7) {
                         if (visibleOverwrite === null && self.isVisible()) {
                             visibleOverwrite = true;
                             self.hide();
@@ -213,14 +199,13 @@ define('io.ox/office/spreadsheet/view/statuspane', [
         // destroy class members on destruction
         this.registerDestructor(function () {
             self = app = docView = sheetToolBar = null;
-            sheetGroup = largeSheetList = smallSheetList = moreMenuGroup = formulaLabel = null;
+            sheetGroup = largeSheetList = smallSheetList = moreMenuGroup = null;
         });
 
-    } // class StatusPane
+    } }); // class StatusPane
 
     // exports ================================================================
 
-    // derive this class from class ToolPane
-    return ToolPane.extend({ constructor: StatusPane });
+    return StatusPane;
 
 });
