@@ -36,11 +36,10 @@ define('io.ox/office/text/app/application', [
     'io.ox/office/text/model/model',
     'io.ox/office/text/view/view',
     'io.ox/office/text/app/controller',
-    'io.ox/office/tk/utils/deferredutils',
 
     'gettext!io.ox/office/text/main'
 
-], function (ConverterUtils, Inline, Utils, DriveUtils, ErrorCode, ErrorContext, ErrorMessages, EditApplication, AttributeUtils, DOM, Export, TextConfig, TextModel, TextView, TextController, DeferredUtils, gt) {
+], function (ConverterUtils, Inline, Utils, DriveUtils, ErrorCode, ErrorContext, ErrorMessages, EditApplication, AttributeUtils, DOM, Export, TextConfig, TextModel, TextView, TextController, gt) {
 
     'use strict';
 
@@ -49,6 +48,9 @@ define('io.ox/office/text/app/application', [
     var ArrayBuffer = window.ArrayBuffer;
     var Uint8Array = window.Uint8Array;
 
+    var characterCountPerLine = 80;
+    var textFragmentMaxLength = characterCountPerLine;
+
     // private static
     function recursivelyReduceTextFragmentFromJQuerySiblings(node, collector) {
         var text = Utils.trimString([
@@ -119,12 +121,12 @@ define('io.ox/office/text/app/application', [
 
             ].join(' '));
 
-            return (text !== '');       // targets the first non empty paragraph.
-          //return (text.length >= 80); // targets all paragraphs till maxLength condition is fulfilled.
+            return (text !== '');                           // targets the first non empty paragraph.
+          //return (text.length >= textFragmentMaxLength);  // targets all paragraphs till maxLength condition is fulfilled.
         });
 
-        if (text.length > 80) {
-            text = text.substring(0, 81).replace((/\s+[^\s]*$/), '');
+        if (text.length > textFragmentMaxLength) {
+            text = text.substring(0, (textFragmentMaxLength + 1)).replace((/\s+[^\s]*$/), '');
         }
       //console.log('predictivelyGetTitleTextFromDOM :: before leeave - text : ', text);
 
@@ -136,12 +138,36 @@ define('io.ox/office/text/app/application', [
 
             title = (
                 predictivelyGetTitleTextFromDOM(contentNode) ||
-                reduceTextFragmentFromDOM(contentNode, 80)
+                reduceTextFragmentFromDOM(contentNode, textFragmentMaxLength)
             );
 
         return title;
     }
 
+    // bugfix: Bug #50399 - "Sending shapes as email content doesn't make sense."
+    function hasMainlyNonConvertibleContent(node) {
+        var isMainlyNonConvertibleContent = false,
+
+            contentNode = DOM.getPageContentNode(node).eq(0),
+
+            textContent = contentNode.text(),
+            imageCollection = contentNode.find('img'),
+            canvasCollection = contentNode.find('canvas');
+
+        if (textContent.length < (characterCountPerLine / 2)) {
+
+            isMainlyNonConvertibleContent = ((imageCollection.length === 0) && (canvasCollection.length >= 1));
+
+        } else if (textContent.length < characterCountPerLine) {
+
+            isMainlyNonConvertibleContent = ((imageCollection.length === 0) && (canvasCollection.length >= 2));
+        }
+        isMainlyNonConvertibleContent = (isMainlyNonConvertibleContent && (imageCollection.length < 2));
+        isMainlyNonConvertibleContent = (isMainlyNonConvertibleContent || (canvasCollection.length > 2));
+
+        return isMainlyNonConvertibleContent;
+    }
+
     // class TextApplication ==================================================
 
     /**
@@ -156,8 +182,26 @@ define('io.ox/office/text/app/application', [
      */
     var TextApplication = EditApplication.extend({ constructor: function (launchOptions) {
 
-        var // self reference
-            self = this;
+        // self reference
+        var self = this;
+
+        /*
+         *  FIXME:
+         *  @FIXME
+         *
+         *  this is the entry point (or hook) for making the new feature -
+         *  'send document as inline html mail' - available to the application.
+         *
+         *  As soon as the next iteration step for this feature take place, please
+         *  consider refactoring this feature by moving its entire tool set into
+         *  an own model mixin ... maybe something like `sendAsMailMixin` that
+         *  should reside in >> /ui/apps/io.ox/office/text/model/ << .
+         */
+        var converterRegistry = { inlineHtml: createInlineHtmlDocument };
+
+        if (TextConfig.CONVERTER_AVAILABLE) {
+            converterRegistry.pdfAttachment = createPdfMailAttachment;
+        }
 
         // base constructor ---------------------------------------------------
 
@@ -178,7 +222,8 @@ define('io.ox/office/text/app/application', [
             localStorageApp: true,
             requiredStorageVersion: 2,
             supportedStorageVersion: 2,
-            supportsOnlineSync: true
+            supportsOnlineSync: true,
+            converterRegistry: converterRegistry
         });
 
         // private methods ----------------------------------------------------
@@ -218,9 +263,10 @@ define('io.ox/office/text/app/application', [
             var // specific error code sent by the server
                 error = new ErrorCode(response);
 
+            //  fulfilling task DOCS-733 - "Improve OOM Error Message in Client" - [https://jira.open-xchange.com/browse/DOCS-733]
             switch (error.getCodeAsConstant()) {
                 case 'LOADDOCUMENT_COMPLEXITY_TOO_HIGH_ERROR':
-                    response.message = gt('This document exceeds the complexity limits.');
+                    self.setInternalError(error, ErrorContext.TEXT, null, { showMessage: false });
                     break;
             }
         }
@@ -351,7 +397,7 @@ define('io.ox/office/text/app/application', [
                             img.src = InlineApi.getInsertedImageUrl(response);
                         });
                     }
-                }, { infoString: 'Application: sanitizeBase64ImageUrlsDeferred', app: self });
+                }, 'Application.sanitizeBase64ImageUrlsDeferred');
 
             return promise.then(function () {
 
@@ -380,7 +426,8 @@ define('io.ox/office/text/app/application', [
                     return ConverterUtils.sendConverterRequest(fileModel, {
                         documentformat: 'pdf',
                         saveas_filename: fileName,
-                        saveas_folder_id: DriveUtils.getStandardTrashFolderId()
+                        saveas_folder_id: DriveUtils.getStandardTrashFolderId(),
+                        revtag: _.uniqueId('mail-attmt-')
                     });
                 });
 
@@ -388,16 +435,13 @@ define('io.ox/office/text/app/application', [
             // in order to support this special failure case ...
 
             deferred.then(function (data) {
-                var
-                    interceptor = DeferredUtils.createDeferred(self, 'Applictation: createPdfMailAttachment');
 
                 if ('cause' in data) {
 
                     // ... an own error switch that passes its data
                     // into the generic deferred failure handling.
-                    interceptor.reject(data);
+                    return new $.Deferred().reject(data);
                 }
-                return interceptor;
             });
 
             deferred.fail(function (error) {
@@ -446,14 +490,21 @@ define('io.ox/office/text/app/application', [
                 selection = editor.getSelection(),
 
                 rootNode  = selection.getRootNode(),
-                titleText = extractTitleTextFromDOM(rootNode);
+                titleText = extractTitleTextFromDOM(rootNode),
+
+                // bugfix: Bug #50399 - "Sending shapes as email content doesn't make sense."
+                isMainlyNonConvertibleContent = hasMainlyNonConvertibleContent(rootNode);
 
             selection.selectAll();
             htmlFragmentString = Export.getHTMLFromSelection(editor/*, { isEncodeBase64: false }*/);
             selection.resetSelection();
 
+            htmlFragmentString = htmlFragmentString.replace((/\s+'=""\s+/g), ' '); // fixing some html syntax errors.
+
             return sanitizeBase64ImageUrlsDeferred(htmlFragmentString).then(function (htmlFragmentString) {
                 return {
+                    isMainlyNonConvertibleContent: isMainlyNonConvertibleContent,
+
                     title:   titleText,
                     content: htmlFragmentString
                 };
@@ -496,21 +547,6 @@ define('io.ox/office/text/app/application', [
 
         // initialization -----------------------------------------------------
 
-        /**
-         *  @FIXME
-         *
-         *  this is the entry point (or hook) for making the new feature -
-         *  'send document as inline html mail' - available to the application.
-         *
-         *  As soon as the next iteration step for this feature take place, please
-         *  consider refactoring this feature by moving its entire tool set into
-         *  an own model mixin ... maybe something like `sendAsMailMixin` that
-         *  should reside in >> /ui/apps/io.ox/office/text/model/ << .
-         */
-        // register the 'inline-html' converter.
-        this.registerConverter('pdf-attachment', createPdfMailAttachment);
-        this.registerConverter('inline-html', createInlineHtmlDocument);
-
     } }); // class TextApplication
 
     // exports ================================================================
