@@ -17,17 +17,17 @@ define('io.ox/office/text/app/controller', [
     'io.ox/office/editframework/utils/color',
     'io.ox/office/editframework/utils/hyperlinkutils',
     'io.ox/office/editframework/utils/mixedborder',
-    'io.ox/office/editframework/utils/paragraphspacing',
     'io.ox/office/editframework/app/editcontroller',
     'io.ox/office/drawinglayer/utils/drawingutils',
     'io.ox/office/drawinglayer/view/drawinglabels',
     'io.ox/office/textframework/utils/config',
-    'io.ox/office/textframework/components/hyperlink/hyperlink',
+    'io.ox/office/textframework/utils/listutils',
     'io.ox/office/textframework/utils/position',
+    'io.ox/office/textframework/components/hyperlink/hyperlink',
     'io.ox/office/text/format/paragraphstyles',
     'io.ox/office/textframework/format/tablestyles',
     'io.ox/office/text/format/drawingstyles'
-], function (Utils, Color, HyperlinkUtils, MixedBorder, ParagraphSpacing, EditController, DrawingUtils, DrawingLabels, Config, Hyperlink, Position, ParagraphStyles, TableStyles, DrawingStyles) {
+], function (Utils, Color, HyperlinkUtils, MixedBorder, EditController, DrawingUtils, DrawingLabels, Config, ListUtils, Position, Hyperlink, ParagraphStyles, TableStyles, DrawingStyles) {
 
     'use strict';
 
@@ -125,13 +125,14 @@ define('io.ox/office/text/app/controller', [
          *  The type of the list styles: either 'bullet' or 'numbering'.
          *
          * @param {String} listStyleId
-         *  The new list style identifier. The special value
-         *  Lists.DEFAULT_VALUE can be used to toggle the default list style.
+         *  The new list style identifier. The value of the special constant
+         *  ListUtils.DEFAULT_LIST_STYLE_ID can be used to toggle the default
+         *  list style.
          */
         function setListStyleId(listType, listStyleId) {
 
             // simulate toggle behavior for default list style
-            if (listStyleId === docModel.getDefaultListValue()) {
+            if (listStyleId === ListUtils.DEFAULT_LIST_STYLE_ID) {
                 if (this.getValue() === '') {
                     docModel.createDefaultList(listType);
                 } else {
@@ -143,21 +144,7 @@ define('io.ox/office/text/app/controller', [
             }
         }
 
-        // initialization -----------------------------------------------------
-
-        if (_.browser.Android) {
-            var originalUpdate = _.wrap(self.update, function (update) {
-                return update.call(self);
-            });
-
-            self.update = function () {
-                if (docModel.isAndroidTyping()) {
-                    self.executeDelayed(self.update, { delay: 1000, infoString: 'Text: android: update', app: app });
-                } else {
-                    originalUpdate();
-                }
-            };
-        }
+        // item registration --------------------------------------------------
 
         // register item definitions
         this.registerDefinitions({
@@ -166,19 +153,19 @@ define('io.ox/office/text/app/controller', [
 
             'view/zoom': {
                 parent: 'app/valid',
-                get: function () { return docView.getZoomFactor() / 100; },
+                get: function () { return docView.getZoomFactor(); },
                 set: function (zoom) { docView.setZoomType(zoom * 100); }
             },
 
             'view/zoom/dec': {
                 parent: 'app/valid',
-                enable: function () { return docView.getZoomFactor() > docView.getMinZoomFactor(); },
+                enable: function () { return docView.getZoomFactor() * 100 > docView.getMinZoomFactor(); },
                 set: function () { docView.decreaseZoomLevel(); }
             },
 
             'view/zoom/inc': {
                 parent: 'app/valid',
-                enable: function () { return docView.getZoomFactor() < docView.getMaxZoomFactor(); },
+                enable: function () { return docView.getZoomFactor() * 100 < docView.getMaxZoomFactor(); },
                 set: function () { docView.increaseZoomLevel(); }
             },
 
@@ -213,6 +200,38 @@ define('io.ox/office/text/app/controller', [
                 preserveFocus: true // do not return focus to document
             },
 
+            'document/selectDocStartPos': {
+                // enabled in read-only mode
+                set: function () { docModel.getSelection().setTextSelection(docModel.getSelection().getFirstDocumentPosition()); },
+                // restrict keyboard shortcut to application pane
+                shortcut: { keyCode: 'HOME', ctrlOrMeta: true, selector: '.app-pane' },
+                preserveFocus: true // do not return focus to document
+            },
+
+            'document/selectDocStartPosWithShift': {
+                // enabled in read-only mode
+                set: function () { docModel.getSelection().setTextSelection(docModel.getSelection().getFirstDocumentPosition(), docModel.getSelection().getEndPosition()); },
+                // restrict keyboard shortcut to application pane
+                shortcut: { keyCode: 'HOME', ctrlOrMeta: true, shift: true, selector: '.app-pane' },
+                preserveFocus: true // do not return focus to document
+            },
+
+            'document/selectDocEndPos': {
+                // enabled in read-only mode
+                set: function () { docModel.getSelection().setTextSelection(docModel.getSelection().getLastDocumentPosition()); },
+                // restrict keyboard shortcut to application pane
+                shortcut: { keyCode: 'END', ctrlOrMeta: true, selector: '.app-pane' },
+                preserveFocus: true // do not return focus to document
+            },
+
+            'document/selectDocEndPosWithShift': {
+                // enabled in read-only mode
+                set: function () { docModel.getSelection().setTextSelection(docModel.getSelection().getStartPosition(), docModel.getSelection().getLastDocumentPosition()); },
+                // restrict keyboard shortcut to application pane
+                shortcut: { keyCode: 'END', ctrlOrMeta: true, shift: true, selector: '.app-pane' },
+                preserveFocus: true // do not return focus to document
+            },
+
             'document/selectDrawing': {
                 set: function (options) {
                     docModel.getSelection().selectNextDrawing({ backwards: Utils.getBooleanOption(options, 'backwards', false) });
@@ -225,6 +244,10 @@ define('io.ox/office/text/app/controller', [
                 },
                 shortcut: { keyCode: 'F2' }
             },
+            'document/noDrawingSelected': {
+                parent: 'document/editable',
+                enable: function () { return !docModel.isDrawingSelected(); }
+            },
 
             // document contents
             'document/cut': {
@@ -361,14 +384,8 @@ define('io.ox/office/text/app/controller', [
             },
             'paragraph/spacing': {
                 parent: ['paragraph/attributes', 'insert/comment/supported/odf'],
-                get: function (attributes) { return ParagraphSpacing.helper.computeMultiplier(attributes, docModel); },
-                set: function (multiplier) {
-                    var marginBottom = ParagraphSpacing.helper.computeMarginBottom(multiplier, docModel);
-
-                    // bug 46249:  margin top needs to be considered when 'Paragraph spacing' is set to none in our GUI
-                    var marginTop = ParagraphSpacing.helper.getZeroSpaceMargin();
-                    docModel.setAttributes('paragraph', { paragraph: { marginTop: marginTop, marginBottom: marginBottom } });
-                }
+                get: function (attributes) { return docModel.getParagraphSpacing(attributes); },
+                set: function (multiplier) { return docModel.setParagraphSpacing(multiplier); }
             },
             'paragraph/fillcolor': {
                 parent: ['paragraph/attributes', 'insert/comment/odf/supported'],
@@ -539,10 +556,6 @@ define('io.ox/office/text/app/controller', [
                 shortcut: { keyCode: 'SPACE', ctrl: true }
             },
 
-            'character/format': {
-                parent: 'app/valid'
-            },
-
             'character/insert/break': {
                 parent: 'document/editable/text',
                 set: function () { return docModel.insertHardBreak(); }
@@ -597,6 +610,10 @@ define('io.ox/office/text/app/controller', [
                 enable: function () { return app.isODF() || !docModel.isHeaderFooterEditState(); }
             },
 
+            'insert/shape/supported': {
+                enable: function () { return docModel.isInsertShapePosition(); }
+            },
+
             // tables
 
             'table/group': {
@@ -616,10 +633,6 @@ define('io.ox/office/text/app/controller', [
                 parent: 'table/group',
                 enable: function () { return docModel.isPositionInTable(); }
             },
-            'document/show/tabletab': {
-                parent: 'document/editable/table',
-                enable: function () { return docModel.isCellRangeSelected() || (!docModel.isCellRangeSelected() && !docModel.hasSelectedRange()); }
-            },
             'table/delete': {
                 parent: 'document/editable/table',
                 set: function () { return docModel.deleteTable(); }
@@ -702,15 +715,21 @@ define('io.ox/office/text/app/controller', [
             'drawing/shapes/support/fill': {
                 parent: 'document/editable/onlysupporteddrawings',
                 enable: function () {
-                    var selection = docModel.getSelection();
-                    return (/^(shape|group)$/).test(selection.getSelectedDrawingType()) || (selection.getSelectionType() === 'text');
+                    var allSelectedTypes = docModel.getSelection().getSelectedDrawingTypes({ forceObject: true });
+                    return allSelectedTypes.shape === 1 || allSelectedTypes.group === 1;
                 }
             },
             'drawing/shapes/support/line': {
                 parent: 'document/editable/onlysupporteddrawings',
                 enable: function () {
-                    var selection = docModel.getSelection();
-                    return (/^(shape|group|image)$/).test(selection.getSelectedDrawingType()) || (selection.getSelectionType() === 'text');
+                    var allSelectedTypes = docModel.getSelection().getSelectedDrawingTypes({ forceObject: true });
+                    return allSelectedTypes.shape === 1 || allSelectedTypes.group === 1 || allSelectedTypes.image === 1 || allSelectedTypes.connector === 1;
+                }
+            },
+            'drawing/shapes/support/lineendings': {
+                parent: ['drawing/attributes/full', 'document/editable/onlysupporteddrawings'],
+                enable: function (attrs) {
+                    return (attrs && attrs.geometry) ? DrawingLabels.isPresetConnector(attrs.geometry.presetShape) : false;
                 }
             },
 
@@ -728,6 +747,16 @@ define('io.ox/office/text/app/controller', [
                 get: function () { return docModel.getAttributes('drawing', { groupOnly: true }).drawing || {}; }
             },
 
+            'drawing/border/style/support': {
+                parent: 'drawing/attributes/full',
+                enable: function (attributes) { return !((attributes && attributes.geometry) ? DrawingLabels.isPresetConnector(attributes.geometry.presetShape) : false); }
+            },
+
+            'drawing/line/style/support': {
+                parent: 'drawing/attributes/full',
+                enable: function (attributes) { return (attributes && attributes.geometry) ? DrawingLabels.isPresetConnector(attributes.geometry.presetShape) : false; }
+            },
+
             'drawing/delete': {
                 parent: 'document/editable/anydrawing',
                 set: function () {
@@ -769,6 +798,29 @@ define('io.ox/office/text/app/controller', [
                 }
             },
 
+            // parent item for drawing objects that can be flipped and rotated
+            'drawing/operation/transform': {
+                parent: 'drawing/position'
+            },
+
+            // (stateless command) flips the selected drawing objects horizontally
+            'drawing/transform/fliph': {
+                parent: 'drawing/operation/transform',
+                set: function () { docModel.transformDrawings(0, true, false); }
+            },
+
+            // (stateless command) flips the selected drawing objects vertically
+            'drawing/transform/flipv': {
+                parent: 'drawing/operation/transform',
+                set: function () { docModel.transformDrawings(0, false, true); }
+            },
+
+            // (stateless command) rotates the selected drawing objects by the passed angle
+            'drawing/transform/rotate': {
+                parent: 'drawing/operation/transform',
+                set: function (angle) { docModel.transformDrawings(angle, false, false); }
+            },
+
             // drawing z-order
 
             'drawing/order': {
@@ -776,6 +828,13 @@ define('io.ox/office/text/app/controller', [
                 set: function (value) { docModel.getDrawingLayer().updateDrawingOrder(value); }
             },
 
+            'drawing/type/shape': {
+                parent: 'document/editable',
+                enable: function () {
+                    return (docModel.getSelection().getClosestSelectedDrawingType() === 'shape' || docModel.getSelection().getClosestSelectedDrawingType() === 'connector');
+                }
+            },
+
             'drawing/type/label': {
                 parent: 'document/editable/drawing',
                 get: function () { return DrawingLabels.getDrawingTypeLabel(docModel.getSelection().getClosestSelectedDrawingType()); }
@@ -789,6 +848,11 @@ define('io.ox/office/text/app/controller', [
 
             // drawing fill formatting
 
+            'drawing/fill/style/support': {
+                parent: 'drawing/attributes/full',
+                enable: function (attributes) { return !((attributes && attributes.geometry) ? DrawingLabels.isPresetConnector(attributes.geometry.presetShape) : false); }
+            },
+
             'drawing/fill/attributes': {
                 parent: 'drawing/attributes/full',
                 get: function (attributes) { return attributes.fill || {}; }
@@ -807,6 +871,12 @@ define('io.ox/office/text/app/controller', [
                 get: function (attributes) { return attributes.line || {}; }
             },
 
+            'drawing/line/endings': {
+                parent: ['drawing/line/attributes', 'drawing/shapes/support/lineendings'],
+                get: function (lineAttrs) { return lineAttrs.headEndType + ':' + lineAttrs.tailEndType; },
+                set: function (endings) { docModel.setLineEnds(endings); }
+            },
+
             'drawing/border/style': {
                 parent: 'drawing/line/attributes',
                 get: function (attributes) { return DrawingUtils.getPresetBorder(attributes); },
@@ -829,7 +899,7 @@ define('io.ox/office/text/app/controller', [
             // comments
 
             'comment/insert': {
-                parent: ['document/editable/text/notextframe', 'insert/comment/supported', 'insert/margin/supported'],
+                parent: ['document/editable/text/notextframe', 'insert/comment/supported', 'document/noDrawingSelected', 'insert/margin/supported'],
                 set: function () { docModel.getCommentLayer().insertComment(); }
             },
 
@@ -870,6 +940,20 @@ define('io.ox/office/text/app/controller', [
                 set: function (dialogType) { return docModel.showInsertImageDialog(dialogType); }
             },
 
+            'shape/insert': {
+                parent: ['document/editable/text', 'insert/shape/supported'],
+                get: function () { return docModel.isInsertShapeActive(); },
+                set: function (presetShape, inputOptions) {
+                    if (Utils.getStringOption(inputOptions, 'sourceType') === 'keyboard') {
+                        return docModel.insertShapeWithDefaultBox(presetShape);
+                    } else if (Utils.TOUCHDEVICE) {
+                        return docModel.insertShapeWithDefaultBox(presetShape);
+                    } else {
+                        return docModel.insertShapePreparation(presetShape);
+                    }
+                }
+            },
+
             // change tracking
 
             checkCurrentChangeTracking: {
@@ -900,6 +984,7 @@ define('io.ox/office/text/app/controller', [
                 set: function () {
                     docModel.getChangeTrack().resolveChangeTracking(null, { accepted: true, all: false });
                     docView.getChangeTrackPopup().hide();
+                    docModel.setValidSelectionIfRequired();
                 }
             },
             acceptMoveSelectedChangeTracking: {
@@ -915,6 +1000,7 @@ define('io.ox/office/text/app/controller', [
                 set: function () {
                     docModel.getChangeTrack().resolveChangeTracking(null, { accepted: false, all: false });
                     docView.getChangeTrackPopup().hide();
+                    docModel.setValidSelectionIfRequired();
                 }
             },
             rejectMoveSelectedChangeTracking: {
@@ -1007,9 +1093,15 @@ define('io.ox/office/text/app/controller', [
                 set: function (value) { docModel.getFieldManager().updateFieldFormatting(value); }
             },
 
-            'document/toggledatepicker': {
-                parent: 'document/editable',
-                set: function () { docView.toggleDatePicker(); }
+            'document/inserttoc': {
+                parent: ['document/editable/text/notextframe', 'insert/comment/supported', 'insert/margin/supported'],
+                enable: function () { return !app.isODF(); },
+                set: function (value) { docModel.getFieldManager().dispatchInsertToc(value); }
+            },
+
+            goToAnchor: {
+                parent: 'app/valid',
+                set: function () { docView.goToSelectedAnchor(); }
             },
 
             // android-entry for selection which cant be deleted by softkeyboard
@@ -1026,8 +1118,20 @@ define('io.ox/office/text/app/controller', [
             }
         });
 
+        // initialization -----------------------------------------------------
+
+        if (_.browser.Android) {
+            this.update = _.wrap(this.update, function (updateFunc) {
+                if (docModel.isAndroidTyping()) {
+                    return self.executeDelayed(self.update, 'TextController.update', 1000);
+                } else {
+                    return updateFunc.call(self);
+                }
+            });
+        }
+
         // update GUI after changed selection
-        this.listenTo(docModel, 'selection', function () { self.update(); });
+        this._updateOnEvent(docModel, 'selection');
 
         // destroy class members on destruction
         this.registerDestructor(function () {
