@@ -52,11 +52,13 @@ define('io.ox/office/text/components/drawing/drawingresize', [
             // the node containing the scroll bar
             scrollNode = app.getView().getContentRootNode(),
             // object containing information about movable and resizable
-            options = { movable: true, resizable: true },  // -> parameter?
+            options = { movable: true, resizable: true, rotatable: true },  // -> parameter?
             // whether the drawing is located in the drawing layer
             isDrawingLayerNode = DOM.isDrawingLayerNode($(drawingNode).parent()),
             // whether the drawing is anchored to the paragraph
             isAbsoluteParagraphNode = !isDrawingLayerNode && DOM.isAbsoluteParagraphDrawing(drawingNode),
+            // whether the selected drawing is of type 'connector'
+            isConnector = DrawingFrame.isConnectorDrawingFrame(drawingNode),
             // the container element used to visualize the selection
             selectionBox = null,
             // saving the selected resize node
@@ -75,6 +77,15 @@ define('io.ox/office/text/components/drawing/drawingresize', [
             moveBox.css({ left: '', top: '', right: '', bottom: '', width: '', height: '' });
         }
 
+        function extendAndGenerateOp(generator, drawingNode, operationProperties, target) {
+            editor.extendPropertiesWithTarget(operationProperties, target);
+            generator.generateOperation(Operations.SET_ATTRIBUTES, operationProperties);
+        }
+
+        function triggerDragging() {
+            app.getView().getContentRootNode().trigger('activedragging');
+        }
+
         /**
          * Handling all tracking events while moving a drawing.
          */
@@ -114,7 +125,7 @@ define('io.ox/office/text/components/drawing/drawingresize', [
             // initialing the moving of the drawing according to the passed tracking event
             function startMoveDrawing(event) {
 
-                zoomFactor = app.getView().getZoomFactor() / 100;
+                zoomFactor = app.getView().getZoomFactor();
 
                 // storing old height and width of drawing
                 drawingWidth = drawingNode.width();
@@ -154,7 +165,7 @@ define('io.ox/office/text/components/drawing/drawingresize', [
 
             // updating the drawing position according to the passed tracking event
             function updateMove(event) {
-
+                var flipH, flipV, rotation, normalizedCoords;
                 // make move box visible when tracking position has moved
                 DrawingFrame.toggleTracking(drawingNode, true);
 
@@ -174,11 +185,15 @@ define('io.ox/office/text/components/drawing/drawingresize', [
                     if (event.pageX - leftDrawingDistance > maxRightPosition) { shiftX += (maxRightPosition - event.pageX + leftDrawingDistance) / zoomFactor; }
 
                     // the upper left corner of the drawing always has to be inside the page content node -> reduce or increase shiftX and shiftY, if necessary
-                    if (event.pageY - topDrawingDistance < minTopPosition) { shiftY += (minTopPosition - event.PageY + topDrawingDistance) / zoomFactor; }
+                    if (event.pageY - topDrawingDistance < minTopPosition) { shiftY += (minTopPosition - event.pageY + topDrawingDistance) / zoomFactor; }
                     if (event.pageY - topDrawingDistance > maxBottomPosition) { shiftY += (maxBottomPosition - event.pageY + topDrawingDistance) / zoomFactor; }
 
                     if (_.isNumber(shiftX) && _.isNumber(shiftY) && ((shiftX !== 0) || (shiftY !== 0))) {
-                        moveBox.css({ left: shiftX, top: shiftY, width: drawingWidth, height: drawingHeight });
+                        flipH = DrawingFrame.isFlippedHorz(drawingNode);
+                        flipV = DrawingFrame.isFlippedVert(drawingNode);
+                        rotation = DrawingFrame.getDrawingRotationAngle(editor, drawingNode);
+                        normalizedCoords = DrawingFrame.getNormalizedMoveCoordinates(shiftX, shiftY, rotation, flipH, flipV);
+                        moveBox.css({ left: normalizedCoords.x, top: normalizedCoords.y, width: drawingWidth, height: drawingHeight });
                     }
                 }
             }
@@ -203,7 +218,7 @@ define('io.ox/office/text/components/drawing/drawingresize', [
             function stopMoveDrawing(event) {
 
                 // mouse up handler
-                var generator = editor.createOperationsGenerator(),
+                var generator = editor.createOperationGenerator(),
                     // the horizontal move of the drawing in 1/100 mm
                     moveX = 0,
                     // the vertical move of the drawing in 1/100 mm
@@ -277,7 +292,9 @@ define('io.ox/office/text/components/drawing/drawingresize', [
                     // an optional footer offset
                     footerOffset = 0,
                     // whether position relative to margin shall be calculated instead of page
-                    keepMarginSettings = false;
+                    keepMarginSettings = false,
+                    // offset of the drawing against rotation angle
+                    normalizedOffset = null;
 
                 function adaptPositionIntoDocument(posX, posY) {
 
@@ -395,7 +412,7 @@ define('io.ox/office/text/components/drawing/drawingresize', [
                     return;
                 }
 
-                zoomFactor = app.getView().getZoomFactor() / 100;
+                zoomFactor = app.getView().getZoomFactor();
 
                 // setting position of tracking:end event
                 currentX = event.pageX / zoomFactor;
@@ -414,8 +431,9 @@ define('io.ox/office/text/components/drawing/drawingresize', [
                 shiftY = currentY - ((event.startY - scrollY) / zoomFactor);
 
                 // top left corner of the drawing
-                drawingLeftX = currentX - (leftDrawingDistance / zoomFactor);
-                drawingTopY = currentY - (topDrawingDistance / zoomFactor);
+                normalizedOffset = DrawingFrame.normalizeMoveOffset(editor, drawingNode, moveBox);
+                drawingLeftX = normalizedOffset.left / zoomFactor;
+                drawingTopY = normalizedOffset.top / zoomFactor;
 
                 updatePosition = Position.getOxoPosition(rootNode, drawingNode, 0);
 
@@ -429,13 +447,13 @@ define('io.ox/office/text/components/drawing/drawingresize', [
 
                         isHeaderOrFooter = DOM.isHeaderOrFooter(activeRootNode);
 
-                        startPosition = Position.getPixelPositionToRootNodeOffset(activeRootNode, drawingNode, zoomFactor * 100);
-
-                        maxVertPageOffset = Utils.convertHmmToLength(app.getModel().getPageLayout().getPageAttribute('height'), 'px', 0.001) - drawingNode.height();
+                        startPosition = Position.getUnrotatedPixelPositionToRoot(activeRootNode, drawingNode, DrawingFrame.getDrawingRotationAngle(editor, drawingNode), zoomFactor);
 
                         // checking the page number of the drawing
                         pageLayout = app.getModel().getPageLayout();
 
+                        maxVertPageOffset = Utils.convertHmmToLength(pageLayout.getPageAttribute('height'), 'px', 0.001) - drawingNode.height();
+
                         // checking the page number of the drawing
                         pageNumber = isHeaderOrFooter ? 1 : pageLayout.getPageNumber(DOM.getDrawingPlaceHolderNode(drawingNode));
 
@@ -719,7 +737,7 @@ define('io.ox/office/text/components/drawing/drawingresize', [
                                 attrs: allDrawingAttrs
                             };
                             editor.extendPropertiesWithTarget(operationProperties, target);
-                            generator.generateOperation(Operations.DRAWING_INSERT, operationProperties);
+                            generator.generateOperation(Operations.INSERT_DRAWING, operationProperties);
 
                             updatePosition = _.clone(destPosition); // for setting attributes required
                         }
@@ -747,7 +765,7 @@ define('io.ox/office/text/components/drawing/drawingresize', [
                         app.getModel().executeDelayed(function () {
                             DrawingFrame.clearSelection(drawingNode);
                             DrawingResize.drawDrawingSelection(app, drawingNode);
-                        }, { infoString: 'DrawingResize: setTextSelectionAfterMove', app: app });
+                        }, 'DrawingResize.setTextSelectionAfterMove');
                     }
                 }
                 if (DOM.isMarginalNode(drawingNode)) {
@@ -768,7 +786,8 @@ define('io.ox/office/text/components/drawing/drawingresize', [
             return function (event) {
 
                 // handling for text frame drawings, if the click happened inside the internal text frame element
-                if ($(event.target).closest(DrawingFrame.TEXTFRAME_NODE_SELECTOR).length > 0) {
+                // -> but not doing so, if the drawing is located inside a comment node (53081)
+                if (!editor.isCommentFunctionality() && $(event.target).closest(DrawingFrame.TEXTFRAME_NODE_SELECTOR).length > 0) {
 
                     Tracking.disableTracking(drawingNode)
                         .off('tracking:start', trackingStartHandler)
@@ -813,7 +832,7 @@ define('io.ox/office/text/components/drawing/drawingresize', [
                 // the initial scroll position
                 startScrollX = 0, startScrollY = 0,
                 // whether resizing is available in horizontal/vertical direction
-                useX = false, useY = false, topResize = false, leftResize = false, bottomResize = false,
+                useX = false, useY = false, topResize = false, leftResize = false,
                 // correction factor for resizing to the left/top
                 scaleX = 0, scaleY = 0,
                 // the maximum width of the drawing on the page or in a table cell
@@ -836,7 +855,7 @@ define('io.ox/office/text/components/drawing/drawingresize', [
                 // updating whether the drawing is located in the drawing layer
                 isDrawingLayerNode = DOM.isDrawingLayerNode(drawingNode.parent());
 
-                zoomFactor = app.getView().getZoomFactor() / 100;
+                zoomFactor = app.getView().getZoomFactor();
 
                 // storing old height and width of drawing
                 oldWidth = finalWidth = drawingNode.width();
@@ -846,24 +865,25 @@ define('io.ox/office/text/components/drawing/drawingresize', [
                 useX = /[lr]/.test(pos);
                 useY = /[tb]/.test(pos);
                 topResize = /[t]/.test(pos);
-                bottomResize = /[b]/.test(pos);
                 leftResize = /[l]/.test(pos);
 
-                if (/l/.test(pos)) {
+                if (leftResize) {
                     scaleX = -1;
                     moveBox.css({ left: 'auto', right: 0 });
                 } else {
                     scaleX = 1;
                     moveBox.css({ left: 0, right: 'auto' });
                 }
+                if (DrawingFrame.isFlippedHorz(drawingNode)) { scaleX *= -1; }
 
-                if (/t/.test(pos)) {
+                if (topResize) {
                     scaleY = -1;
                     moveBox.css({ top: 'auto', bottom: 0 });
                 } else {
                     scaleY = 1;
                     moveBox.css({ top: 0, bottom: 'auto' });
                 }
+                if (DrawingFrame.isFlippedVert(drawingNode)) { scaleY *= -1; }
 
                 startScrollX = scrollNode.scrollLeft();
                 startScrollY = scrollNode.scrollTop();
@@ -905,49 +925,65 @@ define('io.ox/office/text/components/drawing/drawingresize', [
             // updates resizing the drawing according to the passed tracking event
             function updateResize(event) {
 
-                var deltaX = useX ? ((event.pageX / zoomFactor - event.startX / zoomFactor + scrollX) * scaleX) : 0,
-                    deltaY = useY ? ((event.pageY / zoomFactor - event.startY / zoomFactor + scrollY) * scaleY) : 0,
-                    // the scaling factor for the width
-                    scaleWidth = 1,
-                    // the scaling factor for the height
-                    scaleHeight = 1;
-
-                // update drawing size
-                finalWidth = Math.max(0, oldWidth + deltaX);
-                finalHeight = Math.max(0, oldHeight + deltaY);
+                var deltaX = event.pageX / zoomFactor - event.startX / zoomFactor + scrollX;
+                var deltaY = event.pageY / zoomFactor - event.startY / zoomFactor + scrollY;
+                // the scaling factor for the width
+                var scaleWidth = 1;
+                // the scaling factor for the height
+                var scaleHeight = 1;
+                // normalize and scale deltas of the dimensions
+                var normalizedDeltas = DrawingFrame.getNormalizedResizeDeltas(deltaX, deltaY, useX, useY, scaleX, scaleY, DrawingFrame.getDrawingRotationAngle(editor, drawingNode));
+                var sumWidth = oldWidth + normalizedDeltas.x;
+                var sumHeight = oldHeight + normalizedDeltas.y;
+                var signWidth = sumWidth > 0 ? 1 : -1;
+                var signHeight = sumHeight > 0 ? 1 : -1;
+                var flipH = sumWidth < 0;
+                var flipV = sumHeight < 0;
+                var transformProp = 'scaleX(' + (flipH ? -1 : 1) + ') scaleY(' + (flipV ? -1 : 1) + ')';
+                var topPos, bottomPos, leftPos, rightPos;
 
                 // The maximum value for the width is 'maxDrawingWidth' -> avoid endless scrolling
                 // There is no limit for the height (only in non-deforming resizing).
-                if (finalWidth >= maxDrawingWidth) {
-                    finalWidth = maxDrawingWidth;
+                if (sumWidth >= maxDrawingWidth) {
+                    sumWidth = maxDrawingWidth;
                 }
 
-                if (finalHeight >= maxDrawingHeight) {
-                    finalHeight = maxDrawingHeight;
+                if (sumHeight >= maxDrawingHeight) {
+                    sumHeight = maxDrawingHeight;
                 }
 
-                // use the same scaling factor for vertical and horizontal resizing, if both are enabled
+                // use the same scaling factor for vertical and horizontal resizing, if both are enabled (and this is not a connector)
                 // -> the larger number wins
-                if (useX && useY) {
-                    scaleWidth = finalWidth / oldWidth;
-                    scaleHeight = finalHeight / oldHeight;
+                if (useX && useY && !isConnector) {
+                    scaleWidth = Math.abs(sumWidth / oldWidth); // scale shouldn't be negative
+                    scaleHeight = Math.abs(sumHeight / oldHeight);
 
                     if (scaleWidth > scaleHeight) {
-                        finalHeight = scaleWidth * oldHeight;
+                        sumHeight = scaleWidth * oldHeight * signHeight; // return sign of current width/height after scale
                     } else {
-                        finalWidth = scaleHeight * oldWidth;
+                        sumWidth = scaleHeight * oldWidth * signWidth;
                     }
                 }
+                topPos = topResize ? 'auto' : Math.min(0, sumHeight);
+                bottomPos = topResize ? Math.min(0, sumHeight) : 'auto';
+                leftPos = leftResize ? 'auto' : Math.min(0, sumWidth);
+                rightPos = leftResize ? Math.min(0, sumWidth) : 'auto';
+
+                // update drawing size
+                finalWidth = Math.abs(sumWidth);
+                finalHeight = Math.abs(sumHeight);
+
+                moveBox.css({ width: finalWidth, height: finalHeight, top: topPos, left: leftPos, bottom: bottomPos, right: rightPos, transform: transformProp });
+                moveBox.data({ flipH: flipH, flipV: flipV });
 
                 // make move box visible when tracking position has moved
                 DrawingFrame.toggleTracking(drawingNode, true);
-                moveBox.css({ width: finalWidth, height: finalHeight });
             }
 
             // resizes the drawing according to the passed tracking event
             function stopResizeDrawing() {
 
-                var generator = editor.createOperationsGenerator(),
+                var generator = editor.createOperationGenerator(),
                     // all attributes for the operation
                     allAttrs = {},
                     // drawing attributes for the operation
@@ -977,7 +1013,21 @@ define('io.ox/office/text/components/drawing/drawingresize', [
                     // an optional offset of the footer node in the page
                     footerOffset = 0,
                     // whether position relative to margin shall be calculated instead of page
-                    keepMarginSettings = false;
+                    keepMarginSettings = false,
+                    // whether drawing is alredy horizontally or vertically flipped by operation
+                    isFlipH = DrawingFrame.isFlippedHorz(drawingNode),
+                    isFlipV = DrawingFrame.isFlippedVert(drawingNode),
+                    // whether drawing is in process of being flipped on resizing
+                    isCurrentlyFlippedH = moveBox.data('flipH'),
+                    isCurrentlyFlippedV = moveBox.data('flipV'),
+                    rotationAngle = DrawingFrame.getDrawingRotationAngle(editor, drawingNode),
+                    positionDiff = DrawingFrame.getPositionDiffAfterResize(drawingNode, moveBox, rotationAngle, isFlipH, isFlipV),
+                    leftDiff = positionDiff.leftDiff / zoomFactor,
+                    topDiff = positionDiff.topDiff / zoomFactor,
+                    bottomDiff = positionDiff.bottomDiff / zoomFactor,
+                    leftResizeNormalized = leftDiff !== 0,
+                    topResizeNormalized = topDiff !== 0,
+                    bottomResizeNormalized = !topResizeNormalized && bottomDiff !== 0;
 
                 // Calculating new width and height
 
@@ -1005,10 +1055,11 @@ define('io.ox/office/text/components/drawing/drawingresize', [
 
                     activeRootNode = editor.getCurrentRootNode();
 
-                    zoomFactor = app.getView().getZoomFactor();
+                    zoomFactor = app.getView().getZoomFactor() * 100;
 
                     // is it necessary to update the upper left corner of the drawing?
-                    startPosition = Position.getPixelPositionToRootNodeOffset(activeRootNode, drawingNode, zoomFactor);
+                    //startPosition = Position.getPixelPositionToRootNodeOffset(activeRootNode, drawingNode, zoomFactor);
+                    startPosition = Position.getUnrotatedPixelPositionToRoot(activeRootNode, drawingNode, rotationAngle, zoomFactor / 100);
                     pageLayout = app.getModel().getPageLayout();
 
                     // checking the page number of the drawing
@@ -1016,9 +1067,9 @@ define('io.ox/office/text/components/drawing/drawingresize', [
 
                     if (pageNumber > 1) { startPosition.y -= Position.getVerticalPagePixelPosition(editor.getNode(), pageLayout, pageNumber, zoomFactor); }
 
-                    if (topResize) {
+                    if (topResizeNormalized) {
                         // comparing final height and old height
-                        attributes.anchorVertOffset = Math.max(Utils.convertLengthToHmm(startPosition.y, 'px') - Utils.convertLengthToHmm((finalHeight - oldHeight), 'px'), 0);
+                        attributes.anchorVertOffset = Math.max(Utils.convertLengthToHmm(startPosition.y, 'px') - Utils.convertLengthToHmm(topDiff, 'px'), 0);
                     } else {
                         attributes.anchorVertOffset = Utils.convertLengthToHmm(startPosition.y, 'px');
                     }
@@ -1029,19 +1080,19 @@ define('io.ox/office/text/components/drawing/drawingresize', [
                         attributes.anchorVertOffset += footerOffset;
                     }
 
-                    if (leftResize) {
+                    if (leftResizeNormalized) {
                         // comparing final width and old width
-                        attributes.anchorHorOffset = Math.max(Utils.convertLengthToHmm(startPosition.x, 'px') - Utils.convertLengthToHmm((finalWidth - oldWidth), 'px'), 0);
+                        attributes.anchorHorOffset = Math.max(Utils.convertLengthToHmm(startPosition.x, 'px') - Utils.convertLengthToHmm(leftDiff, 'px'), 0);
                     }
 
                     // using margin instead of page, if drawing was anchored to margin before
                     if (keepMarginSettings) {
-                        if (leftResize) { attributes.anchorHorOffset -= pageLayout.getPageAttribute('marginLeft'); }
+                        if (leftResizeNormalized) { attributes.anchorHorOffset -= pageLayout.getPageAttribute('marginLeft'); }
                         attributes.anchorVertOffset -= pageLayout.getPageAttribute('marginTop');
                     }
 
                     // always sending this? Or only, if it was modified? Avoid sending horizontal information, if it was not modified (43996)
-                    if (leftResize) {
+                    if (leftResizeNormalized) {
                         attributes.anchorHorAlign = 'offset';
                         attributes.anchorHorBase = keepMarginSettings ? 'margin' : 'page';
                     }
@@ -1051,38 +1102,36 @@ define('io.ox/office/text/components/drawing/drawingresize', [
 
                 } else if (isAbsoluteParagraphNode) {
 
-                    // if the drawing was resized to the left or to the top, it might be necessary to update the values
-                    // for anchorHorOffset and anchorVertOffset
-                    if (topResize || bottomResize) {
+                    if (!_.isEmpty(attributes)) { // not setting only 'anchorHorOffset' and 'anchorVertOffset' for resize operation
 
-                        drawingNodeAttrs = editor.getStyleCollection('drawing').getElementAttributes(drawingNode).drawing;
+                        // if the drawing was resized to the left or to the top, it might be necessary to update the values
+                        // for anchorHorOffset and anchorVertOffset
+                        if (topResizeNormalized || bottomResizeNormalized) {
 
-                        oldAnchorVertOffset = drawingNodeAttrs.anchorVertOffset || 0;
+                            drawingNodeAttrs = editor.getStyleCollection('drawing').getElementAttributes(drawingNode).drawing;
 
-                        if ((oldAnchorVertOffset >= 0 && topResize) || (oldAnchorVertOffset < 0 && bottomResize)) {
+                            oldAnchorVertOffset = drawingNodeAttrs.anchorVertOffset || 0;
 
-                            var deltaHeight = topResize ? (finalHeight - oldHeight) : (oldHeight - finalHeight);
+                            if ((oldAnchorVertOffset >= 0 && topResizeNormalized) || (oldAnchorVertOffset < 0 && bottomResizeNormalized)) {
+                                attributes.anchorVertOffset = oldAnchorVertOffset - Utils.convertLengthToHmm(topDiff, 'px');
 
-                            attributes.anchorVertOffset = oldAnchorVertOffset - Utils.convertLengthToHmm(deltaHeight, 'px');
-
-                            // simplification -> not allowing to resize drawing above paragraph borders
-                            if (topResize && attributes.anchorVertOffset < 0) {
-                                attributes.anchorVertOffset = 0;
-                            } else if (bottomResize && attributes.anchorVertOffset >= 0) {
-                                attributes.anchorVertOffset = -1;
+                                // simplification -> not allowing to resize drawing above paragraph borders
+                                if (topResizeNormalized && attributes.anchorVertOffset < 0) {
+                                    attributes.anchorVertOffset = 0;
+                                } else if (bottomResizeNormalized && attributes.anchorVertOffset >= 0) {
+                                    attributes.anchorVertOffset = -1;
+                                }
                             }
                         }
-                    }
 
-                    // the drawing was resized in left direction
-                    if (leftResize) {
+                        // the drawing was resized in left direction
+                        if (leftResizeNormalized) {
+                            drawingNodeAttrs = drawingNodeAttrs || editor.getStyleCollection('drawing').getElementAttributes(drawingNode).drawing;
+                            oldAnchorHorOffset = drawingNodeAttrs.anchorHorOffset || 0;
 
-                        drawingNodeAttrs = drawingNodeAttrs || editor.getStyleCollection('drawing').getElementAttributes(drawingNode).drawing;
-
-                        oldAnchorHorOffset = drawingNodeAttrs.anchorHorOffset ? drawingNodeAttrs.anchorHorOffset : 0;
-
-                        attributes.anchorHorOffset = oldAnchorHorOffset - Utils.convertLengthToHmm((finalWidth - oldWidth), 'px');
-                        if (attributes.anchorHorOffset < 0) {  attributes.anchorHorOffset = 0; }
+                            attributes.anchorHorOffset = oldAnchorHorOffset - Utils.convertLengthToHmm(leftDiff, 'px');
+                            if (attributes.anchorHorOffset < 0) {  attributes.anchorHorOffset = 0; }
+                        }
                     }
                 }
 
@@ -1091,6 +1140,9 @@ define('io.ox/office/text/components/drawing/drawingresize', [
 
                     allAttrs = { drawing: attributes };
 
+                    if (isCurrentlyFlippedH) { allAttrs.drawing.flipH = !isFlipH; }
+                    if (isCurrentlyFlippedV) { allAttrs.drawing.flipV = !isFlipV; }
+
                     // after resizing an automatic resized text frame in vertical direction by the user,
                     // the automatic resize will be removed
                     if (_.isNumber(attributes.height)) {
@@ -1188,6 +1240,133 @@ define('io.ox/office/text/components/drawing/drawingresize', [
 
         }()); // end of drawingResizeHandler() local scope
 
+        var drawingRotateHandler = (function () {
+            // dimensions of the drawing
+            var drawingWidth = 0, drawingHeight = 0;
+            // position of the center rotation of the drawingWidth
+            var centerX, centerY;
+            // the current scroll position
+            var scrollX = 0, scrollY = 0;
+            // the initial scroll position
+            var startScrollX = 0, startScrollY = 0;
+            // starting angle before rotation
+            var startAngle = 0;
+            // final angle on finish of the rotation
+            var rotationAngle = null;
+            // flag for marking that the operation is generated
+            var generatedOp = false;
+
+            function startRotateDrawing() {
+                var drawingOffset;
+                zoomFactor = app.getView().getZoomFactor();
+                startAngle = DrawingFrame.getDrawingRotationAngle(editor, drawingNode);
+                if (_.isNumber(startAngle)) {
+                    $(drawingNode).css('transform', ''); // reset to def to get values
+                    drawingOffset = drawingNode.offset();
+                    DrawingFrame.updateCssTransform(drawingNode, startAngle);
+                } else {
+                    startAngle = 0;
+                    drawingOffset = drawingNode.offset();
+                }
+
+                drawingHeight = drawingNode.height() * zoomFactor;
+                drawingWidth = drawingNode.width() * zoomFactor;
+                centerX = drawingOffset.left + (drawingWidth / 2);
+                centerY = drawingOffset.top + (drawingHeight / 2);
+
+                drawingNode.addClass('rotating-state');
+            }
+
+            function updateRotate(event) {
+                var radians = Math.atan2(event.pageX + scrollX - centerX, event.pageY + scrollY - centerY);
+                rotationAngle = Math.round(180 - radians * 180 / Math.PI);
+
+                if (event.shiftKey) {
+                    rotationAngle = Utils.round(rotationAngle, 15); // make 15 deg step with shift key
+                }
+                if (DrawingFrame.isFlippedVert(drawingNode)) {
+                    rotationAngle += 180;
+                }
+
+                DrawingFrame.updateCssTransform(drawingNode, rotationAngle);
+            }
+
+            function updateRotateScroll(event) {
+                // update scrollPosition with suggestion from event
+                scrollNode
+                    .scrollLeft(scrollNode.scrollLeft() + event.scrollX)
+                    .scrollTop(scrollNode.scrollTop() + event.scrollY);
+
+                scrollX = scrollNode.scrollLeft() - startScrollX;
+                scrollY = scrollNode.scrollTop() - startScrollY;
+            }
+
+            function stopRotateDrawing() {
+                var generator = editor.createOperationGenerator();
+                var operationProperties;
+
+                if (_.isNumber(rotationAngle)) {
+                    // normalize angle between 0 and 359 deg
+                    rotationAngle =  Utils.mod(rotationAngle, 360);
+
+                    operationProperties = {
+                        start: Position.getOxoPosition(rootNode, drawingNode, 0),
+                        attrs: { drawing: { rotation: rotationAngle } }
+                    };
+
+                    extendAndGenerateOp(generator, drawingNode, operationProperties, target);
+
+                    // Applying the operations (undo group is created automatically)
+                    editor.applyOperations(generator);
+                    generatedOp = true;
+                }
+            }
+
+            function finalizeRotateDrawing() {
+                drawingNode.removeClass('rotating-state');
+
+                if (!generatedOp) { // reset to start angle if tracking was canceled
+                    DrawingFrame.updateCssTransform(drawingNode, startAngle);
+                } else {
+                    DrawingFrame.updateResizersMousePointers(drawingNode, DrawingFrame.getDrawingRotationAngle(editor, drawingNode));
+                }
+
+                leaveTracking();
+
+                generatedOp = false;
+            }
+
+            // return the actual drawingRotateHandler() function
+            return function (event) {
+
+                event.preventDefault();
+
+                switch (event.type) {
+                    case 'tracking:start':
+                        startRotateDrawing(event);
+                        break;
+                    case 'tracking:move':
+                        updateRotate(event);
+                        break;
+                    case 'tracking:scroll':
+                        updateRotateScroll(event);
+                        break;
+                    case 'tracking:end':
+                        stopRotateDrawing(event);
+                        finalizeRotateDrawing(event);
+                        break;
+                    case 'tracking:cancel':
+                        finalizeRotateDrawing(event);
+                        break;
+                }
+
+                // events must not bubble up to drawing node (move handling)
+                event.stopPropagation();
+
+                triggerDragging();
+            };
+        }()); // end of drawingRotateHandler local scope
+
         /**
          * Handler for 'tracking:start' events for 'div.handle' and 'div.move'
          * nodes. This handler has to decide, which node got the event. For this
@@ -1207,6 +1386,10 @@ define('io.ox/office/text/components/drawing/drawingresize', [
                 resizeNode.off(TRACKING_EVENT_NAMES);
                 resizeNode.on(TRACKING_EVENT_NAMES, drawingResizeHandler);
                 drawingResizeHandler.call(this, event);
+            } else if (DrawingFrame.isRotateHandle(event.target)) {
+                drawingNode.off(TRACKING_EVENT_NAMES); // <- should not be necessary, but it is (more and more setAttributes OPs)
+                drawingNode.on(TRACKING_EVENT_NAMES, drawingRotateHandler);
+                drawingRotateHandler.call(this, event);
             } else {
                 drawingNode.off(TRACKING_EVENT_NAMES); // <- should not be necessary, but it is (more and more setAttributes OPs)
                 drawingNode.on(TRACKING_EVENT_NAMES, drawingMoveHandler);
@@ -1214,6 +1397,22 @@ define('io.ox/office/text/components/drawing/drawingresize', [
             }
         }
 
+        function toggleTracking(node, state) {
+            if (state) {
+                Tracking.enableTracking(node, {
+                    autoScroll: true,
+                    borderNode: scrollNode,
+                    borderMargin: -30,
+                    borderSize: 60,
+                    minSpeed: 10,
+                    maxSpeed: 250,
+                    trackModifiers: true
+                });
+            } else {
+                Tracking.disableTracking(node);
+            }
+        }
+
         // starting code of static method drawDrawingSelection()
         drawingNode = $(drawingNode);
         if (drawingNode.length !== 1) {
@@ -1228,11 +1427,18 @@ define('io.ox/office/text/components/drawing/drawingresize', [
             drawingNode = drawingNode.closest(DrawingFrame.GROUPCONTENT_SELECTOR).parent();
         }
 
-        if (!editor.getEditMode()) {
-            options.movable = options.resizable = false;
+        if (!app.isEditable()) {
+            options.movable = options.resizable = options.rotatable = false;
         }
 
-        options.scaleHandles = 100 / app.getView().getZoomFactor();
+        if (app.isODF() && DrawingFrame.isFullOdfTextframeNode(drawingNode)) { // default text frames are not rotatable
+            options.rotatable = false;
+        }
+
+        var currentZoomFactor = app.getView().getZoomFactor();
+        options.zoomValue     = 100 * currentZoomFactor;
+        options.scaleHandles  = 1 / currentZoomFactor;
+        options.rotation      = DrawingFrame.getDrawingRotationAngle(editor, drawingNode) || 0;
 
         // the container element used to visualize the selection
         selectionBox = DrawingFrame.drawSelection(drawingNode, options);
@@ -1243,36 +1449,16 @@ define('io.ox/office/text/components/drawing/drawingresize', [
         // initialize move tracking
         moveBox = selectionBox.children('.tracker');
 
-        if (options.movable) {
-            Tracking.enableTracking(drawingNode, {
-                autoScroll: true,
-                borderNode: scrollNode,
-                borderMargin: -30,
-                borderSize: 60,
-                minSpeed: 10,
-                maxSpeed: 250
-            });
-            drawingNode.on('tracking:start', trackingStartHandler);
-        } else {
-            Tracking.disableTracking(drawingNode);
-            drawingNode.off('tracking:start', trackingStartHandler);
-        }
-
+        toggleTracking(drawingNode, options.movable);
         // initialize resize tracking
-        var resizeHandles = selectionBox.find('>.resizers>[data-pos]');
-        if (options.resizable) {
-            Tracking.enableTracking(resizeHandles, {
-                autoScroll: true,
-                borderNode: scrollNode,
-                borderMargin: -30,
-                borderSize: 60,
-                minSpeed: 10,
-                maxSpeed: 250
-            });
-            resizeHandles.on('tracking:start', trackingStartHandler);
+        toggleTracking(selectionBox.find('>.resizers>[data-pos]'), options.resizable);
+        // initialize rotate tracking
+        toggleTracking(selectionBox.find('.rotate-handle'), options.rotatable);
+
+        if (options.movable || options.resizeable || options.rotatable) {
+            editor.listenTo(drawingNode, 'tracking:start', trackingStartHandler);
         } else {
-            Tracking.disableTracking(resizeHandles);
-            resizeHandles.off('tracking:start', trackingStartHandler);
+            editor.stopListeningTo(drawingNode, 'tracking:start', trackingStartHandler);
         }
     };
 
