@@ -16,13 +16,12 @@
 define('io.ox/office/text/format/drawingstyles', [
     'io.ox/office/textframework/utils/textutils',
     'io.ox/office/editframework/utils/attributeutils',
-    'io.ox/office/editframework/utils/border',
     'io.ox/office/drawinglayer/model/drawingstylecollection',
     'io.ox/office/drawinglayer/view/drawingframe',
     'io.ox/office/text/components/drawing/drawingresize',
     'io.ox/office/textframework/utils/dom',
     'io.ox/office/textframework/utils/position'
-], function (Utils, AttributeUtils, Border, DrawingStyleCollection, DrawingFrame, DrawingResize, DOM, Position) {
+], function (Utils, AttributeUtils, DrawingStyleCollection, DrawingFrame, DrawingResize, DOM, Position) {
 
     'use strict';
 
@@ -55,86 +54,18 @@ define('io.ox/office/text/format/drawingstyles', [
              */
             marginRight: { def: 0 },
 
-            /**
-             * Style, width and color of the left drawing border.
-             */
-            borderLeft: {
-                def: Border.NONE,
-                format: function (element, border) {
-                    element.css('border-left', this.getCssBorder(border));
-                }
-            },
-
-            /**
-             * Style, width and color of the right drawing border.
-             */
-            borderRight: {
-                def: Border.NONE,
-                format: function (element, border) {
-                    element.css('border-right', this.getCssBorder(border));
-                }
-            },
-
-            /**
-             * Style, width and color of the top drawing border.
-             */
-            borderTop: {
-                def: Border.NONE,
-                format: function (element, border) {
-                    element.css('border-top', this.getCssBorder(border));
-                }
-            },
-
-            /**
-             * Style, width and color of the bottom drawing border.
-             */
-            borderBottom: {
-                def: Border.NONE,
-                format: function (element, border) {
-                    element.css('border-bottom', this.getCssBorder(border));
-                }
-            },
-
             // object anchor --------------------------------------------------
 
             /**
              * Width of the drawing, as number in 1/100 of millimeters. The
              * value 0 will be interpreted as 100% width of the parent element.
              */
-            width: {
-                def: 0,
-                format: function (element, width) {
-                    if (!DrawingFrame.isGroupedDrawingFrame(element)) {
-
-                        // bugfix :: BUG#45141 :: https://bugs.open-xchange.com/show_bug.cgi?id=45141 :: Vertical drawing object is shown diagonally
-                        if (_.isString(width)) {
-                            var
-                                value = parseInt(width, 10),
-                                tuple = width.split(value),
-                                unit  = (tuple.length === 2) ? $.trim(tuple[1]) : '';
-
-                            if (unit === '%') {
-                                element.width([value, unit].join(''));
-                            }/* else if (unit !== '') {
-                                element.width(Utils.convertLength(value, unit, 'px', 1));
-                            }*/
-                        } else {
-                            if (width === 0) {          // cause of BUG#45141 in presentation:
-                                element.width('100%');  // - needs to be removed after changig to shape geometry in OX Text.
-                            } else {                    // - see: >> office/presentation/format/drawingstyles.js <<
-                                element.width(Utils.convertHmmToLength(width, 'px', 1));
-                            }
-                        }
-                    }
-                }
-            },
+            width: { def: 0 },
 
             /**
              * Height of the drawing, as number in 1/100 of millimeters.
              */
-            height: {
-                def: 0
-            },
+            height: { def: 0 },
 
             /**
              * If set to true, the drawing is rendered as inline element ('as
@@ -178,7 +109,12 @@ define('io.ox/office/text/format/drawingstyles', [
              * - 'right': Text floats at the right side of the drawing only.
              * - 'largest': Text floats at the larger side of the drawing only.
              */
-            textWrapSide: { def: 'both' }
+            textWrapSide: { def: 'both' },
+
+            /**
+             * Drawing rotation
+             */
+            rotation: { def: 0 }
 
         },
 
@@ -208,14 +144,11 @@ define('io.ox/office/text/format/drawingstyles', [
      * @param {TextModel} docModel
      *  The text document model containing instance.
      */
-    function TextDrawingStyles(docModel) {
+    var TextDrawingStyles = DrawingStyleCollection.extend({ constructor: function (docModel) {
 
         // base constructor ---------------------------------------------------
 
-        DrawingStyleCollection.call(this, docModel, {
-            families: 'line fill image shape geometry connector changes',
-            formatHandler: updateDrawingFormatting
-        });
+        DrawingStyleCollection.call(this, docModel, { families: 'changes' });
 
         // private methods ----------------------------------------------------
 
@@ -629,8 +562,40 @@ define('io.ox/office/text/format/drawingstyles', [
         }
 
         /**
-         * Setting the height of the drawing. This needs to be done, because it might be
-         * dependent from other attribute values.
+         * Sets the width of the drawing.
+         *
+         * @param {jQuery} drawing
+         *  The drawing node as jQuery object.
+         *
+         * @param {Object} attributes
+         *  A map with the merged drawing attributes, as name/value pairs.
+         */
+        function setDrawingWidth(drawing, attributes) {
+
+            if (DrawingFrame.isGroupedDrawingFrame(drawing)) { return; }
+
+            // bugfix :: BUG#45141 :: https://bugs.open-xchange.com/show_bug.cgi?id=45141 :: Vertical drawing object is shown diagonally
+            var width = attributes.drawing.width;
+            if (_.isString(width)) {
+                var
+                    value = parseInt(width, 10),
+                    tuple = width.split(value),
+                    unit  = (tuple.length === 2) ? $.trim(tuple[1]) : '';
+
+                if (unit === '%') {
+                    drawing.width([value, unit].join(''));
+                }/* else if (unit !== '') {
+                    element.width(Utils.convertLength(value, unit, 'px', 1));
+                }*/
+            } else if (width === 0) {          // cause of BUG#45141 in presentation:
+                drawing.width('100%');  // - needs to be removed after changig to shape geometry in OX Text.
+            } else {                    // - see: >> office/presentation/format/drawingstyles.js <<
+                drawing.width(Utils.convertHmmToLength(width, 'px', 1));
+            }
+        }
+
+        /**
+         * Sets the height of the drawing.
          *
          * @param {jQuery} drawing
          *  The drawing node as jQuery object.
@@ -912,7 +877,7 @@ define('io.ox/office/text/format/drawingstyles', [
             var // the drawing attributes of the passed attribute map
                 drawingAttributes = mergedAttributes.drawing,
                 // the current zoom factor
-                zoomFactor = docModel.getApp().getView().getZoomFactor() / 100,
+                zoomFactor = docModel.getApp().getView().getZoomFactor(),
                 // the paragraph element containing the drawing node
                 // -> this can also be a drawing group without paragraphs
                 paragraph = drawing.parent(),
@@ -932,8 +897,11 @@ define('io.ox/office/text/format/drawingstyles', [
                 // current drawing width, in 1/100 mm, without margin
                 // -> since the border is drawn with a canvas, the drawing width (including border) needs to be adjusted
                 // -> the canvas draws half of the border width outside and half of it inside the drawing.
-                drawingWidth = Utils.convertLengthToHmm(drawing.width(), 'px') + borderWidth;
+                drawingWidth;
 
+            // Setting the width of the drawing
+            setDrawingWidth(drawing, mergedAttributes);
+            drawingWidth = Utils.convertLengthToHmm(drawing.width(), 'px') + borderWidth;
             // Setting the height of the drawing
             setDrawingHeight(drawing, mergedAttributes);
 
@@ -947,6 +915,11 @@ define('io.ox/office/text/format/drawingstyles', [
                 return;
             }
 
+            // applying rotation
+            var degrees = drawingAttributes.rotation || 0;
+            DrawingFrame.updateCssTransform(drawing, degrees);
+            drawing.toggleClass(DrawingFrame.ROTATED_DRAWING_CLASSNAME, degrees !== 0);
+
             // setting marker for drawings in header or footer
             if (inHeaderFooter) { drawing.addClass(DOM.TARGET_NODE_CLASSNAME); }
 
@@ -987,7 +960,7 @@ define('io.ox/office/text/format/drawingstyles', [
          *  A map of attribute maps (name/value pairs), keyed by attribute family, containing the
          *  effective attribute values merged from style sheets and explicit attributes.
          */
-        var handleLayerOrder = Utils.profileMethod('DrawingStyles.handleLayerOrder(): ', function (drawing, inHeaderFooter, drawingAttributes) {
+        function handleLayerOrder(drawing, inHeaderFooter, drawingAttributes) {
 
             var drawingEl = drawing[0];
 
@@ -1014,19 +987,22 @@ define('io.ox/office/text/format/drawingstyles', [
                 }
                 Utils.sortDrawingsOrder(allDrawings, startIndex);
             }
-        });
+        }
 
         // initialization -----------------------------------------------------
 
         // register the attribute definitions for the style family
-        docModel.registerAttributeDefinitions('drawing', DEFINITIONS);
+        docModel.registerAttributes('drawing', DEFINITIONS);
+
+        // register the formatting handler for DOM elements
+        this.registerFormatHandler(updateDrawingFormatting);
 
         // destroy all class members on destruction
         this.registerDestructor(function () {
             docModel = null;
         });
 
-    } // class TextDrawingStyles
+    } }); // class TextDrawingStyles
 
     // static methods ---------------------------------------------------------
 
@@ -1119,7 +1095,6 @@ define('io.ox/office/text/format/drawingstyles', [
 
     // exports ================================================================
 
-    // derive this class from class DrawingStyleCollection
-    return DrawingStyleCollection.extend({ constructor: TextDrawingStyles });
+    return TextDrawingStyles;
 
 });
