@@ -24,193 +24,205 @@ define('io.ox/office/text/format/listcollection', [
 
     'use strict';
 
-    var // the default bullet list definition with different bullets per list level
-        DEFAULT_BULLET_LIST_DEFINITION = {
-            listLevel0: { textAlign: 'left', indentLeft: 1270,     numberFormat: 'bullet', listStartValue: 1, fontName: 'Symbol', levelText: '\uf0b7', indentFirstLine: -635 },
-            listLevel1: { textAlign: 'left', indentLeft: 2 * 1270, numberFormat: 'bullet', listStartValue: 1, fontName: 'Times New Roman', levelText: '\u25CB', indentFirstLine: -635 },
-            listLevel2: { textAlign: 'left', indentLeft: 3 * 1270, numberFormat: 'bullet', listStartValue: 1, fontName: 'Times New Roman', levelText: '\u25A0', indentFirstLine: -635 },
-            listLevel3: { textAlign: 'left', indentLeft: 4 * 1270, numberFormat: 'bullet', listStartValue: 1, fontName: 'Symbol', levelText: '\uf0b7', indentFirstLine: -635 },
-            listLevel4: { textAlign: 'left', indentLeft: 5 * 1270, numberFormat: 'bullet', listStartValue: 1, fontName: 'Times New Roman', levelText: '\u25CB', indentFirstLine: -635 },
-            listLevel5: { textAlign: 'left', indentLeft: 6 * 1270, numberFormat: 'bullet', listStartValue: 1, fontName: 'Times New Roman', levelText: '\u25A0', indentFirstLine: -635 },
-            listLevel6: { textAlign: 'left', indentLeft: 7 * 1270, numberFormat: 'bullet', listStartValue: 1, fontName: 'Symbol', levelText: '\uf0b7', indentFirstLine: -635 },
-            listLevel7: { textAlign: 'left', indentLeft: 8 * 1270, numberFormat: 'bullet', listStartValue: 1, fontName: 'Times New Roman', levelText: '\u25CB', indentFirstLine: -635 },
-            listLevel8: { textAlign: 'left', indentLeft: 9 * 1270, numberFormat: 'bullet', listStartValue: 1, fontName: 'Times New Roman', levelText: '\u25A0', indentFirstLine: -635 }
-        },
+    // the default bullet list definition with different bullets per list level
+    var DEFAULT_BULLET_LIST_DEFINITION = {
+        listLevel0: { textAlign: 'left', indentLeft: 1270,     numberFormat: 'bullet', listStartValue: 1, fontName: 'Symbol', levelText: '\uf0b7', indentFirstLine: -635 },
+        listLevel1: { textAlign: 'left', indentLeft: 2 * 1270, numberFormat: 'bullet', listStartValue: 1, fontName: 'Times New Roman', levelText: '\u25CB', indentFirstLine: -635 },
+        listLevel2: { textAlign: 'left', indentLeft: 3 * 1270, numberFormat: 'bullet', listStartValue: 1, fontName: 'Times New Roman', levelText: '\u25A0', indentFirstLine: -635 },
+        listLevel3: { textAlign: 'left', indentLeft: 4 * 1270, numberFormat: 'bullet', listStartValue: 1, fontName: 'Symbol', levelText: '\uf0b7', indentFirstLine: -635 },
+        listLevel4: { textAlign: 'left', indentLeft: 5 * 1270, numberFormat: 'bullet', listStartValue: 1, fontName: 'Times New Roman', levelText: '\u25CB', indentFirstLine: -635 },
+        listLevel5: { textAlign: 'left', indentLeft: 6 * 1270, numberFormat: 'bullet', listStartValue: 1, fontName: 'Times New Roman', levelText: '\u25A0', indentFirstLine: -635 },
+        listLevel6: { textAlign: 'left', indentLeft: 7 * 1270, numberFormat: 'bullet', listStartValue: 1, fontName: 'Symbol', levelText: '\uf0b7', indentFirstLine: -635 },
+        listLevel7: { textAlign: 'left', indentLeft: 8 * 1270, numberFormat: 'bullet', listStartValue: 1, fontName: 'Times New Roman', levelText: '\u25CB', indentFirstLine: -635 },
+        listLevel8: { textAlign: 'left', indentLeft: 9 * 1270, numberFormat: 'bullet', listStartValue: 1, fontName: 'Times New Roman', levelText: '\u25A0', indentFirstLine: -635 }
+    };
 
-        // the default numbered list definition with different number formats per list level (as used in MSO2010)
-        DEFAULT_NUMBERING_LIST_DEFINITION = {
-            listLevel0: { numberFormat: 'decimal',     listStartValue: 1, indentLeft: 1270,     indentFirstLine: -635, textAlign: 'left',  levelText: '%1.' },
-            listLevel1: { numberFormat: 'lowerLetter', listStartValue: 1, indentLeft: 2 * 1270, indentFirstLine: -635, textAlign: 'left',  levelText: '%2.' },
-            listLevel2: { numberFormat: 'upperLetter', listStartValue: 1, indentLeft: 3 * 1270, indentFirstLine: -635, textAlign: 'right', levelText: '%3.' },
-            listLevel3: { numberFormat: 'lowerRoman',  listStartValue: 1, indentLeft: 4 * 1270, indentFirstLine: -635, textAlign: 'left',  levelText: '%4.' },
-            listLevel4: { numberFormat: 'upperRoman',  listStartValue: 1, indentLeft: 5 * 1270, indentFirstLine: -635, textAlign: 'left',  levelText: '%5.' },
-            listLevel5: { numberFormat: 'decimal',     listStartValue: 1, indentLeft: 6 * 1270, indentFirstLine: -635, textAlign: 'right', levelText: '%6.' },
-            listLevel6: { numberFormat: 'lowerLetter', listStartValue: 1, indentLeft: 7 * 1270, indentFirstLine: -635, textAlign: 'left',  levelText: '%7.' },
-            listLevel7: { numberFormat: 'upperLetter', listStartValue: 1, indentLeft: 8 * 1270, indentFirstLine: -635, textAlign: 'left',  levelText: '%8.' },
-            listLevel8: { numberFormat: 'lowerRoman',  listStartValue: 1, indentLeft: 9 * 1270, indentFirstLine: -635, textAlign: 'right', levelText: '%9.' }
-        },
+    // the default numbered list definition with different number formats per list level (as used in MSO2010)
+    var DEFAULT_NUMBERING_LIST_DEFINITION = {
+        listLevel0: { numberFormat: 'decimal',     listStartValue: 1, indentLeft: 1270,     indentFirstLine: -635, textAlign: 'left',  levelText: '%1.' },
+        listLevel1: { numberFormat: 'lowerLetter', listStartValue: 1, indentLeft: 2 * 1270, indentFirstLine: -635, textAlign: 'left',  levelText: '%2.' },
+        listLevel2: { numberFormat: 'upperLetter', listStartValue: 1, indentLeft: 3 * 1270, indentFirstLine: -635, textAlign: 'right', levelText: '%3.' },
+        listLevel3: { numberFormat: 'lowerRoman',  listStartValue: 1, indentLeft: 4 * 1270, indentFirstLine: -635, textAlign: 'left',  levelText: '%4.' },
+        listLevel4: { numberFormat: 'upperRoman',  listStartValue: 1, indentLeft: 5 * 1270, indentFirstLine: -635, textAlign: 'left',  levelText: '%5.' },
+        listLevel5: { numberFormat: 'decimal',     listStartValue: 1, indentLeft: 6 * 1270, indentFirstLine: -635, textAlign: 'right', levelText: '%6.' },
+        listLevel6: { numberFormat: 'lowerLetter', listStartValue: 1, indentLeft: 7 * 1270, indentFirstLine: -635, textAlign: 'left',  levelText: '%7.' },
+        listLevel7: { numberFormat: 'upperLetter', listStartValue: 1, indentLeft: 8 * 1270, indentFirstLine: -635, textAlign: 'left',  levelText: '%8.' },
+        listLevel8: { numberFormat: 'lowerRoman',  listStartValue: 1, indentLeft: 9 * 1270, indentFirstLine: -635, textAlign: 'right', levelText: '%9.' }
+    };
 
-        // all predefined list styles for the GUI controls, mapped by list identifier
-        PREDEFINED_LISTSTYLES = (function () {
+    // all predefined list styles for the GUI controls, mapped by list identifier
+    var PREDEFINED_LISTSTYLES = (function () {
 
-            /**
-             * Creates and returns a style definition for a bullet list with
-             * the same bullet character in all list levels.
-             *
-             * @param {Function} levelCallback
-             *  A function that generates a style definition for a single list
-             *  level. Receives the list level in the first parameter.
-             *
-             * @param {String} listKey
-             *  A unique key for the list style.
-             *
-             * @param {String} listLabel
-             *  The button label for the list style used in GUI from controls.
-             *
-             * @param {String} tooltip
-             *  A tool tip for the list style used in GUI from controls.
-             *
-             * @returns {Object}
-             *  An object with an attribute 'definition' and the string
-             *  attributes 'listKey', 'listLabel', and 'tooltip'. The list
-             *  definition object containing the attributes 'listLevel0' to
-             *  'listLevel8' referring to list style definitions with an
-             *  indentation according to the respective list level.
-             */
-            function createListStyle(levelCallback, listKey, listLabel, tooltip) {
-                var definition = {};
-                _(9).times(function (level) {
-                    definition['listLevel' + level] = levelCallback(level);
-                });
-                return { definition: definition, listKey: listKey, listLabel: listLabel, tooltip: tooltip };
-            }
+        /**
+         * Creates and returns a style definition for a bullet list with
+         * the same bullet character in all list levels.
+         *
+         * @param {String} listKey
+         *  A unique key for the list style.
+         *
+         * @param {String} listLabel
+         *  The button label for the list style used in GUI from controls.
+         *
+         * @param {Number} sortIndex
+         *  The sorting index used in drop-down lists in GUI controls.
+         *
+         * @param {String} tooltip
+         *  A tool tip for the list style used in GUI from controls.
+         *
+         * @param {Function} levelGenerator
+         *  A callback function that generates a style definition for a single
+         *  list level. Receives the list level in the first parameter.
+         *
+         * @returns {Object}
+         *  An object with an attribute 'definition' and the string
+         *  attributes 'listKey', 'listLabel', and 'tooltip'. The list
+         *  definition object containing the attributes 'listLevel0' to
+         *  'listLevel8' referring to list style definitions with an
+         *  indentation according to the respective list level.
+         */
+        function createListStyle(numberFormat, listKey, listLabel, sortIndex, tooltip, levelGenerator) {
+            var definition = {};
+            _(9).times(function (level) {
+                definition['listLevel' + level] = _.extend({
+                    numberFormat: numberFormat,
+                    listStartValue: 1
+                }, levelGenerator(level));
+            });
+            return { definition: definition, format: numberFormat, listKey: listKey, listLabel: listLabel, sortIndex: sortIndex, tooltip: tooltip };
+        }
 
-            /**
-             * Creates and returns a style definition for a bullet list with
-             * the same bullet character in all list levels.
-             *
-             * @param {String} bulletKey
-             *  A unique key for the bullet list style.
-             *
-             * @param {String} bulletCharacter
-             *  The bullet character for all list levels.
-             *
-             * @param {String} tooltip
-             *  A tool tip for the list style used in GUI from controls.
-             *
-             * @returns {Object}
-             *  An object with an attribute 'definition' and the string
-             *  attributes 'listLabel' and 'tooltip'. The list definition
-             *  object containing the attributes 'listLevel0' to 'listLevel8'
-             *  referring to list style definitions with an indentation
-             *  according to the respective list level.
-             */
-            function createBulletListStyle(bulletKey, bulletCharacter, tooltip) {
-                return createListStyle(function (level) {
-                    return {
-                        numberFormat: 'bullet',
-                        listStartValue: 1,
-                        indentLeft: (level + 1) * 1270,
-                        indentFirstLine: -635,
-                        textAlign: 'left',
-                        levelText: bulletCharacter,
-                        fontName: 'Times New Roman'
-                    };
-                }, bulletKey, bulletCharacter, tooltip);
-            }
+        /**
+         * Creates and returns a style definition for a bullet list with
+         * the same bullet character in all list levels.
+         *
+         * @param {String} bulletKey
+         *  A unique key for the bullet list style.
+         *
+         * @param {String} bulletCharacter
+         *  The bullet character for all list levels.
+         *
+         * @param {Number} sortIndex
+         *  The sorting index used in drop-down lists in GUI controls.
+         *
+         * @param {String} tooltip
+         *  A tool tip for the list style used in GUI from controls.
+         *
+         * @returns {Object}
+         *  An object with an attribute 'definition' and the string
+         *  attributes 'listLabel' and 'tooltip'. The list definition
+         *  object containing the attributes 'listLevel0' to 'listLevel8'
+         *  referring to list style definitions with an indentation
+         *  according to the respective list level.
+         */
+        function createBulletListStyle(bulletKey, bulletCharacter, sortIndex, tooltip) {
+            return createListStyle('bullet', bulletKey, bulletCharacter, sortIndex, tooltip, function (level) {
+                return {
+                    indentLeft: (level + 1) * 1270,
+                    indentFirstLine: -635,
+                    textAlign: 'left',
+                    levelText: bulletCharacter,
+                    fontName: 'Times New Roman'
+                };
+            });
+        }
 
-            /**
-             * Creates and returns a style definition for a numbered list with
-             * the same numbering style in all list levels.
-             *
-             * @param {String} numberFormat
-             *  One of the predefined number formats 'decimal', 'lowerLetter',
-             *  'upperLetter', 'lowerRoman', or 'upperRoman'.
-             *
-             * @param {String} textBefore
-             *  Fixed text inserted before each numeric list label.
-             *
-             * @param {String} textAfter
-             *  Fixed text inserted after each numeric list label.
-             *
-             * @param {String} tooltip
-             *  A tool tip for the list style used in GUI from controls.
-             *
-             * @returns {Object}
-             *  An object with an attribute 'definition' and the string
-             *  attributes 'listLabel' and 'tooltip'. The list definition
-             *  object containing the attributes 'listLevel0' to 'listLevel8'
-             *  referring to list style definitions with an indentation
-             *  according to the respective list level.
-             */
-            function createNumberedListStyle(numberFormat, textBefore, textAfter, tooltip, indentLeftVal, indentFirstLineVal, textAlignVal) {
+        /**
+         * Creates and returns a style definition for a numbered list with
+         * the same numbering style in all list levels.
+         *
+         * @param {String} numberFormat
+         *  One of the predefined number formats 'decimal', 'lowerLetter',
+         *  'upperLetter', 'lowerRoman', or 'upperRoman'.
+         *
+         * @param {String} textBefore
+         *  Fixed text inserted before each numeric list label.
+         *
+         * @param {String} textAfter
+         *  Fixed text inserted after each numeric list label.
+         *
+         * @param {Number} sortIndex
+         *  The sorting index used in drop-down lists in GUI controls.
+         *
+         * @param {String} tooltip
+         *  A tool tip for the list style used in GUI from controls.
+         *
+         * @returns {Object}
+         *  An object with an attribute 'definition' and the string
+         *  attributes 'listLabel' and 'tooltip'. The list definition
+         *  object containing the attributes 'listLevel0' to 'listLevel8'
+         *  referring to list style definitions with an indentation
+         *  according to the respective list level.
+         */
+        function createNumberedListStyle(numberFormat, textBefore, textAfter, sortIndex, tooltip, indentLeftVal, indentFirstLineVal, textAlignVal) {
 
-                var // default value for left indent in 1/100 mm
-                    defaultIndentLeftValue = 1270,
-                    // default value for first line indent in 1/100 mm
-                    defaultIndentFirstLineValue = -635,
-                    // default value for alignment of list numbers
-                    defaultTextAlignValue = 'left',
-                    // value for left indent in 1/100 mm
-                    indentLeftValue = indentLeftVal || defaultIndentLeftValue,
-                    // value for first line indent in 1/100 mm
-                    indentFirstLineValue = indentFirstLineVal || defaultIndentFirstLineValue,
-                    // value for alignment of list numbers (only left supported yet)
-                    textAlignValue = textAlignVal || defaultTextAlignValue;
+            // default value for left indent in 1/100 mm
+            var defaultIndentLeftValue = 1270;
+            // default value for first line indent in 1/100 mm
+            var defaultIndentFirstLineValue = -635;
+            // default value for alignment of list numbers
+            var defaultTextAlignValue = 'left';
+            // value for left indent in 1/100 mm
+            var indentLeftValue = indentLeftVal || defaultIndentLeftValue;
+            // value for first line indent in 1/100 mm
+            var indentFirstLineValue = indentFirstLineVal || defaultIndentFirstLineValue;
+            // value for alignment of list numbers (only left supported yet)
+            var textAlignValue = textAlignVal || defaultTextAlignValue;
+            // unique key for the list style
+            var listKey = textBefore + numberFormat + textAfter;
+            // GUI label for the list style
+            var listLabel = textBefore + ListUtils.formatNumber(1, numberFormat) + textAfter;
 
-                return createListStyle(function (level) {
-                    return {
-                        numberFormat: numberFormat,
-                        listStartValue: 1,
-                        indentLeft: (level + 1) * indentLeftValue,
-                        indentFirstLine: indentFirstLineValue,
-                        textAlign: textAlignValue,
-                        levelText: textBefore + '%' + (level + 1) + textAfter
-                    };
-                }, textBefore + numberFormat + textAfter, textBefore + ListUtils.formatNumber(1, numberFormat) + textAfter, tooltip);
-            }
+            return createListStyle(numberFormat, listKey, listLabel, sortIndex, tooltip, function (level) {
+                return {
+                    indentLeft: (level + 1) * indentLeftValue,
+                    indentFirstLine: indentFirstLineValue,
+                    textAlign: textAlignValue,
+                    levelText: textBefore + '%' + (level + 1) + textAfter
+                };
+            });
+        }
 
-            // generate and return the array with all predefined list styles
-            return {
-                L20000: createBulletListStyle('filled-circle',       '\u25CF', /*#. symbol in bullet lists (filled) */ gt('Filled circle')),
-                L20001: createBulletListStyle('small-filled-circle', '\u2022', /*#. symbol in bullet lists (filled) */ gt('Small filled circle')),
-                L20002: createBulletListStyle('circle',              '\u25CB', /*#. symbol in bullet lists (not filled) */ gt('Circle')),
-                L20003: createBulletListStyle('small-circle',        '\u25E6', /*#. symbol in bullet lists (not filled) */ gt('Small circle')),
-                L20004: createBulletListStyle('filled-square',       '\u25A0', /*#. symbol in bullet lists (filled) */ gt('Filled square')),
-                L20005: createBulletListStyle('small-filled-square', '\u25AA', /*#. symbol in bullet lists (filled) */ gt('Small filled square')),
-                L20006: createBulletListStyle('square',              '\u25A1', /*#. symbol in bullet lists (not filled) */ gt('Square')),
-                L20007: createBulletListStyle('small-square',        '\u25AB', /*#. symbol in bullet lists (not filled) */ gt('Small square')),
-                L20008: createBulletListStyle('filled-diamond',      '\u2666', /*#. symbol in bullet lists (filled) */ gt('Filled diamond')),
-                L20009: createBulletListStyle('diamond',             '\u25CA', /*#. symbol in bullet lists (not filled) */ gt('Diamond')),
-                L20010: createBulletListStyle('filled-triangle',     '\u25BA', /*#. symbol in bullet lists (filled) */ gt('Filled triangle')),
-                L20011: createBulletListStyle('chevron',             '>',      /*#. symbol in bullet lists */ gt('Chevron')),
-                L20012: createBulletListStyle('arrow',               '\u2192', /*#. symbol in bullet lists */ gt('Arrow')),
-                L20013: createBulletListStyle('dash',                '\u2013', /*#. symbol in bullet lists */ gt('Dash')),
-                L20014: createBulletListStyle('none',                ' ',      /*#. bullet lists without symbols */ gt('No symbol')),
+        // generate and return the array with all predefined list styles
+        return {
+            L20000: createBulletListStyle('filled-circle',       '\u25CF', 11, /*#. symbol in bullet lists (filled) */ gt('Filled circle')),
+            L20001: createBulletListStyle('small-filled-circle', '\u2022', 12, /*#. symbol in bullet lists (filled) */ gt('Small filled circle')),
+            L20002: createBulletListStyle('circle',              '\u25CB', 13, /*#. symbol in bullet lists (not filled) */ gt('Circle')),
+            L20003: createBulletListStyle('small-circle',        '\u25E6', 14, /*#. symbol in bullet lists (not filled) */ gt('Small circle')),
+            L20004: createBulletListStyle('filled-square',       '\u25A0', 21, /*#. symbol in bullet lists (filled) */ gt('Filled square')),
+            L20005: createBulletListStyle('small-filled-square', '\u25AA', 22, /*#. symbol in bullet lists (filled) */ gt('Small filled square')),
+            L20006: createBulletListStyle('square',              '\u25A1', 23, /*#. symbol in bullet lists (not filled) */ gt('Square')),
+            L20007: createBulletListStyle('small-square',        '\u25AB', 24, /*#. symbol in bullet lists (not filled) */ gt('Small square')),
+            L20008: createBulletListStyle('filled-diamond',      '\u2666', 31, /*#. symbol in bullet lists (filled) */ gt('Filled diamond')),
+            L20009: createBulletListStyle('diamond',             '\u25CA', 32, /*#. symbol in bullet lists (not filled) */ gt('Diamond')),
+            L20010: createBulletListStyle('filled-triangle',     '\u25BA', 41, /*#. symbol in bullet lists (filled) */ gt('Filled triangle')),
+            L20011: createBulletListStyle('chevron',             '>',      42, /*#. symbol in bullet lists */ gt('Chevron')),
+            L20012: createBulletListStyle('arrow',               '\u2192', 51, /*#. symbol in bullet lists */ gt('Arrow')),
+            L20013: createBulletListStyle('dash',                '\u2013', 52, /*#. symbol in bullet lists */ gt('Dash')),
+            L20014: createBulletListStyle('none',                ' ',      99, /*#. bullet lists without symbols */ gt('No symbol')),
 
-                L30000: createNumberedListStyle('decimal',     '',  '',  /*#. label style in numbered lists */ gt('Decimal numbers')),
-                L30001: createNumberedListStyle('decimal',     '',  '.', /*#. label style in numbered lists */ gt('Decimal numbers')),
-                L30002: createNumberedListStyle('decimal',     '',  ')', /*#. label style in numbered lists */ gt('Decimal numbers')),
-                L30003: createNumberedListStyle('decimal',     '(', ')', /*#. label style in numbered lists */ gt('Decimal numbers')),
-                L30010: createNumberedListStyle('lowerLetter', '',  '',  /*#. label style in numbered lists */ gt('Small Latin letters')),
-                L30011: createNumberedListStyle('lowerLetter', '',  '.', /*#. label style in numbered lists */ gt('Small Latin letters')),
-                L30012: createNumberedListStyle('lowerLetter', '',  ')', /*#. label style in numbered lists */ gt('Small Latin letters')),
-                L30013: createNumberedListStyle('lowerLetter', '(', ')', /*#. label style in numbered lists */ gt('Small Latin letters')),
-                L30020: createNumberedListStyle('upperLetter', '',  '',  /*#. label style in numbered lists */ gt('Capital Latin letters')),
-                L30021: createNumberedListStyle('upperLetter', '',  '.', /*#. label style in numbered lists */ gt('Capital Latin letters')),
-                L30022: createNumberedListStyle('upperLetter', '',  ')', /*#. label style in numbered lists */ gt('Capital Latin letters')),
-                L30023: createNumberedListStyle('upperLetter', '(', ')', /*#. label style in numbered lists */ gt('Capital Latin letters')),
-                L30030: createNumberedListStyle('lowerRoman',  '',  '',  /*#. label style in numbered lists */ gt('Small Roman numbers')),
-                L30031: createNumberedListStyle('lowerRoman',  '',  '.', /*#. label style in numbered lists */ gt('Small Roman numbers')),
-                L30032: createNumberedListStyle('lowerRoman',  '',  ')', /*#. label style in numbered lists */ gt('Small Roman numbers')),
-                L30033: createNumberedListStyle('lowerRoman',  '(', ')', /*#. label style in numbered lists */ gt('Small Roman numbers')),
-                L30040: createNumberedListStyle('upperRoman',  '',  '',  /*#. label style in numbered lists */ gt('Capital Roman numbers')),
-                L30041: createNumberedListStyle('upperRoman',  '',  '.', /*#. label style in numbered lists */ gt('Capital Roman numbers')),
-                L30042: createNumberedListStyle('upperRoman',  '',  ')', /*#. label style in numbered lists */ gt('Capital Roman numbers')),
-                L30043: createNumberedListStyle('upperRoman',  '(', ')', /*#. label style in numbered lists */ gt('Capital Roman numbers'), 1905, -1270)
-            };
+            L30000: createNumberedListStyle('decimal',     '',  '',  11, /*#. label style in numbered lists */ gt('Decimal numbers')),
+            L30001: createNumberedListStyle('decimal',     '',  '.', 12, /*#. label style in numbered lists */ gt('Decimal numbers')),
+            L30002: createNumberedListStyle('decimal',     '',  ')', 13, /*#. label style in numbered lists */ gt('Decimal numbers')),
+            L30003: createNumberedListStyle('decimal',     '(', ')', 14, /*#. label style in numbered lists */ gt('Decimal numbers')),
+            L30010: createNumberedListStyle('lowerLetter', '',  '',  21, /*#. label style in numbered lists */ gt('Small Latin letters')),
+            L30011: createNumberedListStyle('lowerLetter', '',  '.', 22, /*#. label style in numbered lists */ gt('Small Latin letters')),
+            L30012: createNumberedListStyle('lowerLetter', '',  ')', 23, /*#. label style in numbered lists */ gt('Small Latin letters')),
+            L30013: createNumberedListStyle('lowerLetter', '(', ')', 24, /*#. label style in numbered lists */ gt('Small Latin letters')),
+            L30020: createNumberedListStyle('upperLetter', '',  '',  31, /*#. label style in numbered lists */ gt('Capital Latin letters')),
+            L30021: createNumberedListStyle('upperLetter', '',  '.', 32, /*#. label style in numbered lists */ gt('Capital Latin letters')),
+            L30022: createNumberedListStyle('upperLetter', '',  ')', 33, /*#. label style in numbered lists */ gt('Capital Latin letters')),
+            L30023: createNumberedListStyle('upperLetter', '(', ')', 34, /*#. label style in numbered lists */ gt('Capital Latin letters')),
+            L30030: createNumberedListStyle('lowerRoman',  '',  '',  41, /*#. label style in numbered lists */ gt('Small Roman numbers')),
+            L30031: createNumberedListStyle('lowerRoman',  '',  '.', 42, /*#. label style in numbered lists */ gt('Small Roman numbers')),
+            L30032: createNumberedListStyle('lowerRoman',  '',  ')', 43, /*#. label style in numbered lists */ gt('Small Roman numbers')),
+            L30033: createNumberedListStyle('lowerRoman',  '(', ')', 44, /*#. label style in numbered lists */ gt('Small Roman numbers')),
+            L30040: createNumberedListStyle('upperRoman',  '',  '',  51, /*#. label style in numbered lists */ gt('Capital Roman numbers')),
+            L30041: createNumberedListStyle('upperRoman',  '',  '.', 52, /*#. label style in numbered lists */ gt('Capital Roman numbers')),
+            L30042: createNumberedListStyle('upperRoman',  '',  ')', 53, /*#. label style in numbered lists */ gt('Capital Roman numbers')),
+            L30043: createNumberedListStyle('upperRoman',  '(', ')', 54, /*#. label style in numbered lists */ gt('Capital Roman numbers'), 1905, -1270)
+        };
 
-        }()); // end of PREDEFINED_LISTSTYLES local scope
+    }()); // end of PREDEFINED_LISTSTYLES local scope
 
     // static private function ================================================
 
@@ -1165,14 +1177,14 @@ define('io.ox/office/text/format/listcollection', [
         this.getListId = function (listDefinition, id) {
             var listId = this.hasListStyleId(id) ? null : id;
             if (listDefinition) {
-                var pageNode = docModel.getNode();
+                var rootNode = docModel.getCurrentRootNode();
                 var startPosition = docModel.getSelection().getStartPosition();
                 startPosition.pop();
-                var paragraph = Position.getParagraphElement(pageNode, startPosition);
-                var prevParagraph = TextUtils.findPreviousNode(pageNode, paragraph, DOM.PARAGRAPH_NODE_SELECTOR);
+                var paragraph = Position.getParagraphElement(rootNode, startPosition);
+                var prevParagraph = TextUtils.findPreviousNode(rootNode, paragraph, DOM.PARAGRAPH_NODE_SELECTOR);
                 while (prevParagraph) {
                     if (DOM.isEmptyParagraph(prevParagraph)) {
-                        prevParagraph = TextUtils.findPreviousNode(pageNode, prevParagraph, DOM.PARAGRAPH_NODE_SELECTOR);
+                        prevParagraph = TextUtils.findPreviousNode(rootNode, prevParagraph, DOM.PARAGRAPH_NODE_SELECTOR);
                     } else {
                         var attrs = docModel.getParagraphStyles().getElementAttributes(prevParagraph);
                         if (attrs.paragraph.listStyleId !== '' && isArrayDefinitionEqual(this.getList(attrs.paragraph.listStyleId), listDefinition)) {
@@ -1196,14 +1208,6 @@ define('io.ox/office/text/format/listcollection', [
 
     } // class ListCollection
 
-    // constants --------------------------------------------------------------
-
-    /**
-     * A constant that will be used in the GUI to represent the default style
-     * of bullet lists or numbered lists.
-     */
-    ListCollection.DEFAULT_VALUE = '__DEFAULT__';
-
     // static methods ---------------------------------------------------------
 
     ListCollection.getListTypeFromHtmlListType = function (htmlType) {
