@@ -15,12 +15,12 @@
 define('io.ox/office/text/format/stylesheetmixin', [
     'io.ox/office/tk/utils',
     'io.ox/office/tk/locale/localedata',
-    'io.ox/office/textframework/view/textdialogs',
     'io.ox/office/textframework/utils/operations',
     'io.ox/office/textframework/utils/position',
     'io.ox/office/textframework/utils/dom',
+    'io.ox/office/textframework/view/dialogs',
     'gettext!io.ox/office/text/main'
-], function (Utils, LocaleData, Dialogs, Operations, Position, DOM, gt) {
+], function (Utils, LocaleData, Operations, Position, DOM, Dialogs, gt) {
 
     'use strict';
 
@@ -245,7 +245,7 @@ define('io.ox/office/text/format/stylesheetmixin', [
                 var startPos = selection.getStartPosition();
                 var paraPos = _.initial(startPos);
                 var paraNode = self.getCurrentRootNode();
-                var localGenerator = self.createOperationsGenerator();
+                var localGenerator = self.createOperationGenerator();
 
                 self.getUndoManager().enterUndoGroup(function () {
                     self.doCheckImplicitParagraph(startPos);
@@ -294,7 +294,7 @@ define('io.ox/office/text/format/stylesheetmixin', [
 
             def = def.then(function () {
                 var newName = dialog.getText();
-                var localGenerator = self.createOperationsGenerator();
+                var localGenerator = self.createOperationGenerator();
                 localGenerator.generateOperation(Operations.CHANGE_STYLESHEET, {
                     type: 'paragraph',
                     styleId: styleId,
@@ -320,7 +320,7 @@ define('io.ox/office/text/format/stylesheetmixin', [
             var startPos = selection.getStartPosition();
             var paraPos = _.initial(startPos);
             var paraNode = self.getCurrentRootNode();
-            var localGenerator = self.createOperationsGenerator();
+            var localGenerator = self.createOperationGenerator();
 
             self.getUndoManager().enterUndoGroup(function () {
 
@@ -342,7 +342,7 @@ define('io.ox/office/text/format/stylesheetmixin', [
         };
 
         this.deleteStylesheet = function (styleId) {
-            var localGenerator = self.createOperationsGenerator();
+            var localGenerator = self.createOperationGenerator();
             var defaultParaStyle = paraStyles.getDefaultStyleId();
             var defaultAtts = { styleId: defaultParaStyle };
             var allP = self.getNode().find('.p').not(DOM.MARGINAL_NODE_SELECTOR);
@@ -428,10 +428,10 @@ define('io.ox/office/text/format/stylesheetmixin', [
                 var data = para.data();
                 var attrs = Utils.getOption(data, 'attributes', emptyAttr);
                 var paraStyleId = Utils.getStringOption(attrs, 'styleId', defaultParaStyle);
-                if (paraStyles.isChildOfOther(paraStyleId, styleId)) {
+                if ((paraStyleId === styleId) || paraStyles.isChildOfOther(paraStyleId, styleId)) {
                     paraStyles.updateElementFormatting(para);
                 }
-            }, { infoString: 'Text: Change:styleSheet', app: app }).always(function () {
+            }, 'StyleSheetMixin.changeStyleSheetHandler').always(function () {
                 app.getView().leaveBusy();
                 self.insertPageBreaks();
             });
