@@ -30,73 +30,42 @@ define('io.ox/office/text/format/tablecellstyles', [
              */
             gridSpan: {
                 def: 1,
-                scope: 'element',
-                format: function (element, gridSpan) {
-                    element.attr('colspan', gridSpan);
-                }
+                scope: 'element'
             },
 
             /**
              * Fill color of the table cell.
              */
             fillColor: {
-                def: Color.AUTO,
-                format: function (element, color) {
-                    element.css('background-color', this.getCssColor(color, 'fill'));
-                },
-                preview: true // 'true' calls the own 'format' method
+                def: Color.AUTO
             },
 
             /**
              * Style, width and color of the left table cell border.
              */
             borderLeft: {
-                def: Border.NONE,
-                format: function (element, border) {
-                    element.css('border-left', this.getCssBorder(border, { clearNone: true }));
-                },
-                preview: function (element, border) {
-                    element.css('border-left', this.getCssBorder(border, { preview: true }));
-                }
+                def: Border.NONE
             },
 
             /**
              * Style, width and color of the right table cell border.
              */
             borderRight: {
-                def: Border.NONE,
-                format: function (element, border) {
-                    element.css('border-right', this.getCssBorder(border, { clearNone: true }));
-                },
-                preview: function (element, border) {
-                    element.css('border-right', this.getCssBorder(border, { preview: true }));
-                }
+                def: Border.NONE
             },
 
             /**
              * Style, width and color of the top table cell border.
              */
             borderTop: {
-                def: Border.NONE,
-                format: function (element, border) {
-                    element.css('border-top', this.getCssBorder(border, { clearNone: true }));
-                },
-                preview: function (element, border) {
-                    element.css('border-top', this.getCssBorder(border, { preview: true }));
-                }
+                def: Border.NONE
             },
 
             /**
              * Style, width and color of the bottom table cell border.
              */
             borderBottom: {
-                def: Border.NONE,
-                format: function (element, border) {
-                    element.css('border-bottom', this.getCssBorder(border, { clearNone: true }));
-                },
-                preview: function (element, border) {
-                    element.css('border-bottom', this.getCssBorder(border, { preview: true }));
-                }
+                def: Border.NONE
             },
 
             /**
@@ -123,50 +92,36 @@ define('io.ox/office/text/format/tablecellstyles', [
              * Top padding of the table cell
              */
             paddingTop: {
-                def: 0,
-                format: function (element, value) {
-                    value = Utils.convertHmmToLength(value, 'px', 1);
-                    if (value < 2) { value = 2; }  // minimum 2px, required for cell resizing
-                    element.css('padding-top', value);
-                }
+                def: 0
             },
 
             /**
              * Bottom padding of the table cell
              */
             paddingBottom: {
-                def: 0,
-                format: function (element, value) {
-                    value = Utils.convertHmmToLength(value, 'px', 1);
-                    if (value < 2) { value = 2; }  // minimum 2px,  required for cell resizing
-                    element.css('padding-bottom', value);
-                }
+                def: 0
             },
 
             /**
              * Left padding of the table cell
              */
             paddingLeft: {
-                def: 0,
-                format: function (element, value) {
-                    value = Utils.convertHmmToLength(value, 'px', 1);
-                    if (value < 2) { value = 2; }  // minimum 2px, required for cell resizing
-                    element.css('padding-left', value);
-                }
+                def: 0
             },
 
             /**
              * Right padding of the table cell
              */
             paddingRight: {
-                def: 0,
-                format: function (element, value) {
-                    value = Utils.convertHmmToLength(value, 'px', 1);
-                    if (value < 2) { value = 2; }  // minimum 2px, required for cell resizing
-                    element.css('padding-right', value);
-                }
-            }
+                def: 0
+            },
 
+            /**
+             * Vertical merge of table cells.
+             */
+            mergeVert: {
+                def: 'noMerge'
+            }
         },
 
         // parent families with parent element resolver functions
@@ -174,6 +129,22 @@ define('io.ox/office/text/format/tablecellstyles', [
             table: function (cell) { return cell.closest(DOM.TABLE_NODE_SELECTOR); }
         };
 
+    // private global functions ===============================================
+
+    /**
+     * Converts the passed padding from 1/100 of millimeters to pixels.
+     *
+     * @param {Number} padding
+     *  The padding, in 1/100 of millimeters.
+     *
+     * @returns {Number}
+     *  The padding, in pixels.
+     */
+    function getPadding(padding) {
+        // minimum 2px, required for cell resizing
+        return Math.max(2, Utils.convertHmmToLength(padding, 'px', 1));
+    }
+
     // class TableCellStyles ==================================================
 
     /**
@@ -187,19 +158,71 @@ define('io.ox/office/text/format/tablecellstyles', [
      * @param {TextModel} docModel
      *  The text document model containing instance.
      */
-    function TableCellStyles(docModel) {
+    var TableCellStyles = StyleCollection.extend({ constructor: function (docModel) {
 
         // base constructor ---------------------------------------------------
 
         StyleCollection.call(this, docModel, 'cell', {
             styleSheetSupport: false,
             families: 'paragraph character changes',
-            parentResolvers: PARENT_RESOLVERS,
-            formatHandler: updateTableCellFormatting
+            parentResolvers: PARENT_RESOLVERS
         });
 
         // private methods ----------------------------------------------------
 
+        /**
+         * Will be called for every table cell for table preview generation.
+         * Formats the table cell according to the passed attributes.
+         *
+         * @param {jQuery} cell
+         *  The table cell element whose table attributes need to be formatted, as
+         *  jQuery object.
+         *
+         * @param {Object} mergedAttributes
+         *  A map of attribute value maps (name/value pairs), keyed by
+         *  attribute family, containing the effective attribute values merged
+         *  from style sheets and explicit attributes.
+         *
+         * @param {Object} [options]
+         *  Optional parameters passed to Border.getCssBorder().
+         */
+        function updateGenericFormatting(cell, mergedAttributes, options) {
+
+            // the cell attributes
+            var cellAttrs = mergedAttributes.cell;
+
+            cell.css({
+                backgroundColor: docModel.getCssColor(cellAttrs.fillColor, 'fill'),
+                borderLeft: docModel.getCssBorder(cellAttrs.borderLeft, null, options),
+                borderRight: docModel.getCssBorder(cellAttrs.borderRight, null, options),
+                borderTop: docModel.getCssBorder(cellAttrs.borderTop, null, options),
+                borderBottom: docModel.getCssBorder(cellAttrs.borderBottom, null, options)
+            });
+        }
+
+        /**
+         * Handling vertically merged cells, so that they are not visible to the user.
+         *
+         * @param {jQuery} cell
+         *  The table cell element whose table attributes need to be formatted, as
+         *  jQuery object.
+         *
+         * @param {Object} cellAttrs
+         *  The 'cell' family attributes of the merged cells.
+         */
+        function handleVerticallyMergedTableCells(cell, cellAttrs) {
+
+            var cellContentNode = DOM.getCellContentNode(cell);
+            var mergeVert = cellAttrs.mergeVert;
+
+            if (mergeVert === 'continue') {
+                cellContentNode.attr('contenteditable', false);
+                cellContentNode.css('visibility', 'hidden');
+            }
+
+            cell.attr('mergeVert', mergeVert); // setting marker attribute at cell
+        }
+
         /**
          * Will be called for every table cell element whose attributes have
          * been changed. Reformats the table cell according to the passed
@@ -216,8 +239,25 @@ define('io.ox/office/text/format/tablecellstyles', [
          */
         function updateTableCellFormatting(cell, mergedAttributes) {
 
-            var // the paragraph style sheet container
-                paragraphStyles = docModel.getStyleCollection('paragraph');
+            // the paragraph style sheet container
+            var paragraphStyles = docModel.getStyleCollection('paragraph');
+            // the cell attributes
+            var cellAttrs = mergedAttributes.cell;
+
+            // horizontal span size
+            cell.attr('colspan', cellAttrs.gridSpan);
+
+            // Hiding vertically merged cells to avoid impression of data loss (56291)
+            handleVerticallyMergedTableCells(cell, cellAttrs);
+
+            // update CSS attributes
+            updateGenericFormatting(cell, mergedAttributes);
+            cell.css({
+                paddingTop: getPadding(cellAttrs.paddingTop),
+                paddingBottom: getPadding(cellAttrs.paddingBottom),
+                paddingLeft: getPadding(cellAttrs.paddingLeft),
+                paddingRight: getPadding(cellAttrs.paddingRight)
+            });
 
             // Center cell content vertically. This solution is not dynamic
             // -> changing row height or inserting text destroys center position.
@@ -231,24 +271,40 @@ define('io.ox/office/text/format/tablecellstyles', [
 
             // change track attribute handling
             docModel.getChangeTrack().updateChangeTrackAttributes(cell, mergedAttributes);
+        }
 
+        /**
+         * Will be called for table cells used as preview elements in the GUI.
+         *
+         * @param {jQuery} cell
+         *  The preview table cell node, as jQuery object.
+         *
+         * @param {Object} mergedAttributes
+         *  A complete attribute set, containing the effective attribute values
+         *  merged from style sheets and explicit attributes.
+         */
+        function updatePreviewFormatting(cell, mergedAttributes) {
+            updateGenericFormatting(cell, mergedAttributes, { preview: true });
         }
 
         // initialization -----------------------------------------------------
 
         // register the attribute definitions for the style family
-        docModel.registerAttributeDefinitions('cell', DEFINITIONS);
+        docModel.registerAttributes('cell', DEFINITIONS);
+
+        // register the formatting handlers for DOM elements
+        this.registerFormatHandler(updateTableCellFormatting);
+        this.registerPreviewHandler(updatePreviewFormatting);
 
         // destroy all class members on destruction
         this.registerDestructor(function () {
             docModel = null;
         });
 
-    } // class TableCellStyles
+    } }); // class TableCellStyles
 
     // exports ================================================================
 
-    // derive this class from class StyleCollection
-    return StyleCollection.extend({ constructor: TableCellStyles });
+    return TableCellStyles;
 
 });
