@@ -365,16 +365,6 @@ define('io.ox/office/text/model/listhandlermixin', [
             return numberedListStyles;
         };
 
-        /**
-         * Getter for the default value.
-         *
-         * @returns {String}
-         *  The default constant value
-         */
-        this.getDefaultListValue = function () {
-            return ListHandlerMixin.DEFAULT_VALUE;
-        };
-
         /**
          * Check, whether the specified paragraph attribute set specifies a paragraph with
          * defined bullet type. The bullet can be a character, a number or a bitmap.
@@ -433,14 +423,6 @@ define('io.ox/office/text/model/listhandlermixin', [
 
     } // class ListHandlerMixin
 
-    // constants --------------------------------------------------------------
-
-    /**
-     * A constant that will be used in the GUI to represent the default style
-     * of bullet lists or numbered lists.
-     */
-    ListHandlerMixin.DEFAULT_VALUE = '__DEFAULT__';
-
     // exports ================================================================
 
     return ListHandlerMixin;
