@@ -51,7 +51,7 @@ define('io.ox/office/text/model/pagehandlermixin', [
         function pageProcessMouseDownHandler(event) {
 
             var // whether the user has privileges to edit the document
-                readOnly = self.getEditMode() !== true,
+                readOnly = !app.isEditable(),
                 // jQuerified target of the event
                 $eventTarget = $(event.target),
                 // mouse click on a table
@@ -223,6 +223,19 @@ define('io.ox/office/text/model/pagehandlermixin', [
             }
 
             if (tableCell.length > 0) {
+                if (DOM.isTablePageBreakRowNode(tableCell.parent())) {
+                    tableCell = tableCell.parent().next().children().eq(tableCell.index());
+                    tableCell = tableCell.find('.p').first();
+                    if (tableCell.length) { // if clicked on table cell in repeated row, try to find position in a same cell one row behind
+                        startPosition = Position.getOxoPosition(selection.getRootNode(), tableCell, 0);
+                        if (_.isArray(startPosition)) {
+                            startPosition.push(0);
+                            selection.setTextSelection(startPosition);
+                            event.preventDefault();
+                            return;
+                        }
+                    }
+                }
                 // saving initial cell as anchor cell for table cell selection
                 // -> this has to work also in read-only mode
                 tableCellPoint = DOM.Point.createPointForNode(tableCell);
