@@ -13,12 +13,13 @@
  */
 
 define('io.ox/office/text/model/updatedocumentmixin', [
+    'io.ox/office/drawinglayer/utils/drawingutils',
     'io.ox/office/drawinglayer/view/drawingframe',
+    'io.ox/office/editframework/utils/attributeutils',
     'io.ox/office/textframework/utils/config',
     'io.ox/office/textframework/utils/dom',
-    'io.ox/office/textframework/utils/textutils',
-    'io.ox/office/tk/utils/deferredutils'
-], function (DrawingFrame, Config, DOM, Utils, DeferredUtils) {
+    'io.ox/office/textframework/utils/textutils'
+], function (DrawingUtils, DrawingFrame, AttributeUtils, Config, DOM, Utils) {
 
     'use strict';
 
@@ -97,7 +98,7 @@ define('io.ox/office/text/model/updatedocumentmixin', [
         this.updateDocumentFormatting = function () {
 
             var // the result deferred object
-                def = DeferredUtils.createDeferred(app, 'UpdateDocumentMixin: updateDocumentFormatting'),
+                def = this.createDeferred('UpdateDocumentMixin.updateDocumentFormatting'),
                 // the page node
                 editdiv = self.getNode(),
                 // the content node of the page
@@ -192,6 +193,9 @@ define('io.ox/office/text/model/updatedocumentmixin', [
                         $(element).css({ width: 'auto' });
                     }
 
+                    // adding an implicit paragraph into shapes without paragraph (50644)
+                    if (!app.isODF()) { DrawingFrame.checkEmptyTextShape(self, element); }
+
                     // also updating all paragraphs inside text frames (not searching twice for the drawings)
                     self.implParagraphChangedSync($(element).find(DOM.PARAGRAPH_NODE_SELECTOR));
 
@@ -305,11 +309,11 @@ define('io.ox/office/text/model/updatedocumentmixin', [
             // abort first promise before calling function second time (avoid duplicate calls if first is not finished)
             if (initialPbPromise) { initialPbPromise.abort(); }
 
-            this.iterateArraySliced(formattingNodes, updateElementFormatting, { delay: 'immediate', infoString: 'Text: updateElementFormatting', app: app })
+            this.iterateArraySliced(formattingNodes, updateElementFormatting, 'UpdateDocumentMixin.updateElementFormatting')
                 // .then(updateDrawingGroups)
                 .then(updateListFormatting)
                 .then(function () { return pageLayout.callInitialPageBreaks({ triggerEvent: true }); })
-                .then(function () { return app.getModel().startParagraphMarginColorAndBorderFormating(); }) // must be after page-breaks
+                .then(function () { return self.startParagraphMarginColorAndBorderFormating(); }) // must be after page-breaks
                 .done(function () { dumpProfilingInformation(); def.resolve(); })
                 .fail(function () { def.reject(); });
 
