@@ -14,9 +14,10 @@
 
 define('io.ox/office/text/model/updatelistsmixin', [
     'io.ox/office/tk/io',
+    'io.ox/office/editframework/utils/attributeutils',
     'io.ox/office/textframework/utils/textutils',
     'io.ox/office/textframework/utils/dom'
-], function (IO, Utils, DOM) {
+], function (IO, AttributeUtils, Utils, DOM) {
 
     'use strict';
 
@@ -36,9 +37,7 @@ define('io.ox/office/text/model/updatelistsmixin', [
         var // self reference for local functions
             self = this,
             // collects information for debounced list update
-            updateListsDebouncedOptions = {},
-            // the debounced list handler function
-            updateListsDebounced = self.createDebouncedMethod(registerListUpdate, updateLists, { delay: 10, infoString: 'Text: updateLists', app: app });
+            updateListsDebouncedOptions = {};
 
         // private methods ----------------------------------------------------
 
@@ -307,7 +306,7 @@ define('io.ox/office/text/model/updatelistsmixin', [
                                 listSpans.css('font-style', (elementCharAttributes.italic || paraCharStyles.character.italic) ? 'italic' : 'normal');
                             }
 
-                            listSpans.css('text-decoration', self.getCssTextDecoration(elementCharAttributes));
+                            listSpans.css('text-decoration', AttributeUtils.getCssTextDecoration(elementCharAttributes));
 
                             if (elementCharAttributes.color || paraCharStyles.character.color) {
                                 listSpans.css('color', self.getCssColor((elementCharAttributes.color || paraCharStyles.character.color), 'text'));
@@ -337,7 +336,7 @@ define('io.ox/office/text/model/updatelistsmixin', [
                                 listSpans.css('font-style', (elementAttributes.character.italic || paraCharStyles.character.italic) ? 'italic' : 'normal');
                             }
 
-                            listSpans.css('text-decoration', self.getCssTextDecoration(elementAttributes.character));
+                            listSpans.css('text-decoration', AttributeUtils.getCssTextDecoration(elementAttributes.character));
 
                             if (elementAttributes.character.color || paraCharStyles.character.color) {
                                 listSpans.css('color', self.getCssColor((elementAttributes.character.color || paraCharStyles.character.color), 'text'));
@@ -432,11 +431,11 @@ define('io.ox/office/text/model/updatelistsmixin', [
                 // with the 'updateList' or 'removeLabel' (after backspace) data.
                 if (updateListsDebouncedOptions.paraInsert) {
                     paragraphNodes = paragraphNodes.filter(function () {
-                        return (DOM.isListLabelNode(this.firstChild) || $(this).data('updateList'));
+                        return DOM.isListParagraphNode(this) || $(this).data('updateList');
                     });
                 } else {
                     paragraphNodes = paragraphNodes.filter(function () {
-                        return DOM.isListLabelNode(this.firstChild);
+                        return DOM.isListParagraphNode(this);
                     });
                 }
 
@@ -456,7 +455,7 @@ define('io.ox/office/text/model/updatelistsmixin', [
             if (doNothing) {
                 def = $.when();
             } else if (Utils.getBooleanOption(options, 'async', false)) {
-                def = self.iterateArraySliced(paragraphNodes, updateListInParagraph, { delay: 'immediate', infoString: 'Text: updateListInParagraph', app: app });
+                def = self.iterateArraySliced(paragraphNodes, updateListInParagraph, 'UpdateListMixin.updateListInParagraph');
             } else {
                 paragraphNodes.each(function () { updateListInParagraph(this); });
                 def = $.when();
@@ -468,6 +467,9 @@ define('io.ox/office/text/model/updatelistsmixin', [
             return def.promise();
         }
 
+        // the debounced list handler function
+        var updateListsDebounced = this.createDebouncedMethod('UpdateListsMixin.updateListsDebounced', registerListUpdate, updateLists, { delay: 10 });
+
         // public methods -----------------------------------------------------
 
         /**
