@@ -16,7 +16,7 @@ define('io.ox/office/textframework/components/field/fieldmanager', [
     'io.ox/office/tk/utils/dateutils',
     'io.ox/office/tk/locale/localedata',
     'io.ox/office/tk/object/triggerobject',
-    'io.ox/office/tk/object/timermixin',
+    'io.ox/office/tk/forms',
     'io.ox/office/baseframework/app/appobjectmixin',
     'io.ox/office/textframework/utils/textutils',
     'io.ox/office/textframework/utils/operations',
@@ -25,7 +25,7 @@ define('io.ox/office/textframework/components/field/fieldmanager', [
     'io.ox/office/textframework/components/field/simplefield',
     'io.ox/office/textframework/components/field/complexfield',
     'gettext!io.ox/office/textframework/main'
-], function (DateUtils, LocaleData, TriggerObject, TimerMixin, AppObjectMixin, Utils, Operations, DOM, Position, SimpleField, ComplexField, gt) {
+], function (DateUtils, LocaleData, TriggerObject, Forms, AppObjectMixin, Utils, Operations, DOM, Position, SimpleField, ComplexField, gt) {
 
     'use strict';
 
@@ -133,8 +133,7 @@ define('io.ox/office/textframework/components/field/fieldmanager', [
 
         // base constructors --------------------------------------------------
 
-        TriggerObject.call(this);
-        TimerMixin.call(this);
+        TriggerObject.call(this, app);
         AppObjectMixin.call(this, app);
 
         // private methods ----------------------------------------------------
@@ -430,7 +429,7 @@ define('io.ox/office/textframework/components/field/fieldmanager', [
         function setDateFieldToAutoUpdate(event, state) {
             var node,
                 pos,
-                generator = model.createOperationsGenerator(),
+                generator = model.createOperationGenerator(),
                 operation = {},
                 // target for operation - if exists, it's for ex. header or footer
                 target = model.getActiveTarget(),
@@ -646,12 +645,19 @@ define('io.ox/office/textframework/components/field/fieldmanager', [
          *  jQuery object event triggered on hover in.
          */
         this.createHoverHighlight = function (event) {
-            var // id of the hovered field
-                id = DOM.getComplexFieldMemberId(event.currentTarget);
+            var id = DOM.getComplexFieldMemberId(event.currentTarget); // id of the hovered field
+            var node = self.getComplexField(id);
+            var instruction = DOM.getComplexFieldInstruction(node);
+            var isTOCfield = instruction && (/TOC/i).test(instruction);
+            var tooltipText = gt('Table of Contents. Right click...');
 
-            if (currentlyHighlightedId !== id) {
+            if (!isTOCfield && currentlyHighlightedId !== id) { // no highlighting of toc fields, #50504
                 rangeMarker.highLightRange(id, 'cx-field-highlight');
             }
+            // set tooltip to table of contents field element, if hyperlink switch is set in instruction
+            if (isTOCfield && (/\\h/i).test(instruction)) {
+                Forms.setToolTip(event.currentTarget, tooltipText);
+            }
 
             // fallback with jquery/css highlighting
             //model.getCurrentRootNode().find('.complex' + id).addClass('cx-field-highlight');
@@ -765,7 +771,7 @@ define('io.ox/office/textframework/components/field/fieldmanager', [
             if (highlightedFieldType && isSupportedFormat && isMouseTouchEvent && !isRightClick && isNotChangeTracked) {
                 fieldFormatPopupTimeout = self.executeDelayed(function () {
                     app.getView().showFieldFormatPopup(fieldinstruction, node, options);
-                }, { delay: 500, infoString: 'Text: FieldManager: fieldFormatPopupTimeout', app: app });
+                }, 'FieldManager.createEnterHighlight', 500);
             }
 
             // for debugging ->
@@ -867,7 +873,12 @@ define('io.ox/office/textframework/components/field/fieldmanager', [
 
                 field = isSimpleField ? self.getSimpleField(fieldId) : self.getComplexField(fieldId);
                 if (!field) {
-                    Utils.error('fieldmanager.updateAllFields(): no valid field fetched from the model: ', field);
+                    // this usually happens with nested fields, that are beeing deleted durring update of base level field,
+                    // where update was triggered from this method. Iterator still has references to this dynamically deleted fields,
+                    // but they are removed from document and model.
+                    // Not expected to break anything, therefore log level. For debugging, change to Utils.error
+                    Utils.log('fieldmanager.updateAllFields(): field with id: ' + fieldId + ' is not in the document anymore ');
+                    return;
                 }
                 if (!DOM.isMarginalNode(field) || !DOM.isInsideHeaderFooterTemplateNode(model.getNode(), field)) {
                     instruction = isSimpleField ? DOM.getFieldInstruction(field) : DOM.getComplexFieldInstruction(field);
@@ -881,7 +892,7 @@ define('io.ox/office/textframework/components/field/fieldmanager', [
             }
 
             if (self.fieldsAreInDocument()) {
-                mergedFields = _.extend(simpleField.getAllFields(), complexField.getAllFields());
+                mergedFields = _.extend({}, simpleField.getAllFields(), complexField.getAllFields());
 
                 // show a message with cancel button
                 app.getView().enterBusy({
@@ -894,7 +905,7 @@ define('io.ox/office/textframework/components/field/fieldmanager', [
                 });
 
                 // iterate objects
-                generateDef = self.iterateObjectSliced(mergedFields, handleFieldUpdate, { delay: 'immediate', infoString: 'Text: handleFieldUpdate', app: app })
+                generateDef = self.iterateObjectSliced(mergedFields, handleFieldUpdate, 'FieldManager.updateAllFields')
                 .always(function () {
                     // leave busy state
                     app.getView().leaveBusy().grabFocus();
@@ -935,7 +946,7 @@ define('io.ox/office/textframework/components/field/fieldmanager', [
          *  End offset of given node.
          */
         this.checkRestoringSpecialFields = function (searchNode, startOffset, endOffset) {
-            if (startOffset && endOffset) {
+            if (_.isNumber(startOffset) && _.isNumber(endOffset)) {
                 complexField.checkRestoringSpecialFields(searchNode, startOffset, endOffset);
             } else {
                 complexField.checkRestoringSpecialFieldsInContainer(searchNode); // if startOffset or endOffset are undefined, we search whole node. See #42235
@@ -1239,9 +1250,9 @@ define('io.ox/office/textframework/components/field/fieldmanager', [
                 }
             }
             // do nothing in read-only mode
-            if (!model.getEditMode()) { return; }
+            if (!app.isEditable()) { return; }
 
-            mergedFields = _.extend(simpleField.getAllFields(), complexField.getAllFields());
+            mergedFields = _.extend({}, simpleField.getAllFields(), complexField.getAllFields());
             _.each(mergedFields, handleFieldUpdate);
 
         };
@@ -1331,6 +1342,52 @@ define('io.ox/office/textframework/components/field/fieldmanager', [
             }
         };
 
+        /**
+         * Triggered by user from dropdown, inserts table of contents as complex field.
+         *
+         * @param {Number} value
+         *  Value of the type of toc picked by user from dropdown menu.
+         * @param {Object} [options]
+         *  @param {Boolean} [options.testMode=false]
+         *      When set to true, pagination is ignored.
+         *      Warning: used for speeding up unit tests only. Do not use this flag for other purposes!
+         *
+         * @returns {jQuery.Promise}
+         *  A promise that will be resolved if the insertion of table of contents
+         *  ended. It is rejected, if the dialog has been canceled.
+         */
+        this.dispatchInsertToc = function (value, options) {
+            var tabStyle = value === 2 ? 'none' : 'dot';
+            var fieldFormat = value === 3 ? 'TOC \\o "1-3" \\n \\h \\u' : 'TOC \\o "1-3" \\h \\u';
+            var testMode = Utils.getBooleanOption(options, 'testMode', false);
+
+            return complexField.insertTOCField(fieldFormat, { tabStyle: tabStyle, testMode: testMode });
+        };
+
+        /**
+         * Public accessor method to dispatch update of passed complex field node and instruction.
+         *
+         * @param {jQuery|Node} node
+         *  Complex field node
+         *
+         * @param {String|Array} format
+         *  Format of the field with switches. Can be one string, or array of strings.
+         *
+         * @param {Object} options
+         *  @param {String} options.tabStyle
+         *      Style of the tabstops in table of contents
+         *  @param {Boolean} [options.testMode=false]
+         *      When set to true, pagination is ignored.
+         *      Warning: used for speeding up unit tests only. Do not use this flag for other purposes!
+         *
+         * @returns {jQuery.Promise}
+         *  A promise that will be resolved if the insertion of table of contents
+         *  ended. It is rejected, if the dialog has been canceled.
+         */
+        this.dispatchUpdateTOC = function (node, instruction, options) {
+            return complexField.updateTOCField(node, instruction, options);
+        };
+
         /**
          * Clicking on remove button in popup, removes highlighted simple or complex field.
          */
@@ -1448,6 +1505,16 @@ define('io.ox/office/textframework/components/field/fieldmanager', [
             }
         };
 
+        /**
+         * Returns highlighted field type if is explicitly setr.
+         *
+         * @returns {String}
+         *  Highlighted field type.
+         */
+        this.getSelectedFieldType = function () {
+            return highlightedFieldType || '';
+        };
+
         /**
          * Returns highlighted field format, or default one.
          *
@@ -1495,7 +1562,7 @@ define('io.ox/office/textframework/components/field/fieldmanager', [
         this.cleanUpClassWhenDeleteCx = function (node) {
             var cxFieldContentSelector = 'complex' + DOM.getComplexFieldId(node);
 
-            selection.getRootNode().find('.' + cxFieldContentSelector).removeClass(cxFieldContentSelector + ' ' + DOM.COMPLEXFIELDMEMBERNODE_CLASS);
+            selection.getRootNode().find('.' + cxFieldContentSelector).removeClass(cxFieldContentSelector + ' ' + DOM.COMPLEXFIELDMEMBERNODE_CLASS).removeData('fieldId');
         };
 
         /**
@@ -1579,12 +1646,12 @@ define('io.ox/office/textframework/components/field/fieldmanager', [
         };
 
         /**
-         * Check if highlighted field is supported type by OX Text.
+         * Checks if highlighted field is supported type by OX Text.
          *
          * @returns {Boolean}
          */
         this.isSupportedFieldType = function () {
-            var supportedTypes = [/NUMPAGES/i, /PAGE/i, /^DATE/i, /^TIME/i, /FILE-?NAME/i, /^AUTHOR$/i, /^author-name$/, /^creator$/];
+            var supportedTypes = [/NUMPAGES/i, /PAGE/i, /^DATE/i, /^TIME/i, /TOC/, /FILE-?NAME/i, /^AUTHOR$/i, /^author-name$/, /^creator$/];
             var result = false;
 
             if (highlightedFieldType && !(/PAGEREF/i).test(highlightedFieldType)) {
@@ -1598,6 +1665,15 @@ define('io.ox/office/textframework/components/field/fieldmanager', [
             return result;
         };
 
+        /**
+         * Checks if highlighted field is Table of contents (TOC) field type.
+         *
+         * @returns {Boolean}
+         */
+        this.isTableOfContentsHighlighted = function () {
+            return highlightedFieldType && (/TOC/i).test(highlightedFieldType);
+        };
+
         /**
          * Check if currently highlighted field doesn't support format change.
          * Usually ODF autor and document name fields don't support this feature.
@@ -1606,7 +1682,7 @@ define('io.ox/office/textframework/components/field/fieldmanager', [
          * @return {Boolean}
          */
         this.supportsFieldFormatting = function () {
-            var unsupportedRegex = /(^author-name$)|(^creator$)|(^file-name$)/;
+            var unsupportedRegex = /(^author-name$)|(^creator$)|(^file-name$)|(^TOC$)/;
 
             return highlightedFieldType && !unsupportedRegex.test(highlightedFieldType);
         };
@@ -1641,17 +1717,33 @@ define('io.ox/office/textframework/components/field/fieldmanager', [
             return result;
         };
 
+        /**
+         * Convinience method to get number of all fields present in the document.
+         * If document is ODF, it will get count of simple fields,
+         * otherwise count of complex fields from coresponding models.
+         *
+         * @return {Number}
+         */
+        this.getCountOfAllFields = function () {
+            return simpleField.getAllFieldsCount() + complexField.getAllFieldsCount();
+        };
+
         // initialization -----------------------------------------------------
 
         app.onInit(function () {
-            var d1 = self.createDeferredObject({ infoString: 'FieldManager: app.onInit 1', app: app });
-            var d2 = self.createDeferredObject({ infoString: 'FieldManager: app.onInit 2', app: app });
+
+            var deferred1 = self.createDeferred('FieldManager.onInit#1');
+            var deferred2 = self.createDeferred('FieldManager.onInit#2');
 
             model = app.getModel();
             selection = model.getSelection();
             rangeMarker = model.getRangeMarker();
             numberFormatter = model.getNumberFormatter();
 
+            self.listenTo(app, 'docs:editmode:leave', function () {
+                self.destroyFieldPopup();
+            });
+
             self.waitForImportSuccess(function () {
                 if (model.isLocalStorageImport() || model.isFastLoadImport()) {
                     complexField.refreshComplexFields(model.isLocalStorageImport(), model.isFastLoadImport());
@@ -1660,7 +1752,7 @@ define('io.ox/office/textframework/components/field/fieldmanager', [
                     rangeMarker.refreshModel({ onlyOnce: true });
                 }
                 // resolve import success for update fields callback
-                d2.resolve();
+                deferred2.resolve();
 
                 // category codes loaded from local resource
                 categoryCodesDate = numberFormatter.getCategoryCodes('date');
@@ -1697,18 +1789,23 @@ define('io.ox/office/textframework/components/field/fieldmanager', [
 
             self.waitForImportFailure(function () {
                 // reject promise on import failed, so that update fields doesn't hang
-                d1.reject();
-                d2.reject();
+                deferred1.reject();
+                deferred2.reject();
             });
 
             self.listenTo(app, 'docs:beforequit', function () {
-                d1.reject();
-                d2.reject();
+                deferred1.reject();
+                deferred2.reject();
             });
 
-            model.one('pageBreak:after initialPageBreaks:done', function () { return d1.resolve(); });
+            // mark all complex fields contents after undo/redo
+            self.listenTo(model.getUndoManager(), 'undo:after redo:after', function () {
+                complexField.markAllFieldsAfterUndo();
+            });
+
+            model.one('pageBreak:after initialPageBreaks:done', function () { return deferred1.resolve(); });
             // only when import is finished and page breaks are rendered call update fields
-            $.when(d1, d2).then(updateFieldsCallback);
+            $.when(deferred1, deferred2).then(updateFieldsCallback);
 
             selection.on('position:calculated', checkRangeSelection);
             selection.on('update', checkHighlighting);
@@ -1727,6 +1824,8 @@ define('io.ox/office/textframework/components/field/fieldmanager', [
             simpleField.destroy();
             complexField.destroy();
             model = selection = rangeMarker = numberFormatter = null;
+            currentlyHighlightedNode = authorFileNameArray = pageNumberArray = localFormatList = null;
+            categoryCodesDate = categoryCodesTime = categoryCodesDateTime = tempSpecFieldCollection = complexFieldStackId = null;
         });
 
     } // class FieldManager
