@@ -349,6 +349,15 @@ define('io.ox/office/textframework/components/field/simplefield', [
             return allSimpleFields;
         };
 
+        /**
+         * Public method to get number of all simple fields from model.
+         *
+         * @returns {Number}
+         */
+        this.getAllFieldsCount = function () {
+            return _.size(allSimpleFields);
+        };
+
         /**
          * Gets simple field from collection by passed id.
          *
@@ -618,7 +627,7 @@ define('io.ox/office/textframework/components/field/simplefield', [
 
             _.each(allSimpleFields, function (id, fieldEntry) {
                 var field = self.getSimpleField(fieldEntry);
-                if (model.getEditMode() && !DOM.isFixedSimpleField(field, app.isODF()) && (!DOM.isMarginalNode(field) || !DOM.isInsideHeaderFooterTemplateNode(model.getNode(), field))) {
+                if (app.isEditable() && !DOM.isFixedSimpleField(field, app.isODF()) && (!DOM.isMarginalNode(field) || !DOM.isInsideHeaderFooterTemplateNode(model.getNode(), field))) {
                     // if previously updated field is marginal, and this is not, leave header edit state
                     selection.swichToValidRootNode(field);
                     self.updateDateTimeField(field, DOM.getFieldInstruction(field));
@@ -696,7 +705,7 @@ define('io.ox/office/textframework/components/field/simplefield', [
             return model.getUndoManager().enterUndoGroup(function () {
                 function doInsertField() {
                     var start = selection.getStartPosition(),
-                        generator = model.createOperationsGenerator(),
+                        generator = model.createOperationGenerator(),
                         operation = {},
                         // target for operation - if exists, it's for ex. header or footer
                         target = model.getActiveTarget(),
@@ -910,7 +919,7 @@ define('io.ox/office/textframework/components/field/simplefield', [
 
         // destroy all class members on destruction
         this.registerDestructor(function () {
-            model = selection = pageLayout = changeTrack = numberFormatter = null;
+            self = model = selection = pageLayout = changeTrack = numberFormatter = allSimpleFields = null;
         });
 
     } // class SimpleField
