@@ -388,7 +388,7 @@ define('io.ox/office/textframework/components/hyperlink/hyperlink', [
 
         var hyperlinkStyleId = editor.getDefaultUIHyperlinkStylesheet(),
             characterStyles = editor.getStyleCollection('character'),
-            generator = editor.createOperationsGenerator(),
+            generator = editor.createOperationGenerator(),
             operationProperties = {},
             removeHyperLinkAttributes = Utils.getBooleanOption(options, 'removeHyperLinkAttributes', false);
 
@@ -453,7 +453,7 @@ define('io.ox/office/textframework/components/hyperlink/hyperlink', [
      */
     Hyperlink.removeHyperlink = function (editor, start, end) {
 
-        var generator = editor.createOperationsGenerator();
+        var generator = editor.createOperationGenerator();
 
         generator.generateOperation(Operations.SET_ATTRIBUTES, {
             attrs: Hyperlink.CLEAR_ATTRIBUTES,
