@@ -14,17 +14,16 @@
 
 define('io.ox/office/textframework/components/rangemarker/rangemarker', [
     'io.ox/office/tk/object/triggerobject',
-    'io.ox/office/tk/object/timermixin',
     'io.ox/office/baseframework/app/appobjectmixin',
     'io.ox/office/textframework/utils/operations',
     'io.ox/office/textframework/utils/textutils',
     'io.ox/office/textframework/utils/dom',
     'io.ox/office/textframework/utils/position'
-], function (TriggerObject, TimerMixin, AppObjectMixin, Operations, Utils, DOM, Position) {
+], function (TriggerObject, AppObjectMixin, Operations, Utils, DOM, Position) {
 
     'use strict';
 
-    // class RangeMarker =====================================================
+    // class RangeMarker ======================================================
 
     /**
      * An instance of this class represents the model for all markers in the
@@ -33,7 +32,6 @@ define('io.ox/office/textframework/components/rangemarker/rangemarker', [
      * @constructor
      *
      * @extends TriggerObject
-     * @extends TimerMixin
      * @extends AppObjectMixin
      *
      * @param {TextApplication} app
@@ -62,8 +60,7 @@ define('io.ox/office/textframework/components/rangemarker/rangemarker', [
 
         // base constructors --------------------------------------------------
 
-        TriggerObject.call(this);
-        TimerMixin.call(this);
+        TriggerObject.call(this, app);
         AppObjectMixin.call(this, app);
 
         // private methods ----------------------------------------------------
@@ -556,7 +553,7 @@ define('io.ox/office/textframework/components/rangemarker/rangemarker', [
                 // the range marker end node
                 endNode = self.getEndMarker(id),
                 // the current zoom factor
-                zoomFactor = app.getView().getZoomFactor(),
+                zoomFactor = app.getView().getZoomFactor() * 100,
                 // the parent nodes of the start and end node
                 startParentNode = null, endParentNode = null,
                 // the pixel positions of the range marker nodes and its parents
@@ -661,7 +658,8 @@ define('io.ox/office/textframework/components/rangemarker/rangemarker', [
                     endParentNode = endNode.parent();
 
                     // the width of the body overlay node is the maximum of the parents widths
-                    bodyWidth = Math.max(startParentNode.width(), endParentNode.width());
+                    // -> using outerWidth() instead of width() to include the padding (51588)
+                    bodyWidth = Math.max(startParentNode.outerWidth(), endParentNode.outerWidth());
 
                     // start and end node are empty lines (paragraphs)
                     if (!bodyWidth) { bodyWidth = pageNode.width(); }
@@ -673,7 +671,7 @@ define('io.ox/office/textframework/components/rangemarker/rangemarker', [
                     headOverlay.css({
                         top: startPos.y,
                         left: startPos.x,
-                        width: isListRange ? startParentPos.x + startParentNode.width() - startPos.x + startPrevNodeWidth : startParentPos.x  + startParentNode.width() - startPos.x,
+                        width: isListRange ? startParentPos.x + startParentNode.width() - startPos.x + startPrevNodeWidth : startParentPos.x  + startParentNode.outerWidth() - startPos.x,
                         height: startLineHeight
                     });
 
