@@ -21,9 +21,8 @@ define('io.ox/office/textframework/components/searchhandler/searchhandler', [
     'io.ox/office/textframework/view/labels',
     'io.ox/office/tk/object/triggerobject',
     'io.ox/office/drawinglayer/view/drawingframe',
-    'io.ox/office/tk/utils/deferredutils',
     'gettext!io.ox/office/textframework/main'
-], function (AttributeUtils, Utils, Operations, DOM, Position, Labels, TriggerObject, DrawingFrame, DeferredUtils, gt) {
+], function (AttributeUtils, Utils, Operations, DOM, Position, Labels, TriggerObject, DrawingFrame, gt) {
 
     'use strict';
 
@@ -56,7 +55,7 @@ define('io.ox/office/textframework/components/searchhandler/searchhandler', [
 
         // base constructor ---------------------------------------------------
 
-        TriggerObject.call(this);
+        TriggerObject.call(this, app);
 
         // private methods ----------------------------------------------------
 
@@ -259,7 +258,7 @@ define('io.ox/office/textframework/components/searchhandler/searchhandler', [
 
                     selection.setTextSelection(result.start, result.end);
                 }
-            }, { infoString: 'SearchHandler: selectSearchResult', app: app });
+            }, 'SearchHandler.selectSearchResult');
         }
 
         function handleNoResult() {
@@ -567,7 +566,7 @@ define('io.ox/office/textframework/components/searchhandler/searchhandler', [
             }
 
             // create and return the debounced method Editor.debouncedQuickSearch()
-            return model.createDebouncedMethod(storeParameters, executeQuickSearch, { delay: 2000, infoString: 'SearchHandler debouncedQuickSearch()', app: app });
+            return model.createDebouncedMethod('SearchHandler.debouncedQuickSearch', storeParameters, executeQuickSearch, { delay: 2000 });
 
         }()); // Editor.debouncedQuickSearch()
 
@@ -869,11 +868,11 @@ define('io.ox/office/textframework/components/searchhandler/searchhandler', [
             undoManager.enterUndoGroup(function () {
 
                 var // the deferred to keep the undo group open until it is resolved or rejected
-                    undoDef = DeferredUtils.createDeferred(app, 'SearchHandler: searchAndReplaceAll'),
+                    undoDef = self.createDeferred('SearchHandler.searchAndReplaceAll'),
                     // the apply actions deferred
                     applyDef = null,
                     // the operations generator
-                    generator = model.createOperationsGenerator(),
+                    generator = model.createOperationGenerator(),
                     // the collector for all paragraphs inside text frames
                     paragraphInTextFrameCollector = [],
                     // the collector for all paragraphs not inside text frames
