@@ -11,20 +11,30 @@
  *
  * @author Stefan Eckert <stefan.eckert@open-xchange.com>
  * @author Ingo Schmidt-Rosbiegal <ingo.schmidt-rosbiegal@open-xchange.com>
+ * @author York Richter <york.richter@open-xchange.com>
  */
 
 define('io.ox/office/textframework/components/spellcheck/spellchecker', [
+
     'io.ox/office/tk/utils',
+
     'io.ox/office/tk/locale/localedata',
     'io.ox/office/tk/object/triggerobject',
+
+    'io.ox/office/settings/userdictionary',
+    'io.ox/office/settings/spellchecking',
+    'io.ox/office/settings/spellchecklanguagenotification',
+
     'io.ox/office/baseframework/app/appobjectmixin',
+
     'io.ox/office/textframework/utils/config',
     'io.ox/office/textframework/utils/dom',
     'io.ox/office/textframework/utils/position',
     'io.ox/office/textframework/utils/textutils',
-    'io.ox/office/settings/userdictionary',
+
     'gettext!io.ox/office/textframework/main'
-], function (Utils, LocaleData, TriggerObject, AppObjectMixin, Config, DOM, Position, TextUtils, UserDictionary, gt) {
+
+], function (Utils, LocaleData, TriggerObject, UserDictionary, SpellChecking, SpellcheckNotification, AppObjectMixin, Config, DOM, Position, TextUtils, gt) {
 
     'use strict';
 
@@ -38,18 +48,17 @@ define('io.ox/office/textframework/components/spellcheck/spellchecker', [
      * @extends TriggerObject
      * @extends AppObjectMixin
      *
-     * @param {TextApplication} app
-     *  The application instance.
-     *
-     * @param {Object} model
+     * @param {Editor} model
      *  The text editor model.
      */
-    function SpellChecker(app, model) {
+    function SpellChecker(model, initOptions) {
 
         var // self reference for local functions
             self = this,
-            // online spelling mode off
-            onlineSpelling = Config.SPELLING_ENABLED && app.getUserSettingsValue('onlineSpelling'),
+            // the application instance
+            app = model.getApp(),
+            // online spelling mode off (there are no app specific spell-check user settings anymore due to DOCS-630)
+            spellingSupported = Config.SPELLING_ENABLED && Utils.getBooleanOption(initOptions, 'spellingSupported', false),
             // the scroll node
             scrollNode = null,
             // collects replacements of misspelled words by locale
@@ -62,14 +71,16 @@ define('io.ox/office/textframework/components/spellcheck/spellchecker', [
             unsupportedLanguageWithoutNotification = [],
             // list of unsupported languages with a notification
             unsupportedLanguages = [],
-            // show the Notification if unsupported languages exist
-            showUnsupportedLanguageNotificationDebounced = model.createDebouncedMethod($.noop, showUnsupportedLanguageNotification, { delay: 1000, infoString: 'Text: spellchecker.showUnsupportedLanguageNotification', app: app }),
+
+            // in case a page does start as empty it will flag whether it always stod empty or if it, at one point, did contain real text content.
+            hasPageAlwaysBeenEmpty = true, // the `true` value default will be overwritten exactly once as soon as the page starts carrying content.
+
+            // list of all languages that are not supposed to be notified about theirs missing spell-check(er) support.
+            spellcheckLanguageBlacklist = [],
             // local list of misspelled words which are ignored by the user
             ignoredMisspelledWords = _.clone(UserDictionary.getDictionary()),
             // The undo manager
             undoManager = model.getUndoManager(),
-            // A debounced function for starting adding or removing ignored words
-            implStartAddOrRemoveIgnoreWordsDebounced = model.createDebouncedMethod($.noop, implStartAddOrRemoveIgnoreWords, { delay: 500, infoString: 'Text: spellchecker.implStartOnlineSpelling', app: app }),
             // ignore actions for add or remove a ignore word, it will be used in the 'implStartAddOrRemoveIgnoreWords' function
             ignoreWordActions = [],
             // counter to set a unique request id
@@ -86,9 +97,10 @@ define('io.ox/office/textframework/components/spellcheck/spellchecker', [
                     implStartOnlineSpellingDebounced();
                 }
             };
+
         // base constructor ---------------------------------------------------
 
-        TriggerObject.call(this);
+        TriggerObject.call(this, model);
         AppObjectMixin.call(this, app);
 
         // private methods ----------------------------------------------------
@@ -106,7 +118,7 @@ define('io.ox/office/textframework/components/spellcheck/spellchecker', [
         function implStartOnlineSpelling() {
             // # 51390: Spellchecking can interrupt an active composition by manipulating
             // DOM nodes. Make sure that this doesn't happen.
-            if (onlineSpelling && model.getEditMode() && (_.isFunction(model.isImeActive) && !model.isImeActive()) && self.isImportFinished()) {
+            if (self.isOnlineSpelling() && app.isEditable() && (_.isFunction(model.isImeActive) && !model.isImeActive()) && self.isImportFinished()) {
                 implCheckSpelling();
             }
         }
@@ -114,7 +126,7 @@ define('io.ox/office/textframework/components/spellcheck/spellchecker', [
         /**
          * A debounced function for starting spell checking by calling 'implStartOnlineSpelling'
          */
-        var implStartOnlineSpellingDebounced = model.createDebouncedMethod($.noop, implStartOnlineSpelling, { delay: 1000, infoString: 'Text: spellchecker.implStartOnlineSpelling', app: app });
+        var implStartOnlineSpellingDebounced = model.createDebouncedMethod('SpellChecker.implStartOnlineSpellingDebounced', null, implStartOnlineSpelling, { delay: 1000 });
 
         /**
          * Receiving a list of replacement words for a specified word in a specified language from
@@ -433,10 +445,14 @@ define('io.ox/office/textframework/components/spellcheck/spellchecker', [
                 selection.restoreBrowserSelection({ preserveFocus: true });
             }
 
-            return;
         });
 
         var wordIterator = function (paraSpans, textSpans) {
+
+            // - provide/get a list of all languages that are not supposed to be notified about theirs missing spell-check(er) support.
+            // - a user though, is able of editing this very list from within one's document settings.
+            spellcheckLanguageBlacklist = SpellcheckNotification.getLanguageBlacklist();
+
             return function (node) {
 
                 // iterating over all text spans
@@ -483,7 +499,7 @@ define('io.ox/office/textframework/components/spellcheck/spellchecker', [
 
             // Slicing, so that there are not too many parallel server calls
             // -> it is useful to profile the sliced function using 'Utils.profileMethod' in following performance tests.
-            model.iterateArraySliced(allParagraphs, function (paragraph) {
+            var promise = model.iterateArraySliced(allParagraphs, function (paragraph) {
 
                 var // all text spans in the paragraph, as array
                     textSpans,
@@ -542,16 +558,18 @@ define('io.ox/office/textframework/components/spellcheck/spellchecker', [
                             removeAllSpellErrorsInParagraph(paragraph);
                         }
 
-                        // trigger dialog if unsupported languages without a notification exist.
-                        if (!_.isEmpty(unsupportedLanguageWithoutNotification)) {
+                        // - trigger dialog if unsupported languages without a notification exist.
+                        // - always prevent dialog if app runs within an automated test environment.
+                        if (!Config.AUTOTEST && !_.isEmpty(unsupportedLanguageWithoutNotification)) {
                             showUnsupportedLanguageNotificationDebounced();
                         }
                     }
                 }
-            }, { delay: 'immediate', infoString: 'Spellchecker: implCheckSpelling', app: app })
-                .always(function () {
-                    paragraphCache = $();
-                });
+            }, 'Spellchecker.implCheckSpelling');
+
+            promise.always(function () {
+                paragraphCache = $();
+            });
         }
 
         /**
@@ -564,6 +582,7 @@ define('io.ox/office/textframework/components/spellcheck/spellchecker', [
             if (self.isOnlineSpelling()) {
                 self.setOnlineSpelling(true, true);
             }
+            SpellcheckNotification.registerEditSettingsAction(app);
         }
 
         /**
@@ -596,13 +615,16 @@ define('io.ox/office/textframework/components/spellcheck/spellchecker', [
          * Start adding or removing ignored words.
          */
         function implStartAddOrRemoveIgnoreWords() {
-            if (onlineSpelling && model.getEditMode() && self.isImportFinished()) {
+            if (self.isOnlineSpelling() && app.isEditable() && self.isImportFinished()) {
                 while (ignoreWordActions.length > 0) {
                     implAddWordToIgnoreSpellcheck(ignoreWordActions.shift());
                 }
             }
         }
 
+        // A debounced function for starting adding or removing ignored words
+        var implStartAddOrRemoveIgnoreWordsDebounced = this.createDebouncedMethod('Spellchecker.implStartAddOrRemoveIgnoreWordsDebounced', null, implStartAddOrRemoveIgnoreWords, { delay: 500 });
+
         /**
          * Add or remove a word to/from the ignore word list.
          * ignoreWordAction.node or ignoreWordAction.start/ignoreWordAction.end are optional BUT at least one must be set.
@@ -688,16 +710,17 @@ define('io.ox/office/textframework/components/spellcheck/spellchecker', [
             var word = ignoreWord.toLowerCase(),
                 paragraphs = model.getNode().find(DOM.PARAGRAPH_NODE_SELECTOR + '.p_spelled');
 
-            model.iterateArraySliced(paragraphs, function (paragraph) {
+            var promise = model.iterateArraySliced(paragraphs, function (paragraph) {
                 if ((remove || self.hasSpellResultCache(paragraph)) && $(paragraph).text().toLowerCase().indexOf(word) >= 0) {
                     self.resetDirectly(paragraph);
                     self.clearSpellResultCache(paragraph);
                 }
-            }, { delay: 'immediate', infoString: 'Spellchecker: implAddWordToIgnoreSpellcheck', app: app })
-                .always(function () {
-                    paragraphCache = $();
-                    implStartOnlineSpellingDebounced();
-                });
+            }, 'Spellchecker.implAddWordToIgnoreSpellcheck');
+
+            promise.always(function () {
+                paragraphCache = $();
+                implStartOnlineSpellingDebounced();
+            });
         }
 
         /**
@@ -726,7 +749,11 @@ define('io.ox/office/textframework/components/spellcheck/spellchecker', [
          * @param {String} lang the language local e.g. en-US
          */
         function addUnsupportedLanguageForNotification(lang) {
-            if (!_.contains(unsupportedLanguages, lang) && !_.contains(unsupportedLanguageWithoutNotification, lang)) {
+            if (
+                !_.contains(unsupportedLanguages, lang) &&
+                !_.contains(unsupportedLanguageWithoutNotification, lang) &&
+                !_.contains(spellcheckLanguageBlacklist, lang)
+            ) {
                 unsupportedLanguageWithoutNotification.push(lang);
             }
         }
@@ -736,11 +763,23 @@ define('io.ox/office/textframework/components/spellcheck/spellchecker', [
          * The dialog appears only once for each language.
          */
         function showUnsupportedLanguageNotification() {
-            var langText,
+            var
+                msg,
+                langText,
+
                 addComma = false,
-                showDialog = false;
-            if (!_.isEmpty(unsupportedLanguageWithoutNotification)) {
-                var msg = gt('This document contains text in languages which couldn\'t be proofed: ');
+                showDialog = false,
+
+                // see: https://bugs.open-xchange.com/show_bug.cgi?id=50880
+                //
+                // - does prevent raising the dialog right after having opened an entirely empty page.
+                // - does work with guarding flag since `model.isEmptyPage()` is quite expensive and will be invoked otherwise every second.
+                isPageConsideredEmpty = (hasPageAlwaysBeenEmpty && (hasPageAlwaysBeenEmpty = model.isEmptyPage())),
+
+                isLanguageNotification = !_.isEmpty(unsupportedLanguageWithoutNotification);
+
+            if (!isPageConsideredEmpty && isLanguageNotification) {
+                msg = gt('This document contains text in languages which couldn\'t be proofed: ');
 
                 _.each(unsupportedLanguageWithoutNotification, function (lang) {
 
@@ -756,18 +795,28 @@ define('io.ox/office/textframework/components/spellcheck/spellchecker', [
                         showDialog = true;
                     }
                     unsupportedLanguages.push(lang);
-
                 });
+
+                // immediately save any newly detected language into the spell-check language whitelist.
+                SpellcheckNotification.saveToLanguageWhitelist(unsupportedLanguages);
+
                 if (showDialog) {
                     app.getView().yell({
-                        message: msg
+                        message: msg,
+                        action: {
+                            itemKey: 'document/settings/editspellchecknotification',
+                            label: /*#. Button label for open the user spell-check languages dialog */gt('Set language notification.'),
+                            icon: 'fa-cog'
+                        }
                     });
                 }
-
                 unsupportedLanguageWithoutNotification = [];
             }
         }
 
+        // show the Notification if unsupported languages exist
+        var showUnsupportedLanguageNotificationDebounced = this.createDebouncedMethod('SpellChecker.showUnsupportedLanguageNotificationDebounced', null, showUnsupportedLanguageNotification, { delay: 1000 });
+
         function restoreTextSelection() {
             var selection;
             if (restoreStartPosition) {
@@ -782,9 +831,10 @@ define('io.ox/office/textframework/components/spellcheck/spellchecker', [
          * Set or remove the event listeners
          */
         function setEventListeners() {
-            if (onlineSpelling) {
+            if (self.isOnlineSpelling()) {
                 // after receiving edit privileges it is necessary to check the document
-                self.listenTo(model, 'change:editmode operations:success', implStartOnlineSpellingDebounced);
+                self.listenTo(app, 'docs:editmode:enter', implStartOnlineSpellingDebounced);
+                self.listenTo(model, 'operations:success', implStartOnlineSpellingDebounced);
 
                 self.listenTo(scrollNode, 'scroll', implStartOnlineSpellingDebounced);
 
@@ -795,13 +845,23 @@ define('io.ox/office/textframework/components/spellcheck/spellchecker', [
                 // now the spellchecker must start to check the text with the updated dictionary.
                 self.listenTo(app.getWindow(), 'show', appVisibleHandler);
             } else {
-                self.stopListeningTo(model, 'change:editmode operations:success', implStartOnlineSpellingDebounced);
+                self.stopListeningTo(app, 'docs:editmode:enter', implStartOnlineSpellingDebounced);
+                self.stopListeningTo(model, 'operations:success', implStartOnlineSpellingDebounced);
                 self.stopListeningTo(scrollNode, 'scroll', implStartOnlineSpellingDebounced);
                 self.stopListeningTo(UserDictionary, 'save', onSaveUserDictionary);
                 self.stopListeningTo(app.getWindow(), 'show', appVisibleHandler);
             }
         }
 
+        /**
+         * After the event 'document:reloaded' was fired by the model, some cached nodes and caches
+         * need to be invalidated.
+         */
+        function handleDocumentReload() {
+            // invalidating paragraph cache, after the document was reloaded
+            paragraphCache = $();
+        }
+
         // public methods -----------------------------------------------------
 
         this.getSpellErrorWord = function () {
@@ -983,18 +1043,19 @@ define('io.ox/office/textframework/components/spellcheck/spellchecker', [
          * Toggle automatic spell checking in the document.
          */
         this.setOnlineSpelling = function (state, noConfig) {
+            if (!spellingSupported) { return; }
             var rootNode = model.getNode(),
-                stateChange = state !== onlineSpelling;
+                stateChange = state !== self.isOnlineSpelling();
             if (stateChange || noConfig === true) {
-                onlineSpelling = state;
                 if (noConfig !== true) {
-                    app.setUserSettingsValue('onlineSpelling', onlineSpelling);
+                    // there are no app specific spell-check user settings anymore due to DOCS-630
+                    SpellChecking.setOnlineSpelling(state);
                 }
-                rootNode.toggleClass('spellerror-visible', onlineSpelling);
+                rootNode.toggleClass('spellerror-visible', state);
 
                 setEventListeners();
 
-                if (onlineSpelling) {
+                if (self.isOnlineSpelling()) {
                     // deleting the paragraph cache, so that all paragraphs are checked
                     paragraphCache = $();
                     // start timeout handler
@@ -1005,7 +1066,7 @@ define('io.ox/office/textframework/components/spellcheck/spellchecker', [
                         removeAllSpellErrorsInParagraph(paragraph);
                         $(paragraph).removeClass('p_spelled');
                         self.clearSpellResultCache(paragraph);
-                    }, { infoString: 'Spellchecker: setOnlineSpelling', app: app });
+                    }, 'Spellchecker.setOnlineSpelling');
                     paragraphCache = $();
                 }
             }
@@ -1018,7 +1079,7 @@ define('io.ox/office/textframework/components/spellcheck/spellchecker', [
          *  Whether spellcheck in config and in user-hud is enabled
          */
         this.isOnlineSpelling = function () {
-            return onlineSpelling;
+            return spellingSupported && SpellChecking.isOnlineSpelling();
         };
 
         /**
@@ -1129,6 +1190,11 @@ define('io.ox/office/textframework/components/spellcheck/spellchecker', [
             self.waitForImportSuccess(documentLoaded);
         });
 
+        app.onInit(function () {
+            // updating the model after the document was reloaded (after cancelling long running actions)
+            self.listenTo(model, 'document:reloaded', handleDocumentReload);
+        });
+
     } // class SpellChecker
 
     // constants --------------------------------------------------------------
