@@ -125,7 +125,7 @@ define('io.ox/office/textframework/components/table/tableresize', [
                 // minimum height of a row in px
                 minRowHeight = 5,
                 //zoom factor in floating point notation
-                zoomFactor = view.getZoomFactor() / 100,
+                zoomFactor = view.getZoomFactor(),
                 // the current scroll position
                 scrollX = 0, scrollY = 0,
                 // the start scroll position
@@ -334,7 +334,7 @@ define('io.ox/office/textframework/components/table/tableresize', [
              */
             function stopResizeTable(event) {
 
-                var generator = editor.createOperationsGenerator(),
+                var generator = editor.createOperationGenerator(),
                     rowPosition = null,
                     rowHeight = 0,
                     newRowHeight = 0, oldRowHeight = 0,
@@ -568,6 +568,10 @@ define('io.ox/office/textframework/components/table/tableresize', [
                         generator.generateOperation(Operations.SET_ATTRIBUTES, operationProperties);
 
                         editor.applyOperations(generator);
+
+                        if (editor.getApp().isODF() && editor.useSlideMode()) { // table height must be send to the filter via operation
+                            editor.trigger('drawingHeight:update', drawingNode ? drawingNode : rowNode.closest('div.drawing'));
+                        }
                     }
                 }
 
