@@ -27,17 +27,11 @@ define('io.ox/office/textframework/format/characterstyles', [
         DEFINITIONS = {
 
             fontName: {
-                def: 'Arial',
-                preview: function (element, fontName) {
-                    element.css('font-family', this.getCssFontFamily(fontName));
-                }
+                def: AttributeUtils.MINOR_FONT_KEY
             },
 
             fontNameSymbol: {
-                def: '',
-                preview: function (element, fontName) {
-                    element.css('font-family', this.getCssFontFamily(fontName));
-                }
+                def: ''
             },
 
             fontNameComplex: {
@@ -49,28 +43,15 @@ define('io.ox/office/textframework/format/characterstyles', [
             },
 
             fontSize: {
-                def: 11,
-                // format: done together with escapement in the format handler
-                preview: function (element, fontSize) {
-                    fontSize = Utils.round(10 + (fontSize - 10) / 1.5, 0.1);
-                    element.css('font-size', Utils.minMax(fontSize, 6, 22) + 'pt');
-                }
+                def: 11
             },
 
             bold: {
-                def: false,
-                format: function (element, state) {
-                    element.css('font-weight', state ? 'bold' : 'normal');
-                },
-                preview: true // 'true' calls the own 'format' method
+                def: false
             },
 
             italic: {
-                def: false,
-                format: function (element, state) {
-                    element.css('font-style', state ? 'italic' : 'normal');
-                },
-                preview: true // 'true' calls the own 'format' method
+                def: false
             },
 
             underline: {
@@ -81,65 +62,50 @@ define('io.ox/office/textframework/format/characterstyles', [
                 def: 'none'
             },
 
+            caps: {
+                def: 'none'
+            },
+
             // baseline for Text
-            vertAlign: { def: 'baseline' },
+            vertAlign: {
+                def: 'baseline'
+            },
 
             // baseline for Presentation
-            baseline: { def: 0 },
+            baseline: {
+                def: 0
+            },
 
             color: {
-                def: Color.AUTO,
-                // format: color will be set in format handler, depending on fill colors
-                preview: function (element, color) {
-                    var colorModel = this.resolveColor(Color.parseJSON(color), 'text');
-                    if (colorModel.y > 0.95) {
-                        //white text on white background is bad, we do the MS-Word trick (Bug 40872)
-                        element.css('color', 'black');
-                    } else {
-                        element.css('color', colorModel.css);
-                    }
-                }
+                def: Color.AUTO
             },
 
             fillColor: {
-                def: Color.AUTO,
-                format: function (element, color) {
-                    element.css('background-color', this.getCssColor(color, 'fill'));
-                }
+                def: Color.AUTO
             },
 
             language: {
-                def: '',
-                format: function (element, value) {
-                    element.attr('lang', value);
-                }
+                def: ''
             },
 
             url: {
                 def: '',
-                scope: 'element',
-                format: function (element, url) {
-                    if (_.isString(url) && (url.length > 0)) {
-                        element.attr('title', url);
-                        element.attr('data-hyperlink-url', url);
-                    } else {
-                        element.removeAttr('title');
-                        element.removeAttr('data-hyperlink-url');
-                    }
-                }
+                scope: 'element'
+            },
+
+            anchor: {
+                def: '',
+                scope: 'element'
             },
 
             autoDateField: {
                 def: '',
-                format: function (element, value) {
-                    if (value) {
-                        element.attr('data-auto-date', value);
-                    }
-                }
+                scope: 'element'
             },
 
             field: {
-                def: '' // #45332, new odf filter sends field properties as character attribute
+                def: '', // #45332, new odf filter sends field properties as character attribute
+                scope: 'element'
             },
 
             // special attributes
@@ -147,29 +113,14 @@ define('io.ox/office/textframework/format/characterstyles', [
             spellerror: {
                 def: false,
                 scope: 'element',
-                format: function (element, state) {
-                    element.toggleClass('spellerror', state);
-                },
                 special: true
             },
 
             highlight: {
                 def: false,
                 scope: 'element',
-                format: function (element, state) {
-                    element.toggleClass('highlight', state);
-                },
                 special: true
-            },
-
-            caps: {
-                def: 'none',
-                format: function (element, state) {
-                    element.toggleClass('uppercase', state === 'all');
-                    element.toggleClass('lowercase', state === 'small');
-                }
             }
-
         },
 
         PARENT_RESOLVERS = {
@@ -187,21 +138,23 @@ define('io.ox/office/textframework/format/characterstyles', [
      *
      * @extends StyleCollection
      *
-     * @param {TextModel} docModel
-     *  The text document model containing instance.
+     * @param {TextBaseModel} docModel
+     *  The document model containing this instance.
+     *
+     * @param {Object} [initoptions]
+     *  Optional parameters passed to the base class constructor.
      */
-    function CharacterStyles(docModel) {
+    var CharacterStyles = StyleCollection.extend({ constructor: function (docModel, initOptions) {
 
-        var // self reference
-            self = this;
+        // self reference
+        var self = this;
+
+        // the collection of paragraph style sheets
+        var paraStyles = null;
 
         // base constructor ---------------------------------------------------
 
-        StyleCollection.call(this, docModel, 'character', {
-            parentResolvers: PARENT_RESOLVERS,
-            formatHandler: updateCharacterFormatting,
-            families: 'changes'
-        });
+        StyleCollection.call(this, docModel, 'character', _.extend({}, initOptions, { parentResolvers: PARENT_RESOLVERS }));
 
         // private methods ----------------------------------------------------
 
@@ -221,21 +174,19 @@ define('io.ox/office/textframework/format/characterstyles', [
         function updateCharacterFormatting(textSpan, mergedAttributes) {
 
             var // the parent paragraph of the node (may be a grandparent)
-                paragraph = $(textSpan).closest(DOM.PARAGRAPH_NODE_SELECTOR),
+                paragraph = textSpan.closest(DOM.PARAGRAPH_NODE_SELECTOR),
                 // the closest cell node (if it exists)
-                cell = $(textSpan).closest(DOM.TABLE_CELLNODE_SELECTOR),
+                cell = textSpan.closest(DOM.TABLE_CELLNODE_SELECTOR),
                 // the closest text frame content node (if it exists)
-                textframeContent = $(textSpan).closest(DOM.TEXTFRAMECONTENT_NODE_SELECTOR),
-                // the paragraph style container
-                paragraphStyles = docModel.getStyleCollection('paragraph'),
+                textframeContent = textSpan.closest(DOM.TEXTFRAMECONTENT_NODE_SELECTOR),
                 // the merged attributes of the paragraph
-                paragraphAttributes = paragraphStyles.getElementAttributes(paragraph).paragraph,
+                paraAttrs = paraStyles.getElementAttributes(paragraph).paragraph,
                 // the character attributes of the passed attribute map
-                characterAttributes = mergedAttributes.character,
+                charAttrs = mergedAttributes.character,
                 // effective text color, font size, and vertical offset
-                textColor = characterAttributes.color,
-                fontSize = characterAttributes.fontSize,
-                textDecoration = self.getCssTextDecoration(characterAttributes),
+                textColor = charAttrs.color,
+                fontSize = charAttrs.fontSize,
+                textDecoration = AttributeUtils.getCssTextDecoration(charAttrs),
                 position = 'static',
                 bottom = null,
                 // the background color of the cell and text frame
@@ -243,17 +194,42 @@ define('io.ox/office/textframework/format/characterstyles', [
                 // an array containing all affected fill colors of text, paragraph and cell
                 allFillColors = [],
                 // the effective line height, that might be reduced inside comment
-                effectiveLineHeight = paragraphAttributes.lineHeight,
+                effectiveLineHeight = paraAttrs.lineHeight,
                 // the maximum font size inside a comment
                 commentMaxFontSize = 10,
                 // the target chain, that is required to resolve the correct theme
-                target = null;
+                targets = null;
 
             // restriction of max font size for small devices
             if (Utils.SMALL_DEVICE && fontSize > 16) {
                 fontSize = 16;
             }
 
+            // update formatting of the passed text span
+            textSpan.attr('lang', charAttrs.language);
+            textSpan.css({
+                fontWeight: charAttrs.bold ? 'bold' : 'normal',
+                fontStyle: charAttrs.italic ? 'italic' : 'normal',
+                backgroundColor: docModel.getCssColor(charAttrs.fillColor, 'fill')
+            });
+
+            var url = charAttrs.url;
+            if (!_.isString(url) || (url.length === 0)) { url = null; }
+            var anchor = charAttrs.anchor;
+            if (!_.isString(anchor) || (anchor.length === 0)) { anchor = null; }
+
+            paragraph.attr({
+                title: url,
+                'data-hyperlink-url': url,
+                'data-anchor-url': anchor,
+                'data-auto-date': charAttrs.autoDateField || null
+            });
+
+            textSpan.toggleClass('spellerror', !!charAttrs.spellerror);
+            textSpan.toggleClass('highlight', !!charAttrs.highlight);
+            textSpan.toggleClass('uppercase', charAttrs.caps === 'all');
+            textSpan.toggleClass('lowercase', charAttrs.caps === 'small');
+
             // Checking also the background-color of an affected cell, if there is one (28988).
             // For performance reasons, not using attributes (might be assigned to row or table, too),
             // but checking CSS style 'background-color' of the table directly.
@@ -269,27 +245,27 @@ define('io.ox/office/textframework/format/characterstyles', [
             }
 
             // adding fill color of paragraph and character (order is important)
-            allFillColors.push(paragraphAttributes.fillColor);
-            allFillColors.push(characterAttributes.fillColor);
+            allFillColors.push(paraAttrs.fillColor);
+            allFillColors.push(charAttrs.fillColor);
 
             // calculate effective text color, according to fill colors
             // or theme if it's hyperlink, #45263
             if (DOM.isHyperlinkNode(textSpan) && docModel.useSlideMode()) {
-                textColor = '#' + docModel.getTheme(docModel.getTargetChainForNode(textSpan)).getSchemeColor('hyperlink', '00f');
+                textColor = '#' + docModel.getThemeModelForNode(textSpan).getSchemeColor('hyperlink', '00f');
                 textDecoration = 'underline';
             } else {
-                if (docModel.useSlideMode() && AttributeUtils.isColorThemed(textColor)) { target = docModel.getTargetChainForNode(paragraph); }
-                textColor = self.getCssTextColor(textColor, allFillColors, target);
+                if (AttributeUtils.isColorThemed(textColor)) { targets = docModel.getThemeTargets(paragraph); }
+                textColor = docModel.getCssTextColor(textColor, allFillColors, targets);
             }
 
             // calculate font height and vertical alignment (according to escapement)
-            if (characterAttributes.vertAlign === 'sub' || characterAttributes.baseline < 0) {
+            if ((charAttrs.vertAlign === 'sub') || (charAttrs.baseline < 0)) {
                 position = 'relative';
                 bottom = 0;
                 fontSize = Utils.round(fontSize * 0.66, 0.1);
-            } else if (characterAttributes.vertAlign === 'super' || characterAttributes.baseline > 0) {
+            } else if ((charAttrs.vertAlign === 'super') || charAttrs.baseline > 0) {
                 position = 'relative';
-                bottom = '0.5EM';
+                bottom = '0.5em';
                 fontSize = Utils.round(fontSize * 0.66, 0.1);
             }
 
@@ -297,33 +273,28 @@ define('io.ox/office/textframework/format/characterstyles', [
             // the font size is set to a maximum value and the line height is set to single.
             if (!docModel.getApp().isODF() && !docModel.getCommentLayer().isEmpty() && DOM.isNodeInsideComment(textSpan)) {
                 if (fontSize > commentMaxFontSize) {
-                    characterAttributes.fontSize = commentMaxFontSize;
+                    charAttrs.fontSize = commentMaxFontSize;
                     fontSize = commentMaxFontSize;
                 }
                 effectiveLineHeight = LineHeight.SINGLE;
             }
 
-            if (!target && docModel.useSlideMode() && AttributeUtils.isCharacterFontThemed(characterAttributes)) {
-                target = docModel.getTargetChainForNode(paragraph);
+            if (!targets && AttributeUtils.isCharacterFontThemed(charAttrs)) {
+                targets = docModel.getThemeTargets(paragraph);
             }
 
-            var fontFamily = self.getCssFontFamily(characterAttributes.fontName, target);
-            if (characterAttributes.fontNameSymbol !== '') {
-                fontFamily += fontFamily === '' ? '' : ', ';
-                fontFamily += self.getCssFontFamily(characterAttributes.fontNameSymbol);
-            }
             // update CSS of the text span
             textSpan.css({
-                color: textColor,
+                fontFamily: self.resolveCssFontFamily(charAttrs, targets),
                 fontSize: Utils.convertToEM(fontSize, 'pt'),
+                color: textColor,
                 textDecoration: textDecoration,
                 position: position,
-                bottom: bottom,
-                fontFamily: fontFamily
+                bottom: bottom
             });
 
             // update line height due to changed font settings
-            self.updateElementLineHeight(textSpan, effectiveLineHeight, characterAttributes, target);
+            self.updateElementLineHeight(textSpan, effectiveLineHeight, charAttrs, targets);
 
             // change track attribute handling
             docModel.getChangeTrack().updateChangeTrackAttributes(textSpan, mergedAttributes);
@@ -336,8 +307,59 @@ define('io.ox/office/textframework/format/characterstyles', [
             //$(paragraph).find('> ' + DOM.LIST_LABEL_NODE_SELECTOR + ' > span').css('font-size', characterAttributes.fontSize + 'pt');
         }
 
+        /**
+         * Will be called for every text span used as preview in the UI.
+         *
+         * @param {jQuery} textSpan
+         *  The text span preview node, as jQuery object.
+         *
+         * @param {Object} mergedAttributes
+         *  A complete attribute set, containing the effective attribute values
+         *  merged from style sheets and explicit attributes.
+         */
+        function updatePreviewFormatting(textSpan, mergedAttributes) {
+
+            // the merged character attributes
+            var charAttrs = mergedAttributes.character;
+            // the resolved text color
+            var colorDesc = docModel.resolveColor(Color.parseJSON(charAttrs.color), 'text');
+
+            // update formatting of the passed text span
+            textSpan.css({
+                fontFamily: self.resolveCssFontFamily(charAttrs),
+                fontSize: Utils.minMax(Utils.round(10 + (charAttrs.fontSize - 10) / 1.5, 0.1), 6, 22) + 'pt',
+                fontWeight: charAttrs.bold ? 'bold' : 'normal',
+                fontStyle: charAttrs.italic ? 'italic' : 'normal',
+                color: (colorDesc.y > 0.95) ? 'black' : colorDesc.css // bug 40872: use black if color is too light
+            });
+        }
+
         // public methods -----------------------------------------------------
 
+        /**
+         * Returns the effective CSS font family for the passed character
+         * attributes.
+         *
+         * @param {Object} charAttributes
+         *  A complete map with character attributes supported by this
+         *  instance.
+         *
+         * @param {String|Array<String>} [targets]
+         *  A single target name or an array of target names to specify the
+         *  theme's target.
+         *
+         * @returns {String}
+         *  The effective CSS font family for the passed character attributes.
+         */
+        this.resolveCssFontFamily = function (charAttributes, targets) {
+            var fontFamily = docModel.getCssFontFamily(charAttributes.fontName, targets);
+            if (charAttributes.fontNameSymbol) {
+                if (fontFamily) { fontFamily += ','; }
+                fontFamily += docModel.getCssFontFamily(charAttributes.fontNameSymbol, targets);
+            }
+            return fontFamily;
+        };
+
         /**
          * Sets the text line height of the specified DOM element.
          *
@@ -360,43 +382,27 @@ define('io.ox/office/textframework/format/characterstyles', [
          *  @param {Boolean} [attributes.italic=false]
          *      Whether the text will be rendered in italic characters.
          *
-         * @param {String|Array<String>} [target]
-         *  An optional target string or an ordered collection of target strings
-         *  to specify the theme's target.
+         * @param {String|Array<String>} [targets]
+         *  A single target name or an array of target names to specify the
+         *  theme's target.
          *
          */
-        this.updateElementLineHeight = function (element, lineHeight, charAttributes, target) {
+        this.updateElementLineHeight = function (element, lineHeight, charAttributes, targets) {
 
-            var // the font collection
-                fontCollection = docModel.getFontCollection(),
-                // effective line height in pixels (start with passed value, converted from 1/100 mm)
-                height = Utils.convertHmmToLength(lineHeight.value, 'px'),
-                // type could be 'px' or '%
-                type = 'px',
-                //
-                normalLineHeight = 0,
-                //
-                fontHeight = 0,
-                //
-                theme = null,
-                //
-                vertAlign = null;
+            // effective line height in pixels (start with passed value, converted from 1/100 mm)
+            var height = Utils.convertHmmToLength(lineHeight.value, 'px');
+            // CSS unit string to be appended to the effective line height
+            var unit = 'px';
+            // value for the CSS attribute 'vertical-align'
+            var vertAlign = null;
 
-            if (lineHeight.type === 'fixed') {
-                //line height as passed
-            } else {
-                if (target) {
-                    theme = docModel.getThemeCollection().getTheme('', target);
-                }
-                // workaround for bug 47960
-                normalLineHeight = fontCollection.getNormalLineHeight(charAttributes, { theme: theme, zoom: 10 }) / 10;
+            // type 'fixed': use line height as passed, otherwise convert to percentage
+            if (lineHeight.type !== 'fixed') {
 
+                // workaround for bug 47960: get normal line height of enlarged font
+                var normalLineHeight = docModel.getRenderFont(charAttributes, targets, 10).getNormalLineHeight() / 10;
                 // workaround for Bug 47960 & Bug 45951
-                if (docModel.useSlideMode()) {
-                    fontHeight = normalLineHeight;
-                } else {
-                    fontHeight = Utils.convertLength(charAttributes.fontSize, 'pt', 'px');
-                }
+                var fontHeight = docModel.useSlideMode() ? normalLineHeight : Utils.convertLength(charAttributes.fontSize, 'pt', 'px');
 
                 // calculate effective line height
                 switch (lineHeight.type) {
@@ -407,6 +413,7 @@ define('io.ox/office/textframework/format/characterstyles', [
                         height = Math.max(height, normalLineHeight);
                         break;
                     case 'percent':
+                        // 'lineHeight.value' is a value in percent
                         height = normalLineHeight * lineHeight.value / 100;
                         break;
                     case 'normal':
@@ -416,39 +423,48 @@ define('io.ox/office/textframework/format/characterstyles', [
                         Utils.error('CharacterStyles.updateElementLineHeight(): invalid line height type');
                 }
 
-                // offset to pretend rounding error fix for Bug 47960
+                // bug 47960: offset to pretend rounding error
                 height =  Math.ceil(height) + 0.5;
 
-                //transform to relative size, (lineHeight / fontSize)
-                height = Utils.round((height / fontHeight) * 100, 0.01);
-                type = '%';
+                // convert to relative size in percent
+                height = Utils.round(height / fontHeight * 100, 0.01);
+                unit = '%';
 
                 if (height < 100) {
                     //workaround for Bug 48695
                     vertAlign = '0.5em';
                 }
             }
+
             $(element).first().css({
-                lineHeight: height + type,
+                lineHeight: height + unit,
                 verticalAlign: vertAlign
             });
         };
 
         // initialization -----------------------------------------------------
 
+        // deferred initialization
+        docModel.getApp().onInit(function () {
+            paraStyles = docModel.getStyleCollection('paragraph');
+        }, this);
+
         // register the attribute definitions for the style family
-        docModel.registerAttributeDefinitions('character', DEFINITIONS);
+        docModel.registerAttributes('character', DEFINITIONS);
+
+        // register the formatting handlers for DOM elements
+        this.registerFormatHandler(updateCharacterFormatting);
+        this.registerPreviewHandler(updatePreviewFormatting);
 
         // destroy all class members on destruction
         this.registerDestructor(function () {
-            docModel = self = null;
+            docModel = self = paraStyles = null;
         });
 
-    } // class CharacterStyles
+    } }); // class CharacterStyles
 
     // exports ================================================================
 
-    // derive this class from class StyleCollection
-    return StyleCollection.extend({ constructor: CharacterStyles });
+    return CharacterStyles;
 
 });
