@@ -14,8 +14,9 @@
 
 define('io.ox/office/textframework/format/tablerowstyles', [
     'io.ox/office/tk/utils',
-    'io.ox/office/editframework/model/stylecollection'
-], function (Utils, StyleCollection) {
+    'io.ox/office/editframework/model/stylecollection',
+    'io.ox/office/textframework/utils/dom'
+], function (Utils, StyleCollection, DOM) {
 
     'use strict';
 
@@ -25,7 +26,11 @@ define('io.ox/office/textframework/format/tablerowstyles', [
             /**
              * The height of the table row. If 'auto' then the row is auto sized.
              */
-            height: { def: 'auto' }
+            height: { def: 'auto' },
+            /**
+             * Denotes row to be repeated across pages of split table (repeated rows).
+             */
+            headerRow: { def: false }
 
         };
 
@@ -42,14 +47,13 @@ define('io.ox/office/textframework/format/tablerowstyles', [
      * @param {TextModel} docModel
      *  The text document model containing instance.
      */
-    function TableRowStyles(docModel) {
+    var TableRowStyles = StyleCollection.extend({ constructor: function (docModel) {
 
         // base constructor ---------------------------------------------------
 
         StyleCollection.call(this, docModel, 'row', {
             families: 'changes',
-            styleSheetSupport: false,
-            formatHandler: updateTableRowFormatting
+            styleSheetSupport: false
         });
 
         // private methods ----------------------------------------------------
@@ -117,6 +121,7 @@ define('io.ox/office/textframework/format/tablerowstyles', [
                     row.css('height', '');
                 }
             }
+            if (rowAttributes.headerRow) { row.addClass(DOM.TABLE_REPEAT_ROWNODE_CLASSNAME); }
 
             // change track attribute handling
             docModel.getChangeTrack().updateChangeTrackAttributes(row, mergedAttributes);
@@ -126,18 +131,20 @@ define('io.ox/office/textframework/format/tablerowstyles', [
         // initialization -----------------------------------------------------
 
         // register the attribute definitions for the style family
-        docModel.registerAttributeDefinitions('row', DEFINITIONS);
+        docModel.registerAttributes('row', DEFINITIONS);
+
+        // register the formatting handler for DOM elements
+        this.registerFormatHandler(updateTableRowFormatting);
 
         // destroy all class members on destruction
         this.registerDestructor(function () {
             docModel = null;
         });
 
-    } // class TableRowStyles
+    } }); // class TableRowStyles
 
     // exports ================================================================
 
-    // derive this class from class StyleCollection
-    return StyleCollection.extend({ constructor: TableRowStyles });
+    return TableRowStyles;
 
 });
