@@ -12,16 +12,20 @@
  * @author Mario Schroeder <mario.schroeder@open-xchange.com>
  */
 
-define('io.ox/office/textframework/model/clipboardmixin', [
+define.async('io.ox/office/textframework/model/clipboardmixin', [
     'io.ox/office/tk/utils',
+    'io.ox/office/tk/io',
     'io.ox/office/textframework/utils/operations',
     'io.ox/office/textframework/utils/dom',
     'io.ox/office/drawinglayer/view/imageutil',
+    'io.ox/office/tk/render/colorutils',
     'static/3rd.party/unorm/unorm.js'           // Polyfill for String.prototype.normalize()
-], function (Utils, Operations, DOM, ImageUtil) {
+], function (Utils, IO, Operations, DOM, ImageUtil, ColorUtils) {
 
     'use strict';
 
+    var OPEN_SYMBOL_REPLACEMENT = null;
+
     // mix-in class ClipboardMixin ============================================
 
     /**
@@ -208,6 +212,20 @@ define('io.ox/office/textframework/model/clipboardmixin', [
                                         result.push({ operation: 'insertCellData', data: text });
                                     } else {
                                         result.push({ operation: Operations.TEXT_INSERT, data: text, depth: depth });
+
+                                        // ------------------------------------------------------
+                                        //    SET CSS ATTRIBUTES
+                                        // ------------------------------------------------------
+                                        var charStyles = self.getCssStyle(child, 'character'),
+                                            styles = {
+                                                len: text.length,
+                                                attrs: {
+                                                    character: charStyles
+                                                }
+                                            };
+
+                                        result.push({ operation: Operations.SET_ATTRIBUTES, data: styles, depth: depth });
+                                        // ------------------------------------------------------
                                     }
                                 }
                             }
@@ -305,14 +323,14 @@ define('io.ox/office/textframework/model/clipboardmixin', [
                                 if (ox.session === childData.sessionId && fileId === childData.fileId && childData.altsrc) {
                                     // The image URL points to a document and the copy&paste action
                                     // takes place inside the same editor instance, so we use relative document media URL.
-                                    result.push({ operation: Operations.DRAWING_INSERT, type: 'image', data: childData.altsrc, depth: depth });
+                                    result.push({ operation: Operations.INSERT_DRAWING, type: 'image', data: childData.altsrc, depth: depth });
 
                                 } else if (DOM.isDocumentImageNode(child)) {
                                     // The image URL points to a document, but copy&paste is done from one editor instance to another
                                     // and the image src has not been replaced with a base64 data URL (e.g. IE 9 does not support this).
                                     // So the base64 data URL can be generated from the image node as long as the session is valid.
                                     result.push({
-                                        operation: Operations.DRAWING_INSERT,
+                                        operation: Operations.INSERT_DRAWING,
                                         type: 'image',
                                         data: DOM.getBase64FromImageNode(child, ImageUtil.getMimeTypeFromImageUri(DOM.getUrlParamFromImageNode(child, 'get_filename'))),
                                         depth: depth
@@ -320,7 +338,7 @@ define('io.ox/office/textframework/model/clipboardmixin', [
 
                                 } else {
                                     // The image src is an external web URL or already a base64 data URL
-                                    result.push({ operation: Operations.DRAWING_INSERT, type: 'image', data: child.src, depth: depth });
+                                    result.push({ operation: Operations.INSERT_DRAWING, type: 'image', data: child.src, depth: depth });
 
                                 }
                                 insertLength += 1;
@@ -887,10 +905,17 @@ define('io.ox/office/textframework/model/clipboardmixin', [
          *                  The font family of the char.
          */
         this.getUnicodeReplacementForChar = function (char, fontFamily) {
+            // the font family in lower case
+            var fontFamilyLowerCase = null;
+
             if (_.isString(fontFamily) && !_.isEmpty(fontFamily)) {
-                if (fontFamily.indexOf('ingdings') > 0) {
-                    return (fontFamily.indexOf('2') > 0) ? this.getUnicodeForWingdings2Char(char) : this.getUnicodeForWingdings1Char(char);
-                } else if (fontFamily.indexOf('ymbol') > 0) {
+                fontFamilyLowerCase = fontFamily.toLowerCase();
+
+                if (fontFamilyLowerCase.indexOf('wingdings') > -1) {
+                    return (fontFamilyLowerCase.indexOf('2') > 0) ? this.getUnicodeForWingdings2Char(char) : this.getUnicodeForWingdings1Char(char);
+                } else if ((fontFamilyLowerCase.indexOf('starsymbol') > -1) || (fontFamilyLowerCase.indexOf('opensymbol') > -1)) {
+                    return this.getUnicodeForOpenSymbolChar(char);
+                } else if (fontFamilyLowerCase.indexOf('symbol') > -1) {
                     return this.getUnicodeForSymbolChar(char);
                 }
             }
@@ -2230,6 +2255,96 @@ define('io.ox/office/textframework/model/clipboardmixin', [
             }
         };
 
+        /**
+         * Maps OpenSymbol characters of the Unicode private use area to a replacement
+         * that can be displayed in common browser fonts.
+         *
+         * @param {String} char
+         *  The Symbol char.
+         *
+         * @returns {Object}
+         *              {String} levelText
+         *                  The Unicode char.
+         *              {String} fontFamily
+         *                  The font family of the char.
+         */
+        this.getUnicodeForOpenSymbolChar = function (char) {
+
+            if (!_.isString(char) || (char.length !== 1)) {
+                return { levelText: '\u2022', fontFamily: 'Times New Roman' };
+            }
+
+            if (_.isObject(OPEN_SYMBOL_REPLACEMENT[char])) {
+                // take private use area replacement
+                return _.copy(OPEN_SYMBOL_REPLACEMENT[char]);
+            }
+
+            // take the character as it is
+            return { levelText: char, fontFamily: 'Times New Roman' };
+        };
+
+        this.getCssStyle = function (child, family) {
+            function colorResolver() {
+                if (css.color) {
+                    var colorDescriptor = ColorUtils.parseColor(css.color);
+                    return (colorDescriptor) ? { type: 'rgb', value: colorDescriptor.hex } : null;
+
+                } else {
+                    return null;
+                }
+            }
+
+            function backgroundcolorResolver() {
+                if (css['background-color'] && css['background-color'] !== 'rgba(0, 0, 0, 0)' && css['background-color'] !== 'transparent') {
+                    var colorDescriptor = ColorUtils.parseColor(css['background-color']);
+                    return (colorDescriptor) ? { type: 'rgb', value: colorDescriptor.hex } : null;
+
+                } else {
+                    return null;
+                }
+            }
+
+            function fontWeightResolver() {
+                return (css['font-weight'] && (css['font-weight'] === 'bold' || parseInt(css['font-weight'], 10) > 400));
+            }
+
+            function fontSizeResolver() {
+                return (css['font-size']) ? Utils.convertCssLength(css['font-size'], 'pt') : null;
+            }
+
+            function italicResolver() {
+                return (css['font-style']) ? (css['font-style'] === 'italic') : null;
+            }
+
+            function underlineResolver() {
+                return (css['text-decoration']) ? (css['text-decoration'].indexOf('underline') !== -1) : null;
+            }
+
+            function strikeResolver() {
+                return (css['text-decoration']) ? (css['text-decoration'].indexOf('line-through') !== -1) ? 'single' : null : null;
+            }
+
+            var css         = Utils.getCss(child.parentNode, { attrs: ['color', 'background-color', 'font-weight', 'font-size', 'text-decoration', 'font-style'] }),
+                attrs       = {},
+                attributes  = {
+                    character:      {
+                        color:      colorResolver,
+                        fillColor:  backgroundcolorResolver,
+                        fontSize:   fontSizeResolver,
+                        bold:       fontWeightResolver,
+                        italic:     italicResolver,
+                        strike:     strikeResolver,
+                        underline:  underlineResolver
+                    }
+                };
+
+            _.each(attributes[family], function (resolver, key) {
+                attrs[key] = resolver();
+            });
+
+            return attrs;
+        };
+
         // initialization -----------------------------------------------------
 
         // initialize class members
@@ -2245,5 +2360,9 @@ define('io.ox/office/textframework/model/clipboardmixin', [
 
     // exports ================================================================
 
-    return ClipboardMixin;
+    var promise = IO.loadJSON('io.ox/office/textframework/resource/fontreplacements/opensymbol');
+
+    promise.done(function (opensymbol) { OPEN_SYMBOL_REPLACEMENT = opensymbol; });
+
+    return promise.then(_.constant(ClipboardMixin));
 });
