@@ -18,8 +18,9 @@ define('io.ox/office/textframework/model/groupoperationmixin', [
     'io.ox/office/textframework/utils/dom',
     'io.ox/office/textframework/utils/operations',
     'io.ox/office/textframework/utils/position',
-    'io.ox/office/textframework/utils/textutils'
-], function (DrawingFrame, AttributeUtils, DOM, Operations, Position, Utils) {
+    'io.ox/office/textframework/utils/textutils',
+    'io.ox/office/drawinglayer/utils/drawingutils'
+], function (DrawingFrame, AttributeUtils, DOM, Operations, Position, Utils, DrawingUtils) {
 
     'use strict';
 
@@ -105,7 +106,7 @@ define('io.ox/office/textframework/model/groupoperationmixin', [
             // can directly be taken from the selection. All other clients need to find
             // the drawings with their logical positions.
             // -> but not if undo/redo is running
-            if (self.getEditMode() && !self.isUndoRedoRunning()) {
+            if (app.isEditable() && !self.isUndoRedoRunning()) {
                 allChildDrawings = self.getSelection().getArrayOfSelectedDrawingNodes();
             } else {
                 // collecting all drawings, before the new group drawing is inserted
@@ -249,6 +250,7 @@ define('io.ox/office/textframework/model/groupoperationmixin', [
                 if (span) {
                     $(drawingNode).removeClass(DrawingFrame.GROUPED_NODE_CLASS).insertAfter(span);
                     drawingStyles.updateElementFormatting(drawingNode);
+                    if (DrawingFrame.isAutoResizeHeightDrawingFrame(drawingNode)) { $(drawingNode).data('drawingHeight', $(drawingNode).height()); } // #49890
                 } else {
                     return false;
                 }
@@ -284,6 +286,9 @@ define('io.ox/office/textframework/model/groupoperationmixin', [
                 if (explicitAttrs.drawing) {
 
                     explicitAttrs = explicitAttrs.drawing;
+                    if ('rotation' in explicitAttrs) { // #50006
+                        explicitAttrs = _.extend(explicitAttrs, DrawingUtils.getRotatedDrawingPoints(explicitAttrs, explicitAttrs.rotation));
+                    }
 
                     if (!_.isNumber(explicitAttrs.left)) { explicitAttrs.left = 0; } // setting the default value (47463)
                     if (!_.isNumber(explicitAttrs.top)) { explicitAttrs.top = 0; } // setting the default value
@@ -330,12 +335,16 @@ define('io.ox/office/textframework/model/groupoperationmixin', [
             // the object for saving the drawing attributes
             var savedDrawingAttrs = {};
             // the properties that need to be saved
-            var props = ['left', 'top', 'width', 'height', 'rotation'];
+            var props = ['left', 'top', 'width', 'height', 'rotation', 'flipH', 'flipV'];
 
             _.each(props, function (prop) {
                 if (_.isNumber(drawingAttrs[prop])) { savedDrawingAttrs[prop] = drawingAttrs[prop]; }
                 // rotation must be set explicitely
                 if (prop === 'rotation' && !_.isNumber(savedDrawingAttrs[prop])) { savedDrawingAttrs[prop] = 0; }
+                // flip properties are Boolean, and must be set also explicitely
+                if ((prop === 'flipH' || prop === 'flipV') && _.isBoolean(drawingAttrs[prop])) {
+                    savedDrawingAttrs[prop] = drawingAttrs[prop];
+                }
             });
 
             container.push({ drawing: savedDrawingAttrs });
@@ -369,9 +378,13 @@ define('io.ox/office/textframework/model/groupoperationmixin', [
             // the jQuery offset of the complete slide
             var slideOffset = drawingGroupNode.closest(DOM.SLIDE_SELECTOR).offset();
             // the current zoom factor
-            var zoomFactor = app.getView().getZoomFactor() / 100;
+            var zoomFactor = app.getView().getZoomFactor();
             // the explicit drawing attributes of the group
             var drawingGroupAttrs = null;
+            // group horizontal flip property
+            var groupFlipH = DrawingFrame.isFlippedHorz(drawingGroupNode);
+            // group vertical flip property
+            var groupFlipV = DrawingFrame.isFlippedVert(drawingGroupNode);
 
             // is the drawing group rotated? -> all children need to get the rotation of the group node
             if (DrawingFrame.isRotatedDrawingNode(drawingGroupNode)) { groupRotationAngle = DrawingFrame.getDrawingRotationAngle(self, drawingGroupNode); }
@@ -392,14 +405,24 @@ define('io.ox/office/textframework/model/groupoperationmixin', [
                     // the jQuery offset of one drawing
                     drawingOffset = null,
                     // the explicit drawing attributes of the child
-                    drawingAttrs = null;
+                    drawingAttrs = null,
+                    // drawing horizontal flip property
+                    drawingFlipH = DrawingFrame.isFlippedHorz(drawing),
+                    // drawing vertical flip property
+                    drawingFlipV = DrawingFrame.isFlippedVert(drawing),
+                    // combined values for flip horizontal of drawing itself and group flip in one variable
+                    mergedFlipH = drawingFlipH !== groupFlipH,
+                    // combined values for flip vertical of drawing itself and group flip in one variable
+                    mergedFlipV = drawingFlipV !== groupFlipV,
+                    // final calculated angle of the drawing
+                    finalDrawingAngle = 0;
 
                 if (DrawingFrame.isRotatedDrawingNode(drawing)) { drawingAngle = DrawingFrame.getDrawingRotationAngle(self, drawing); }
                 if (drawingAngle) { $(drawing).css({ transform: 'rotate(0deg)' }); } // rotating back the child drawing
-                if (groupRotationAngle) {
+                if (groupRotationAngle || groupFlipH || groupFlipV) {
                     completeDrawingAngle = -groupRotationAngle;
                     // assigning the negative group rotation to the child drawing so that there is no remaining rotation
-                    if (completeDrawingAngle !== 0) { $(drawing).css({ transform: 'rotate(' + completeDrawingAngle + 'deg)' }); }
+                    if (completeDrawingAngle !== 0) { DrawingFrame.setCssTransform(drawing, completeDrawingAngle, mergedFlipH, mergedFlipV); }
                     // saving the original positions in the childAttrsContainer (only for rotated drawings to generate undo operation)
                     drawingAttrs = AttributeUtils.getExplicitAttributes(drawing);
                     // saving the values for 'left', 'top', 'width', 'height' and 'rotation' of the grouped drawing
@@ -408,13 +431,17 @@ define('io.ox/office/textframework/model/groupoperationmixin', [
 
                 // reading value of upper left corner of the unrotated drawing
                 drawingOffset = $drawing.offset();
+                finalDrawingAngle = groupRotationAngle + drawingAngle;
+                finalDrawingAngle = mergedFlipH !== mergedFlipV ? (360 - finalDrawingAngle) : finalDrawingAngle;
 
                 allNewDrawingAttributes.push({
                     left: Utils.convertLengthToHmm((drawingOffset.left - slideOffset.left) / zoomFactor, 'px'),
                     top: Utils.convertLengthToHmm((drawingOffset.top - slideOffset.top) / zoomFactor, 'px'),
                     width: Utils.convertLengthToHmm($drawing.width(), 'px'),
                     height: Utils.convertLengthToHmm($drawing.height(), 'px'),
-                    rotation: groupRotationAngle + drawingAngle
+                    rotation: finalDrawingAngle,
+                    flipH: mergedFlipH,
+                    flipV: mergedFlipV
                 });
             });
 
@@ -445,7 +472,7 @@ define('io.ox/office/textframework/model/groupoperationmixin', [
         this.groupDrawings = function () {
 
             var // the operations generator
-                generator = self.createOperationsGenerator(),
+                generator = self.createOperationGenerator(),
                 // the selection object
                 selection = self.getSelection(),
                 // a collector for all logical positions of the selected drawings
@@ -491,7 +518,7 @@ define('io.ox/office/textframework/model/groupoperationmixin', [
         this.ungroupDrawings = function () {
 
             var // the operations generator
-                generator = self.createOperationsGenerator(),
+                generator = self.createOperationGenerator(),
                 // created operation
                 newOperation = null,
                 // the selection object
@@ -499,7 +526,7 @@ define('io.ox/office/textframework/model/groupoperationmixin', [
                 // the logical position of the selected drawing
                 start = selection.isDrawingSelection() ? selection.getStartPosition() : null,
                 // a selected drawing group node (drawing selection or additional drawing selection)
-                drawingNode = selection.isAnyDrawingSelection() ? selection.getClosestSelectedDrawing() : null,
+                drawingNode = null,
                 // the content node inside the selected drawing(s)
                 contentNode = null,
                 // the number of drawing children inside a selected group
