@@ -212,7 +212,7 @@ define('io.ox/office/textframework/model/hardbreakmixin', [
                     // object passed to generateOperation method
                     operationOptions,
                     // operations generator
-                    generator = this.createOperationsGenerator();
+                    generator = this.createOperationGenerator();
 
                 function doInsertManualPageBreak() {
 
