@@ -18,7 +18,7 @@ define('io.ox/office/textframework/model/hyperlinkmixin', [
     'io.ox/office/textframework/utils/dom',
     'io.ox/office/textframework/utils/operations',
     'io.ox/office/textframework/utils/position',
-    'io.ox/office/textframework/view/textdialogs'
+    'io.ox/office/textframework/view/dialogs'
 ], function (AttributeUtils, Hyperlink, DOM, Operations, Position, Dialogs) {
 
     'use strict';
@@ -57,7 +57,7 @@ define('io.ox/office/textframework/model/hyperlinkmixin', [
          */
         this.insertHyperlinkDirect = function (url, text, dropPosition) {
 
-            var generator = self.createOperationsGenerator(),
+            var generator = self.createOperationGenerator(),
                 hyperlinkStyleId = self.useSlideMode() ? null : self.getDefaultUIHyperlinkStylesheet();
 
             if (url && url.length > 0) {
@@ -134,7 +134,7 @@ define('io.ox/office/textframework/model/hyperlinkmixin', [
             var // the selection object
                 selection = self.getSelection(),
                 // the generator object for the operations
-                generator = self.createOperationsGenerator(),
+                generator = self.createOperationGenerator(),
                 text = '', url = '',
                 startPos = null,
                 start = selection.getStartPosition(),
@@ -300,7 +300,8 @@ define('io.ox/office/textframework/model/hyperlinkmixin', [
 
                             // insert new text
                             self.doCheckImplicitParagraph(start);
-                            newOperation = { text: data.text, start: _.clone(start), attrs: attrs };
+                            newOperation = { text: data.text, start: _.clone(start) };
+                            if (attrs) { newOperation.attrs = attrs; }
                             self.extendPropertiesWithTarget(newOperation, target);
                             generator.generateOperation(Operations.TEXT_INSERT, newOperation);
 
@@ -366,7 +367,7 @@ define('io.ox/office/textframework/model/hyperlinkmixin', [
             var // the selection object
                 selection = self.getSelection(),
                 // the generator object for the operations
-                generator = self.createOperationsGenerator(),
+                generator = self.createOperationGenerator(),
                 startPos = null,
                 start = selection.getStartPosition(),
                 end = selection.getEndPosition(),
@@ -438,7 +439,7 @@ define('io.ox/office/textframework/model/hyperlinkmixin', [
                     if (startPos) {
                         selection.setTextSelection(startPos);
                     }
-                }, { infoString: 'HyperlinkMixin: removeHyperLink', app: app });
+                }, 'HyperlinkMixin.removeHyperLink');
             }
         };
 
