@@ -23,7 +23,7 @@ define('io.ox/office/textframework/model/paragraphmixin', [
 
     'use strict';
 
-    // mix-in class ParagraphMixin ======================================
+    // mix-in class ParagraphMixin ============================================
 
     /**
      * A mix-in class for the paragraph handling in the document model.
@@ -32,8 +32,8 @@ define('io.ox/office/textframework/model/paragraphmixin', [
      */
     function ParagraphMixin(app) {
 
-        var // self reference for local functions
-            self = this;
+        // self reference (the document model)
+        var self = this;
 
         // private methods ----------------------------------------------------
 
@@ -100,7 +100,7 @@ define('io.ox/office/textframework/model/paragraphmixin', [
                 // whether the split paragraph contains selected drawing(s)
                 updateSelectedDrawing = false,
                 // whether the document is in read-only mode
-                readOnly = self.getEditMode() !== true,
+                readOnly = !app.isEditable(),
                 // the list label node inside a paragraph
                 listLabelNode = null,
                 // the current element
@@ -310,13 +310,17 @@ define('io.ox/office/textframework/model/paragraphmixin', [
             var
                 // currently active root node
                 activeRootNode = self.getCurrentRootNode(),
+                // the operations generator
+                generator = self.createOperationGenerator(),
                 // the paragraph node, if not specified as parameter
                 paragraph = para || Position.getParagraphElement(activeRootNode, position.slice(0, -1)),
                 // the last position of the specified logical split position
                 offset = _.last(position),
                 // target for operation - if exists, it's for ex. header or footer
                 target = self.getActiveTarget(),
-                // the operation options
+                // the explicit paragraph attributes
+                expAttrs = null,
+                // the generated operations
                 operationOptions = {};
 
             // moving the leading absolute drawings to the new paragraph
@@ -324,9 +328,22 @@ define('io.ox/office/textframework/model/paragraphmixin', [
                 position[position.length - 1] = 0;
             }
 
-            operationOptions = { name: Operations.PARA_SPLIT, start: _.clone(position) };
+            operationOptions = { start: _.clone(position) };
             self.extendPropertiesWithTarget(operationOptions, target);
-            self.applyOperations(operationOptions);
+
+            generator.generateOperation(Operations.PARA_SPLIT, _.copy(operationOptions, true));
+
+            // the second paragraph must not have pageBreakBefore attribute set to true (53110)
+            if (app.isODF()) {
+                expAttrs = AttributeUtils.getExplicitAttributes(paragraph, { family: 'paragraph' });
+                if (expAttrs && expAttrs.pageBreakBefore) {
+                    operationOptions = { start: Position.increaseLastIndex(_.initial(position)), attrs: { paragraph: { pageBreakBefore: null } } }; // removing the pageBreakBefore attribute
+                    self.extendPropertiesWithTarget(operationOptions, target);
+                    generator.generateOperation(Operations.SET_ATTRIBUTES, _.copy(operationOptions, true));
+                }
+            }
+
+            self.applyOperations(generator);
         };
 
         /**
@@ -394,7 +411,7 @@ define('io.ox/office/textframework/model/paragraphmixin', [
                 // first child node of next paragraph
                 firstChildNode = null,
                 // the undo/redo operations
-                generator = self.getUndoManager().isUndoEnabled() ? this.createOperationsGenerator() : null,
+                generator = self.getUndoManager().isUndoEnabled() ? this.createOperationGenerator() : null,
                 // start node from where to run page break calculations
                 currentElement,
                 // the character attributes
@@ -507,45 +524,34 @@ define('io.ox/office/textframework/model/paragraphmixin', [
         /**
          * The handler for the insertParagraph operation.
          *
-         * @param {Object} operation
-         *  The operation object.
+         * @param {OperationContext} context
+         *  The context object wrapping the document operation.
          *
-         * @returns {Boolean}
-         *  Whether the paragraph was inserted successfully.
+         * @throws {OperationError}
+         *  If the paragraph could not be inserted successfully.
          */
-        this.insertParagraphHandler = function (operation) {
+        this.insertParagraphHandler = function (context) {
 
-            var // the new paragraph
-                paragraph = DOM.createParagraphNode(),
-                // insert the paragraph into the DOM tree
-                inserted,
-                // text position at the beginning of the paragraph
-                startPosition = null,
-                //parents required for page breaks
-                parents = paragraph.parents('table'),
-                //page breaks
-                currentElement = paragraph[0],
-                undoOperation,
-                // a helper object for modified attributes
-                modifiedAttributes = null,
-                // the undo manager object
-                undoManager = self.getUndoManager();
+            // the new paragraph
+            var paragraph = DOM.createParagraphNode();
+            // the insertion position of the new paragraph
+            var paraStart = context.getPos('start');
+            // the target root node
+            var target = context.getOptStr('target');
+            // the attributes of the operation
+            var attrs = context.getOptObj('attrs');
+            // an attribute helper object
+            var modifiedAttrs = null;
+            // the undo manager
+            var undoManager = self.getUndoManager();
+            // the undo operation
+            var undoOperation = null;
 
             // checking valid paragraph operation for presentation app (48608)
-            if (self.useSlideMode() && operation.start.length < 3) { return false; }
+            if (self.useSlideMode()) { context.ensure(paraStart.length >= 3, 'invalid start position'); }
 
-            if (parents.length > 0) {
-                currentElement = parents.last();
-            }
-
-            if (operation.target) {
-                inserted = self.insertContentNode(_.clone(operation.start), paragraph, operation.target);
-            } else {
-                inserted = self.insertContentNode(_.clone(operation.start), paragraph);
-            }
-
-            // insertContentNode() writes warning to console
-            if (!inserted) { return false; }
+            // insert the new paragraph into the root node addressed by the operation
+            context.ensure(self.insertContentNode(_.clone(paraStart), paragraph, target), 'cannot create new paragraph');
 
             // insert required helper nodes
             self.validateParagraphNode(paragraph);
@@ -554,8 +560,6 @@ define('io.ox/office/textframework/model/paragraphmixin', [
             // newly, also in other browsers (new jQuery version?)
             self.repairEmptyTextNodes(paragraph);
 
-            startPosition = Position.appendNewIndex(operation.start);
-
             // removing a following implicit paragraph (for example in a table cell)
             // -> exchanging an implicit paragraph with a non-implicit paragraph
             if (DOM.isImplicitParagraphNode(paragraph.next())) {
@@ -564,51 +568,65 @@ define('io.ox/office/textframework/model/paragraphmixin', [
 
             // generate undo/redo operations
             if (undoManager.isUndoEnabled()) {
-                undoOperation = { name: Operations.DELETE, start: operation.start };
-                self.extendPropertiesWithTarget(undoOperation, operation.target);
-                undoManager.addUndo(undoOperation, operation);
+                undoOperation = { name: Operations.DELETE, start: paraStart };
+                self.extendPropertiesWithTarget(undoOperation, target);
+                undoManager.addUndo(undoOperation, context.operation);
             }
 
             // apply the passed paragraph attributes
-            if (_.isObject(operation.attrs)) {
+            if (attrs) {
+
                 // No list style in comments in odt: 38829 (simply removing the list style id)
-                if (app.isODF() && operation.target && operation.attrs && operation.attrs.paragraph && operation.attrs.paragraph.listStyleId && self.getCommentLayer().isCommentTarget(operation.target)) { delete operation.attrs.paragraph.listStyleId; }
+                if (app.isODF() && target && attrs.paragraph && attrs.paragraph.listStyleId && self.getCommentLayer().isCommentTarget(target)) {
+                    attrs = _.clone(attrs);
+                    attrs.paragraph = _.clone(attrs.paragraph);
+                    delete attrs.paragraph.listStyleId;
+                }
 
-                modifiedAttributes = _.copy(operation.attrs, true);  // not modifying the original object
-
-                if (!app.isODF()) {
+                if (app.isODF()) {
+                    if (!_.isEmpty(attrs)) { self.getParagraphStyles().setElementAttributes(paragraph, attrs); }
+                } else {
 
                     // assigning character attributes to text spans, not to paragraphs (41250)
-                    if ('character' in operation.attrs) {
+                    if ('character' in attrs) {
 
-                        // setting the character attributes to the text span(s) inside the paragraph
+                        modifiedAttrs = _.copy(attrs, true);  // not modifying the original object
+
+                        // setting the character attributes to the text span inside the paragraph
                         _.each(paragraph.children('span'), function (node) {
-                            if (DOM.isTextSpan(node)) { self.getCharacterStyles().setElementAttributes(node, operation.attrs); }
+                            if (DOM.isTextSpan(node)) { self.getCharacterStyles().setElementAttributes(node, attrs); }
                         });
 
                         // removing the character attributes, so that they are not assigned to the paragraph
-                        delete modifiedAttributes.character;
+                        delete modifiedAttrs.character;
+
+                        if (!_.isEmpty(modifiedAttrs)) {
+                            self.getParagraphStyles().setElementAttributes(paragraph, modifiedAttrs);
+                        }
                     }
 
+                    // saving attributes at paragraph node
+                    if (!modifiedAttrs && !_.isEmpty(attrs)) {
+                        self.getParagraphStyles().setElementAttributes(paragraph, attrs);
+                    }
                 }
-
-                // saving attributes at paragraph node
-                if (!_.isEmpty(modifiedAttributes)) { self.getParagraphStyles().setElementAttributes(paragraph, operation.attrs); }
             }
 
             // set cursor to beginning of the new paragraph
             // But not, if this was triggered by an insertColumn or insertRow operation (Task 30859)
-            if (!self.isGUITriggeredOperation()) { self.setLastOperationEnd(startPosition); }
+            if (!self.isGUITriggeredOperation()) {
+                self.setLastOperationEnd(Position.appendNewIndex(paraStart));
+            }
 
             // register paragraph for deferred formatting, especially empty paragraphs
             // or update them immediately after the document import has finished (Task 28370)
             if (self.isImportFinished()) {
-                self.implParagraphChangedSync($(paragraph));
+                self.implParagraphChangedSync(paragraph);
 
                 // only for text, there are no paragraph borders and color in presentation
                 if (!self.useSlideMode()) {
                     // only needed for updating paragraphs that have a color or a border
-                    self.getParagraphStyles().updateParagraphBorderAndColorNodes($(paragraph).next());
+                    self.getParagraphStyles().updateParagraphBorderAndColorNodes(paragraph.next());
                 }
 
             } else {
@@ -619,22 +637,26 @@ define('io.ox/office/textframework/model/paragraphmixin', [
             if (self.handleTriggeringListUpdate(paragraph, { paraInsert: true })) {
                 // mark this paragraph for later list update. This is necessary, because it does not yet contain
                 // the list label node (DOM.LIST_LABEL_NODE_SELECTOR) and is therefore ignored in updateLists.
-                $(paragraph).data('updateList', 'true');
+                paragraph.data('updateList', 'true');
             }
 
-            //render pagebreaks after insert
+            // table parents required for page breaks
+            var currentElement = paragraph[0];
+            var parents = paragraph.parents('table');
+            if (parents.length > 0) {
+                currentElement = parents.last();
+            }
+            // render pagebreaks after insert
             self.insertPageBreaks(currentElement, DrawingFrame.getClosestTextFrameDrawingNode(paragraph));
             if (!self.isPageBreakMode()) { app.getView().recalculateDocumentMargin(); }
 
             // Performance: Saving paragraph info for following operations
-            self.getSelection().setParagraphCache(paragraph, _.clone(operation.start), 0);
+            self.getSelection().setParagraphCache(paragraph, _.clone(paraStart), 0);
 
             // #39486
-            if (operation.target) {
-                self.getPageLayout().markParagraphAsMarginal(paragraph, operation.target);
+            if (target) {
+                self.getPageLayout().markParagraphAsMarginal(paragraph, target);
             }
-
-            return true;
         };
 
         // initialization -----------------------------------------------------
