@@ -15,9 +15,8 @@
 define('io.ox/office/textframework/model/stringconvertermixin', [
     'io.ox/office/drawinglayer/view/drawingframe',
     'io.ox/office/textframework/utils/dom',
-    'io.ox/office/textframework/utils/textutils',
-    'io.ox/office/tk/utils/deferredutils'
-], function (DrawingFrame, DOM, Utils, DeferredUtils) {
+    'io.ox/office/textframework/utils/textutils'
+], function (DrawingFrame, DOM, Utils) {
 
     'use strict';
 
@@ -98,6 +97,29 @@ define('io.ox/office/textframework/model/stringconvertermixin', [
 
         }
 
+        /**
+         * Helper function to remove empty text frame nodes without paragraph in shapes. In fast load process
+         * every shape gets a text frame node, so that a paragraph can be inserted. This is not correct for
+         * selected connector shapes (bug 50349). Because this information is not available on server side,
+         * this needs to be fixed with this process on client side. An improved server side process might be
+         * created later.
+         *
+         * @param {Node|jQuery} drawing
+         *  The drawing node.
+         */
+        function removeEmptyTextFrameNodesInDrawing(drawing) {
+
+            var textFrameNode = DrawingFrame.getTextFrameNode(drawing);
+
+            if (textFrameNode.children().length === 0) {
+                // removing the drawing node
+                textFrameNode.remove();
+                // removing class from 'textframecontent' from content node
+                DrawingFrame.getContentNode(drawing).removeClass(DrawingFrame.TEXTFRAMECONTENT_NODE_CLASS);
+            }
+
+        }
+
         // public methods -----------------------------------------------------
 
         /**
@@ -151,7 +173,7 @@ define('io.ox/office/textframework/model/stringconvertermixin', [
                 var // the jQuery data object of the node
                     dataObject = null,
                     // the return promise
-                    def = DeferredUtils.createDeferred(app, 'StringConverterMixin: prepareNodeForStorage');
+                    def = self.createDeferred('StringConverterMixin.prepareNodeForStorage');
 
                 // updating progress bar
                 if (maindef) {
@@ -274,18 +296,18 @@ define('io.ox/office/textframework/model/stringconvertermixin', [
             if (!self.getCommentLayer().isEmpty()) { allNodesCollector.push({ extension: '_CL', selector: DOM.COMMENTLAYER_NODE_SELECTOR, allNodes: self.getNode().children(DOM.COMMENTLAYER_NODE_SELECTOR).find('*') }); }
 
             // iterating over all nodes (first page content, then drawing layer, ...)
-            return self.iterateArraySliced(allNodesCollector, function (oneLayer) {
+            var promise = self.iterateArraySliced(allNodesCollector, function (oneLayer) {
 
-                return self.iterateArraySliced(oneLayer.allNodes, prepareNodeForStorage, { delay: 'immediate', infoString: 'Text: getFullModelDescription: inner', app: app })
+                return self.iterateArraySliced(oneLayer.allNodes, prepareNodeForStorage, 'StringConverterMixin.getFullModelDescription')
                 .done(function () {
                     // collecting the html strings for each layer
                     allHtmlStrings.push({ extension: oneLayer.extension, htmlString: self.getNode().children(oneLayer.selector).html() });
                 });
-            }, { infoString: 'Text: getFullModelDescription: outer', app: app })
-            .then(function () {
+            }, 'StringConverterMixin.getFullModelDescription');
+
+            return promise.then(function () {
                 return allHtmlStrings;
             });
-
         };
 
         /**
@@ -431,6 +453,8 @@ define('io.ox/office/textframework/model/stringconvertermixin', [
                                 imgNode.attr('src', srcAttr);
                                 imgNode.attr(DOM.LOCALSTORAGE_SRC_OVERRIDE, null);
                             }
+                        } else if (!app.isODF() && DrawingFrame.isShapeDrawingFrame(node)) {
+                            removeEmptyTextFrameNodesInDrawing(node); // removing empty text frames without paragraphs (no paragraphs in special shapes, 50349)
                         }
 
                     });
@@ -452,7 +476,9 @@ define('io.ox/office/textframework/model/stringconvertermixin', [
 
                 // setting table cell attribute 'contenteditable' to true for non-MSIE browsers (task 33642)
                 // -> this is not necessary, if the document was loaded from the local storage
-                if (!usedLocalStorage && !_.browser.IE) { contentNode.find('div.cell').attr('contenteditable', true); }
+                if (!usedLocalStorage) {
+                    Utils.handleReadOnly(contentNode.find('div.cell'));
+                }
 
                 // assigning page content attributes, that are saved at its first child
                 if (contentNode.children(':first').attr('pagecontentattr')) {
