@@ -47,7 +47,7 @@ define('io.ox/office/textframework/model/tableoperationmixin', [
          * Removing all cell contents.
          *
          * @param {HTMLElement|jQuery} cellNode
-         *  The cell node, whose content will be replaced by an implicit paragraph.
+         *  The cell node, whose content will be replaced by a non-implicit paragraph.
          */
         function implClearCell(cellNode) {
 
@@ -80,9 +80,7 @@ define('io.ox/office/textframework/model/tableoperationmixin', [
         function implInsertTable(operation) {
 
             var // the new table
-                table = $('<table>').attr('role', 'grid').append($('<colgroup>')),
-                // insert the table into the DOM tree
-                inserted,
+                table = $('<table role="grid">').append($('<colgroup>')),
                 // new implicit paragraph behind the table
                 newParagraph = null,
                 // number of rows in the table (only for operation.sizeExceeded)
@@ -109,14 +107,8 @@ define('io.ox/office/textframework/model/tableoperationmixin', [
                 currentElement = Position.getContentNodeElement(self.getNode(), operation.start);
             }
 
-            if (operation.target) {
-                inserted = self.insertContentNode(_.clone(operation.start), table, operation.target);
-            } else {
-                inserted = self.insertContentNode(_.clone(operation.start), table);
-            }
-
             // insertContentNode() writes warning to console
-            if (!inserted) { return false; }
+            if (!self.insertContentNode(_.clone(operation.start), table, operation.target)) { return false; }
 
             // generate undo/redo operations
             if (self.getUndoManager().isUndoEnabled()) {
@@ -577,7 +569,7 @@ define('io.ox/office/textframework/model/tableoperationmixin', [
                 // the undo manager object
                 undoManager = self.getUndoManager(),
                 //generator of operations
-                generator = undoManager.isUndoEnabled() ? self.createOperationsGenerator() : null,
+                generator = undoManager.isUndoEnabled() ? self.createOperationGenerator() : null,
                 // created operation
                 newOperation = null;
 
@@ -803,7 +795,7 @@ define('io.ox/office/textframework/model/tableoperationmixin', [
                     // a new implicit paragraph
                     newParagraph = null,
                     // operations generator
-                    generator = this.createOperationsGenerator(),
+                    generator = this.createOperationGenerator(),
                     // whether an additional paragraph is required behind or before the table
                     insertAdditionalParagraph = false,
                     // the logical position of the additional paragraph
@@ -978,7 +970,7 @@ define('io.ox/office/textframework/model/tableoperationmixin', [
                     // the row attributes
                     rowAttrs = {},
                     // operations generator
-                    generator = this.createOperationsGenerator(),
+                    generator = this.createOperationGenerator(),
                     // created operation
                     newOperation = null;
 
@@ -1074,7 +1066,7 @@ define('io.ox/office/textframework/model/tableoperationmixin', [
                     // all rows in the table
                     allRows = DOM.getTableRows(tablePoint.node),
                     // operations generator
-                    generator = this.createOperationsGenerator(),
+                    generator = this.createOperationGenerator(),
                     // the attributes assigned to the cell(s)
                     cellAttrs = null,
                     // created operation
@@ -1136,7 +1128,7 @@ define('io.ox/office/textframework/model/tableoperationmixin', [
                                 // -> no implicit paragraph in these cells
                                 newOperation = { start: paraPos, attrs: paraAttributes };
                                 self.extendPropertiesWithTarget(newOperation, target);
-                                generator.generateOperation(Operations.PARA_INSERT, newOperation);
+                                generator.generateOperation(Operations.SET_ATTRIBUTES, newOperation); // setAttributes instead of insertParagraph (53152)
                             }
                         }
 
@@ -1351,7 +1343,7 @@ define('io.ox/office/textframework/model/tableoperationmixin', [
             return undoManager.enterUndoGroup(function () {
 
                 var // operations generator
-                    generator = this.createOperationsGenerator(),
+                    generator = this.createOperationGenerator(),
                     // the selection object
                     selection = self.getSelection(),
                     //position of the cursor
@@ -1396,7 +1388,8 @@ define('io.ox/office/textframework/model/tableoperationmixin', [
                     // #36130 - avoid error in console: Selection.restoreBrowserSelection(): missing text selection range
                     selection.setTextSelection(Position.getFirstPositionInParagraph(activeRootNode, newPosition.slice(0, -1)));
 
-                    operationOptions = { start: newPosition.slice(0, -1), attrs: attrs };
+                    operationOptions = { start: newPosition.slice(0, -1) };
+                    if (attrs) { operationOptions.attrs = attrs; }
                     self.extendPropertiesWithTarget(operationOptions, target);
                     generator.generateOperation(Operations.PARA_INSERT, operationOptions);
 
@@ -1444,7 +1437,7 @@ define('io.ox/office/textframework/model/tableoperationmixin', [
                     // second table node, which we try to merge with first, old one
                     secondTableNode,
                     // operations generator
-                    generator = this.createOperationsGenerator(),
+                    generator = this.createOperationGenerator(),
                     operationOptions = {};
 
                 // merging is designed to try to merge with next element, so if we are already at next element jump back to previous
