@@ -13,25 +13,19 @@
  */
 
 define('io.ox/office/textframework/selection/androidselection', [
-    'io.ox/office/tk/utils',
+    'io.ox/office/textframework/utils/textutils',
     'io.ox/office/tk/keycodes',
     'io.ox/office/tk/forms',
     'io.ox/office/tk/render/font',
-    'io.ox/office/baseframework/app/appobjectmixin',
     'io.ox/office/textframework/utils/operations',
     'io.ox/office/textframework/utils/position',
     'io.ox/office/textframework/utils/dom'
-], function (Utils, KeyCodes, Forms, Font, AppObjectMixin, Operations, Position, DOM) {
+], function (Utils, KeyCodes, Forms, Font, Operations, Position, DOM) {
 
     'use strict';
 
     var NBSP = '\xa0';
     var DUMMYLEN = 50;
-    var CURSOR = 'androidcursor';
-    var IMEMODE = 'androidime';
-    var BLINK = 'androidblink';
-    var SELECTOR = '.' + CURSOR + ', .' + IMEMODE;
-    var CLASSES = CURSOR + ' ' + IMEMODE;
 
     //first letter is workaround for Camel-Case-Behavior on some devices (Bug 40066)
     var INITTEXT = 'G' + Utils.repeatString(' ', DUMMYLEN - 1);
@@ -46,39 +40,60 @@ define('io.ox/office/textframework/selection/androidselection', [
     /**
      *
      * @constructor
-     *
-     * @extends AppObjectMixin
      */
-    function AndroidSelection(app, rootNode) {
+    function AndroidSelection(docModel, updateLogicalPosition) {
 
         var self = this;
+
+        // the application instance
+        var app = docModel.getApp();
+
+        // slide mode for spreadsheet/presentation
+        var slideMode = docModel.useSlideMode();
+
         var blinkDeferred = null;
-        var oldPara = null;
-        var oldStart = null;
-        var oldEnd = null;
+        var positionOx = null;
 
         var wordFrom = null;
         var wordTo = null;
         var word = null;
 
-        var div = $('<div>');
+        var div = $('<div class="edit-overlay">');
         var textarea = null;
+        var caret = null;
+        var highlight = null;
         var singleArray = [0];
 
-        var restoreFN = null;
-        var lastCursorIndex = -5000;
-
-        // base constructor ---------------------------------------------------
-
-        AppObjectMixin.call(this, app);
+        var restoreFN = $.noop;
 
         // private methods ----------------------------------------------------
 
+        function updateHighlight(from, to) {
+            var rootNode = docModel.getSelection().getRootNode();
+            var imeRect = getRectangleFromPoints(Position.getDOMPosition(rootNode, from), Position.getDOMPosition(rootNode, to));
+
+            highlight.css({
+                top: imeRect.top + imeRect.height + 1,
+                left: imeRect.left,
+                width: imeRect.width
+            });
+
+        }
         function isSoftKeyboardOpen() {
-            if (Utils.isSoftKeyboardOpen()) {
-                //TODO: better check focus in textarea!!!
-                return (Utils.getInnerWindowHeight() / Utils.getScreenHeight()) < 0.7;
-            }
+            return (Utils.getInnerWindowHeight() / Utils.getScreenHeight()) < 0.7;
+        }
+
+        function getRectangleFromPoints(point1, point2) {
+            // the root node of the document
+            var rootNode = docModel.getNode();
+
+            var offsetTop = parseFloat(rootNode.css('margin-top'));
+            // use only top because page transform-origin is "center top"
+
+            var rect = Utils.getCSSRectangleFromPoints(point1, point2, rootNode, 1, true);
+            rect.left +=  (app.getView().getZoomFactor() < 0.99 ? 3 : 0); // magic number '3' is needed because of 'recalculateDocumentMargin' in presentation/view.js
+            rect.top += offsetTop;
+            return rect;
         }
 
         function splitTextSpan(para, pos) {
@@ -114,37 +129,19 @@ define('io.ox/office/textframework/selection/androidselection', [
             span.appendChild(document.createTextNode(text));
         }
 
-        function getWordBoundary(para, pos, beginning, dontAddSpace) {
-            var len = pos.length;
-            singleArray[0] = pos[len - 1];
-
-            var result = _.clone(pos);
-            result[len - 1] = Position.getWordBoundary(para[0], singleArray, beginning, dontAddSpace)[0];
-            return result;
-        }
-
         function changeSelection(event, selectionInfo) {
-            var start = selectionInfo.start;
-            var end = selectionInfo.end;
+            //console.log('fff changeSelection', selectionInfo);
+            var start = _.clone(selectionInfo.start);
+            var end = _.clone(selectionInfo.end);
+            // the selection object
+            var selection = docModel.getSelection();
 
-            var spans = null;
-            var node = null;
+            positionOx = null;
 
-            if (oldPara) {
-                oldPara.removeClass(BLINK);
-                spans = oldPara.find(SELECTOR);
-                spans.removeClass(CLASSES);
-                /*
-                spans.each(function () {
-                    TextUtils.mergeSiblingTextSpans(this, true);
-                });
-                */
-                oldPara = null;
-            }
+//            var visibility = 'hidden';
+            var imeVis = 'hidden';
 
-            var visibility = 'hidden';
-
-            if (app.getModel().getEditMode()) {
+            if (app.isEditable()) {
 
                 var selType = window.getSelection().type;
                 if (!selType || selType === 'None') {
@@ -153,35 +150,44 @@ define('io.ox/office/textframework/selection/androidselection', [
 
                 if (_.isEqual(start, end) && selType) {
 
-                    oldPara = $(Position.getDOMPosition(app.getModel().getCurrentRootNode(), _.initial(start)).node);
-                    oldPara.addClass(BLINK);
+                    var oldPara = $(Position.getDOMPosition(selectionInfo.rootNode, _.initial(start)).node);
+                    var wordSelection = Position.getWordSelection(oldPara, _.last(start), ENDCHARS, { fillPlaceholders: true });
+                    if (wordSelection) {
+                        var i = 0;
+                        for (i = 0; i < wordSelection.text.length; i++) {
+                            if (wordSelection.text[0] === ' ') {
+                                wordSelection.text = wordSelection.text.substring(1, wordSelection.text.length);
+                                wordSelection.start++;
+                            } else {
+                                break;
+                            }
+                        }
+                        for (i = wordSelection.text.length - 1; i >= 0; i--) {
+                            if (wordSelection.text[wordSelection.text.length - 1] === ' ') {
+                                wordSelection.text = wordSelection.text.substring(0, wordSelection.text.length - 1);
+                                wordSelection.end--;
+                            } else {
+                                break;
+                            }
+                        }
 
-                    wordFrom = getWordBoundary(oldPara, start, true);
-                    wordTo = getWordBoundary(oldPara, start, false, true);
-                    if (_.isEqual(wordFrom, wordTo) ||  _.last(wordFrom) >= _.last(wordTo)) {
-                        start[start.length - 1] -= 1;
-                        wordFrom = getWordBoundary(oldPara, start, true);
-                        wordTo = getWordBoundary(oldPara, start, false, true);
-                        start[start.length - 1] += 1;
-                    }
+                        wordSelection.text = wordSelection.text.replace(/\s/g, '\u200B');
 
-                    if (_.last(wordFrom) < _.last(wordTo)) {
-                        splitTextSpan(oldPara, wordFrom);
-                        splitTextSpan(oldPara, wordTo);
+                        wordFrom = _.clone(start);
+                        wordFrom[wordFrom.length - 1] = wordSelection.start;
 
-                        word = '';
+                        wordTo = _.clone(start);
+                        wordTo[wordTo.length - 1] = wordSelection.end;
 
-                        singleArray[0] = _.last(wordFrom);
-                        var spanFrom = Position.getDOMPosition(oldPara[0], singleArray, true).node;
+                        if (_.last(wordFrom) < _.last(wordTo)) {
+                            word = wordSelection.text;
 
-                        var len = 0;
-                        var maxLen = _.last(wordTo) - _.last(wordFrom);
-
-                        while (len < maxLen && spanFrom) {
-                            word += spanFrom.innerHTML;
-                            len = word.length;
-                            spanFrom.classList.add(IMEMODE);
-                            spanFrom = spanFrom.nextSibling;
+                            imeVis = 'visible';
+                            updateHighlight(wordFrom, wordTo);
+                        } else {
+                            wordFrom = _.clone(start);
+                            wordTo =  _.clone(start);
+                            word = '';
                         }
                     } else {
                         wordFrom = _.clone(start);
@@ -189,34 +195,58 @@ define('io.ox/office/textframework/selection/androidselection', [
                         word = '';
                     }
 
-                    oldPara.find('.' + CURSOR).removeClass(CURSOR);
-                    node = splitTextSpan(oldPara, start);
-                    node = $(node);
-                    node.addClass(CURSOR);
-                    oldStart = start;
-                    oldEnd = end;
+                    positionOx = { start: start, end: end, para: oldPara, rootNode: selectionInfo.rootNode };
 
                     selectTextArea();
+
+                    // if (slideMode || !app.getView().isSoftkeyboardEditModeOff()) {
+                    //     selectTextArea();
+                    // }
+
                     handleTextAreaPos();
-                    visibility = 'visible';
+        //            visibility = 'visible';
                 }
+
+                // no blinking cursor, if a drawing is selected or this is a slide selection (52922)
+                if (docModel.useSlideMode()) { caret.toggleClass('noblinkingcursor', selection.isSlideSelection() || selection.isDrawingSelection()); }
+
             }
-            div.css('visibility', visibility);
+
+        //    textarea.css('visibility', visibility);
+            highlight.css('visibility', imeVis);
         }
 
         function handleTextAreaPos() {
-            var parent = div.parent();
-            if (parent && parent.length) {
+            // not edit mode -> return
+            if (positionOx === null) { return; }
 
-                var zoom = app.getView().getZoomFactor();
-                var pos = Position.getPixelPositionFromDomPoint(rootNode,
-                        [_.last(oldStart)], zoom, oldPara);
-                var multi = zoom / 100;
-                div.css({
-                    left: pos.left * multi - 5,
-                    top: pos.top * multi + pos.height * multi - 30
-                });
+            var start = Position.getDOMPosition(positionOx.rootNode, positionOx.start);
+            if (!start) {
+                Utils.warn(positionOx.start + ' does not lead to a DomPos!');
+                return;
             }
+
+            var end = null;
+            if (_.last(positionOx.start) > 0) {
+                // workaround for empty paragraph -> lead to zero size range rectangle
+                end = start;
+            }
+            var rect = getRectangleFromPoints(start, end);
+
+            caret.css({
+                left: rect.left,
+                top: rect.top,
+                width: 2,
+                height: rect.height
+            });
+            textarea.css({
+                left: rect.left - 4,
+                top: rect.top - 10,
+                width: 8,
+                minWidth: 8,
+                height: rect.height + 20,
+                zIndex: 100
+            });
         }
 
         function isPassThrough(event, press) {
@@ -250,10 +280,12 @@ define('io.ox/office/textframework/selection/androidselection', [
         }
 
         function handlePassThrough(event) {
-            var docModel = app.getModel();
+            var rootNode = docModel.getNode();
 
             if (!event.shiftKey && (event.keyCode === KeyCodes.UP_ARROW || event.keyCode === KeyCodes.DOWN_ARROW)) {
                 event.preventDefault();
+                /*
+                FIXME
                 if (event.type === 'keydown' && oldPara) {
                     var offset = event.keyCode === KeyCodes.UP_ARROW ? -1 : 1;
 
@@ -284,7 +316,7 @@ define('io.ox/office/textframework/selection/androidselection', [
                     }
 
                     self.setTextSelection(newOxo.start);
-                }
+                }*/
             } else if (!event.shiftKey && (event.keyCode === KeyCodes.LEFT_ARROW || event.keyCode === KeyCodes.RIGHT_ARROW)) {
                 docModel.handleAndroidTyping();
                 event.preventDefault();
@@ -298,34 +330,56 @@ define('io.ox/office/textframework/selection/androidselection', [
             return true;
         }
 
-        function simulateEvent(keyCode) {
-            handlePassThrough(new $.Event('keydown', { keyCode: keyCode }));
-            handlePassThrough(new $.Event('keypress', { keyCode: keyCode }));
-            handlePassThrough(new $.Event('keyup', { keyCode: keyCode }));
+        function simulateEvent(event, keyCode) {
+
+            updateLogicalPosition(positionOx.start, { start: true });
+            updateLogicalPosition(positionOx.end, { start: false });
+
+            textarea.val(INITTEXT);
+            Forms.setInputSelection(textarea, DUMMYLEN);
+
+            if (event.type === 'keyup') {
+                handlePassThrough(new $.Event('keydown', { keyCode: keyCode }));
+                handlePassThrough(new $.Event('keypress', { keyCode: keyCode, charCode: keyCode }));
+                handlePassThrough(new $.Event('keyup', { keyCode: keyCode }));
+            }
         }
 
         function changedText(event) {
-            var docModel = app.getModel();
+
             var cursorIndex = getCursorIndex();
+            // console.log('');
+            // console.warn('space?', cursorIndex, event.type, event.keyCode, event.charCode);
 
             if (isPassThrough(event)) {
                 handlePassThrough(event);
-                lastCursorIndex = cursorIndex;
+                restoreFN();
+                return;
             } else {
                 var text = getText();
+                // console.warn('text', text.length, '"' + text + '"');
 
-                if (cursorIndex < 0 || (cursorIndex + 1 === lastCursorIndex && text.length <= 1)) {
-                    //backspace!
-                    if (event.type === 'input') {
-                        simulateEvent(KeyCodes.BACKSPACE);
-                    }
-                    lastCursorIndex = cursorIndex;
+                if (cursorIndex < 0) {
+                    // backspace!
+                    // console.warn('sim BACKSPACE');
+                    simulateEvent(event, KeyCodes.BACKSPACE);
+                    return;
+                } else if (!text.length) {
+                    docModel.handleAndroidTyping();
+                    // console.warn('RETURN');
+                    return;
+                } else if (text === ' ' && cursorIndex === 1) {
+                    // space!
+                    // console.warn('sim SPACE');
+                    simulateEvent(event, KeyCodes.SPACE);
+                    return;
+                } else if (text.indexOf('\n') >= 0) {
+                    // enter!
+                    // console.warn('sim ENTER');
+                    simulateEvent(event, KeyCodes.ENTER);
                     return;
                 }
 
-                lastCursorIndex = cursorIndex;
-
-                docModel.handleAndroidTyping();
                 if (text.length > 0) {
 
                     var preAttrs = docModel.getPreselectedAttributes() || undefined;
@@ -343,81 +397,100 @@ define('io.ox/office/textframework/selection/androidselection', [
                     var undoOperations = [];
                     var redoOperations = [];
 
-                    if (DOM.isImplicitParagraphNode(oldPara[0])) {
-                        oldPara.data('implicit', false);
+                    if (DOM.isImplicitParagraphNode(positionOx.para[0])) {
+                        positionOx.para.data('implicit', false);
                         redoOperations.push({ name: Operations.PARA_INSERT, start: _.initial(wordFrom) });
-                        undoOperations.push({ name: Operations.DELETE, start: _.initial(wordFrom) });
+                        makeDelOps(undoOperations, _.initial(wordFrom));
                     }
 
-                    if (text.length - 1 === word.length && text.substring(0, text.length - 1) === word && !preAttrs) {
-                        //optimized for forward typing
-                        redoOperations.push({ name: Operations.TEXT_INSERT, start: _.clone(wordTo), text: text.substring(text.length - 1, text.length), attrs: attrs });
-                        undoOperations.push({ name: Operations.DELETE, start: _.clone(wordTo), end: _.clone(wordTo) });
+                    var insertOp = { name: Operations.TEXT_INSERT, start: _.clone(wordTo), text: text, attrs: attrs };
+                    redoOperations.push(insertOp);
+
+                    var startWord = _.clone(wordFrom);
+                    var endWord = null;
+                    var offset = 0;
+
+                    if (_.last(wordFrom) !== _.last(wordTo)) {
+                        endWord = Position.increaseLastIndex(wordTo, -1);
+                        offset = makeDelOps(redoOperations, startWord, endWord);
+
+                        var insStart = Position.increaseLastIndex(wordFrom, text.length);
+                        var undoDeleteOp = { name: Operations.TEXT_INSERT, start: insStart, text: word, attrs: preAttrs };
+                        undoOperations.push(undoDeleteOp);
                     } else {
-                        var insertOp = { name: Operations.TEXT_INSERT, start: _.clone(wordTo), text: text, attrs: attrs };
-                        redoOperations.push(insertOp);
-
-                        var deleteOp = null;
-
-                        if (_.last(wordFrom) !== _.last(wordTo)) {
-                            deleteOp = { name: Operations.DELETE, start: _.clone(wordFrom), end: Position.increaseLastIndex(wordTo, -1) };
-                            redoOperations.push(deleteOp);
-                        }
-
-                        if (deleteOp) {
-                            var insStart = Position.increaseLastIndex(wordFrom, text.length);
-                            var undoDeleteOp = { name: Operations.TEXT_INSERT, start: insStart, text: word, attrs: preAttrs };
-                            undoOperations.push(undoDeleteOp);
-                        }
-
-                        var undoInsertOp = { name: Operations.DELETE, start: _.clone(wordFrom), end: Position.increaseLastIndex(wordTo, -1) };
-                        undoOperations.push(undoInsertOp);
+                        endWord = _.clone(wordFrom);
                     }
 
+                    makeDelOps(undoOperations, startWord, endWord);
+
                     sendOperations(docModel, changeTrack, undoOperations, redoOperations);
 
                     var leftNoIME = _.contains(ENDCHARS, text[cursorIndex - 1]);
 
                     applyOperations(docModel, redoOperations);
 
+                    // var pos = _.last(wordTo) - text.length + cursorIndex;
                     var pos = _.last(wordFrom) + cursorIndex;
-                    if (cursorIndex > 0 && cursorIndex < text.length) {
-                        var before = splitTextSpan(oldPara, [pos]);
-                        oldPara.find('.' + CURSOR).removeClass(CURSOR);
-                        before.classList.add(CURSOR);
-                    }
-                    oldStart[oldStart.length - 1] = pos;
-                    oldEnd[oldEnd.length - 1] = pos;
+                    positionOx.start[positionOx.start.length - 1] = pos;
+                    positionOx.end[positionOx.end.length - 1] = pos;
+
+                    updateLogicalPosition(positionOx.start, { start: true });
+                    updateLogicalPosition(positionOx.end, { start: false });
 
                     if (leftNoIME) {
                         word = text.substring(cursorIndex);
                         wordFrom[wordFrom.length - 1] = pos;
                         wordTo[wordTo.length - 1] = _.last(wordFrom) + word.length;
 
-                        oldPara.find('span.' + IMEMODE).removeClass(IMEMODE);
-
                         selectTextArea();
                     } else {
                         word = text;
                         wordTo[wordTo.length - 1] = _.last(wordFrom) + text.length;
-
-                        var bulletDiv = oldPara.find('>div.' + CURSOR);
-                        if (bulletDiv.length) {
-                            bulletDiv.removeClass(CURSOR);
-                            oldPara.find('span.' + IMEMODE).addClass(CURSOR);
-                        }
                     }
 
+                    updateHighlight(wordFrom, wordTo);
                     handleTextAreaPos();
 
-                    if (attrs) {
-                        docModel.getStyleCollection('paragraph').updateElementFormatting(oldPara);
-                    }
+                    // console.warn('change', 'start', positionOx.start, 'wordFrom', wordFrom, 'wordTo', wordTo);
 
+                    if (attrs) {
+                        docModel.getStyleCollection('paragraph').updateElementFormatting(positionOx.para);
+                    }
+                    if (offset > 0) {
+                        changeSelection(null, { start:  _.clone(positionOx.start), end: _.clone(positionOx.end), rootNode: docModel.getSelection().getRootNode() });
+                    }
                 }
+                docModel.handleAndroidTyping();
             }
         }
 
+        function makeDelOps(ops, start, end) {
+            var offset = 0;
+            if (end) {
+                var startPos = getDOMPosition(start);
+                var endPos = getDOMPosition(end);
+                if (startPos.nodeIndex === endPos.nodeIndex) {
+                    ops.push({ name: Operations.DELETE, start: start, end: end });
+                } else {
+
+                    for (var i = _.last(end); i >= _.last(start); i--) {
+                        var pos = _.initial(start);
+                        pos.push(i);
+
+                        var domPos = getDOMPosition(pos);
+                        if (DOM.isRangeMarkerNode(domPos.node) || DOM.isSubstitutionPlaceHolderNode(domPos.node)) {
+                            offset++;
+                        } else {
+                            ops.push({ name: Operations.DELETE, start: pos, end: pos });
+                        }
+                    }
+                }
+            } else {
+                ops.push({ name: Operations.DELETE, start: start });
+            }
+            return offset;
+        }
+
         function sendOperations(docModel, changeTrack, undoOperations, redoOperations) {
             if (changeTrack.isActiveChangeTracking()) {
                 var info = changeTrack.getChangeTrackInfo();
@@ -436,7 +509,7 @@ define('io.ox/office/textframework/selection/androidselection', [
             if (!pos) { return; }
 
             singleArray[0] = _.last(pos);
-            var node = Position.getDOMPosition(oldPara, singleArray, true);
+            var node = Position.getDOMPosition(positionOx.para, singleArray, true);
             if (node) {
 //                node.node = node.node.parentElement;
                 node.nodeIndex = $(node.node).index();
@@ -449,10 +522,10 @@ define('io.ox/office/textframework/selection/androidselection', [
             _.each(ops, function (op) {
 
                 var start = getDOMPosition(op.start);
-                var end = getDOMPosition(op.end);
                 var text;
 
                 if (op.name === Operations.DELETE) {
+                    var end = getDOMPosition(op.end);
 
                     if (start.nodeIndex === end.nodeIndex) {
                         text = start.node.innerText;
@@ -463,10 +536,10 @@ define('io.ox/office/textframework/selection/androidselection', [
                         fillTextInSpan(start.node, startText.substring(0, start.offset));
                         var endText = end.node.innerText;
                         fillTextInSpan(end.node, endText.substring(end.offset + 1));
-                        var children = oldPara.children();
+                        var children = positionOx.para.children();
                         if ((end.nodeIndex - start.nodeIndex) > 1) {
                             for (var ni = start.nodeIndex + 1; ni < end.nodeIndex; ni++) {
-                                oldPara[0].removeChild(children[ni]);
+                                positionOx.para[0].removeChild(children[ni]);
                             }
                         }
                     }
@@ -477,22 +550,28 @@ define('io.ox/office/textframework/selection/androidselection', [
                         opText = opText.substring(0, opText.length - 1) + NBSP;
                     }
 
+                    if (!start.offset && start.nodeIndex > 0 && DOM.isTextSpan(start.node.previousSibling)) {
+                        start.nodeIndex--;
+                        start.node = start.node.previousSibling;
+                        start.offset = start.node.innerHTML.length;
+                    }
+
                     var attrs = op.attrs;
                     text = start.node.innerText;
                     text = text.substring(0, start.offset) + opText + text.substring(start.offset);
                     fillTextInSpan(start.node, text);
 
-                    start.node.classList.add(IMEMODE);
                     var splitStart = _.last(op.start);
                     var splitEnd = splitStart - start.offset;
 
+                    // console.warn('splitStart', splitStart, 'splitEnd', splitEnd);
+
                     var counter = start.offset;
                     for (var i = splitStart; i >= splitEnd; i--) {
                         counter--;
                         if (_.contains(ENDCHARS, text[counter])) {
 
-                            var before = splitTextSpan(oldPara, [i]);
-                            before.classList.remove(IMEMODE, CURSOR);
+                            var before = splitTextSpan(positionOx.para, [i]);
                             var beforeText = before.innerText;
 
                             if (_.last(beforeText) === NBSP) {
@@ -502,7 +581,7 @@ define('io.ox/office/textframework/selection/androidselection', [
                         }
                     }
 
-                    handlePreselectedAttrs(attrs, start.node);
+                    handlePreselectedAttrs(attrs, start); //fix me wrong node
                 }
             });
 
@@ -530,21 +609,32 @@ define('io.ox/office/textframework/selection/androidselection', [
 
         }
 
-        function handlePreselectedAttrs(attrs) {
+        function handlePreselectedAttrs(attrs, domPos) {
+
             if (attrs) {
+                // if (domPos.offset > 0) {   //TODO must be splitted
+                //     DOM.splitTextSpan(domPos.node, domPos.offset);
+                // }
                 attrs = { attributes: attrs };
-                for (var i = 1; i < arguments.length; i++) {
-                    $(arguments[i]).data(attrs);
-                }
+                $(domPos.node).data(attrs);
             }
         }
 
-        textarea = $('<textarea>');
+        textarea = $('<textarea class="edit-textarea">');
+        caret = $('<div class="edit-caret"></div>');
+        highlight = $('<div class="edit-highlight"></div>');
 
         function selectTextArea() {
-            Utils.setFocus(textarea);
+            //console.error('fff selectTextArea');
+
+            // not edit mode -> return
+            if (positionOx === null) { return; }
+
+            if (document.activeElement !== textarea[0]) {
+                Utils.setFocus(textarea);
+            }
             textarea.val(INITTEXT + word);
-            Forms.setInputSelection(textarea, DUMMYLEN + (_.last(oldStart) - _.last(wordFrom)));
+            Forms.setInputSelection(textarea, DUMMYLEN + (_.last(positionOx.start) - _.last(wordFrom)));
         }
 
         function getCursorIndex() {
@@ -552,49 +642,57 @@ define('io.ox/office/textframework/selection/androidselection', [
         }
 
         function getText() {
-            return textarea.val().substring(DUMMYLEN);
-        }
-
-        function resetTextarea() {
-            div.css('visibility', 'hidden');
-        }
-
-        function setReadOnly() {
-            //console.error('setReadOnly');
-            rootNode.css('-webkit-user-modify', 'read-only');
-        }
-
-        function setReadWrite() {
-            //console.error('setReadWrite');
-            rootNode.css('-webkit-user-modify', 'read-write');
+            return textarea.val().substring(DUMMYLEN).replace(/\\u200B/g, '');
         }
 
         var processSelectUpdate = (function () {
+        //    var lastEvent = null;
+
             var always = function () {
+                if (!docModel) { return; }
+
                 var selecttype = window.getSelection().type;
-                if (Utils.getActiveElement() === rootNode[0] || (app.getModel().useSlideMode() && $(Utils.getActiveElement()).is('.drawing'))) {
-                    //listener hangs directly on document, but we only want the events of editdiv
+        //        console.log('always');
+                // selecting
+                var rootNode = docModel.getSelection().getRootNode();
+//                console.log('always1', Utils.getActiveElement(), rootNode[0]);
+                if (Utils.getActiveElement() === rootNode[0] || (slideMode && $(Utils.getActiveElement()).is('.drawing'))) {
+//                    console.log('in....');
+                    // listener hangs directly on document, but we only want the events of editdiv
                     if (selecttype !== 'None') {
-                        self.updateSelectionAfterBrowserSelection({ preserveFocus: false, forceTrigger: false });
-                        if (selecttype === 'Caret') {
-                            setReadOnly();
-                        }
+//                        console.log('always2', selecttype);
+                        self.updateSelectionAfterBrowserSelection({ preserveFocus: false, forceTrigger: false }); // prpbrowserevent
+        //               self.processBrowserEvent(lastEvent);
+
                     }
+
+                    // hide caret when a selection range is visible
+                    if (selecttype === 'Range') {
+            //            console.log('RANGE');
+                        caret.css('visibility', 'hidden');
+                        highlight.css('visibility', 'hidden');
+
+                        // close keyboard when a range is selected and the keyboard is open -> ime backspace problem
+                        if (isSoftKeyboardOpen()) {
+    //                        console.log('CLOSE KEYBOARD');
+                            docModel.trigger('selection:possibleKeyboardClose', { forceClose: true });
+                        }
+
+                    } else {
+                        caret.css('visibility', 'visible');
+                    }
+
+                // writing
                 } else if (Utils.getActiveElement() === textarea[0]) {
                     if (window.getSelection().anchorNode === div[0]) {
                         //focus really in textarea
                         if (selecttype === 'Range') {
+    //                        console.log('TEXTAREA');
                             if (_.last(wordFrom) < _.last(wordTo)) {
                                 restoreFN();
                                 self.setTextSelection(wordFrom, wordTo);
                             }
                         }
-                        setReadOnly();
-                    } else {
-                        //focus in document
-                        if (selecttype !== 'Range') {
-                            setReadOnly();
-                        }
                     }
                 }
             };
@@ -603,6 +701,10 @@ define('io.ox/office/textframework/selection/androidselection', [
             return function (evt) {
 
                 var selecttype = window.getSelection().type;
+
+            //    console.log('processSelectUpdate', selecttype);
+    //            lastEvent = evt;
+
                 if (evt.type === 'selectstart') {
                     if (selecttype === 'Range') {
                         ///User seems to call "select all", but android chrome does not really support that featurem when contenteditable=true and begins with scrolling :(
@@ -614,99 +716,88 @@ define('io.ox/office/textframework/selection/androidselection', [
                     notAlways();
                 }
 
-                if (selecttype === 'Range') {
-                    if (isSoftKeyboardOpen()) {
-                        setReadOnly();
-                        _.defer(setReadWrite);
-                    } else if (rootNode.css('-webkit-user-modify') === 'read-only') {
-                        setReadWrite();
-                    }
-                }
+                // if (selecttype === 'Range') {
+                //     if (isSoftKeyboardOpen()) {
+                //         docModel.trigger('selection:possibleKeyboardClose');
+                //     }
+                // }
+
             };
         }());
 
-        //---------init---------
+        // initialization -----------------------------------------------------
 
-        textarea.on('keyup keydown change input', changedText);
+        textarea.on('keyup keydown', changedText);
         textarea.on('keypress', passThrough);
 
         self.on('changecursorinfo', changeSelection);
 
         blinkDeferred = app.repeatDelayed(function () {
-            if (oldPara) {
-                if (Utils.getActiveElement() && Utils.getActiveElement().tagName === 'INPUT') {
-                    oldPara.removeClass(BLINK);
-                } else {
-                    oldPara.toggleClass(BLINK);
-                }
-            }
-        }, { delay: 500, infoString: 'Text: Selection: blinkDeferred', app: app });
+            caret.toggleClass('androidblink');
+        }, 'AndroidSelection.blinkDeferred', 500);
 
         this.waitForImportSuccess(function () {
             var docView = app.getView();
 
             restoreFN = _.bind(self.restoreBrowserSelection, self);
-
+            /*
             self.restoreBrowserSelection = function () {
                 //sideEffect of passThrough, with original restoreFN textarea-focus gets lost
                 if (!_.isEqual(self.getStartPosition(), self.getEndPosition())) {
                     restoreFN();
                 }
             };
+            */
 
-            var docModel = app.getModel();
             textarea.on('cut copy paste', function (evt) {
+                // TODO maybe update oxoposition to be sure that it's correct?
                 docModel[evt.type](evt);
             });
 
-            div.css({
-                position: 'absolute',
-                zIndex: 10,
-                top: '30px',
-                width: '10px',
-                height: '40px',
-                overflow: 'hidden'
-            });
-
             textarea.css({
-                position: 'absolute',
-                width: '10px',
                 letterSpacing: -LETTER_WIDTH + 'px',
                 fontFamily: MONO_FONT.family,
                 fontSize: MONO_FONT.size + 'pt',
-                lineHeight: MONO_FONT.size + 'pt',
-                height: '30px',
-                overflow: 'hidden',
-                outline: 'none',
-                opacitiy: 0,
-                margin: 0,
-                padding: 0,
-                textIndent: '3px',
-                left: 0,
-                top: 0
+                lineHeight: MONO_FONT.size + 'pt'
             });
 
             textarea.addClass('transparent-selection');
 
             div.append(textarea);
-            rootNode.parent().append(div);
+            div.append(caret);
+            div.append(highlight);
+
+            docModel.getNode().parent().append(div);
 
             docModel.listenTo($(document), 'selectstart selectionchange select', processSelectUpdate);
 
-            if (false) {
-                //TODO
-                app.registerWindowResizeHandler(function () {
-                    if (isSoftKeyboardOpen() && window.getSelection().type !== 'Range') {
-                        var boundRect = docModel.getSelection().getFocusPositionBoundRect();
-                        if (boundRect) {
-                            docView.scrollToPageRectangle(boundRect);
-                        }
-                    }
-                });
-            }
+            app.registerWindowResizeHandler(function () {
 
-            app.registerGlobalEventHandler(window, 'orientationchange', resetTextarea);
-            docModel.listenTo(docView, 'change:zoom', resetTextarea);
+                //console.warn('resize', 'soft off:   ', app.getWindowNode().hasClass('soft-keyboard-off'));
+                //console.warn('resize', 'isPopupOpen:', BasePopup.isPopupOpen());
+                //console.warn('resize', 'keyboard op:', isSoftKeyboardOpen());
+
+                // too early
+                if (positionOx === null) { return; }
+
+                handleTextAreaPos();
+    //            console.log('ANDROID RESIZE');
+                if (app.getWindowNode().hasClass('soft-keyboard-off')) {
+                    // do nothing
+                } else {
+                    if ($('.io-ox-office-main.popup-container:not(.context-menu)').length > 0) {
+                        // do nothing, wait for popup close
+                    } else if (!isSoftKeyboardOpen()) {
+                        docModel.trigger('selection:possibleKeyboardClose');
+                    }
+                }
+            });
+
+            docModel.on('selection:focusToEditPage', selectTextArea);
+            docModel.listenTo(docView, 'change:zoom', function () {
+                if (wordFrom && wordTo) { updateHighlight(wordFrom, wordTo); }
+                handleTextAreaPos();
+            });
 
         });
 
@@ -718,7 +809,7 @@ define('io.ox/office/textframework/selection/androidselection', [
 
         // destroy all class members on destruction
         this.registerDestructor(function () {
-            blinkDeferred = textarea = div = null;
+            self = docModel = app = blinkDeferred = textarea = div = null;
         });
 
     } // class AndroidSelection
