@@ -28,22 +28,29 @@ define('io.ox/office/textframework/selection/multiselectionmixin', [
      *
      * @constructor
      *
-     * @param {TextApplication} app
-     *  The application instance.
+     * @param {TextBaseModel} docModel
+     *  The document model instance.
      */
-    function MultiSelectionMixin(app) {
+    function MultiSelectionMixin(docModel) {
 
         var // self reference
             self = this,
 
+            // the application instance
+            app = docModel.getApp(),
+
+            // slide mode for spreadsheet/presentation
+            slideMode = docModel.useSlideMode(),
+
             // whether the application supports multiple selections
-            isMultiSelectionApp = true,
+            isMultiSelectionApp = app.isMultiSelectionApplication(),
 
             // the container for the objects describing a selection with the
             // properties 'startPosition' and 'endPosition'. The selections are
             // sorted corresponding to the start position value.  Furthermore
             // the selection contains the property 'drawing', that contains the
-            //  jQuerified drawing node.
+            // jQuerified drawing node. For performance reasons, the selection
+            // must also contain the drawing type.
             multipleSelections = [];
 
         // private methods ----------------------------------------------------
@@ -66,6 +73,7 @@ define('io.ox/office/textframework/selection/multiselectionmixin', [
                 return Utils.compareNumberArrays(sel1.startPosition, sel2.startPosition);
             });
             self.setValidMultiSelectionValues(multipleSelections);
+            if (!selection.type) { selection.type = DrawingFrame.getDrawingType(selection.drawing); } // adding the drawing type, for faster access
             return multipleSelections.length;
         }
 
@@ -151,6 +159,37 @@ define('io.ox/office/textframework/selection/multiselectionmixin', [
             return multipleSelections;
         };
 
+        /**
+         * If this is a drawing selection (one drawing or multi drawing selection), this function
+         * creates a container that can be used like the container with drawing selections from a
+         * multiple drawing selection. This makes is superfluous to distinguish between single
+         * drawing selections and multiple drawing selections.
+         *
+         * @param {Object} [options]
+         *  Optional parameters:
+         *  @param {Boolean} [options.anyDrawing=false]
+         *      Whether the an additional text frame drawing is in the result.
+         *
+         * @returns {Obejct[]}
+         *  An array containing a selection object for multi and single drawing selections.
+         *  If no drawing is selected or this is an additional textframe selection and anyDrawing
+         *  is set to false, an empty array is returned.
+         */
+        this.getMultiSelectionLikeContainer = function (options) {
+
+            if (self.isMultiSelection()) {
+                return self.getMultiSelection();
+            } else if (self.isDrawingSelection()) {
+                return [{ drawing: self.getSelectedDrawing(), startPosition: self.getStartPosition(), endPosition: self.getEndPosition() }];
+            } else if (self.isAdditionalTextframeSelection() && Utils.getBooleanOption(options, 'anyDrawing', true)) {
+                var drawing = self.getSelectedTextFrameDrawing();
+                var drawingPos = Position.getOxoPosition(self.getRootNode(), drawing);
+                return [{ drawing: drawing, startPosition: drawingPos, endPosition: Position.increaseLastIndex(drawingPos) }];
+            } else {
+                return [];
+            }
+        };
+
         /**
          * Returns a collector with all drawing nodes in the selection. If this
          * is no multiple drawing selection, an empty array is returned.
@@ -179,9 +218,14 @@ define('io.ox/office/textframework/selection/multiselectionmixin', [
          *  Whether in a multi drawing selection at least one text frame shape
          *  is seleted.
          */
-        this.isAtLeastOneTextFrameInMultiSelection = function () {
+        this.isAtLeastOneTextFrameInMultiSelection = function (options) {
+            var searchInGroup = Utils.getBooleanOption(options, 'searchInGroup', false);
             return self.isMultiSelectionSupported() && self.isMultiSelection() && _.isObject(_.find(multipleSelections, function (selection) {
-                return DrawingFrame.isTextFrameShapeDrawingFrame(self.getDrawingNodeFromMultiSelection(selection));
+                var drawingNode = self.getDrawingNodeFromMultiSelection(selection);
+                if (DrawingFrame.isTextFrameShapeDrawingFrame(drawingNode) || (searchInGroup && DrawingFrame.isGroupDrawingFrameWithShape(drawingNode))) {
+                    return true;
+                }
+                return false;
             }));
         };
 
@@ -193,9 +237,52 @@ define('io.ox/office/textframework/selection/multiselectionmixin', [
          *  Whether in a multi drawing selection at least one table drawing is seleted.
          */
         this.isAtLeastOneTableInMultiSelection = function () {
-            return self.isMultiSelectionSupported() && self.isMultiSelection() && _.isObject(_.find(multipleSelections, function (selection) {
-                return DrawingFrame.isTableDrawingFrame(self.getDrawingNodeFromMultiSelection(selection));
-            }));
+            return self.isMultiSelectionSupported() && self.isMultiSelection() && self.getSelectedDrawingTypes({ forceObject: true }).table === 1;
+        };
+
+        /**
+         * Returns, whether in a multi drawing selection one table drawings are selected.
+         *
+         * @returns {Boolean}
+         *  Whether in a multi drawing selection only table drawings are seleted.
+         */
+        this.onlyTableDrawingsInMultiSelection = function () {
+
+            var // whether only tables are selected in a multi selection
+                onlyTables = false,
+                // a collector for all selected drawing types
+                drawingTypes = null;
+
+            if (self.isMultiSelectionSupported() && self.isMultiSelection()) {
+                drawingTypes = self.getSelectedDrawingTypes({ forceObject: true });
+                onlyTables = drawingTypes.table === 1 && _.keys(drawingTypes).length === 1;
+            }
+
+            return onlyTables;
+        };
+
+        /**
+         * Returns whether the current selection (single or multi drawing selection) contains
+         * only table drawing nodes.
+         *
+         * @returns {Boolean}
+         *  Whether the current selection contains at least one and only table drawing nodes.
+         */
+        this.isOnlyTableSelection = function () {
+            var drawingTypes = self.getSelectedDrawingTypes({ forceObject: true });
+            return drawingTypes.table === 1 && _.keys(drawingTypes).length === 1;
+        };
+
+        /**
+         * Returns whether the current selection (single or multi drawing selection) contains
+         * no table drawing nodes.
+         *
+         * @returns {Boolean}
+         *  Whether the current selection contains no table drawing nodes.
+         */
+        this.isDrawingSelectionWithoutTable = function () {
+            var drawingTypes = self.getSelectedDrawingTypes({ forceObject: true });
+            return _.keys(drawingTypes).length && !drawingTypes.table; // there are selected drawing(s), but no table
         };
 
         /**
@@ -205,9 +292,7 @@ define('io.ox/office/textframework/selection/multiselectionmixin', [
          *  Whether in a multi drawing selection at least one drawing of type 'group' is selected.
          */
         this.isAtLeastOneGroupInMultiSelection = function () {
-            return self.isMultiSelectionSupported() && self.isMultiSelection() && _.isObject(_.find(multipleSelections, function (selection) {
-                return DrawingFrame.isGroupDrawingFrame(self.getDrawingNodeFromMultiSelection(selection));
-            }));
+            return self.isMultiSelectionSupported() && self.isMultiSelection() && self.getSelectedDrawingTypes({ forceObject: true }).group === 1;
         };
 
         /**
@@ -281,6 +366,21 @@ define('io.ox/office/textframework/selection/multiselectionmixin', [
             return selection && selection.endPosition ? selection.endPosition : null;
         };
 
+        /**
+         * Returns from a specified selection object of a multiple drawing selection
+         * the drawing type. If no selection object exists or the type cannot be found,
+         * an empty string is returned.
+         *
+         * @param {Object} selection
+         *  The selection object from a multiple drawing selection.
+         *
+         * @returns {String}
+         *  The type of a drawing belonging to a multiple drawing selection.
+         */
+        this.getDrawingTypeFromMultiSelection = function (selection) {
+            return selection && selection.type ? selection.type : '';
+        };
+
         /**
          * Clearing the container for the multiple selections and removing the
          * selection boxes around every drawing.
@@ -327,7 +427,7 @@ define('io.ox/office/textframework/selection/multiselectionmixin', [
                         // the end position of the drawing
                         endPos = Position.increaseLastIndex(startPos);
 
-                    self.drawDrawingSelection(app, oneDrawing);
+                    self.drawDrawingSelection(oneDrawing);
                     addOneDrawingSelectionIntoMultiSelection({ drawing: $(oneDrawing), startPosition: slidePos.concat(startPos), endPosition: slidePos.concat(endPos) });
                 });
 
@@ -359,27 +459,34 @@ define('io.ox/office/textframework/selection/multiselectionmixin', [
 
             var // the slide position
                 slidePos = null,
+                // the drawing position
+                drawingPos = null,
                 // the slide node
                 slide = null;
 
             if (allDrawings.length > 0) {
 
                 slide = $(allDrawings[0]).closest(DOM.SLIDE_SELECTOR);
-                slidePos = app.getModel().getSlidePositionById(app.getModel().getSlideId(slide));
+                slidePos = docModel.getSlidePositionById(docModel.getSlideId(slide));
 
                 // clearing an existing multi drawing selection
                 self.clearAllDrawingSelections();
 
-                _.each(allDrawings, function (oneDrawing) {
+                if (allDrawings.length === 1) {
+                    drawingPos = slidePos.concat(Position.getOxoPosition(slide, allDrawings[0]));
+                    self.setTextSelection(drawingPos, Position.increaseLastIndex(drawingPos));
+                } else {
+                    _.each(allDrawings, function (oneDrawing) {
 
-                    var // the start position of the drawing
-                        startPos = Position.getOxoPosition(slide, oneDrawing),
-                        // the end position of the drawing
-                        endPos = Position.increaseLastIndex(startPos);
+                        var // the start position of the drawing
+                            startPos = Position.getOxoPosition(slide, oneDrawing),
+                            // the end position of the drawing
+                            endPos = Position.increaseLastIndex(startPos);
 
-                    self.drawDrawingSelection(app, oneDrawing);
-                    addOneDrawingSelectionIntoMultiSelection({ drawing: $(oneDrawing), startPosition: slidePos.concat(startPos), endPosition: slidePos.concat(endPos) });
-                });
+                        self.drawDrawingSelection(oneDrawing);
+                        addOneDrawingSelectionIntoMultiSelection({ drawing: $(oneDrawing), startPosition: slidePos.concat(startPos), endPosition: slidePos.concat(endPos) });
+                    });
+                }
 
                 // informing the listeners
                 self.trigger('change');
@@ -416,19 +523,22 @@ define('io.ox/office/textframework/selection/multiselectionmixin', [
                 // clearing an existing multi drawing selection
                 self.clearAllDrawingSelections();
 
-                _.each(allPositions, function (position) {
+                if (allPositions.length === 1) {
+                    self.setTextSelection(allPositions[0], Position.increaseLastIndex(allPositions[0]));
+                } else {
+                    _.each(allPositions, function (position) {
+                        var // the start position of the drawing
+                            oneDrawing = Position.getDOMPosition(slide, [_.last(position)], true),
+                            // the end position of the drawing
+                            endPos = Position.increaseLastIndex(position);
 
-                    var // the start position of the drawing
-                        oneDrawing = Position.getDOMPosition(slide, [_.last(position)], true),
-                        // the end position of the drawing
-                        endPos = Position.increaseLastIndex(position);
-
-                    if (oneDrawing && oneDrawing.node) {
-                        oneDrawing = $(oneDrawing.node);
-                        self.drawDrawingSelection(app, oneDrawing);
-                        addOneDrawingSelectionIntoMultiSelection({ drawing: oneDrawing, startPosition: position, endPosition: endPos });
-                    }
-                });
+                        if (oneDrawing && oneDrawing.node) {
+                            oneDrawing = $(oneDrawing.node);
+                            self.drawDrawingSelection(oneDrawing);
+                            addOneDrawingSelectionIntoMultiSelection({ drawing: oneDrawing, startPosition: position, endPosition: endPos });
+                        }
+                    });
+                }
 
                 // informing the listeners
                 self.trigger('change');
@@ -437,26 +547,6 @@ define('io.ox/office/textframework/selection/multiselectionmixin', [
             return allPositions ? allPositions.length : 0;
         };
 
-        /**
-         * If this is a drawing selection (one drawing is selected), this function creates
-         * a container that can be used like the container with drawing selections from a
-         * multiple drawing selection. This makes is superfluous to distinguish between
-         * single drawing selections and multiple drawing selections.
-         *
-         * @param {Object} [options]
-         *  Optional parameters:
-         *  @param {Boolean} [options.anyDrawing=false]
-         *      Whether the an additional text frame drawing is in the result.
-         *
-         * @returns {Obejct[]}
-         *  An array containing a selection object for single drawing selections. If this
-         *  is no single drawing selection, the container is empty.
-         */
-        this.generateMultiSelectionObjectFromDrawingSelection = function (options) {
-            var anyDrawing = Utils.getBooleanOption(options, 'anyDrawing', false);
-            return self.isDrawingSelection() || (anyDrawing && self.isAdditionalTextframeSelection()) ? [{ drawing: anyDrawing ? self.getAnyDrawingSelection() : self.getSelectedDrawing(), startPosition: self.getStartPosition(), endPosition: self.getEndPosition() }] : [];
-        };
-
         /**
          * Checking, whether the selection of a specified drawing needs an update of the
          * multiple drawing selection.
@@ -488,18 +578,16 @@ define('io.ox/office/textframework/selection/multiselectionmixin', [
          */
         this.addOneDrawingIntoMultipleSelection = function (drawingNode) {
 
-            var // the model
-                model = app.getModel(),
-                // the active slide node
-                slide = model.getSlideById(model.getActiveSlideId()),
+            var // the active slide node
+                slide = docModel.getSlideById(docModel.getActiveSlideId()),
                 // the logical position of the active slide
-                slidePos = model.getActiveSlidePosition(),
+                slidePos = docModel.getActiveSlidePosition(),
                 // the logical start position of a drawing
                 startPos = Position.getOxoPosition(slide, drawingNode),
                 // the logical end position of a drawing
                 endPos = Position.increaseLastIndex(startPos);
 
-            self.drawDrawingSelection(app, drawingNode);
+            self.drawDrawingSelection(drawingNode);
             return addOneDrawingSelectionIntoMultiSelection({ drawing: $(drawingNode), startPosition: slidePos.concat(startPos), endPosition: slidePos.concat(endPos) });
         };
 
@@ -517,12 +605,10 @@ define('io.ox/office/textframework/selection/multiselectionmixin', [
          */
         this.removeOneDrawingFromMultipleSelection = function (drawingNode) {
 
-            var // the model
-                model = app.getModel(),
-                // the active slide node
-                slide = model.getSlideById(model.getActiveSlideId()),
+            var // the active slide node
+                slide = docModel.getSlideById(docModel.getActiveSlideId()),
                 // the logical position of the active slide
-                slidePos = model.getActiveSlidePosition(),
+                slidePos = docModel.getActiveSlidePosition(),
                 // the logical start position of a drawing
                 startPos = Position.getOxoPosition(slide, drawingNode);
 
@@ -590,7 +676,7 @@ define('io.ox/office/textframework/selection/multiselectionmixin', [
 
                     // if the drawing was not a text frame, the selection needs to be set into the slide
                     if (!self.isAdditionalTextframeSelection()) {
-                        if (app.getModel().useSlideMode()) { self.setSlideSelection({ triggerChange: false }); }
+                        if (slideMode) { self.setSlideSelection({ triggerChange: false }); }
                     }
 
                 } else {
@@ -630,10 +716,13 @@ define('io.ox/office/textframework/selection/multiselectionmixin', [
             // -> setting the 'slide selection' ([3,0] for the slide at position [3]).
             // A trigger of 'change' is not required in start handler, because it can be done in the
             // stop handler.
-            if (app.getModel().useSlideMode()) { self.setSlideSelection({ triggerChange: false }); }
+            if (slideMode) { self.setSlideSelection({ triggerChange: false }); }
 
             // additionally clear a possible multi selection in the slide pane
-            app.getModel().trigger('slidepane:clearselection');
+            docModel.trigger('slidepane:clearselection');
+
+            // set the virtual focus to the document
+            app.getView().setVirtualFocusSlidepane(false);
         };
 
         /**
@@ -650,14 +739,12 @@ define('io.ox/office/textframework/selection/multiselectionmixin', [
             // selecting all drawings on the active slide, that are completely inside
             // the selection box.
 
-            var // the model
-                model = app.getModel(),
-                // the active slide node
-                slide = model.getSlideById(model.getActiveSlideId()),
+            var // the active slide node
+                slide = docModel.getSlideById(docModel.getActiveSlideId()),
                 // the container for all drawings on the slide
                 allDrawings = slide.children(DOM.ABSOLUTE_DRAWING_SELECTOR),
                 // the logical position of the active slide
-                slidePos = model.getActiveSlidePosition(),
+                slidePos = docModel.getActiveSlidePosition(),
                 // a collector for all selected drawings
                 allSelectedDrawings = [],
                 // the content root node, the base for the position calculation
@@ -842,9 +929,9 @@ define('io.ox/office/textframework/selection/multiselectionmixin', [
 
             if (!(self.isMultiSelectionSupported() && self.isMultiSelection())) { return false; }
 
-            if (!app.getModel().useSlideMode()) { return true; }
+            if (!slideMode) { return true; }
 
-            return !app.getModel().isAtLeastOneNotGroupableDrawingInSelection();
+            return !docModel.isAtLeastOneNotGroupableDrawingInSelection();
         };
 
         /**
@@ -859,19 +946,84 @@ define('io.ox/office/textframework/selection/multiselectionmixin', [
             return self.isAnyDrawingGroupSelection() || self.isAtLeastOneGroupInMultiSelection();
         };
 
+        /**
+         * Getting an array containing all selected drawings.
+         *
+         * @param {Object} [options]
+         *  An object containing some additional properties:
+         *  @param {Boolean} [options.includeTextFrameSelection=true]
+         *      Whether additional text frame selections shall be handled like selected drawings. In this case
+         *      the selection is a text selection, and the surrounding drawing is 'additionally' selected. If
+         *      this option is set to false, only 'pure' drawing selections (single drawing and multi drawing
+         *      selection (if supported)) are returned.
+         *  @param {Boolean} [options.forceArray=false]
+         *      If set to true and no drawing is selected, an empty array is returned instead of null.
+         *
+         * @returns {jQuery[]|[]|Null}
+         *  An array with all drawing nodes in the selection. This can be a single drawing selection or a multi
+         *  drawing selection. If no drawing is selected, null is returned.
+         */
+        this.getSelectedDrawings = function (options) {
+
+            if (self.isMultiSelectionSupported() && self.isMultiSelection()) {
+                return self.getAllSelectedDrawingNodes();
+            } else if (self.isDrawingSelection()) {
+                return [self.getSelectedDrawing()];
+            } else if (self.isAdditionalTextframeSelection() && Utils.getBooleanOption(options, 'includeTextFrameSelection', true)) {
+                return [self.getSelectedTextFrameDrawing()];
+            } else {
+                return Utils.getBooleanOption(options, 'forceArray', false) ? [] : null;
+            }
+        };
+
+        /**
+         * Getting an object containing the types of all selected drawings.
+         * If no drawing is selected, null is returned.
+         *
+         * @param {Object} [options]
+         *  An object containing some additional properties:
+         *  @param {Boolean} [options.includeTextFrameSelection=true]
+         *      Whether additional text frame selections shall be handled like selected drawings. In this case
+         *      the selection is a text selection, and the surrounding drawing is 'additionally' selected. If
+         *      this option is set to false, only 'pure' drawing selections (single drawing and multi drawing
+         *      selection (if supported)) are returned.
+         *  @param {Boolean} [options.forceObject=false]
+         *      If set to true and no drawing is selected, an empty array is returned instead of null.
+         *
+         * @returns {Object|Null}
+         *  An object containing the types of all selected drawings as keys. If no  with all drawing nodes in the selection. This can be a single drawing selection or a multi
+         *  drawing selection. If no drawing is selected, null is returned.
+         */
+        this.getSelectedDrawingTypes = function (options) {
+
+            var allTypes = {};
+
+            // TODO: Handling of drawings inside selected groups (via option)!?
+
+            if (self.isMultiSelectionSupported() && self.isMultiSelection()) {
+                _.each(multipleSelections, function (drawingSelection) {
+                    allTypes[self.getDrawingTypeFromMultiSelection(drawingSelection)] = 1;
+                });
+            } else if (self.isDrawingSelection()) {
+                allTypes[DrawingFrame.getDrawingType(self.getSelectedDrawing())] = 1;
+            } else if (self.isAdditionalTextframeSelection() && Utils.getBooleanOption(options, 'includeTextFrameSelection', true)) {
+                allTypes[DrawingFrame.getDrawingType(self.getSelectedTextFrameDrawing())] = 1;
+            } else if (!Utils.getBooleanOption(options, 'forceObject', false)) {
+                allTypes = null;
+            }
+
+            return allTypes;
+        };
+
         // initialization -----------------------------------------------------
 
         // destroy all class members on destruction
         this.registerDestructor(function () {
-            // self = null;
+            self = app = docModel = null;
         });
 
-        isMultiSelectionApp = app.isMultiSelectionApplication();
-
     } // class MultiSelectionMixin
 
-    // constants --------------------------------------------------------------
-
     // export =================================================================
 
     return MultiSelectionMixin;
