@@ -13,12 +13,13 @@
  */
 define('io.ox/office/textframework/selection/remoteselection', [
     'io.ox/office/tk/object/baseobject',
-    'io.ox/office/tk/object/timermixin',
     'io.ox/office/textframework/utils/config',
     'io.ox/office/textframework/utils/textutils',
     'io.ox/office/textframework/utils/position',
-    'io.ox/office/textframework/utils/dom'
-], function (BaseObject, TimerMixin, Config, Utils, Position, DOM) {
+    'io.ox/office/editframework/utils/attributeutils',
+    'io.ox/office/drawinglayer/view/drawingframe',
+    'io.ox/office/drawinglayer/utils/drawingutils'
+], function (BaseObject, Config, Utils, Position, AttributeUtils, DrawingFrame, DrawingUtils) {
 
     'use strict';
 
@@ -30,18 +31,23 @@ define('io.ox/office/textframework/selection/remoteselection', [
      *
      * @extends BaseObject
      *
-     * @param {TextApplication} app
-     *  The application instance.
-     *
-     * @param {HTMLElement|jQuery} rootNode
-     *  The root node of the document. If this object is a jQuery collection,
-     *  uses the first node it contains.
+     * @param {TextBaseModel} docModel
+     *  The document model instance.
      */
-    function RemoteSelection(app, rootNode) {
+    function RemoteSelection(docModel) {
 
         var // the local selection instance
             selection = null,
 
+            // the application instance
+            app = docModel.getApp(),
+
+            // the root node of the document
+            rootNode = docModel.getNode(),
+
+            // slide mode for spreadsheet/presentation
+            slideMode = docModel.useSlideMode(),
+
             // the display timer of the collaborative overlay
             overlayTimer = null,
 
@@ -52,8 +58,7 @@ define('io.ox/office/textframework/selection/remoteselection', [
 
         // base constructor ---------------------------------------------------
 
-        BaseObject.call(this);
-        TimerMixin.call(this);
+        BaseObject.call(this, app);
 
         // private methods ----------------------------------------------------
 
@@ -76,65 +81,19 @@ define('io.ox/office/textframework/selection/remoteselection', [
             // quit if no logical selection is available
             if (!anchorPoint || !focusPoint) { return null; }
 
-            var // get logical start and end positions for restoring text selection later
-                selectionStart = selection.getStartPosition(),
-                selectionEnd = selection.getEndPosition(),
-                backwards = selection.isBackwards(),
-                zoom = app.getView().getZoomFactor() / 100;
+            var zoom = app.getView().getZoomFactor();
 
-            // use decoy span technique and get absolute physical positions of a selection point
-            function getPhysicalPosition(point) {
-
-                // ignore this current user's own selection points of course
-                if (!point) { return null; }
-
-                var caretSpan = $('<span>').addClass('collaborative-caret').text('|'),
-                    cursorElement = $(point.node.parentNode),
-                    cursorElementLineHeight = parseFloat(cursorElement.css('line-height'));
-
-                // break cursor element on the text offset
-                if (point.offset === 0) {
-                    cursorElement.before(caretSpan);
-                } else {
-                    DOM.splitTextSpan(cursorElement, point.offset, { append: true });
-                    cursorElement.after(caretSpan);
-                }
-
-                // create caret overlay and calculate its position
-                var caretTop = (caretSpan.offset().top - rootNode.offset().top) / zoom  - cursorElementLineHeight  + caretSpan.outerHeight(),
-                    caretLeft = (caretSpan.offset().left - rootNode.offset().left) / zoom;
-
-                // restore original state of document
-                caretSpan.remove();
-
-                if (point.offset > 0) {
-                    Utils.mergeSiblingTextSpans(cursorElement, true);
-                }
-
-                return { top: caretTop, left: caretLeft };
+            function getPhysicalPosition(point1, point2, start) {
+                return Utils.getCSSRectangleFromPoints(point1, point2, rootNode, zoom, start);
             }
 
-            var position = { anchor: getPhysicalPosition(anchorPoint), focus: getPhysicalPosition(focusPoint) };
-
-            // only reset text selection if the page node is the active element.
-            // Otherwise, there is a overlay which gets the focus (BUG #36469)
-            if (DOM.isPageNode(Utils.getActiveElement())) {
-                // return original position of browser cursor after merge
-
-                // never destroying multiple selection (TODO)
-                if (!(selection.isMultiSelectionSupported() && selection.isMultiSelection())) {
-                    selection.setTextSelection(selectionStart, selectionEnd, { userDataUpdateHandler: true, backwards: backwards });
-                }
-
-            }
-
-            return position;
+            return { anchor: getPhysicalPosition(anchorPoint, null, true), focus: getPhysicalPosition(focusPoint), range: getPhysicalPosition(anchorPoint, focusPoint) };
         }
 
         /**
          * Draw overlays for a specific remote user's selection debounced.
          */
-        var renderCollaborativeSelectionDebounced = this.createDebouncedMethod($.noop, function () {
+        var renderCollaborativeSelectionDebounced = this.createDebouncedMethod('RemoteSelection.renderCollaborativeSelectionDebounced', null, function () {
             if (Config.SHOW_REMOTE_SELECTIONS) {
                 // first, clear all old selection nodes from the DOM
                 rootNode.find('.collaborative-overlay').children().remove();
@@ -144,7 +103,7 @@ define('io.ox/office/textframework/selection/remoteselection', [
                 // render all remote selections
                 _.each(app.getActiveClients(), renderSelection);
             }
-        }, { delay: 100, infoString: 'RemoteSelection renderCollaborativeSelectionDebounced()', app: app });
+        }, { delay: 300 });
 
         /**
          * Create a Overlay with the username to show the remote username for a selection.
@@ -153,19 +112,10 @@ define('io.ox/office/textframework/selection/remoteselection', [
          * @param {jQuery} UserName Overlay
          */
         function getUserNameOverlay(username, className) {
-            var usernameOverlay = (_.browser.IE === 10) ? document.createElementNS('http://www.w3.org/2000/svg', 'svg') : document.createElement('div');
-
+            var usernameOverlay = document.createElement('div');
             // draw user name
             usernameOverlay.setAttribute('class', 'collaborative-username ' + className);
-            if (_.browser.IE === 10) { // create SVG text node and calculate its width (no text wrap support in SVG)
-                var txtElem = document.createElementNS('http://www.w3.org/2000/svg', 'text');
-                $(txtElem).attr({ x: 5, y: 13, style: 'font-size:12px;fill:white;' });
-                txtElem.appendChild(document.createTextNode(username));
-                usernameOverlay.appendChild(txtElem);
-                $(usernameOverlay).attr({ width: (username.length * 8) + 'px', style: 'height:2em' });
-            } else {
-                $(usernameOverlay).text(username);
-            }
+            $(usernameOverlay).text(username);
 
             return usernameOverlay;
         }
@@ -206,10 +156,7 @@ define('io.ox/office/textframework/selection/remoteselection', [
             var username = client.userName,
                 overlay = rootNode.find('.collaborative-overlay'),
                 className = 'user-' + client.colorIndex,
-                svgNamespace = 'http://www.w3.org/2000/svg',
-                zoom = app.getView().getZoomFactor() / 100,
-                docModel = app.getModel(),
-                useSlideMode = docModel.useSlideMode(),
+                zoom = app.getView().getZoomFactor(),
                 // skip the render of drawing selections if one drawing is not on the active slide
                 skipDrawing = false,
                 usernameOverlay;
@@ -219,13 +166,13 @@ define('io.ox/office/textframework/selection/remoteselection', [
 
                 // special handling if selection is a top level cursor position on a slide
                 // -> not drawing the remote cursor on the slide.
-                if (skipDrawing || (useSlideMode && selection.isTopLevelTextCursor(userSelection))) {
+                if (skipDrawing || (slideMode && selection.isTopLevelTextCursor(userSelection))) {
                     // TODO: Draw remote selection (on slide pane?)
                     return;
                 }
 
                 // Don't draw selection if is on inactive slide, #46237
-                if (useSlideMode && !isSelectionOnActiveSlide(userSelection)) { return; }
+                if (slideMode && !isSelectionOnActiveSlide(userSelection)) { return; }
 
                 var activeRootNode = docModel.getRootNode(userTargetSelection, userTargetIndex),
                     selectionAnchorPoint = Position.getDOMPosition(activeRootNode, userSelection.start),
@@ -235,10 +182,22 @@ define('io.ox/office/textframework/selection/remoteselection', [
 
                 var selectionOverlayGroup = $('<div>').addClass('collaborative-selection-group');
 
+                var drawingNode;
+                var rotation = 0;
+                var drawingAttrs;
+                // if the drawing is rotatet only select the frame and not the text
+                if (slideMode && userSelection.type !== 'drawing') {
+                    drawingNode = DrawingFrame.getDrawingNode($(Position.getDOMPosition(activeRootNode, userSelection.start, true).node));
+                    if (drawingNode) {
+                        drawingAttrs = AttributeUtils.getExplicitAttributes(drawingNode);
+                        rotation = drawingAttrs.drawing ? Utils.getNumberOption(drawingAttrs.drawing, 'rotation', 0) : 0;
+                    }
+                }
+
                 // render the selection for drawings
-                if (userSelection.type === 'drawing') {
+                if (userSelection.type === 'drawing' || rotation > 0) {
                     // Test if the drawing is on the aktive slide (Presentation), if not skip the rendering.
-                    if (useSlideMode) {
+                    if (slideMode) {
                         var slideID = docModel.getActiveSlideId();
                         var layoutOrMaster = docModel.isMasterView();
                         if (layoutOrMaster) {
@@ -256,13 +215,33 @@ define('io.ox/office/textframework/selection/remoteselection', [
                             return;
                         }
                     }
-                    var drawingNode = $(Position.getDOMPosition(activeRootNode, userSelection.start, true).node);
+
+                    if (!drawingNode) {
+                        drawingNode = $(Position.getDOMPosition(activeRootNode, userSelection.start, true).node);
+                    }
+
                     if (drawingNode.length === 0) {
                         return;
                     }
-                    var drawingOverlay = (_.browser.IE === 10) ? document.createElementNS(svgNamespace, 'svg') : document.createElement('div'),
-                        top = useSlideMode ? parseFloat(drawingNode.css('top')) : (drawingNode.offset().top - rootNode.offset().top) / zoom,
-                        left = useSlideMode ? parseFloat(drawingNode.css('left')) : (drawingNode.offset().left - rootNode.offset().left) / zoom;
+                    drawingAttrs = drawingAttrs ? drawingAttrs : AttributeUtils.getExplicitAttributes(drawingNode);
+                    rotation = 0;
+                    var flipH = false;
+                    var flipV = false;
+                    if (drawingAttrs && drawingAttrs.drawing) {
+                        flipH = Utils.getBooleanOption(drawingAttrs.drawing, 'flipH', false);
+                        flipV = Utils.getBooleanOption(drawingAttrs.drawing, 'flipV', false);
+                        rotation = Utils.getNumberOption(drawingAttrs.drawing, 'rotation', 0);
+                    }
+
+                    var drawingOverlay = document.createElement('div'),
+                        top = slideMode ? parseFloat(drawingNode.css('top')) : (drawingNode.offset().top - rootNode.offset().top) / zoom,
+                        left = slideMode ? parseFloat(drawingNode.css('left')) : (drawingNode.offset().left - rootNode.offset().left) / zoom;
+
+                    if (rotation !== 0 && !slideMode) {
+                        var rect = DrawingUtils.getRotatedDrawingPoints({ width: drawingNode.width(), height: drawingNode.height(), top: 0, left: 0 }, -rotation);
+                        top -= rect.top;
+                        left -= rect.left;
+                    }
 
                     usernameOverlay = getUserNameOverlay(username, className);
 
@@ -272,10 +251,14 @@ define('io.ox/office/textframework/selection/remoteselection', [
                         left: left - 2,
                         width: parseFloat(drawingNode.css('width')) + 4,
                         height: parseFloat(drawingNode.css('height')) + 4,
-                        transform: drawingNode.css('transform')
+                        transform: DrawingUtils.getCssTransform(rotation, flipH, flipV)
                     });
 
-                    $(usernameOverlay).css({ top: 0, left: 0 });
+                    $(usernameOverlay).css({
+                        top: 0,
+                        left: 0,
+                        transform: DrawingUtils.getCssTransform(0, flipH, flipV)
+                    });
 
                     selectionOverlayGroup.append(drawingOverlay);
                     selectionOverlayGroup.append(usernameOverlay);
@@ -299,13 +282,13 @@ define('io.ox/office/textframework/selection/remoteselection', [
                         startNode = $(selectionAnchorPoint.node.parentNode),
                         endNode = $(selectionFocusPoint.node.parentNode),
                         physicalPosition = calculatePhysicalPosition(selectionAnchorPoint, selectionFocusPoint),
-                        isRangeSelection = !_.isEqual(physicalPosition.anchor, physicalPosition.focus);
+                        isRangeSelection = physicalPosition.anchor.top !== physicalPosition.focus.top || physicalPosition.anchor.left !== physicalPosition.focus.left;
 
                     usernameOverlay = getUserNameOverlay(username, className);
 
                     // draw user cursors and names
-                    $(usernameOverlay).css('top', endNode.css('line-height'));
-                    caretOverlay.css({ top: physicalPosition.focus.top, left: physicalPosition.focus.left, height: parseFloat(endNode.css('line-height')) }).addClass(className);
+                    $(usernameOverlay).css('top', physicalPosition.focus.height);
+                    caretOverlay.css({ top: physicalPosition.focus.top, left: physicalPosition.focus.left, height: physicalPosition.focus.height }).addClass(className);
                     caretOverlay.append(usernameOverlay, caretHandle);
                     caretHandle.hover(function () { $(usernameOverlay).show(); }, function () { $(usernameOverlay).hide(); });
                     overlay.append(caretOverlay);
@@ -322,18 +305,9 @@ define('io.ox/office/textframework/selection/remoteselection', [
                     if (isRangeSelection) {
 
                         // draw collaborative selection area highlighting if we have an 'range' selection
-
-                        var startParentNode = startNode.parent(),
-                            endParentNode = endNode.parent(),
-                            highlightWidth = Math.max(startParentNode.width(), endParentNode.width()),
-                            rootNodePos = rootNode.offset(),
-                            pageContentNodePos = DOM.getPageContentNode(rootNode).offset(),
-                            startTop = physicalPosition.anchor.top,
-                            startLeft = physicalPosition.anchor.left,
-                            endTop = physicalPosition.focus.top,
-                            endLeft = physicalPosition.focus.left,
-                            startNodeCell = startNode.closest('td'),
-                            endNodeCell = endNode.closest('td'),
+                        var rootNodePos = rootNode.offset(), //both
+                            startNodeCell = startNode.closest('td'), // table
+                            endNodeCell = endNode.closest('td'), // table
                             isTableSelection = startNodeCell.length && endNodeCell.length && !startNodeCell.is(endNodeCell);
 
                         // special handling of pure table selection
@@ -346,7 +320,7 @@ define('io.ox/office/textframework/selection/remoteselection', [
                                     ovEndPos = endNodeCell.offset(),
                                     ovWidth = (ovEndPos.left  - ovStartPos.left) / zoom + endNodeCell.outerWidth(),
                                     ovHeight = (ovEndPos.top  - ovStartPos.top) / zoom + endNodeCell.outerHeight(),
-                                    ov = (_.browser.IE === 10) ? document.createElementNS(svgNamespace, 'svg') : document.createElement('div');
+                                    ov = document.createElement('div');
 
                                 $(ov).css({
                                     top: (ovStartPos.top - rootNodePos.top) / zoom,
@@ -364,7 +338,7 @@ define('io.ox/office/textframework/selection/remoteselection', [
 
                                 cellsToHighlight.each(function () {
 
-                                    var cellOv = (_.browser.IE === 10) ? document.createElementNS(svgNamespace, 'svg') : document.createElement('div'),
+                                    var cellOv = document.createElement('div'),
                                         offset = $(this).offset();
 
                                     $(cellOv).css({
@@ -379,62 +353,64 @@ define('io.ox/office/textframework/selection/remoteselection', [
                                 });
                             }
                         } else { // paragraph / mixed selection
-
-                            var startHeight = parseFloat(startNode.css('line-height')),
-                                endHeight = parseFloat(endNode.css('line-height')),
+                            var startTop = physicalPosition.anchor.top,
+                                startHeight = physicalPosition.anchor.height,
+                                endTop = physicalPosition.focus.top,
+                                endHeight = physicalPosition.focus.height,
                                 startBottom = startTop + startHeight,
                                 endBottom = endTop + endHeight,
-                                isSingleLineSelection = startBottom === endBottom;
+                                isSingleLineSelection = startBottom === endBottom || (endTop >= startTop && endBottom <= startBottom) || (startTop >= endTop && startBottom <= endBottom),
+                                caretHeight;
 
                             // selection area is in a line
                             if (isSingleLineSelection) {
+                                caretHeight = physicalPosition.range.height;
 
-                                var selectionOverlay = (_.browser.IE === 10) ? document.createElementNS(svgNamespace, 'svg') : document.createElement('div');
-                                $(selectionOverlay).css({ top: Math.min(startTop, endTop), left: startLeft, width: endLeft - startLeft, height: Math.max(startHeight, endHeight) });
+                                var selectionOverlay = document.createElement('div');
+                                $(selectionOverlay).css({ top: physicalPosition.range.top, left: physicalPosition.range.left, width: physicalPosition.range.width, height: caretHeight });
                                 selectionOverlayGroup.append(selectionOverlay);
 
+                                $(usernameOverlay).css('top', caretHeight);
+                                caretOverlay.css({ top: physicalPosition.range.top, left: physicalPosition.focus.left, height: caretHeight }).addClass(className);
                             } else { // multi line selection area
 
-                                var startPrevNode = $(Utils.findPreviousSiblingNode(startNode)),
-                                    endPrevNode = $(Utils.findPreviousSiblingNode(endNode)),
-                                    isListSelection = DOM.isListLabelNode(startPrevNode) || DOM.isListLabelNode(endPrevNode);
-
-                                // start and end node are empty lines (paragraphs)
-                                if (!highlightWidth) { highlightWidth = rootNode.width(); }
-
-                                var headOverlay = document.createElement('div'),
-                                    bodyOverlay = document.createElement('div'),
-                                    tailOverlay = document.createElement('div');
-
-                                if (_.browser.IE === 10) {
-                                    headOverlay = document.createElementNS(svgNamespace, 'svg');
-                                    bodyOverlay = document.createElementNS(svgNamespace, 'svg');
-                                    tailOverlay = document.createElementNS(svgNamespace, 'svg');
-                                }
+                                var anchorSelection = physicalPosition.anchor;
+                                var focusSelection = physicalPosition.focus;
+                                var rangeSelection = physicalPosition.range;
 
+                                var height = (anchorSelection.top + anchorSelection.height) - rangeSelection.top;
+                                var headOverlay = document.createElement('div');
                                 $(headOverlay).css({
-                                    top: startTop,
-                                    left: startLeft,
-                                    width: isListSelection ? (startParentNode.offset().left - rootNodePos.left) / zoom  + startParentNode.width() - startLeft + startPrevNode.width() :
-                                        (startParentNode.offset().left - rootNodePos.left) / zoom  + startParentNode.width() - startLeft,
-                                    height: startHeight
-                                });
-
-                                $(bodyOverlay).css({
-                                    top: startTop + startHeight,
-                                    left: (isListSelection ? pageContentNodePos.left - rootNodePos.left : Math.min(startParentNode.offset().left, endParentNode.offset().left) - rootNodePos.left) / zoom,
-                                    width: isListSelection ? rootNode.width() : highlightWidth,
-                                    height: endTop - startTop - startHeight
+                                    top: rangeSelection.top,
+                                    left: anchorSelection.left,
+                                    width: anchorSelection.left === rangeSelection.left ?  rangeSelection.width : (rangeSelection.left + rangeSelection.width) - anchorSelection.left,
+                                    height: height
                                 });
 
+                                var tailOverlay = document.createElement('div');
+                                var tailWidth = focusSelection.left - rangeSelection.left;
                                 $(tailOverlay).css({
-                                    top: endTop,
-                                    left: isListSelection ? (endNode.offset().left - rootNodePos.left) / zoom - endPrevNode.width() :
-                                        (endParentNode.offset().left - rootNodePos.left) / zoom,
-                                    width: endLeft - ((endParentNode.offset().left - rootNodePos.left) / zoom),
-                                    height: endHeight
+                                    top: focusSelection.top,
+                                    left: rangeSelection.left,
+                                    width: tailWidth,
+                                    height: focusSelection.height
                                 });
 
+                                var bodyOverlay = document.createElement('div');
+                                var bodyTop = rangeSelection.top + height;
+                                var bodyHeight = focusSelection.top - bodyTop;
+                                $(bodyOverlay).css({
+                                    top: bodyTop,
+                                    left: rangeSelection.left,
+                                    width: rangeSelection.width,
+                                    height: bodyHeight
+                                });
+
+                                caretHeight = focusSelection.height;
+
+                                $(usernameOverlay).css('top', caretHeight);
+                                caretOverlay.css({ top: focusSelection.top, left: rangeSelection.left + tailWidth, height: caretHeight }).addClass(className);
+
                                 selectionOverlayGroup.append(headOverlay, bodyOverlay, tailOverlay);
                             }
                         }
@@ -455,7 +431,7 @@ define('io.ox/office/textframework/selection/remoteselection', [
 
             overlayTimer = self.executeDelayed(function () {
                 overlay.find('.collaborative-username').fadeOut('fast');
-            }, { delay: 3000, infoString: 'RemoteSelection: overlayTimer', app: app });
+            }, 'RemoteSelection.overlayTimer', 3000);
         }
 
         /**
@@ -488,18 +464,20 @@ define('io.ox/office/textframework/selection/remoteselection', [
         // initialize class members when application is alive
         app.onInit(function () {
             removeDrawingNodesHandler();
-            selection = app.getModel().getSelection();
+            selection = docModel.getSelection();
             // render selection if the user change the slide to see the current selection of the new slide
-            self.listenTo(app.getModel(), 'change:slide', _.bind(self.renderCollaborativeSelections, self));
+            self.listenTo(docModel, 'change:slide', _.bind(self.renderCollaborativeSelections, self));
             // render selection if drawing attributes will be changed
-            self.listenTo(app.getModel(), 'change:drawing', _.bind(self.renderCollaborativeSelections, self));
+            self.listenTo(docModel, 'change:drawing', _.bind(self.renderCollaborativeSelections, self));
             // render selection if the list of active clients has changed
             self.listenTo(app, 'docs:users:selection', _.bind(self.renderCollaborativeSelections, self));
+            docModel.listenTo(app, 'update:absoluteElements', _.bind(self.renderCollaborativeSelections, self));
+            docModel.listenTo(app,  'drawingHeight:update', _.bind(self.renderCollaborativeSelections, self));
         });
 
         // destroy all class members
         this.registerDestructor(function () {
-            app = rootNode = selection = drawingNodesWithHandlers = null;
+            docModel = app = rootNode = selection = drawingNodesWithHandlers = null;
         });
 
     } // class RemoteSelection
