@@ -43,8 +43,8 @@ define('io.ox/office/textframework/utils/export', [
      * Converts the internal HTML mark-up of the current selection to
      * normalized HTML mark-up that can be exported (e.g. to the clipboard).
      *
-     * @param {TextApplication} editor
-     *  The text application instance.
+     * @param {Editor} docModel
+     *  The text model instance.
      *
      * @param {Object} [options]
      *  Optional parameters:
@@ -57,11 +57,13 @@ define('io.ox/office/textframework/utils/export', [
      *  @param {String} [options.clipboardOrigin]
      *      A String to determine whether the cliboard data origin is OX Text
      *      or OX Presentation.
+     *  @param {String} [options.clipboardOriginId]
+     *      An id to identify the clipboard origin
      *
      * @returns {String}
      *  The normalized HTML mark-up for export.
      */
-    Export.getHTMLFromSelection = function (editor, options) {
+    Export.getHTMLFromSelection = function (docModel, options) {
         /**
          * Returns the currently selected contents as HTML mark-up.
          *
@@ -74,7 +76,7 @@ define('io.ox/office/textframework/utils/export', [
 
             if (allDrawingsInSelection.length > 0) {
                 _.each(allDrawingsInSelection, function (drawing) {
-                    returnValue.append(parseSelection(editor, selection, drawing, { type: 'html' }), '<span>&#8203;</span>');
+                    returnValue.append(parseSelection(docModel, selection, drawing, { type: 'html' }), '<span>&#8203;</span>');
                 });
             } else {
                 returnValue.append('<div>');
@@ -84,18 +86,19 @@ define('io.ox/office/textframework/utils/export', [
         }
 
         var resultDiv           = $('<div>'),
-            selection           = editor.getSelection(),
-            paragraphStyles     = editor.getStyleCollection('paragraph'),
-            listStyles          = editor.getListCollection(),
+            selection           = docModel.getSelection(),
+            paragraphStyles     = docModel.getStyleCollection('paragraph'),
+            listStyles          = docModel.getListCollection(),
             paraStylesIds       = createParagraphStyleIds(selection, paragraphStyles),
             clipboardId         = Utils.getStringOption(options, 'clipboardId', ''),
             clipboardOperations = Utils.getArrayOption(options, 'clipboardOperations', []),
             clipboardOrigin     = Utils.getStringOption(options, 'clipboardOrigin', ''),
+            clipboardOriginId   = Utils.getStringOption(options, 'clipboardOriginId', ''),
             isEncodeBase64      = Utils.getBooleanOption(options, 'isEncodeBase64', true),
-            html                = (editor.useSlideMode()) ? getHtmlFromBrowserSelection() : $('<span>').html(selection.getHtmlFromBrowserSelection()),
+            html                = docModel.useSlideMode() ? getHtmlFromBrowserSelection() : $('<span>').html(selection.getHtmlFromBrowserSelection()),
             metaElement;
 
-        if (!editor.useSlideMode()) {
+        if (!docModel.useSlideMode()) {
             createOptimizedStructure(html, resultDiv, paraStylesIds, listStyles, isEncodeBase64);
         } else {
             resultDiv = html;
@@ -115,6 +118,9 @@ define('io.ox/office/textframework/utils/export', [
             if (clipboardOrigin.length > 0) {
                 metaElement.attr('data-ox-origin', clipboardOrigin);
             }
+            if (clipboardOriginId.length > 0) {
+                metaElement.attr('data-ox-origin-id', clipboardOriginId);
+            }
         }
         if (resultDiv.children().length === 1) {
             resultDiv.append('<span>&#8203;</span>');
@@ -122,8 +128,8 @@ define('io.ox/office/textframework/utils/export', [
         return resultDiv.html();
     };
 
-    Export.getPlainTextFromSelection = function (editor) {
-        var selection       = editor.getSelection(),
+    Export.getPlainTextFromSelection = function (docModel) {
+        var selection       = docModel.getSelection(),
             text            = '';
 
         function getTextFromDrawingSelection() {
@@ -131,7 +137,7 @@ define('io.ox/office/textframework/utils/export', [
 
             _.each(selection.getAllDrawingsInSelection(), function (drawing, i) {
                 if (i > 0) { returnValue += '\r\n\r\n'; }
-                returnValue += parseSelection(editor, selection, drawing, { type: 'text' });
+                returnValue += parseSelection(docModel, selection, drawing, { type: 'text' });
             });
             return returnValue;
         }
@@ -184,7 +190,7 @@ define('io.ox/office/textframework/utils/export', [
         return text;
     }
 
-    function parseSelection(editor, selection, drawing, options) {
+    function parseSelection(docModel, selection, drawing, options) {
         var type             = Utils.getStringOption(options, 'type', 'html'),
             browserSelection = window.getSelection(),
             result           = null;
@@ -193,13 +199,14 @@ define('io.ox/office/textframework/utils/export', [
         if (selection.getSelectionType() === 'drawing' || selection.isTextCursor()) {
             switch (DrawingFrame.getDrawingType(drawing)) {
                 case 'shape':
-                    result = extractShape(editor, drawing, { type: type });
+                case 'connector':
+                    result = extractShape(docModel, drawing, { type: type });
                     break;
                 case 'table':
                     result = extractTable(drawing, { type: type });
                     break;
                 case 'image':
-                    result = extractImage(editor, drawing, { type: type });
+                    result = extractImage(docModel, drawing, { type: type });
                     break;
             }
             return (type === 'html') ? result : result;
@@ -221,7 +228,7 @@ define('io.ox/office/textframework/utils/export', [
         }
     }
 
-    function extractImage(editor, drawing, options) {
+    function extractImage(docModel, drawing, options) {
         var attributes  = drawing.first().data('attributes');
 
         if (Utils.getStringOption(options, 'type', 'html') === 'html') {
@@ -235,11 +242,11 @@ define('io.ox/office/textframework/utils/export', [
                 base64String = DOM.getBase64FromImageNode(imageNode, Image.getMimeTypeFromImageUri(imageUrl));
             }
 
-            return applyFillAndLineStyles($('<img src="' + base64String + '" width="' + width + 'px" height="' + height + 'px">'), editor, drawing)[0];
-
-        } else {
-            return attributes.drawing.name;
+            var imgNode = $('<img src="' + base64String + '" width="' + width + 'px" height="' + height + 'px">');
+            return applyFillAndLineStyles(imgNode, docModel, drawing)[0];
         }
+
+        return attributes.drawing.name;
     }
 
     function extractTable(drawing, options) {
@@ -288,7 +295,7 @@ define('io.ox/office/textframework/utils/export', [
         return (Utils.getStringOption(options, 'type', 'html') === 'html') ? $('<div>').append(table) : text;
     }
 
-    function extractShape(editor, drawing, options) {
+    function extractShape(docModel, drawing, options) {
         var type        = Utils.getStringOption(options, 'type', 'html'),
             attributes  = drawing.first().data('attributes'),
             canvas      = drawing.find('canvas'),
@@ -297,39 +304,40 @@ define('io.ox/office/textframework/utils/export', [
             span        = $(paragraph).find('>span'),
             text        = getPreparedText(drawing[0].children, { type: type }),
             content     = $('<div class="content">').append(text),
-            shape       = $('<div class="shape" style="display: block; width: ' + canvas.width() + 'px; height: ' + canvas.height() + 'px;">');
+            shape       = (canvas.length > 0) ? $('<div class="shape" style="display: block; width: ' + canvas.width() + 'px; height: ' + canvas.height() + 'px;">') : $('<div>');
 
         copyStyles(paragraph, shape, 'textframe_p');
         copyStyles(span, content, 'span');
 
         // if we have a preset-shape
-        if (!(attributes.geometry && attributes.geometry.presetShape && attributes.geometry.presetShape === 'rect')) {
+        if ((canvas.length > 0) && !(attributes.geometry && attributes.geometry.presetShape && attributes.geometry.presetShape === 'rect')) {
             shape.attr('style', shape.attr('style') + ' background-image: url(\'' + canvas[0].toDataURL() + '\'); background-repeat: no-repeat; background-position: top left;');
 
         // if we have a "normal" shape (rectangle)
         } else {
-            shape = applyFillAndLineStyles(shape, editor, drawing);
+            shape = applyFillAndLineStyles(shape, docModel, drawing);
         }
 
         return (type === 'html') ? shape.append(content) : text;
     }
 
-    function applyFillAndLineStyles(shape, editor, drawing) {
+    function applyFillAndLineStyles(shape, docModel, drawing) {
         var attributes      = drawing.first().data('attributes'),
+            themeModel      = docModel.getThemeModel(),
 
-            fillC           = (attributes.fill) ? attributes.fill.color : null,
-            fillColor       = (fillC) ? new Color(fillC.type, fillC.value, fillC.transformations, fillC.fallbackValue) : null,
-            fillColorDesc   = (fillC) ? fillColor.resolve('fill', editor.getDocModel().getTheme()) : null,
+            fillC           = attributes.fill ? attributes.fill.color : null,
+            fillColor       = fillC ? new Color(fillC.type, fillC.value, fillC.transformations, fillC.fallbackValue) : null,
+            fillColorDesc   = fillC ? fillColor.resolve('fill', themeModel) : null,
 
-            lineC           = (attributes.line) ? attributes.line.color : null,
-            lineColor       = (lineC) ? new Color(lineC.type, lineC.value, lineC.transformations, lineC.fallbackValue) : null,
-            lineColorDesc   = (lineC) ? lineColor.resolve('line', editor.getDocModel().getTheme()) : null,
-            lineWidth       = (lineC) ? Math.max(1, Utils.convertHmmToLength(attributes.line.width, 'px', 1)) : null,
+            lineC           = attributes.line ? attributes.line.color : null,
+            lineColor       = lineC ? new Color(lineC.type, lineC.value, lineC.transformations, lineC.fallbackValue) : null,
+            lineColorDesc   = lineC ? lineColor.resolve('line', themeModel) : null,
+            lineWidth       = lineC ? Math.max(1, Utils.convertHmmToLength(attributes.line.width, 'px', 1)) : null,
             lineType        = 'solid';
 
         // if the shape has a background
         if (fillColorDesc) {
-            shape.attr('style', ((shape.attr('style')) ? shape.attr('style') : '') + ' background: ' + fillColorDesc.css + ';');
+            shape.attr('style', (shape.attr('style') || '') + ' background: ' + fillColorDesc.css + ';');
         }
 
         // if the shape has a border
@@ -340,7 +348,7 @@ define('io.ox/office/textframework/utils/export', [
                 lineType        = 'dashed';
             }
 
-            shape.attr('style', ((shape.attr('style')) ? shape.attr('style') : '') + ' border: ' + lineWidth + 'px ' + lineType + ' ' + lineColorDesc.css + ';');
+            shape.attr('style', (shape.attr('style') || '') + ' border: ' + lineWidth + 'px ' + lineType + ' ' + lineColorDesc.css + ';');
         }
 
         return shape;
@@ -503,9 +511,14 @@ define('io.ox/office/textframework/utils/export', [
      *  The list element as jQuery.
      */
     function createListElement(level, listStyle) {
-        var format = listStyle.listLevels[level].numberFormat,
-            levelText = listStyle.listLevels[level].levelText,
-            node = (format === 'bullet') ? $('<ul>') : $('<ol>');
+        var format = listStyle.listLevels[level].numberFormat;
+        var levelText = listStyle.listLevels[level].levelText;
+        var startValue = listStyle.listLevels[level].listStartValue;
+        var node = (format === 'bullet') ? $('<ul>') : $('<ol>');
+
+        if (startValue > 1) {
+            node.attr('start', startValue);
+        }
 
         switch (format.toLowerCase()) {
             case 'decimal':
