@@ -14,9 +14,10 @@
 define('io.ox/office/textframework/utils/textutils', [
     'io.ox/office/tk/utils',
     'io.ox/office/tk/utils/logger',
+    'io.ox/office/tk/render/rectangle',
     'io.ox/office/editframework/utils/attributeutils',
     'io.ox/office/textframework/utils/dom'
-], function (Utils, Logger, AttributeUtils, DOM) {
+], function (Utils, Logger, Rectangle, AttributeUtils, DOM) {
 
     'use strict';
 
@@ -65,12 +66,12 @@ define('io.ox/office/textframework/utils/textutils', [
     /**
      * Default background attributes for drawing.
      */
-    TextUtils.NO_DRAWING_BACKGROUND = { fill: { type: 'none', color: null, backgroundColor: null, transparency: null, gradient: null, bitmap: null, pattern: null } };
+    TextUtils.NO_DRAWING_BACKGROUND = { fill: { type: 'none', color: null, color2: null, gradient: null, bitmap: null, pattern: null } };
 
     /**
      * Default background attributes for slide.
      */
-    TextUtils.NO_SLIDE_BACKGROUND = { fill: { type: null, color: null, backgroundColor: null, transparency: null, gradient: null, bitmap: null, pattern: null } };
+    TextUtils.NO_SLIDE_BACKGROUND = { fill: { type: null, color: null, color2: null, gradient: null, bitmap: null, pattern: null } };
 
     // default paperformats of the supported locales
     var PAPERSIZE_BY_FORMAT = {
@@ -90,31 +91,28 @@ define('io.ox/office/textframework/utils/textutils', [
     }
 
     /**
-     * Calculating a specified margin into a specified rectangle with the properties
-     * 'top', 'bottom', 'left', 'right', 'width' and 'height'.
-     * The values in both objects 'clientRect' and 'margins' must use the same unit.
-     * But the values itself must be numbers without unit.
+     * Calculating a specified margin into a specified rectangle with the
+     * properties 'top', 'bottom', 'left', 'right', 'width' and 'height'. The
+     * values in both objects 'clientRect' and 'margins' must use the same
+     * unit, but the values itself must be numbers without unit.
      *
      * @param {Object} clientRect
-     *  The rectangle that will to be expanded.
+     *  The rectangle to be expanded.
      *
      * @param {Object} margins
-     *  The margins object with the properties 'marginLeft', 'marginRight', 'marginTop'
-     *  and 'marginBottom'.
+     *  The margins object with the properties 'marginLeft', 'marginRight',
+     *  'marginTop' and 'marginBottom'.
      *
-     * @returns {Object}
+     * @returns {Rectangle}
      *  The expanded rectangle object.
      */
     function expandRectangleWithMargin(clientRect, margins) {
-
-        return {
-            width: clientRect.width + margins.marginLeft + margins.marginRight,
-            height: clientRect.height + margins.marginTop + margins.marginBottom,
-            top: clientRect.top - margins.marginTop,
-            bottom: clientRect.bottom + margins.marginBottom,
-            left: clientRect.left - margins.marginLeft,
-            right: clientRect.right + margins.marginRight
-        };
+        return new Rectangle(
+            clientRect.left - margins.marginLeft,
+            clientRect.top - margins.marginTop,
+            clientRect.width + margins.marginLeft + margins.marginRight,
+            clientRect.height + margins.marginTop + margins.marginBottom
+        );
     }
 
     // methods ----------------------------------------------------------------
@@ -262,6 +260,72 @@ define('io.ox/office/textframework/utils/textutils', [
         return { top: caretTop, left: caretLeft };
     };
 
+    /**
+     * Returns the absolute CSS position of the passed DOM.Point, relative to a
+     * specific root node and zoom factor.
+     *
+     * Info: Please use 'Position.getPixelPositionFromDomPoint' from the OX Text
+     * pixel API.
+     *
+     * @param {DOM.Point} point1
+     *  the start point object, from which the CSS position should be calculated
+     * @param {DOM.Point} point2
+     *  the end point object, from which the CSS position should be calculated
+     *
+     * @param {jQuery| HTMLElement} rootNode
+     *  the calculated CSS positions are relative to this root node.
+     *
+     * @param {Number} zoom
+     *  the current active zoom factor of the application view.
+     *
+     * @param {Boolean} start
+     *
+     * @returns {Object}
+     *  with the following CSS position properties:
+     *  - {Number} top
+     *  - {Number} left
+     */
+    TextUtils.getCSSRectangleFromPoints = function (point1, point2, rootNode, zoom, start) {
+        var range = document.createRange();
+        var rect;
+
+        range.setStart(point1.node, point1.offset);
+        if (point2) {
+            range.setEnd(point2.node, point2.offset);
+        } else {
+            if (point1.offset + 1 <= point1.node.length) {
+                range.setEnd(point1.node, point1.offset + 1);
+            } else if (!start && point1.node.length > 0) {
+                range.setStart(point1.node, point1.offset - 1);
+                range.setEnd(point1.node, point1.offset);
+                rect = range.getBoundingClientRect();
+                rect = {
+                    top: rect.top,
+                    left: rect.right,
+                    height: rect.height,
+                    width: 0
+                };
+            } else {
+                var nextNode = point1.node.nextSibling;
+                if (nextNode) {
+                    range.setEnd(nextNode, 0);
+                } else {
+                    var left = $(point1.node.parentNode).offset().left + $(point1.node.parentNode).width() * zoom;
+                    rect = {
+                        top: $(point1.node.parentNode).offset().top,
+                        left: left,
+                        height: $(point1.node.parentNode).height() * zoom,
+                        width: 0
+                    };
+                }
+            }
+        }
+
+        rect = rect ? rect : range.getBoundingClientRect();
+
+        return { top: (rect.top - rootNode.offset().top) / zoom, left: (rect.left - rootNode.offset().left) / zoom, height: rect.height / zoom, width: rect.width / zoom };
+    };
+
     /**
      * Returns whether the passed intervals overlap with at least one index.
      *
@@ -512,33 +576,33 @@ define('io.ox/office/textframework/utils/textutils', [
      */
     TextUtils.findAllIntersections = logger.profileMethod('TextUtils.findAllIntersections()', function (source, compareList, options) {
 
-        var // the jQuerified source element
-            $source = $(source),
-            // the rectangle around the source element
-            sourceRect = source.getBoundingClientRect(),
-            // the key name in the data object, that contain the margin size in pixel
-            marginKey = Utils.getStringOption(options, 'marginKey', null),
-            // the result array
-            result = [];
+        // the jQuerified source element
+        var $source = $(source);
+        // the rectangle around the source element
+        var sourceRect = source.getBoundingClientRect();
+        // the key name in the data object, that contain the margin size in pixel
+        var marginKey = Utils.getStringOption(options, 'marginKey', null);
+        // the result array
+        var result = [];
 
+        // ensure to have an instance of the class Rectangle
         if (marginKey && $source.data(marginKey)) {
             sourceRect = expandRectangleWithMargin(sourceRect, $source.data(marginKey));
+        } else {
+            sourceRect = Rectangle.from(sourceRect);
         }
 
         _.each(compareList, function (compare) {
-
-            var // the rectangle around the compare element
-                compareRect = null;
-
             if (compare === source) { return; }
 
-            compareRect = compare.getBoundingClientRect();
+            // the rectangle around the compare element
+            var compareRect = compare.getBoundingClientRect();
 
             if (marginKey && $(compare).data(marginKey)) {
                 compareRect = expandRectangleWithMargin(compareRect, $(compare).data(marginKey));
             }
 
-            if (Utils.rectanglesOverlap(sourceRect, compareRect)) {
+            if (sourceRect.overlaps(compareRect)) {
                 result.push(compare);
             }
         });
@@ -639,6 +703,52 @@ define('io.ox/office/textframework/utils/textutils', [
         return TextUtils.NO_SLIDE_BACKGROUND;
     };
 
+    /**
+     * This function converts the properties of a rectangle object ('top', 'left',
+     * 'width' and 'height'). Specified is a rectangle that has values in pixel
+     * relative to the app-content-root node. This is for example created by the
+     * selectionBox. All properties are converted into values relative to the page.
+     *
+     * @param {Application} app
+     *  The application containing this instance.
+     *
+     * @param {Object} box
+     *  The rectangle with the properties 'top', 'left', 'width' and 'height'.
+     *  The values are given in pixel relative to the app-content-root node.
+     *
+     * @returns {Object}
+     *  The rectangle with the properties 'top', 'left', 'width' and 'height'.
+     *  The values are given in pixel relative to the page node.
+     */
+    TextUtils.convertAppContentBoxToPageBox = function (app, box) {
+
+        var // the current zoom factor
+            zoomFactor = app.getView().getZoomFactor(),
+            // the offset of the active slide inside the content root node
+            pageOffset = app.getModel().getNode().offset(),
+            // the content root node, the base for the position calculation
+            contentRootNode = app.getView().getContentRootNode(),
+            // the position of the content root node
+            pos = contentRootNode.offset(),
+            // the horizontal scroll shift
+            scrollLeft = contentRootNode.scrollLeft(),
+            // the vertical scroll shift
+            scrollTop = contentRootNode.scrollTop(),
+            // the new box object
+            operationBox = {};
+
+        // the left position of the user defined box relative to the slide (can be negative)
+        operationBox.left = Utils.round((box.left - (pageOffset.left - pos.left) - scrollLeft) / zoomFactor, 1);
+        // the top position of the user defined box relative to the slide (can be negative)
+        operationBox.top = Utils.round((box.top - (pageOffset.top - pos.top) - scrollTop) / zoomFactor, 1);
+        // the width of the box
+        operationBox.width = Utils.round(box.width / zoomFactor, 1);
+        // the height of the box
+        operationBox.height = Utils.round(box.height / zoomFactor, 1);
+
+        return operationBox;
+    };
+
     // exports ================================================================
 
     return TextUtils;
