@@ -15,22 +15,25 @@
 define('io.ox/office/textframework/view/controls', [
     'io.ox/office/tk/utils',
     'io.ox/office/editframework/utils/lineheight',
-    'io.ox/office/editframework/utils/paragraphspacing',
     'io.ox/office/editframework/view/editcontrols',
     'io.ox/office/textframework/view/labels',
     'io.ox/office/textframework/view/control/paragraphstylepicker',
-    'io.ox/office/textframework/view/control/tablestylepicker',
     'io.ox/office/textframework/view/control/liststylepicker',
     'io.ox/office/textframework/view/control/changetrackbadge',
     'io.ox/office/textframework/view/control/drawingpositionpicker',
     'io.ox/office/textframework/view/control/commentfiltergroup',
     'io.ox/office/textframework/view/control/fieldformatlist',
-    'io.ox/office/baseframework/view/control/compoundsplitbutton',
     'gettext!io.ox/office/textframework/main'
-], function (Utils, LineHeight, ParagraphSpacing, EditControls, Labels, ParagraphStylePicker, TableStylePicker, ListStylePicker, ChangeTrackBadge, DrawingPositionPicker, CommentFilterGroup, FieldFormatList, CompoundSplitButton, gt) {
+], function (Utils, LineHeight, EditControls, Labels, ParagraphStylePicker, ListStylePicker, ChangeTrackBadge, DrawingPositionPicker, CommentFilterGroup, FieldFormatList, gt) {
 
     'use strict';
 
+    // convenience shortcuts
+    var Button = EditControls.Button;
+    var RadioGroup = EditControls.RadioGroup;
+    var RadioList = EditControls.RadioList;
+    var CompoundButton = EditControls.CompoundButton;
+
     // static class TextControls ==============================================
 
     /**
@@ -41,7 +44,6 @@ define('io.ox/office/textframework/view/controls', [
      */
     var TextControls = _.extend({}, EditControls, {
         ParagraphStylePicker: ParagraphStylePicker,
-        TableStylePicker: TableStylePicker,
         ChangeTrackBadge: ChangeTrackBadge,
         DrawingPositionPicker: DrawingPositionPicker,
         CommentFilterGroup: CommentFilterGroup,
@@ -57,9 +59,9 @@ define('io.ox/office/textframework/view/controls', [
      *
      * @extends RadioGroup
      */
-    TextControls.ParagraphAlignmentGroup = EditControls.RadioGroup.extend({ constructor: function (initOptions) {
+    TextControls.ParagraphAlignmentGroup = RadioGroup.extend({ constructor: function (docView, initOptions) {
 
-        EditControls.RadioGroup.call(this, Utils.extendOptions({
+        RadioGroup.call(this, docView, Utils.extendOptions({
             tooltip: Labels.PARA_ALIGNMENT_LABEL
         }, initOptions));
 
@@ -81,9 +83,9 @@ define('io.ox/office/textframework/view/controls', [
      *
      * @extends RadioGroup
      */
-    TextControls.ParagraphAlignmentPicker = EditControls.RadioList.extend({ constructor: function (initOptions) {
+    TextControls.ParagraphAlignmentPicker = RadioList.extend({ constructor: function (docView, initOptions) {
 
-        EditControls.RadioList.call(this, Utils.extendOptions({
+        RadioList.call(this, docView, Utils.extendOptions({
             icon: 'docs-para-align-left',
             tooltip: Labels.PARA_ALIGNMENT_LABEL,
             updateCaptionMode: 'icon'
@@ -95,58 +97,74 @@ define('io.ox/office/textframework/view/controls', [
 
     } }); // class ParagraphAlignmentPicker
 
-    // class ParagraphAlignmentPicker =========================================
+    // class TextBoxAlignmentPicker ===========================================
 
     /**
-     * A picker control for horizontal text alignment & vertical paragraph alignment.
+     * A picker control for horizontal and vertical alignment of paragraphs in
+     * text boxes.
      *
      * @constructor
      *
-     * @extends RadioGroup
+     * @extends CompoundButton
      */
-    TextControls.GeneralAlignmentPicker = EditControls.CompoundButton.extend({ constructor: function (docView, initOptions) {
+    TextControls.TextBoxAlignmentPicker = CompoundButton.extend({ constructor: function (docView, initOptions) {
 
-        EditControls.CompoundButton.call(this, docView, Utils.extendOptions({
+        CompoundButton.call(this, docView, Utils.extendOptions({
             icon: 'docs-para-align-left',
             tooltip: gt('Paragraph alignment'),
             updateCaptionMode: 'none'
         }, initOptions));
 
-        var horizontal = new EditControls.RadioGroup();
+        var horizontalGroup = new RadioGroup(docView);
         _.each(Labels.PARA_ALIGNMENT_STYLES, function (style) {
-            horizontal.createOptionButton(style.value, { icon: style.icon, label: style.label });
+            horizontalGroup.createOptionButton(style.value, { icon: style.icon, label: style.label });
         });
         this.addSectionLabel(gt('Horizontal alignment'));
-        this.addGroup('paragraph/alignment', horizontal);
+        this.addGroup('paragraph/alignment', horizontalGroup);
 
-        var vertical = new EditControls.RadioGroup();
+        var verticalGroup = new RadioGroup(docView);
         _.each(Labels.PARA_VERT_ALIGNMENT_STYLES, function (style) {
-            vertical.createOptionButton(style.value, { icon: style.icon, label: style.label });
+            verticalGroup.createOptionButton(style.value, { icon: style.icon, label: style.label });
         });
         this.addSectionLabel(gt('Vertical alignment'));
-        this.addGroup('drawing/verticalalignment', vertical);
+        this.addGroup('drawing/verticalalignment', verticalGroup);
 
-    } }); // class GeneralAlignmentPicker
+    } }); // class TextBoxAlignmentPicker
 
-    // class SpacingGroup ================================================
+    // class ParagraphSpacingPicker ===========================================
 
-    TextControls.SpacingGroup = EditControls.CompoundButton.extend({ constructor: function (docView) {
-        EditControls.CompoundButton.call(this, docView, {
+    /**
+     * A picker control for line height inside paragraphs, and spacing between
+     * paragraphs.
+     *
+     * @constructor
+     *
+     * @extends CompoundButton
+     */
+    TextControls.ParagraphSpacingPicker = CompoundButton.extend({ constructor: function (docView) {
+
+        CompoundButton.call(this, docView, {
             icon: 'docs-para-line-spacing-100',
             tooltip: Labels.PARAGRAPH_AND_LINE_SPACING_LABEL,
             dropDownVersion: { label: Labels.PARAGRAPH_AND_LINE_SPACING_LABEL }
         });
 
-        var pickLineHeight       = new TextControls.LineHeightPicker();
-        var pickParagraphSpacing = new TextControls.ParagraphSpacingPicker();
-
+        var lineHeightGroup = new RadioGroup(docView, { dropDownVersion: { label: Labels.LINE_SPACING_LABEL } });
+        lineHeightGroup.createOptionButton(LineHeight.SINGLE,   { icon: 'docs-para-line-spacing-100', label: /*#. text line spacing in paragraphs */ gt('100%') });
+        lineHeightGroup.createOptionButton(LineHeight._115,     { icon: 'docs-para-line-spacing-115', label: /*#. text line spacing in paragraphs */ gt('115%') });
+        lineHeightGroup.createOptionButton(LineHeight.ONE_HALF, { icon: 'docs-para-line-spacing-150', label: /*#. text line spacing in paragraphs */ gt('150%') });
+        lineHeightGroup.createOptionButton(LineHeight.DOUBLE,   { icon: 'docs-para-line-spacing-200', label: /*#. text line spacing in paragraphs */ gt('200%') });
         this.addSectionLabel(Labels.LINE_SPACING_LABEL);
-        this.addGroup('paragraph/lineheight', pickLineHeight);
+        this.addGroup('paragraph/lineheight', lineHeightGroup);
 
+        var spacingGroup = new RadioGroup(docView, { dropDownVersion: { label: Labels.PARAGRAPH_SPACING_LABEL } });
+        spacingGroup.createOptionButton(0, { label: /*#. no distance between selected paragraphs */       gt.pgettext('paragraph-spacing', 'None') });
+        spacingGroup.createOptionButton(1, { label: /*#. a normal distance between selected paragraphs */ gt.pgettext('paragraph-spacing', 'Normal') });
+        spacingGroup.createOptionButton(2, { label: /*#. a large distance between selected paragraphs */  gt.pgettext('paragraph-spacing', 'Wide') });
         this.addSectionLabel(Labels.PARAGRAPH_SPACING_LABEL);
-        this.addGroup('paragraph/spacing', pickParagraphSpacing);
+        this.addGroup('paragraph/spacing', spacingGroup);
 
-    } }); // class SpacingGroup
+    } }); // class ParagraphSpacingPicker
 
     // class TextPositionGroup ================================================
 
@@ -157,9 +175,9 @@ define('io.ox/office/textframework/view/controls', [
      *
      * @extends RadioGroup
      */
-    TextControls.TextPositionGroup = EditControls.RadioGroup.extend({ constructor: function (initOptions) {
+    TextControls.TextPositionGroup = RadioGroup.extend({ constructor: function (docView, initOptions) {
 
-        EditControls.RadioGroup.call(this, Utils.extendOptions({
+        RadioGroup.call(this, docView, _.extend({
             tooltip: Labels.TEXT_POSITION_LABEL,
             toggleValue: 'baseline'
         }, initOptions));
@@ -167,62 +185,16 @@ define('io.ox/office/textframework/view/controls', [
         // set accessible name - WCAG 2.0 Success Criterion 4.1.2
         this.getNode().attr({ 'aria-label': Labels.TEXT_POSITION_LABEL, 'aria-labelledby': 'dummy' });
 
-        this.createOptionButton('sub',   { icon: 'docs-font-subscript',   tooltip: gt('Subscript'),   dropDownVersion: { label: gt('Subscript') } })
-            .createOptionButton('super', { icon: 'docs-font-superscript', tooltip: gt('Superscript'), dropDownVersion: { label: gt('Superscript') } });
+        this.createOptionButton('sub',   { icon: 'docs-font-subscript',   tooltip: gt('Subscript'),   dropDownVersion: { label: gt('Subscript') } });
+        this.createOptionButton('super', { icon: 'docs-font-superscript', tooltip: gt('Superscript'), dropDownVersion: { label: gt('Superscript') } });
 
     } }); // class TextPositionGroup
 
-    // class LineHeightPicker =================================================
-
-    /**
-     * A picker control for the line height in paragraphs.
-     *
-     * @constructor
-     *
-     * @extends RadioGroup
-     */
-    TextControls.LineHeightPicker = EditControls.RadioGroup.extend({ constructor: function () {
-
-        EditControls.RadioGroup.call(this, {
-            dropDownVersion: { label: Labels.LINE_SPACING_LABEL }
-        });
-
-        this.createOptionButton(LineHeight.SINGLE,   { icon: 'docs-para-line-spacing-100', label: /*#. text line spacing in paragraphs */ gt('100%') })
-            .createOptionButton(LineHeight._115,     { icon: 'docs-para-line-spacing-115', label: /*#. text line spacing in paragraphs */ gt('115%') })
-            .createOptionButton(LineHeight.ONE_HALF, { icon: 'docs-para-line-spacing-150', label: /*#. text line spacing in paragraphs */ gt('150%') })
-            .createOptionButton(LineHeight.DOUBLE,   { icon: 'docs-para-line-spacing-200', label: /*#. text line spacing in paragraphs */ gt('200%') });
-
-    } }); // class LineHeightPicker
-
-    // class ParagraphSpacingPicker ===========================================
-
-    /**
-     * A picker control for the 'marginBottom' controlled spacing
-     * in between two or more selected paragraphs.
-     *
-     * @constructor
-     *
-     * @extends RadioGroup
-     */
-    TextControls.ParagraphSpacingPicker = EditControls.RadioGroup.extend({ constructor: function () {
-
-        EditControls.RadioGroup.call(this, {
-            dropDownVersion: { label: Labels.PARAGRAPH_SPACING_LABEL }
-        });
-
-        var multiplier = ParagraphSpacing.setting.multiplier;
-
-        this.createOptionButton(multiplier.NONE,   { label: /*#. no distance at all in between two or more selected paragraphs */ gt('None') })
-            .createOptionButton(multiplier.NORMAL, { label: /*#. a normal distance in between two or more selected paragraphs  */ gt('Normal') })
-            .createOptionButton(multiplier.WIDE,   { label: /*#. a large distance in between two or more selected paragraphs   */ gt('Wide') });
-
-    } }); // class ParagraphSpacingPicker
-
     // class BulletListStylePicker ============================================
 
-    TextControls.BulletListStylePicker = ListStylePicker.extend({ constructor: function (docView, docModel, initOptions) {
+    TextControls.BulletListStylePicker = ListStylePicker.extend({ constructor: function (docView, initOptions) {
 
-        ListStylePicker.call(this, docView, docModel.getPredefinedBulletListStyles(), Utils.extendOptions({
+        ListStylePicker.call(this, docView, docView.getDocModel().getPredefinedBulletListStyles(), Utils.extendOptions({
             icon: 'docs-list-bullet',
             tooltip: gt('Bullet list'),
             gridColumns: 4,
@@ -233,18 +205,21 @@ define('io.ox/office/textframework/view/controls', [
 
     // class NumberedListStylePicker ==========================================
 
-    TextControls.NumberedListStylePicker = ListStylePicker.extend({ constructor: function (docView, docModel, initOptions) {
+    TextControls.NumberedListStylePicker = ListStylePicker.extend({ constructor: function (docView, initOptions) {
 
-        ListStylePicker.call(this, docView, docModel.getPredefinedNumberedListStyles(), Utils.extendOptions({
+        var predefinedStyles = docView.getDocModel().getPredefinedNumberedListStyles();
+        var gridColumns = _.where(predefinedStyles, { format: 'decimal' }).length || 4; // using default value 4 (53055)
+
+        ListStylePicker.call(this, docView, predefinedStyles, Utils.extendOptions({
             icon: 'docs-list-numbered',
             tooltip: gt('Numbered list'),
-            gridColumns: 4,
+            gridColumns: gridColumns,
             dropDownVersion: { label: gt('Numbered list') }
         }, initOptions));
 
     } }); // class NumberedListStylePicker
 
-    // class UserFilterCompoundButton =========================================
+    // class UserFilterPicker =================================================
 
     /**
      * Drop-down menu control for setting a user filter for the comments in the
@@ -254,11 +229,11 @@ define('io.ox/office/textframework/view/controls', [
      *
      * @extends CompoundButton
      */
-    TextControls.UserFilterCompoundButton = EditControls.CompoundButton.extend({ constructor: function (docView) {
+    TextControls.UserFilterPicker = CompoundButton.extend({ constructor: function (docView) {
 
         // base constructor ---------------------------------------------------
 
-        EditControls.CompoundButton.call(this, docView, {
+        CompoundButton.call(this, docView, {
             label: gt('Comment authors'),
             tooltip: gt('Show comment authors'),
             anchorBorder: 'right left bottom top',
@@ -270,7 +245,7 @@ define('io.ox/office/textframework/view/controls', [
 
         this.addGroup('comment/authorFilter', new CommentFilterGroup(docView), { sticky: true });
 
-    } }); // class UserFilterCompoundButton
+    } }); // class UserFilterPicker
 
     // class CommentDisplayModePicker ============================================
 
@@ -284,15 +259,16 @@ define('io.ox/office/textframework/view/controls', [
      *
      * @extends CompoundButton
      */
-    TextControls.CommentDisplayModePicker = EditControls.CompoundButton.extend({ constructor: function (docView, options) {
+    TextControls.CommentDisplayModePicker = CompoundButton.extend({ constructor: function (docView, options) {
 
-        var smallDevice = Utils.getBooleanOption(options, 'smallDevice', false),
-            // the group of all display mode buttons
-            displayModeGroup = new EditControls.RadioGroup();
+        var smallDevice = Utils.getBooleanOption(options, 'smallDevice', false);
+
+        // the group of all display mode buttons
+        var displayModeGroup = new RadioGroup(docView);
 
         // base constructor ---------------------------------------------------
 
-        EditControls.CompoundButton.call(this, docView, {
+        CompoundButton.call(this, docView, {
             icon: 'docs-comment-show',
             label: gt('Markup'),
             tooltip: gt('Highlight comments mode'),
@@ -330,7 +306,7 @@ define('io.ox/office/textframework/view/controls', [
         this.addGroup('comment/displayMode', displayModeGroup)
             .addSeparator()
             // adding the button, that contains a list of all users who created comments in the document
-            .addGroup(null, new TextControls.UserFilterCompoundButton(docView));
+            .addGroup(null, new TextControls.UserFilterPicker(docView));
 
     } }); // class CommentDisplayModePicker
 
@@ -344,11 +320,11 @@ define('io.ox/office/textframework/view/controls', [
      *
      * @extends RadioList
      */
-    TextControls.CommentDisplayViewPicker = EditControls.RadioList.extend({ constructor: function () {
+    TextControls.CommentDisplayViewPicker = RadioList.extend({ constructor: function (docView) {
 
         // base constructor ---------------------------------------------------
 
-        EditControls.RadioList.call(this, {
+        RadioList.call(this, docView, {
             icon: 'fa-cogs',
             label: _.noI18n('Comment view'),
             tooltip: _.noI18n('Set different comment view mode'),
@@ -377,14 +353,14 @@ define('io.ox/office/textframework/view/controls', [
      *
      * @extends RadioList
      */
-    TextControls.AnchoragePicker = EditControls.RadioList.extend({ constructor: function () {
+    TextControls.AnchoragePicker = RadioList.extend({ constructor: function (docView) {
 
         // base constructor ---------------------------------------------------
 
-        EditControls.RadioList.call(this, {
+        RadioList.call(this, docView, {
             icon: 'docs-position-anchor',
-            label: /*#. alignment and text floating of drawing objects in text documents */ gt.pgettext('drawing-pos', 'Position'),
-            tooltip: /*#. alignment and text floating of drawing objects in text documents */ gt.pgettext('drawing-pos', 'Position'),
+            label: /*#. alignment and text floating of drawing objects in text documents */ gt.pgettext('drawing-pos', 'Alignment'),
+            tooltip: /*#. alignment and text floating of drawing objects in text documents */ gt.pgettext('drawing-pos', 'Drawing alignment'),
             updateCaptionMode: 'icon',
             smallerVersion: {
                 hideLabel: true
@@ -399,48 +375,6 @@ define('io.ox/office/textframework/view/controls', [
             .createOptionButton('page',       { icon: 'docs-position-on-page',         label: /*#. drawing object position in paragraph */ gt.pgettext('drawing-pos', 'Move with page') });
     } }); // class AnchoragePicker
 
-    // class DrawingPositionPicker ============================================
-
-    /**
-     *
-     * Drop-down menu control for position and text floating of drawing
-     * objects in text documents.
-     *
-     * @constructor
-     *
-     * @extends RadioList
-     */
-    TextControls.DrawingPositionPicker = EditControls.RadioList.extend({ constructor: function () {
-
-        // base constructor ---------------------------------------------------
-
-        EditControls.RadioList.call(this, {
-            icon: 'docs-drawing-inline',
-            label: /*#. alignment and text floating of drawing objects in text documents */ gt.pgettext('drawing-pos', 'Alignment'),
-            tooltip: /*#. alignment and text floating of drawing objects in text documents */ gt.pgettext('drawing-pos', 'Drawing alignment'),
-            updateCaptionMode: 'icon',
-            smallerVersion: {
-                hideLabel: true
-            }
-        });
-
-        // initialization -----------------------------------------------------
-
-        this//.createMenuSection('inline')
-            // .createOptionButton('inline',       { section: 'inline', icon: 'docs-drawing-inline',       label: /*#. drawing object position in paragraph */ gt.pgettext('drawing-pos', 'Inline with text') })
-            .createMenuSection('left')
-            .createOptionButton('left:none',    { section: 'left',   icon: 'docs-drawing-left-none',    label: /*#. drawing object position in paragraph */ gt.pgettext('drawing-pos', 'Left aligned, no text wrapping') })
-            .createOptionButton('left:right',   { section: 'left',   icon: 'docs-drawing-left-right',   label: /*#. drawing object position in paragraph */ gt.pgettext('drawing-pos', 'Left aligned, text wraps at right side') })
-            .createMenuSection('right')
-            .createOptionButton('right:none',   { section: 'right',  icon: 'docs-drawing-right-none',   label: /*#. drawing object position in paragraph */ gt.pgettext('drawing-pos', 'Right aligned, no text wrapping') })
-            .createOptionButton('right:left',   { section: 'right',  icon: 'docs-drawing-right-left',   label: /*#. drawing object position in paragraph */ gt.pgettext('drawing-pos', 'Right aligned, text wraps at left side') })
-            .createMenuSection('center')
-            .createOptionButton('center:none',  { section: 'center', icon: 'docs-drawing-center-none',  label: /*#. drawing object position in paragraph */ gt.pgettext('drawing-pos', 'Centered, no text wrapping') })
-            .createOptionButton('center:left',  { section: 'center', icon: 'docs-drawing-center-left',  label: /*#. drawing object position in paragraph */ gt.pgettext('drawing-pos', 'Centered, text wraps at left side') })
-            .createOptionButton('center:right', { section: 'center', icon: 'docs-drawing-center-right', label: /*#. drawing object position in paragraph */ gt.pgettext('drawing-pos', 'Centered, text wraps at right side') });
-
-    } }); // class DrawingPositionPicker
-
     // class InTextStyleContextSubMenu ========================================
 
     /**
@@ -449,7 +383,7 @@ define('io.ox/office/textframework/view/controls', [
      *
      * @extends CompoundButton
      */
-    TextControls.InTextStyleContextSubMenu = EditControls.CompoundButton.extend({ constructor: function (docView, initOptions) {
+    TextControls.InTextStyleContextSubMenu = CompoundButton.extend({ constructor: function (docView, initOptions) {
 
         var self = this;
         var docModel = docView.getDocModel();
@@ -457,19 +391,19 @@ define('io.ox/office/textframework/view/controls', [
 
         // base constructor ---------------------------------------------------
 
-        EditControls.CompoundButton.call(this, docView, Utils.extendOptions({
+        CompoundButton.call(this, docView, Utils.extendOptions({
             label: Labels.PARAGRAPH_STYLE_LABEL
         }, initOptions));
 
         // initialization -----------------------------------------------------
 
-        this.addGroup('paragraph/createstylesheet', new TextControls.Button({ label: Labels.CREATE_STYLE_LABEL, tooltip: Labels.CREATE_STYLE_LABEL_TOOLTIP }));
+        this.addGroup('paragraph/createstylesheet', new Button(docView, { label: Labels.CREATE_STYLE_LABEL, tooltip: Labels.CREATE_STYLE_LABEL_TOOLTIP }));
 
         this.on('group:focus', function () {
             var styleId = docModel.getAttributes('paragraph').styleId;
 
             //getTranslatedNameByStyleId call of StyleSheetMixin
-            changeStyleButton = new TextControls.Button({
+            changeStyleButton = new Button(docView, {
                 label: gt('Change style "%1$s"', docModel.getTranslatedNameByStyleId(styleId)),
                 tooltip: Labels.CHANGE_STYLE_LABEL_TOOLTIP,
                 value: styleId
@@ -496,23 +430,53 @@ define('io.ox/office/textframework/view/controls', [
      *
      * @extends CompoundButton
      */
-    TextControls.InsertFieldPicker = EditControls.CompoundButton.extend({ constructor: function (docView, options) {
+    TextControls.InsertFieldPicker = CompoundButton.extend({ constructor: function (docView, options) {
 
-        EditControls.CompoundButton.call(this, docView, Utils.extendOptions(options, {
+        CompoundButton.call(this, docView, Utils.extendOptions(options, {
             label: /*#. button to insert field in document */ gt('Field'),
             tooltip: gt('Insert field'),
             icon: 'docs-field',
             smallerVersion: { hideLabel: true }
         }));
 
-        this.addGroup('document/insertfield', new TextControls.Button({ value: 'pagenumber',    label: /*#. insert page number */ gt('Page number') }))
-            .addGroup('document/insertfield', new TextControls.Button({ value: 'numpages',      label: /*#. insert number of pages in document */ gt('Page count') }))
-            .addGroup('document/insertfield', new TextControls.Button({ value: 'date',          label: /*#. insert current date and time */ gt('Date & time') }))
-            .addGroup('document/insertfield', new TextControls.Button({ value: 'filename',      label: /*#. insert document name */ gt('Document name') }))
-            .addGroup('document/insertfield', new TextControls.Button({ value: 'author',        label: /*#. insert author's name */ gt('Author name') }));
+        this.addGroup('document/insertfield', new Button(docView, { value: 'pagenumber',    label: /*#. insert page number */ gt('Page number') }))
+            .addGroup('document/insertfield', new Button(docView, { value: 'numpages',      label: /*#. insert number of pages in document */ gt('Page count') }))
+            .addGroup('document/insertfield', new Button(docView, { value: 'date',          label: /*#. insert current date and time */ gt('Date & time') }))
+            .addGroup('document/insertfield', new Button(docView, { value: 'filename',      label: /*#. insert document name */ gt('Document name') }))
+            .addGroup('document/insertfield', new Button(docView, { value: 'author',        label: /*#. insert author's name */ gt('Author name') }));
 
     } }); // class InsertFieldPicker
 
+    // class TocPicker =================================================
+
+    /**
+     * Control to pick Table of contents template from dropdown
+     *
+     * @constructor
+     *
+     * @extends RadioList
+     */
+    TextControls.TocPicker = RadioList.extend({ constructor: function (docView, initOptions) {
+
+        RadioList.call(this, docView, Utils.extendOptions({
+            icon: 'docs-table-of-contents',
+            label: /*#. button to insert table of contents in document */ gt('Table of contents'),
+            tooltip: gt('Insert table of contents'),
+            itemDesign: 'grid',
+            gridColumns: 1,
+            smallerVersion: {
+                hideLabel: true
+            }
+        }, initOptions));
+
+        this.getMenuNode().addClass('toc-picker');
+
+        this.createOptionButton(1, { icon: 'text-toc1', tooltip: /*#. insert table of contents template with dots and page numbers */   gt('With dots and page numbers') })
+            .createOptionButton(2, { icon: 'text-toc2', tooltip: /*#. insert table of contents template with page numbers */            gt('With page numbers') })
+            .createOptionButton(3, { icon: 'text-toc3', tooltip: /*#. insert table of contents template with headings text only */      gt('Headings only') });
+
+    } }); // class TocPicker
+
     // class PresentationDateNumberPicker =====================================
 
     /**
@@ -522,50 +486,20 @@ define('io.ox/office/textframework/view/controls', [
      *
      * @extends CompoundButton
      */
-    TextControls.PresentationDateNumberPicker = EditControls.CompoundButton.extend({ constructor: function (docView, options) {
+    TextControls.PresentationDateNumberPicker = CompoundButton.extend({ constructor: function (docView, options) {
 
-        EditControls.CompoundButton.call(this, docView, Utils.extendOptions(options, {
+        CompoundButton.call(this, docView, Utils.extendOptions(options, {
             label: /*#. button to insert slide number or date */ gt('Field'),
             tooltip: gt('Insert field'),
             icon: 'docs-field',
             smallerVersion: { hideLabel: true }
         }));
 
-        this.addGroup('document/insertfield', new TextControls.Button({ value: 'slidenum', label: /*#. insert slide number */ gt('Slide number') }))
-            .addGroup('document/insertfield', new TextControls.Button({ value: 'datetime', label: /*#. insert current date and time */ gt('Date & time') }));
+        this.addGroup('document/insertfield', new Button(docView, { value: 'slidenum', label: /*#. insert slide number */ gt('Slide number') }))
+            .addGroup('document/insertfield', new Button(docView, { value: 'datetime', label: /*#. insert current date and time */ gt('Date & time') }));
 
     } }); // class PresentationDateNumberPicker
 
-    // class VerticalAlignmentPicker ==========================================
-
-    /**
-     * Drop-down menu control for modifying the view of the comments layer. This is
-     * only planned for testing purposes and can be removed in release version.
-     *
-     * @constructor
-     *
-     * @extends RadioList
-     */
-    TextControls.VerticalAlignmentPicker = EditControls.RadioList.extend({ constructor: function () {
-
-        // base constructor ---------------------------------------------------
-
-        EditControls.RadioList.call(this, {
-            icon: 'fa-cogs',
-            label: gt('Vertical alignment'),
-            tooltip: gt('Set the vertical text alignment'),
-            updateCaptionMode: 'icon',
-            smallerVersion: { hideLabel: true }
-        });
-
-        // initialization -----------------------------------------------------
-
-        _.each(Labels.PARA_VERT_ALIGNMENT_STYLES, function (style) {
-            this.createOptionButton(style.value, { icon: style.icon, label: style.label });
-        }, this);
-
-    } }); // class VerticalAlignmentPicker
-
     // exports ================================================================
 
     return TextControls;
