@@ -82,6 +82,19 @@ define('io.ox/office/textframework/view/dialog/pagesettingsdialog', [
             screen_16_by_9_hd:  { value: 'screen_16_by_9_hd', name: /*#. Predefined 'Widescreen HD (16:9)' slide format for presentations */ gt('Widescreen HD (16:9)'), width: 19050, height: 33870 }
         },
 
+        ODP_SPECIFIC_SLIDE_MEASURES = {
+
+            /**
+             *  slide-specific:
+             *  - width/height values need to be set paper format alike in order to handle orientation calculation properly for both use cases screen and paper.
+             */
+            screen_4_by_3:      { width: 21000, height: 28000 },
+            screen_16_by_9:     { width: 15750, height: 28000 },
+            screen_16_by_10:    { width: 17500, height: 28000 },
+          //screen_ultrawide:   { width: 21000, height: 37340 },
+            screen_16_by_9_hd:  { width: 21000, height: 37340 }
+        },
+
         PAGE_FORMAT_SETTING_KEY_LIST = [
             'letter',
             'tabloid',
@@ -121,9 +134,25 @@ define('io.ox/office/textframework/view/dialog/pagesettingsdialog', [
         MARGIN_MIN = 0,
         MARGIN_MAX = 5000;
 
+    function createDocumentSpecificFormatSettings(isOdf) {
+        var
+            formatSettingMap = _.deepClone(FORMAT_SETTING_MAP);
+
+        if (isOdf) {
+            _.keys(ODP_SPECIFIC_SLIDE_MEASURES).forEach(function (key) {
+
+                _.extend(formatSettingMap[key], ODP_SPECIFIC_SLIDE_MEASURES[key]);
+            });
+        }
+        return formatSettingMap;
+    }
+
     function collectFormatSettings(collector, formatKey/*, idx, list*/) {
-        if (formatKey in FORMAT_SETTING_MAP) {
-            collector.push(FORMAT_SETTING_MAP[formatKey]);
+        var
+            formatSettingMap = collector.map;
+
+        if (formatKey in formatSettingMap) {
+            collector.list.push(formatSettingMap[formatKey]);
         }
         return collector;
     }
@@ -156,6 +185,7 @@ define('io.ox/office/textframework/view/dialog/pagesettingsdialog', [
         var self = this,
             // Misc
             docModel = docView.getDocModel(),
+            app = docModel.getApp(),
             // jQuery DOM objects
             jqFormat = null,
             jqOrientation = null,
@@ -174,6 +204,7 @@ define('io.ox/office/textframework/view/dialog/pagesettingsdialog', [
             marginRightSpinner = null,
 
             // Page data
+            formatSettingMap = createDocumentSpecificFormatSettings(app.isODF()),
             formatSettingList = null,
             isPresentationApp = docModel.useSlideMode(),
             initialPageAttrs  = _.copy(docModel.getStyleCollection('page').getElementAttributes(docModel.getNode()).page, true);
@@ -189,13 +220,13 @@ define('io.ox/office/textframework/view/dialog/pagesettingsdialog', [
             pageSizeStr         = slideSizeStr;
 
             // presentation-app specific format-settings
-            formatSettingList = SLIDE_FORMAT_SETTING_KEY_LIST.reduce(collectFormatSettings, []);
+            formatSettingList = SLIDE_FORMAT_SETTING_KEY_LIST.reduce(collectFormatSettings, { map: formatSettingMap, list: [] }).list;
         } else {
             // text-app specific format-settings
-            formatSettingList = PAGE_FORMAT_SETTING_KEY_LIST.reduce(collectFormatSettings, []);
+            formatSettingList = PAGE_FORMAT_SETTING_KEY_LIST.reduce(collectFormatSettings, { map: formatSettingMap, list: [] }).list;
         }
 
-        Dialogs.ModalDialog.call(this, { title: pageSettingsStr, width: (Utils.SMALL_DEVICE || isPresentationApp) ? 320 : 530, container: docView.getApp().getWindowNode() });
+        Dialogs.ModalDialog.call(this, docView, { title: pageSettingsStr, width: (Utils.SMALL_DEVICE || isPresentationApp) ? 320 : 530, container: docView.getApp().getWindowNode() });
 
         // private methods ----------------------------------------------------
 
@@ -208,13 +239,14 @@ define('io.ox/office/textframework/view/dialog/pagesettingsdialog', [
          *  should be set accordingly.
          * @param {String} label String for the label
          */
-        function Spinner(min, max, pageDataKey, label) {
+        var Spinner = EditControls.SpinField.extend({ constructor: function (min, max, pageDataKey, label) {
+
             var spinnerValue,
                 spinnerNode,
                 cleanLabel  = label ? Utils.trimAndCleanString(label.toLowerCase().replace(' ', '')) : false,
                 labelNode = Forms.createElementMarkup('label', { attributes: { class: 'spin-field-label', for: cleanLabel }, content: label });
 
-            EditControls.UnitField.call(this, {
+            EditControls.UnitField.call(this, docView, {
                 width: 70,
                 tooltip: label,
                 min: min,
@@ -260,7 +292,7 @@ define('io.ox/office/textframework/view/dialog/pagesettingsdialog', [
             this.label = function () {
                 return labelNode;
             };
-        }
+        } });
 
         /**
          * Creates and layouts all dialog controls, contained within the body of the
