@@ -129,7 +129,7 @@ define('io.ox/office/textframework/view/popup/universalcontextmenu', [
          * A handler that should be invoked on detect (see in global 'contextmenu.js')
          */
         function detectHandler() {
-            isRangeSelected = !selection.isTextCursor();
+            isRangeSelected = selection.hasRange();
         }
 
         /**
@@ -154,6 +154,7 @@ define('io.ox/office/textframework/view/popup/universalcontextmenu', [
 
             // remove all existing controls from context menu
             self.destroyAllGroups();
+            self.setToolTip('');
 
             if (enableKeys.every(controller.isItemEnabled, controller)) {
 
@@ -204,55 +205,60 @@ define('io.ox/office/textframework/view/popup/universalcontextmenu', [
          * Prepares the context menu for text
          */
         function prepareTextMenu() {
-            var characterAttrs = null;
+
+            var characterAttrs = AttributeUtils.getExplicitAttributes(node, { family: 'character', direct: true });
+            var effectiveUrl = isRangeSelected ? null : characterAttrs.url;
 
             if (Dom.isChangeTrackNode(node) && !isRangeSelected) {
-                self.addGroup('acceptSelectedChangeTracking', new Button(Labels.ACCEPT_CURRENT_OPTIONS))
-                    .addGroup('rejectSelectedChangeTracking', new Button(Labels.REJECT_CURRENT_OPTIONS))
-                    .addGroup('acceptChangeTracking', new Button(Labels.ACCEPT_ALL_OPTIONS))
-                    .addGroup('rejectChangeTracking', new Button(Labels.REJECT_ALL_OPTIONS));
+                self.addGroup('acceptSelectedChangeTracking', new Button(docView, Labels.ACCEPT_CURRENT_OPTIONS))
+                    .addGroup('rejectSelectedChangeTracking', new Button(docView, Labels.REJECT_CURRENT_OPTIONS))
+                    .addGroup('acceptChangeTracking', new Button(docView, Labels.ACCEPT_ALL_OPTIONS))
+                    .addGroup('rejectChangeTracking', new Button(docView, Labels.REJECT_ALL_OPTIONS));
 
             } else if (fieldManager.isHighlightState() && !docModel.useSlideMode()) {
                 if (fieldManager.isSupportedFieldType()) {
-                    if (fieldManager.supportsFieldFormatting()) {
-                        self.addGroup('editField', new Button(Labels.EDIT_FIELD_OPTIONS));
+                    if (characterAttrs.anchor) {
+                        self.addGroup('goToAnchor', new Button(docView, Labels.GO_TO_ANCHOR_LABEL));
                     }
-                    self.addGroup('updateField', new Button(Labels.UPDATE_FIELD_OPTIONS))
+                    if (fieldManager.supportsFieldFormatting()) {
+                        self.addGroup('editField', new Button(docView, Labels.EDIT_FIELD_OPTIONS));
+                    }
+                    if (fieldManager.isTableOfContentsHighlighted()) {
+                        self.addGroup('document/inserttoc', new Controls.TocPicker(docView, { autoCloseParent: false, autoHideGroups: true, updateCaptionMode: 'none', label: gt('Table of contents layouts'), tooltip: gt('Change current layout'), icon: 'fa-chevron-right', iconPos: 'trailing', caret: false, anchorBorder: 'right left' }));
+                    }
+                    self.addGroup('updateField', new Button(docView, Labels.UPDATE_FIELD_OPTIONS))
                     .addSeparator();
-                    self.addGroup('updateAllFields', new Button(Labels.UPDATE_ALL_FIELDS_OPTIONS));
+                    self.addGroup('updateAllFields', new Button(docView, Labels.UPDATE_ALL_FIELDS_OPTIONS));
                 }
             } else {
-                characterAttrs = AttributeUtils.getExplicitAttributes(node, { family: 'character', direct: true });
-
                 // Spellcheck
                 if (characterAttrs.spellerror && !isRangeSelected && spellChecker.isOnlineSpelling()) {
 
                     var spellResult = spellChecker.getSpellErrorWord();
 
-                    docModel.getSpellChecker().selectMisspelledWord(self);
+                    spellChecker.selectMisspelledWord(self);
 
                     if (spellResult.replacements && spellResult.replacements.length > 0) {
                         _.each(spellResult.replacements, function (replace) {
-                            self.addGroup('document/spelling/replace', new Button({ label: replace, value: replace }));
+                            self.addGroup('document/spelling/replace', new Button(docView, { label: replace, value: replace }));
                         });
                     }
 
                     if (spellResult.word && spellChecker.hasSpellerrorClass(spellResult.node)) {
                         self.addSeparator()
-                            .addGroup('document/spelling/ignoreword', new Button({ label: /*#. Context menu entry to ignore a word from spellchecking. */ gt('Ignore all'), value: { word: spellResult.word, start: spellResult.start, end: spellResult.end, nodes: spellResult.nodes, target: docModel.getActiveTarget() } }))
-                            .addGroup('document/spelling/userdictionary', new Button({ label: /*#. Context menu entry to add a word into the user dictionary. */ gt('Add to dictionary'), value: { word: spellResult.word, start: spellResult.start, end: spellResult.end, nodes: spellResult.nodes, target: docModel.getActiveTarget(), userDictionary: true } }));
+                            .addGroup('document/spelling/ignoreword', new Button(docView, { label: /*#. Context menu entry to ignore a word from spellchecking. */ gt('Ignore all'), value: { word: spellResult.word, start: spellResult.start, end: spellResult.end, nodes: spellResult.nodes, target: docModel.getActiveTarget() } }))
+                            .addGroup('document/spelling/userdictionary', new Button(docView, { label: /*#. Context menu entry to add a word into the user dictionary. */ gt('Add to dictionary'), value: { word: spellResult.word, start: spellResult.start, end: spellResult.end, nodes: spellResult.nodes, target: docModel.getActiveTarget(), userDictionary: true } }));
                     }
 
                     addLanguageGroupToMenu();
 
                     // Hyperlink
-                } else if (characterAttrs.url && !isRangeSelected) {
-                    self.addGroup('character/hyperlink/dialog', new Button({ label: Labels.EDIT_HYPERLINK_LABEL }))
-                        .addGroup('character/hyperlink/remove', new Button({ label: Labels.REMOVE_HYPERLINK_LABEL }))
-                        .addGroup('character/hyperlink/valid', new Button({ label: Labels.OPEN_HYPERLINK_LABEL, href: characterAttrs.url }));
+                } else if (effectiveUrl) {
+                    self.addGroup('character/hyperlink/dialog', new Button(docView, { label: Labels.EDIT_HYPERLINK_LABEL }))
+                        .addGroup('character/hyperlink/remove', new Button(docView, { label: Labels.REMOVE_HYPERLINK_LABEL }))
+                        .addGroup('character/hyperlink/valid', new Button(docView, { label: Labels.OPEN_HYPERLINK_LABEL, href: characterAttrs.url }));
 
-                    //AppTooltipMixin
-                    docView.getApp().enableTooltipOnShow(self, characterAttrs.url);
+                    self.setToolTip(effectiveUrl);
 
                     // Normal Text
                 } else {
@@ -268,12 +274,13 @@ define('io.ox/office/textframework/view/popup/universalcontextmenu', [
         }
 
         function prepareHyperlinkMenu() {
+
             var characterAttrs = AttributeUtils.getExplicitAttributes(node, { family: 'character', direct: true });
+            var effectiveUrl = isRangeSelected ? null : characterAttrs.url;
 
-            if (characterAttrs.url && !isRangeSelected) {
-                self.addGroup('character/hyperlink/valid', new Button({ label: Labels.OPEN_HYPERLINK_LABEL, href: characterAttrs.url }));
-
-                docView.getApp().enableTooltipOnShow(self, characterAttrs.url);
+            if (effectiveUrl) {
+                self.addGroup('character/hyperlink/valid', new Button(docView, { label: Labels.OPEN_HYPERLINK_LABEL, href: characterAttrs.url }));
+                self.setToolTip(effectiveUrl);
             }
 
             self.refreshImmediately();
@@ -283,16 +290,22 @@ define('io.ox/office/textframework/view/popup/universalcontextmenu', [
          * Build compound control group and fill it with groups for normal text.
          */
         function buildNormalTextMenu() {
-            var compoundNormalTextBtn = new CompoundButton(docView, { autoCloseParent: false, autoHideGroups: true, label: Labels.INSERT_HEADER_LABEL, anchorBorder: 'right left', icon: 'fa-chevron-right', iconPos: 'trailing', caret: false });
-            compoundNormalTextBtn.addGroup('image/insert/dialog', new Button(Labels.INSERT_IMAGE_OPTIONS))
-                                .addGroup('textframe/insert', new Button(Labels.INSERT_TEXTFRAME_OPTIONS))
-                                .addGroup('comment/insert', new Button(Labels.INSERT_COMMENT_OPTIONS))
-                                .addGroup('character/hyperlink/dialog', new Button(Labels.INSERT_HYPERLINK_OPTIONS));
+
+            var normalTextBtn = new CompoundButton(docView, { autoCloseParent: false, autoHideGroups: true, label: Labels.INSERT_HEADER_LABEL, anchorBorder: 'right left', icon: 'fa-chevron-right', iconPos: 'trailing', caret: false });
+
+            normalTextBtn
+                .addGroup('image/insert/dialog',        new Button(docView, Labels.INSERT_IMAGE_OPTIONS))
+                .addGroup('textframe/insert',           new Controls.InsertTextFrameButton(docView, { icon: null }))
+                .addGroup('comment/insert',             new Button(docView, Labels.INSERT_COMMENT_OPTIONS))
+                .addGroup('character/hyperlink/dialog', new Button(docView, Labels.INSERT_HYPERLINK_OPTIONS));
+
             if (docModel.useSlideMode()) {
-                compoundNormalTextBtn.addGroup('insertSlideNumber', new Button(Labels.INSERT_SLIDE_NUMBER_OPTIONS))
-                                    .addGroup('insertDateTime', new Button(Labels.INSERT_DATE_TIME_OPTIONS));
+                normalTextBtn
+                    .addGroup('insertSlideNumber', new Button(docView, Labels.INSERT_SLIDE_NUMBER_OPTIONS))
+                    .addGroup('insertDateTime',    new Button(docView, Labels.INSERT_DATE_TIME_OPTIONS));
             }
-            self.addGroup(null, compoundNormalTextBtn);
+
+            self.addGroup(null, normalTextBtn);
         }
 
         /**
@@ -300,17 +313,17 @@ define('io.ox/office/textframework/view/popup/universalcontextmenu', [
          */
         function addLanguageGroupToMenu() {
             self.addSeparator()
-                .addGroup('character/language', new LanguagePicker({ autoCloseParent: false, autoHideGroups: true, updateCaptionMode: 'none', label: gt('Language'), icon: 'fa-chevron-right', iconPos: 'trailing', caret: false, showListIcons: false, anchorBorder: 'right left', showAllLanguages: false }));
+                .addGroup('character/language', new LanguagePicker(docView, { autoCloseParent: false, autoHideGroups: true, updateCaptionMode: 'none', label: gt('Language'), icon: 'fa-chevron-right', iconPos: 'trailing', caret: false, showListIcons: false, anchorBorder: 'right left', showAllLanguages: false }));
         }
 
         /**
          * Prepares the context menu for drawings
          */
         function prepareDrawingMenu() {
-            self.addGroup('drawing/delete', new Button({ label: Labels.DELETE_DRAWING_LABEL, tooltip: Labels.DELETE_DRAWING_TOOLTIP }))
+            self.addGroup('drawing/delete', new Button(docView, { label: Labels.DELETE_DRAWING_LABEL, tooltip: Labels.DELETE_DRAWING_TOOLTIP }))
                 .addSeparator()
-                .addGroup('drawing/group', new Button({ label: Labels.GROUP_DRAWING_LABEL, tooltip: Labels.GROUP_DRAWING_TOOLTIP }))
-                .addGroup('drawing/ungroup', new Button({ label: Labels.UNGROUP_DRAWING_LABEL, tooltip: Labels.UNGROUP_DRAWING_TOOLTIP }))
+                .addGroup('drawing/group', new Button(docView, { label: Labels.GROUP_DRAWING_LABEL, tooltip: Labels.GROUP_DRAWING_TOOLTIP }))
+                .addGroup('drawing/ungroup', new Button(docView, { label: Labels.UNGROUP_DRAWING_LABEL, tooltip: Labels.UNGROUP_DRAWING_TOOLTIP }))
                 .addSeparator()
                 .addGroup('drawing/order', new Controls.DrawingOrderPicker(docView, { caret: false, icon: 'fa-chevron-right', iconPos: 'trailing', anchorBorder: 'right left' }));
         }
@@ -319,17 +332,17 @@ define('io.ox/office/textframework/view/popup/universalcontextmenu', [
          * Prepares the context menu for tables
          */
         function prepareTableMenu() {
-            self.addGroup('table/insert/row', new Button({ label: gt('Insert row') }))
-                .addGroup('table/delete/row', new Button({ label: gt('Delete row') }))
-                .addGroup('table/insert/column', new Button({ label: gt('Insert column') }))
-                .addGroup('table/delete/column', new Button({ label: gt('Delete column') }))
-                .addGroup('table/delete', new Button({ label: gt('Delete table') }))
+            self.addGroup('table/insert/row',    new Button(docView, { label: gt('Insert row') }))
+                .addGroup('table/delete/row',    new Button(docView, { label: gt('Delete row') }))
+                .addGroup('table/insert/column', new Button(docView, { label: gt('Insert column') }))
+                .addGroup('table/delete/column', new Button(docView, { label: gt('Delete column') }))
+                .addGroup('table/delete',        new Button(docView, { label: gt('Delete table') }))
                 .addSeparator()
                 .addGroup(null, new CompoundButton(docView, { autoCloseParent: false, autoHideGroups: true, label: Labels.INSERT_HEADER_LABEL, anchorBorder: 'right left', icon: 'fa-chevron-right', iconPos: 'trailing', caret: false })
-                    .addGroup('image/insert/dialog', new Button(Labels.INSERT_IMAGE_OPTIONS))
-                    .addGroup('textframe/insert', new Button(Labels.INSERT_TEXTFRAME_OPTIONS))
-                    .addGroup('comment/insert', new Button(Labels.INSERT_COMMENT_OPTIONS))
-                    .addGroup('character/hyperlink/dialog', new Button(Labels.INSERT_HYPERLINK_OPTIONS))
+                    .addGroup('image/insert/dialog',        new Button(docView, Labels.INSERT_IMAGE_OPTIONS))
+                    .addGroup('textframe/insert',           new Controls.InsertTextFrameButton(docView, { icon: null }))
+                    .addGroup('comment/insert',             new Button(docView, Labels.INSERT_COMMENT_OPTIONS))
+                    .addGroup('character/hyperlink/dialog', new Button(docView, Labels.INSERT_HYPERLINK_OPTIONS))
                 );
         }
 
@@ -345,7 +358,7 @@ define('io.ox/office/textframework/view/popup/universalcontextmenu', [
 
             selection           = docModel.getSelection();
             isDrawingSelected   = docModel.isDrawingSelected();
-            isRangeSelected     = (isDrawingSelected) ? false : !selection.isTextCursor();
+            isRangeSelected     = !isDrawingSelected && selection.hasRange();
 
             if (!sourceTarget && !isDrawingSelected) { return; }
 
