@@ -13,8 +13,10 @@
  */
 
 define('io.ox/office/textframework/view/selectionbox', [
-    'io.ox/office/tk/utils'
-], function (Utils) {
+    'io.ox/office/tk/utils',
+    'io.ox/office/tk/render/rectangle',
+    'io.ox/office/drawinglayer/utils/drawingutils'
+], function (Utils, Rectangle, DrawingUtils) {
 
     'use strict';
 
@@ -49,6 +51,10 @@ define('io.ox/office/textframework/view/selectionbox', [
             selectionBoxAppended = false,
             // whether the click happened on the vertical scrollbar
             isScrollBarEvent = false,
+            // a marker for those operations that are triggered from the selection box
+            // -> this marker can be used recognize operation not from selection box, so
+            //    that the box can be cancelled.
+            isSelectionBoxOperation = false,
             // the selection box element
             selectionBoxNode = $('<div>').addClass('selectionbox'),
             // the container for all registered modes
@@ -67,39 +73,47 @@ define('io.ox/office/textframework/view/selectionbox', [
          */
         function generateSelectionBoxHandler() {
 
-            var // the current position change
-                shiftX = 0, shiftY = 0,
-                // the start position of mouse down event
+            var // the start position of mouse down event
                 startX = 0, startY = 0,
                 // the current position of mouse down event
                 currentX = 0, currentY = 0,
                 // the root node, containing the scrollbar
                 scrollNode = node,
+                // position of the last processed mouse/touch event
+                eventPos = null,
                 // the position of the content root node
-                pos = null;
+                pos = null,
+                // whether the mouse or touch point has really been moved (with threshold distance)
+                mouseMoved = false;
 
             // initialing the selection box according to the passed event
-            function startSelectionBox(event, isTouch) {
+            function startSelectionBox(event, eventType) {
 
                 var // the options for the active mode
                     modeOptions = allModes[activeMode],
                     // the optional filter for the event target
                     selectionFilter = Utils.getStringOption(modeOptions, 'selectionFilter', ''),
+                    // the optional exclude filter for the event target
+                    excludeFilter =  Utils.getStringOption(modeOptions, 'excludeFilter', ''),
                     // a callback function that is triggered when the selection box is created
                     // -> if this function returns 'false', the selection box will be cancelled.
                     startHandler = Utils.getFunctionOption(modeOptions, 'startHandler'),
                     // the context of the callback functions
                     context = Utils.getOption(modeOptions, 'context'),
-                    // the horizontal and vertical event positions
-                    eventPosition = isTouch ? getTouchEventPosition(event) : { x: event.pageX, y: event.pageY },
                     // whether the selection box can continue after executing the start handler
                     continueSelectionBox = true;
 
-                if (!eventPosition && isTouch) {
+                // the horizontal and vertical event position
+                eventPos = self.getEventPosition(event, eventType, eventPos);
+                if (!eventPos || (excludeFilter && $(event.target).is(excludeFilter))) {
+                    selectionBoxActive = true;  // setting to true temporarily
                     self.cancelSelectionBox();
+                    app.getController().update(); // update controller if buttons are highlighted when mode is active
                     return;
                 }
 
+                mouseMoved = false;
+
                 if (!selectionFilter || $(event.target).is(selectionFilter)) {
 
                     // check, if this is an event on the vertical or horizontal scroll bar
@@ -121,15 +135,15 @@ define('io.ox/office/textframework/view/selectionbox', [
                     selectionBoxNode.addClass(activeMode);  // customizing the selection box
 
                     // setting the specified class at the app content root node
-                    if (allModes[activeMode] && allModes[activeMode].contentRootClassActive) { $(node).addClass(allModes[activeMode].contentRootClassActive); }
+                    if (modeOptions && modeOptions.contentRootClassActive) { $(node).addClass(modeOptions.contentRootClassActive); }
 
                     pos = scrollNode.offset();
-                    startX = eventPosition.x + scrollNode.scrollLeft() - pos.left;
-                    startY = eventPosition.y + scrollNode.scrollTop() - pos.top;
+                    startX = eventPos.x + scrollNode.scrollLeft() - pos.left;
+                    startY = eventPos.y + scrollNode.scrollTop() - pos.top;
 
                     selectionBoxNode.css({ left: startX, top: startY });
 
-                    if (startHandler) { continueSelectionBox = startHandler.call(context, { left: startX, top: startY, width: 0, height: 0 }); }
+                    if (startHandler) { continueSelectionBox = startHandler.call(context, new Rectangle(startX, startY, 0, 0)); }
 
                     if (continueSelectionBox === false) {
                         self.cancelSelectionBox();
@@ -139,35 +153,23 @@ define('io.ox/office/textframework/view/selectionbox', [
                     addCaptureEventListeners();
                 }
 
-                // fix for Bug 48616
-                Utils.clearBrowserSelection();
             }
 
             // updating the selection box according to the passed event
-            function updateMove(event, isTouch) {
+            function updateMove(event, eventType) {
 
-                var // the left position of the selection box (must be positive)
-                    left = startX,
-                    // the top position of the selection box (must be positive)
-                    top = startY,
-                    // the options for the active mode
+                var // the options for the active mode
                     modeOptions = allModes[activeMode],
                     // a callback function that is triggered when the selection box is moved
                     moveHandler = Utils.getFunctionOption(modeOptions, 'moveHandler'),
                     // the context of the callback functions
-                    context = Utils.getOption(modeOptions, 'context'),
-                    // the horizontal and vertical event positions
-                    eventPosition = isTouch ? getTouchEventPosition(event) : { x: event.pageX, y: event.pageY },
-                    // temporary width and height variables
-                    tempWidth, tempHeight,
-                    // temporary left and top position variables
-                    tempLeft, tempTop,
-                    // keyboard key used for placing shape center in start position
-                    eventKeyForCenterPos = _.browser.MacOS ? event.altKey : event.ctrlKey;
+                    context = Utils.getOption(modeOptions, 'context');
 
                 if (!selectionBoxActive) { return; }
 
-                if (!eventPosition && isTouch) {
+                // the horizontal and vertical event position
+                eventPos = self.getEventPosition(event, eventType, eventPos);
+                if (!eventPos) {
                     self.cancelSelectionBox();
                     return;
                 }
@@ -179,113 +181,42 @@ define('io.ox/office/textframework/view/selectionbox', [
                 }
 
                 // avoiding scroll problems on touch devices
-                if (isTouch && allModes[activeMode].preventScrolling) { event.preventDefault(); }
+                if ((eventType === 'touch') && modeOptions.preventScrolling) { event.preventDefault(); }
 
                 // reading scrollPosition again. Maybe it was not updated or not updated completely.
+                currentX = eventPos.x + scrollNode.scrollLeft() - pos.left;
+                currentY = eventPos.y + scrollNode.scrollTop() - pos.top;
 
-                currentX = eventPosition.x + scrollNode.scrollLeft() - pos.left;
-                currentY = eventPosition.y + scrollNode.scrollTop() - pos.top;
+                // the current location of the selected frame rectangle
+                var rectOptions = _.extend({}, modeOptions.trackingOptions);
+                if (activeMode === 'shape') { rectOptions.modifierEvent = event; }
+                var rectangle = DrawingUtils.getTrackingRectangle(startX, startY, currentX, currentY, rectOptions);
 
-                shiftX = currentX - startX;
-                shiftY = currentY - startY;
+                // start tracking after a threshold of 3 pixels
+                mouseMoved = mouseMoved || (rectangle.origShift >= 3);
+                if (!mouseMoved) { rectangle.set(startX, startY, 0, 0); }
 
-                if (shiftX < 0) {
-                    left += shiftX;
-                    shiftX = -shiftX;
-                }
+                selectionBoxNode.css(rectangle.toCSS());
+                if (moveHandler) { moveHandler.call(context, rectangle); }
 
-                if (shiftY < 0) {
-                    top += shiftY;
-                    shiftY = -shiftY;
-                }
-
-                tempWidth = shiftX;
-                tempHeight = shiftY;
-                if (activeMode === 'shape' && event.shiftKey) {
-                    if (tempWidth > tempHeight) {
-                        tempHeight = tempWidth;
-                    } else {
-                        tempWidth = tempHeight;
-                    }
-                }
-                tempLeft = left;
-                tempTop = top;
-                if (activeMode === 'shape' && eventKeyForCenterPos) {
-                    tempLeft = startX - tempWidth / 2;
-                    tempTop = startY - tempHeight / 2;
-                }
-
-                selectionBoxNode.css({ left: tempLeft, top: tempTop, width: tempWidth, height: tempHeight });
-
-                if (moveHandler) { moveHandler.call(context, { left: tempLeft, top: tempTop, width: tempWidth, height: tempHeight }); }
+                return rectangle;
             }
 
             // handling the selection box size, when moving is stopped according to the passed event
-            function stopSelectionBox(event, isTouch) {
+            function stopSelectionBox(event, eventType) {
 
-                var // the left position of the selection box (must be positive)
-                    left = startX,
-                    // the top position of the selection box (must be positive)
-                    top = startY,
-                    // the options for the active mode
+                var // the options for the active mode
                     modeOptions = allModes[activeMode],
                     // a callback function that is triggered when the selection box is stopped
                     stopHandler = Utils.getFunctionOption(modeOptions, 'stopHandler'),
                     // the context of the callback functions
-                    context = Utils.getOption(modeOptions, 'context'),
-                    // the horizontal and vertical event positions
-                    eventPosition = isTouch ? getTouchEventPosition(event) : { x: event.pageX, y: event.pageY },
-                    // temporary width and height variables
-                    tempWidth, tempHeight,
-                    // temporary left and top position variables
-                    tempLeft, tempTop,
-                    // keyboard key used for placing shape center in start position
-                    eventKeyForCenterPos = _.browser.MacOS ? event.altKey : event.ctrlKey;
+                    context = Utils.getOption(modeOptions, 'context');
 
                 if (!selectionBoxActive) { return; }
-
                 if (isScrollBarEvent) { return; } // this happens after a click on the vertical or horizontal scroll bar
 
-                if (!eventPosition && isTouch) {
-                    self.cancelSelectionBox();
-                    return;
-                }
-
-                currentX = eventPosition.x + scrollNode.scrollLeft() - pos.left;
-                currentY = eventPosition.y + scrollNode.scrollTop() - pos.top;
-
-                shiftX = currentX - startX;
-                shiftY = currentY - startY;
-
-                if (shiftX < 0) {
-                    left += shiftX;
-                    shiftX = -shiftX;
-                }
-
-                if (shiftY < 0) {
-                    top += shiftY;
-                    shiftY = -shiftY;
-                }
-
-                tempWidth = shiftX;
-                tempHeight = shiftY;
-                if (activeMode === 'shape' && event.shiftKey) {
-                    if (tempWidth > tempHeight) {
-                        tempHeight = tempWidth;
-                    } else {
-                        tempWidth = tempHeight;
-                    }
-                }
-                tempLeft = left;
-                tempTop = top;
-                if (activeMode === 'shape' && eventKeyForCenterPos) {
-                    tempLeft = startX - tempWidth / 2;
-                    tempTop = startY - tempHeight / 2;
-                }
-
-                selectionBoxNode.css({ left: tempLeft, top: tempTop, width: tempWidth, height: tempHeight });
-
-                if (stopHandler) { stopHandler.call(context, { left: tempLeft, top: tempTop, width: tempWidth, height: tempHeight }); }
+                var rectangle = updateMove(event, eventType);
+                if (rectangle && stopHandler) { stopHandler.call(context, rectangle); }
             }
 
             // return the actual selection box handler function
@@ -294,19 +225,23 @@ define('io.ox/office/textframework/view/selectionbox', [
                 switch (event.type) {
                     case 'mousedown':
                     case 'touchstart':
-                        if (event.button !== 2) { // no selection box on right click
-                            startSelectionBox(event, (event.type === 'touchstart'));
-                        } else if ($(event.target).is(app.getModel().getMultiSelectionBoxFilterSelector())) { // setting slide selection on right click when target is outside of slide
+                        if (activeMode && event.button !== 2) { // no selection box on right click
+                            startSelectionBox(event, (event.type === 'touchstart') ? 'touch' : 'mouse');
+                        } else if (app.getModel().useSlideMode() && $(event.target).is(app.getModel().getMultiSelectionBoxFilterSelector())) { // setting slide selection on right click when target is outside of slide
                             app.getModel().getSelection().setSlideSelection();
                         }
                         break;
                     case 'mousemove':
                     case 'touchmove':
-                        updateMove(event, (event.type === 'touchmove'));
+                        updateMove(event, (event.type === 'touchmove') ? 'touch' : 'mouse');
+                        break;
+                    case 'keydown':
+                    case 'keyup':
+                        updateMove(event, 'key');
                         break;
                     case 'mouseup':
                     case 'touchend':
-                        stopSelectionBox(event, (event.type === 'touchend'));
+                        stopSelectionBox(event, (event.type === 'touchend') ? 'touch' : 'mouse');
                         finalizeSelectionBox();
                         break;
                     case 'touchcancel':
@@ -339,7 +274,7 @@ define('io.ox/office/textframework/view/selectionbox', [
             selectionBoxNode.removeClass(activeMode);
 
             // removing the optional specified class from the app content root node
-            if (allModes[activeMode] && allModes[activeMode].contentRootClassActive) { $(node).removeClass(allModes[activeMode].contentRootClassActive); }
+            if (modeOptions && modeOptions.contentRootClassActive) { $(node).removeClass(modeOptions.contentRootClassActive); }
             if (finalizeHandler) { finalizeHandler.call(context); }
 
             selectionBoxActive = false;
@@ -362,35 +297,18 @@ define('io.ox/office/textframework/view/selectionbox', [
         function handleAppContentRootClass(oldMode, newMode) {
 
             // removing the class from the app content root node immediately
-            if (oldMode && allModes[oldMode] && allModes[oldMode].contentRootClass) {
-                $(node).removeClass(allModes[oldMode].contentRootClass);
+            var oldOptions = oldMode ? allModes[oldMode] : null;
+            if (oldOptions && oldOptions.contentRootClass) {
+                $(node).removeClass(oldOptions.contentRootClass);
             }
 
             // setting the class to the app content root node class immediately
-            if (allModes[newMode] && allModes[newMode].contentRootClass) {
-                $(node).addClass(allModes[newMode].contentRootClass);
+            var newOptions = allModes[newMode];
+            if (newOptions && newOptions.contentRootClass) {
+                $(node).addClass(newOptions.contentRootClass);
             }
         }
 
-        /**
-         * Receiving the event positions of touch events.
-         *
-         * @param {jQuery.Event} event
-         *  The key down event.
-         *
-         * @returns {Object}
-         *  An object containing the properties 'x' and 'y' for the horizontal and
-         *  vertical event positions in pixel. Or null, if this is no valid event
-         *  for the selection box.
-         */
-        function getTouchEventPosition(event) {
-
-            var touches = event.originalEvent.touches,
-                changed = event.originalEvent.changedTouches;
-
-            return ((touches.length === ((event.type === 'touchend') ? 0 : 1)) && (changed.length === 1)) ? { x: changed[0].pageX, y: changed[0].pageY } : null;
-        }
-
         /**
          * Add eventListener to window, to capture the events (mousemove, mouseup,...) which are outside of the slide or browser
          */
@@ -441,28 +359,29 @@ define('io.ox/office/textframework/view/selectionbox', [
          *      prevent scrolling while moving
          *  @param {Function} [options.startHandler]
          *      A callback function that is called when the selection box is created.
-         *      The callback function gets as parameter an object with the properties
-         *      'left', 'top', 'width' and 'height' describing the rectangle of the
-         *      selection box. The rectangle is calculated relative to the upper left
-         *      corner of the application content root node.
+         *      The callback function receives the rectangle of the selection box (as
+         *      instance of the class Rectangle). The rectangle is calculated relative
+         *      to the upper left corner of the application content root node.
          *      If the startHandler function returns 'false', the selection box will
          *      not be created.
          *  @param {Function} [options.moveHandler]
-         *      A callback function that is call when the selection box is moved.
-         *      The callback function gets as parameter an object with the properties
-         *      'left', 'top', 'width' and 'height' describing the rectangle of the
-         *      selection box. The rectangle is calculated relative to the upper left
-         *      corner of the application content root node.
+         *      A callback function that is called when the selection box is moved.
+         *      The callback function receives the rectangle of the selection box (as
+         *      instance of the class Rectangle). The rectangle is calculated relative
+         *      to the upper left corner of the application content root node.
          *  @param {Function} [options.stopHandler]
-         *      A callback function that is call when the selection box is stopped.
-         *      The callback function gets as parameter an object with the properties
-         *      'left', 'top', 'width' and 'height' describing the rectangle of the
-         *      selection box. The rectangle is calculated relative to the upper left
-         *      corner of the application content root node.
-         *      after stopHandler, the finalizeHandler is called
+         *      A callback function that is called when the selection box is stopped.
+         *      The callback function receives the rectangle of the selection box (as
+         *      instance of the class Rectangle). The rectangle is calculated relative
+         *      to the upper left corner of the application content root node. After
+         *      the stopHandler, the finalizeHandler will be called.
          *  @param {Function} [options.finalizeHandler]
-         *      A callback function that is call when the selection box is stopped
+         *      A callback function that is called when the selection box is stopped
          *      or canceled. can be used for cleanup code.
+         *  @param {Function} [options.clearGuidelinesHandler]
+         *      A callback function that is called when the selection box is canceled.
+         *      It is used to clean up guidelines, which is neccessary when
+         *      selectionBox is not active anymore.
          *  @param {Object} [options.context]
          *      The context the callback function will be bound to.
          */
@@ -504,6 +423,8 @@ define('io.ox/office/textframework/view/selectionbox', [
 
                 // switching the class at the app content root node immediately
                 handleAppContentRootClass(previousMode, activeMode);
+                // ... and removing the old class from the selection box
+                if (previousMode) { selectionBoxNode.removeClass(previousMode); }
             }
 
             return activeMode;
@@ -535,6 +456,8 @@ define('io.ox/office/textframework/view/selectionbox', [
 
             // switching the class at the app content root node immediately
             handleAppContentRootClass(previousMode, activeMode);
+            // ... and removing the old class from the selection box
+            if (previousMode) { selectionBoxNode.removeClass(previousMode); }
 
             return activeMode;
         };
@@ -593,14 +516,17 @@ define('io.ox/office/textframework/view/selectionbox', [
          *
          */
         this.isCancelModeActive = function () {
-            return allModes[activeMode].leaveModeOnCancel || false;
+            return (allModes[activeMode] && allModes[activeMode].leaveModeOnCancel) || false;
         };
 
         /**
          * Cancel the currently active mode and close selection box.
          */
         this.cancelSelectionBox = function () {
-
+            // remove shape guidelines
+            if (allModes[activeMode] && allModes[activeMode].clearGuidelinesHandler) {
+                allModes[activeMode].clearGuidelinesHandler.call();
+            }
             // closing an open selection box
             if (self.isSelectionBoxActive()) { finalizeSelectionBox(); }
 
@@ -611,7 +537,56 @@ define('io.ox/office/textframework/view/selectionbox', [
                 // update controller if buttons are highlighted when mode is active
                 app.getController().update();
             }
+        };
 
+        /**
+         * Requesting the marker that can be used to identify operations generated from
+         * the selection box. The can be used to cancel an active selection box, if the
+         * current operation was not triggered by the selection box.
+         *
+         * @returns {Boolean}
+         *  Whether the marker for operations generated from the selection box is set.
+         */
+        this.isSelectionBoxOperation = function () {
+            return isSelectionBoxOperation;
+        };
+
+        /**
+         * Setting the marker that can be used to identify operations generated from
+         * the selection box. The can be used to cancel an active selection box, if the
+         * current operation was not triggered by the selection box.
+         *
+         * param {Boolean} value
+         *  Setting the marker for operations generated from the selection box.
+         */
+        this.setSelectionBoxOperation = function (value) {
+            isSelectionBoxOperation = value;
+        };
+
+        /**
+         * Returns horizontal and vertical cursor position from event.
+         *
+         * @param {jQuery.Event} event
+         *  A jQuery event object.
+         * @param {String} eventType
+         *  Type of the event.
+         * @param {Object} [eventPos]
+         *  Optional parameter for already calculated position.
+         *
+         * @return {Object|null}
+         */
+        this.getEventPosition = function (event, eventType, eventPos) {
+            switch (eventType) {
+                case 'mouse':
+                    return { x: event.pageX, y: event.pageY };
+                case 'touch':
+                    var touches = event.originalEvent.touches;
+                    var changed = event.originalEvent.changedTouches;
+                    return ((touches.length === ((event.type === 'touchend') ? 0 : 1)) && (changed.length === 1)) ? { x: changed[0].pageX, y: changed[0].pageY } : null;
+                case 'key':
+                    return eventPos;
+            }
+            return null;
         };
 
         // initialization -----------------------------------------------------
@@ -629,7 +604,7 @@ define('io.ox/office/textframework/view/selectionbox', [
     SelectionBox.SELECTION_BOX_EVENTS = 'mousedown touchstart'; //'mousedown touchstart mouseup touchend mousemove touchmove touchcancel';
 
     // events to capture if the selection box is active, it's need to catch the events wich are outside of the slide or browser
-    SelectionBox.CAPTURE_EVENTS = ['mouseup', 'touchend', 'mousemove', 'touchmove', 'touchcancel'];
+    SelectionBox.CAPTURE_EVENTS = ['mouseup', 'touchend', 'mousemove', 'touchmove', 'touchcancel', 'keydown', 'keyup'];
 
     // exports ================================================================
 
