@@ -18,9 +18,6 @@ define('io.ox/office/tk/config', [
 
     'use strict';
 
-    // the configuration items of the OX Documents modules
-    var documentsConfig = settings.get('module', {});
-
     // static class Config ====================================================
 
     /**
@@ -34,49 +31,29 @@ define('io.ox/office/tk/config', [
      * Returns the value of a specific configuration property, or the complete
      * set of all available configuration properties.
      *
-     * @param {String} [key]
-     *  If specified, the key of a specific configuration property. If omitted,
-     *  this method will return the entire configuration as a map.
+     * @param {String} key
+     *  The key of a specific configuration property.
      *
      * @param {Any} [def]
-     *  A default value, if the configuration property specified with the 'key'
-     *  parameter is not set.
+     *  A default value that will be returned if the configuration property
+     *  specified with the parameter 'key'does not exist.
      *
      * @returns {Any}
-     *  The value of a specific configuration property, or the complete set of
-     *  configuration properties of the OX Documents module, according to the
-     *  'key' parameter.
+     *  The value of the specified configuration property.
      */
     Config.get = function (key, def) {
-        return _.isString(key) ? ((key in documentsConfig) ? documentsConfig[key] : def) : documentsConfig;
+        return settings.get(key, def);
     };
 
     /**
-     * Sets a value of a specific configuration property.
-     *
-     * @param {String} [key]
-     *  The key of a specific configuration property. If the key is missing in
-     *  the configuration, it will be added.
-     *
-     * @param {Any} [value]
-     *  A value to be set in association with the provided key.
-     */
-    Config.set = function (key, value) {
-        if (_.isString(key)) {
-            documentsConfig[key] = value;
-            settings.set('module', documentsConfig).save();
-        }
-    };
-
-    /**
-     * Returns the state of a specific Boolean configuration property.
+     * Returns the state of a specific boolean configuration property.
      *
      * @param {String} key
-     *  The key of a specific Boolean configuration property.
+     *  The key of a specific boolean configuration property.
      *
      * @param {Boolean} [def=false]
      *  The default state, if the configuration property specified with the
-     *  'key' parameter is not set.
+     *  parameter 'key' does not exist.
      *
      * @returns {Boolean}
      *  The state of the specified configuration property. If the property does
@@ -86,6 +63,62 @@ define('io.ox/office/tk/config', [
         return Config.get(key, def === true) === true;
     };
 
+    /**
+     * Returns the state of a specific integer configuration property.
+     *
+     * @param {String} key
+     *  The key of a specific integer configuration property.
+     *
+     * @param {Number} [def=0]
+     *  The default value, if the configuration property specified with the
+     *  parameter 'key' does not exist.
+     *
+     * @param {Number} [min]
+     *  The lower bound for the value. If omitted, all integer values will be
+     *  allowed.
+     *
+     * @returns {Number}
+     *  The state of the specified configuration property. If the property does
+     *  not exist, this method will return the default value.
+     */
+    Config.getInt = function (key, def, min) {
+        var int = Config.get(key, def);
+        if (typeof int !== 'number') { int = 0; }
+        if (typeof min === 'number') { int = Math.max(int, min); }
+        return Math.floor(int);
+    };
+
+    /**
+     * Sets a value of a specific configuration property. Be careful
+     * to only set single properties.
+     *
+     * @param {String} key
+     *  The key of a specific configuration property.
+     *
+     * @param {Any} value
+     *  The value to be set for the specified configuration key.
+     *
+     *  if value is an [Array] you can't delete single entries in that array,
+     *  better call set(key, null) and then save the correct array again
+     *
+     * @returns {jQuery.Promise}
+     *  A promise that will be resolved when the server request has been sent
+     *  successfully.
+     */
+    Config.set = function (key, value) {
+
+        // create a object tree with the value as property
+        var updateTree = key.split('/').reduceRight(function (val, dir) {
+            var obj = {};
+            obj[dir] = val;
+            return obj;
+        }, value);
+
+        // Call merge with update tree to prevent that the whole
+        // tree is sent to the backend
+        return settings.set(key, value).merge(updateTree);
+    };
+
     /**
      * Returns the state of the specified Boolean flag in the anchor part of
      * the browser URL.
@@ -132,7 +165,7 @@ define('io.ox/office/tk/config', [
      * property 'debugondemand' is set to true, and the passed URL hash option
      * is set to true.
      *
-     * @param {String} configFlag
+     * @param {String} configKey
      *  The name of the server-side configuration item.
      *
      * @param {String} urlFlag
@@ -141,8 +174,8 @@ define('io.ox/office/tk/config', [
      * @returns {Boolean}
      *  Whether the specified debug mode is enabled.
      */
-    Config.getDebugState = function (configFlag, urlFlag) {
-        return Config.getFlag(configFlag) ? Config.getUrlFlag(urlFlag, true) : (Config.getFlag('debugondemand') && Config.getUrlFlag(urlFlag));
+    Config.getDebugState = function (configKey, urlFlag) {
+        return Config.getFlag(configKey) ? Config.getUrlFlag(urlFlag, true) : (Config.getFlag('module/debugondemand') && Config.getUrlFlag(urlFlag));
     };
 
     // constants --------------------------------------------------------------
@@ -188,7 +221,7 @@ define('io.ox/office/tk/config', [
      *
      * @type {Boolean}
      */
-    Config.DEBUG = Config.getDebugState('debugavailable', 'office:enable-debug');
+    Config.DEBUG = Config.getDebugState('module/debugavailable', 'office:enable-debug');
 
     /**
      * Specifies whether the current platform is an automated test environment
