@@ -215,6 +215,9 @@ define('io.ox/office/tk/container/sortedarray', [
      */
     SortedArray.prototype.find = function (index, mode) {
 
+        // nothing to do in empty arrays
+        if (this.empty()) { return null; }
+
         // whether to find a preceding array element
         var reverse = mode === 'prev';
 
@@ -224,6 +227,9 @@ define('io.ox/office/tk/container/sortedarray', [
             function (value) { return sorter(value) <= index; } :
             function (value) { return index <= sorter(value); };
 
+        // fast O(1) limit check before binary search
+        if (reverse ? !pred(this.first()) : !pred(this.last())) { return null; }
+
         // find the next or preceding array element with a binary search
         var findFunc = reverse ? Utils.findLastIndex : Utils.findFirstIndex;
         var ai = findFunc(this._array, pred, { sorted: true });
