@@ -41,10 +41,10 @@ define('io.ox/office/tk/control/captionmixin', [
      */
     function CaptionMixin(controlNode, initOptions) {
 
-        var // smallerVersion options
-            smallerVersion = Utils.getOption(initOptions, 'smallerVersion'),
-            // saves the (old) styles in case of switching to small version
-            saveStyles = {};
+        // smallerVersion options
+        var smallerVersion = Utils.getOption(initOptions, 'smallerVersion');
+        // saves the (old) styles in case of switching to small version
+        var savedStyles = {};
 
         // methods ------------------------------------------------------------
 
@@ -157,7 +157,7 @@ define('io.ox/office/tk/control/captionmixin', [
          *  A reference to this instance.
          */
         this.setToolTip = function (text) {
-            Forms.setToolTip(controlNode, { tooltip: text });
+            Forms.setToolTip(controlNode, text);
             return this;
         };
 
@@ -168,7 +168,7 @@ define('io.ox/office/tk/control/captionmixin', [
          *  A reference to this instance.
          */
         this.removeToolTip = function () {
-            Forms.setToolTip(controlNode, null);
+            Forms.setToolTip(controlNode, '');
             return this;
         };
 
@@ -177,45 +177,38 @@ define('io.ox/office/tk/control/captionmixin', [
          * activate/deactivate the small version of the button
          */
         this.activateSmallVersion = function () {
-            // if smallerVersion isn't empty
             if (!_.isEmpty(smallerVersion)) {
                 // change label
-                if (_.has(smallerVersion, 'label')) {
-                    saveStyles.label = saveStyles.label || this.getLabel();
+                if ('label' in smallerVersion) {
+                    savedStyles.label = savedStyles.label || this.getLabel();
                     this.setLabel(smallerVersion.label);
                 }
 
                 // icon
-                if (_.has(smallerVersion, 'icon')) {
+                if ('icon' in smallerVersion) {
                     this.setIcon(smallerVersion.icon);
                 }
 
                 // hide label
-                if (_.has(smallerVersion, 'hideLabel') && smallerVersion.hideLabel === true) {
-                    saveStyles.label = saveStyles.label || this.getLabel();
+                if (smallerVersion.hideLabel === true) {
+                    savedStyles.label = savedStyles.label || this.getLabel();
                     this.removeLabel();
                 }
             }
         };
         this.deactivateSmallVersion = function () {
             // if smallerVersion isn't empty and there are saved styles
-            if (!_.isEmpty(smallerVersion) && !_.isEmpty(saveStyles)) {
+            if (!_.isEmpty(smallerVersion) && !_.isEmpty(savedStyles)) {
                 // reset label
-                if (_.has(saveStyles, 'label')) {
-                    this.setLabel(saveStyles.label);
-                    delete saveStyles.label;
+                if ('label' in savedStyles) {
+                    this.setLabel(savedStyles.label);
+                    delete savedStyles.label;
                 }
 
                 // remove icon
-                if (_.has(smallerVersion, 'icon')) {
+                if ('icon' in smallerVersion) {
                     this.removeIcon();
                 }
-
-                // show old label
-                if (_.has(saveStyles, 'hideLabel') && smallerVersion.hideLabel === true) {
-                    this.setLabel(saveStyles.label);
-                    delete saveStyles.label;
-                }
             }
         };
 
