@@ -34,6 +34,12 @@ define('io.ox/office/tk/control/combofield', [
      * @extends TextField
      * @extends MenuMixin
      *
+     * @param {String|Object} windowId
+     *  The identifier of the root window of the context application owning the
+     *  combo field object, or an object with a method 'getWindowId' that
+     *  returns such a window identifier. Used for debugging and logging of
+     *  running timers in automated test environments.
+     *
      * @param {Object} [initOptions]
      *  Optional parameters. Supports all options of the TextField base class
      *  constructor, and the ListMenu class constructor used for the drop-down
@@ -43,24 +49,24 @@ define('io.ox/office/tk/control/combofield', [
      *      the text currently edited will be inserted into the text field.
      *      The remaining text appended to the current text will be selected.
      */
-    function ComboField(initOptions) {
+    function ComboField(windowId, initOptions) {
 
-        var // self reference
-            self = this,
+        // self reference
+        var self = this;
 
-            // search the list items and insert label into text field while editing
-            typeAhead = Utils.getBooleanOption(initOptions, 'typeAhead', false),
+        // search the list items and insert label into text field while editing
+        var typeAhead = Utils.getBooleanOption(initOptions, 'typeAhead', false);
 
-            // the drop-down button that will be added to the group
-            menuButton = $(Forms.createButtonMarkup({ focusable: false })),
+        // the drop-down button that will be added to the group
+        var menuButton = $(Forms.createButtonMarkup({ focusable: false }));
 
-            // the drop-down menu instance (must be created after TextField base constructor!)
-            menu = null;
+        // the drop-down menu instance (must be created after TextField base constructor!)
+        var menu = null;
 
         // base constructors --------------------------------------------------
 
-        TextField.call(this, Utils.extendOptions(initOptions, { attributes: { role: 'combobox', 'aria-autocomplete': 'inline' } }));
-        menu = new ListMenu(Utils.extendOptions({ expandWidth: true }, initOptions, { anchor: this.getNode(), itemDesign: 'list' }));
+        TextField.call(this, windowId, Utils.extendOptions(initOptions, { attributes: { role: 'combobox', 'aria-autocomplete': 'inline' } }));
+        menu = new ListMenu(windowId, Utils.extendOptions({ expandWidth: true }, initOptions, { anchor: this.getNode(), itemDesign: 'list' }));
         MenuMixin.call(this, menu, { button: menuButton, ariaOwner: this.getInputNode() });
 
         // private methods ----------------------------------------------------
@@ -74,7 +80,7 @@ define('io.ox/office/tk/control/combofield', [
                 // deferred to not confuse focus listeners due to mixed focus events triggered from mouse click and focus() call
                 self.executeDelayed(function () {
                     Utils.setFocus(self.getInputNode());
-                }, { infoString: 'TK: ComboField: returnFocusToTextField' });
+                }, 'ComboField.returnFocusToTextField');
             }
         }
 
@@ -88,10 +94,11 @@ define('io.ox/office/tk/control/combofield', [
         }
 
         /**
-         * Handles 'popup:show' events, moves the focus to the text field and disables the tooltip.
+         * Handles 'popup:show' events, moves the focus to the text field and
+         * disables the tooltip.
          */
         function popupShowHandler() {
-            Forms.disableToolTip(self.getNode());
+            Forms.enableToolTip(self.getNode(), false);
             returnFocusToTextField();
             scrollToListItem(menu.getSelectedItemNodes().first());
         }
@@ -100,7 +107,7 @@ define('io.ox/office/tk/control/combofield', [
          * Handles 'popup:hide' events and enables the tooltip.
          */
         function popupHideHandler() {
-            Forms.enableToolTip(self.getNode());
+            Forms.enableToolTip(self.getNode(), true);
         }
 
         /**
