@@ -16,18 +16,17 @@ define('io.ox/office/tk/control/group', [
     'io.ox/office/tk/utils',
     'io.ox/office/tk/keycodes',
     'io.ox/office/tk/forms',
-    'io.ox/office/tk/object/triggerobject',
-    'io.ox/office/tk/object/timermixin'
-], function (Utils, KeyCodes, Forms, TriggerObject, TimerMixin) {
+    'io.ox/office/tk/object/triggerobject'
+], function (Utils, KeyCodes, Forms, TriggerObject) {
 
     'use strict';
 
-    var // all existing groups and their focusable DOM nodes (stored globally  to be able
-        // to use a single 'change:focus' listener instead of one listener per group instance)
-        focusableNodesMap = {},
+    // all existing groups and their focusable DOM nodes (stored globally  to be able
+    // to use a single 'change:focus' listener instead of one listener per group instance)
+    var focusableNodesMap = {};
 
-        // the unique IDs of the group instances currently focused (as stack, groups may be embedded)
-        focusStack = [];
+    // the unique IDs of the group instances currently focused (as stack, groups may be embedded)
+    var focusStack = [];
 
     // global focus handling ==================================================
 
@@ -125,7 +124,12 @@ define('io.ox/office/tk/control/group', [
      * @constructor
      *
      * @extends TriggerObject
-     * @extends TimerMixin
+     *
+     * @param {String|Object} windowId
+     *  The identifier of the root window of the context application owning the
+     *  control object, or an object with a method 'getWindowId' that returns
+     *  such a window identifier. Used for debugging and logging of running
+     *  timers in automated test environments.
      *
      * @param {Object} [initOptions]
      *  Optional parameters:
@@ -136,30 +140,29 @@ define('io.ox/office/tk/control/group', [
      *      An ARIA role attribute that will be set at the root DOM node of
      *      this instance.
      */
-    function Group(initOptions) {
+    function Group(windowId, initOptions) {
 
-        var // self reference
-            self = this,
+        // self reference
+        var self = this;
 
-            // create the group container element
-            groupNode = $('<div>').addClass('group'),
+        // create the group container element
+        var groupNode = $('<div class="group">');
 
-            // the last cached size of the root node, used to detect layout changes
-            nodeSize = null,
+        // the last cached size of the root node, used to detect layout changes
+        var nodeSize = null;
 
-            // the current value of this control group (must be undefined initially, NOT null)
-            groupValue,
+        // the current value of this control group (must be undefined initially, NOT null)
+        var groupValue;
 
-            // update handler functions
-            updateHandlers = [],
+        // update handler functions
+        var updateHandlers = [];
 
-            // special options for a drop-down version of this group
-            dropDownVersion = Utils.getOption(initOptions, 'dropDownVersion');
+        // special options for a drop-down version of this group
+        var dropDownVersion = Utils.getOption(initOptions, 'dropDownVersion');
 
-        // base constructors --------------------------------------------------
+        // base constructor ---------------------------------------------------
 
-        TriggerObject.call(this);
-        TimerMixin.call(this);
+        TriggerObject.call(this, windowId);
 
         // private methods ----------------------------------------------------
 
@@ -188,8 +191,8 @@ define('io.ox/office/tk/control/group', [
          */
         function updateValue(newValue) {
 
-            var // the old value of this group (for event handlers)
-                oldValue = groupValue;
+            // the old value of this group (for event handlers)
+            var oldValue = groupValue;
 
             // set new value, invoke the update handlers which refresh the appearance of the group
             groupValue = newValue;
@@ -226,14 +229,14 @@ define('io.ox/office/tk/control/group', [
          */
         function getEventOptions(options) {
 
-            var // resulting properties for the event object
-                eventOptions = {
-                    sourceNode: groupNode[0],
-                    sourceType: 'custom',
-                    preserveFocus: false
-                },
-                // the source event object
-                sourceEvent = Utils.getOption(options, 'sourceEvent');
+            // resulting properties for the event object
+            var eventOptions = {
+                sourceNode: groupNode[0],
+                sourceType: 'custom',
+                preserveFocus: false
+            };
+            // the source event object
+            var sourceEvent = Utils.getOption(options, 'sourceEvent');
 
             // special handling for specific events
             if (_.isObject(sourceEvent)) {
@@ -249,7 +252,7 @@ define('io.ox/office/tk/control/group', [
                         eventOptions.sourceType = ('keyCode' in sourceEvent) ? 'keyboard' : 'click';
                         // click events from keyboard: keep focus on button after SPACE or TAB key (see Forms.setButtonKeyHandler() method)
                         eventOptions.preserveFocus = (sourceEvent.keyCode === KeyCodes.SPACE) || (sourceEvent.keyCode === KeyCodes.TAB);
-
+                        // pass type of the source event
                         eventOptions.sourceEventType = sourceEvent.type;
                         break;
                     case 'keydown':
@@ -317,8 +320,18 @@ define('io.ox/office/tk/control/group', [
 
         // methods ------------------------------------------------------------
 
-        this.clone = function (additionalOptions) {
-            return new this.constructor(Utils.extendOptions(initOptions, additionalOptions));
+        /**
+         * Returns a deep clone of this control instance.
+         *
+         * @param {Object} [options]
+         *  Additional options used to override the initial options passed to
+         *  the constructor of this instance.
+         *
+         * @returns {Group}
+         *  A deep clone of this control instance.
+         */
+        this.clone = function (options) {
+            return new this.constructor(windowId, Utils.extendOptions(initOptions, options));
         };
 
         /**
@@ -450,8 +463,8 @@ define('io.ox/office/tk/control/group', [
          */
         this.toggle = function (state) {
 
-            var // whether to show the group instance
-                visible = (state === true) || ((state !== false) && this.isVisible());
+            // whether to show the group instance
+            var visible = (state === true) || ((state !== false) && !this.isVisible());
 
             if (this.isVisible() !== visible) {
                 this.trigger(visible ? 'group:beforeshow' : 'group:beforehide');
@@ -481,8 +494,8 @@ define('io.ox/office/tk/control/group', [
          */
         this.enable = function (state) {
 
-            var // whether to enable the group instance
-                enabled = _.isUndefined(state) || (state === true);
+            // whether to enable the group instance
+            var enabled = (arguments.length === 0) || (state === true);
 
             // enable/disable the entire group node with all its descendants
             if (this.isEnabled() !== enabled) {
@@ -527,9 +540,9 @@ define('io.ox/office/tk/control/group', [
          * @returns {Group}
          *  A reference to this group.
          */
-        this.refresh = this.createDebouncedMethod(Utils.NOOP, function () {
+        this.refresh = this.createDebouncedMethod('Group.refresh', null, function () {
             updateValue(groupValue);
-        }, { infoString: 'Group refresh()' });
+        });
 
         /**
          * Triggers a 'group:change' event at this control group instance, and
