@@ -36,6 +36,12 @@ define('io.ox/office/tk/control/label', [
      * @extends CaptionMixin
      * @extends WidthMixin
      *
+     * @param {String|Object} windowId
+     *  The identifier of the root window of the context application owning the
+     *  label object, or an object with a method 'getWindowId' that returns
+     *  such a window identifier. Used for debugging and logging of running
+     *  timers in automated test environments.
+     *
      * @param {Object} [initOptions]
      *  Optional parameters. Supports all options of the Group base class
      *  constructor, all label formatting options supported by the method
@@ -45,23 +51,23 @@ define('io.ox/office/tk/control/label', [
      *      If specified, the label will known, how it should act, if there
      *      will be not enough free place to show normal view
      */
-    function Label(initOptions) {
+    function Label(windowId, initOptions) {
 
-        var // self reference
-            self = this,
+        // self reference
+        var self = this;
 
-            // the <label> element
-            labelNode = $(Forms.createLabelMarkup(initOptions)),
+        // the <label> element
+        var labelNode = $(Forms.createLabelMarkup(initOptions));
 
-            // smaller version of label (to fit in smaller resolutions)
-            smallerVersion = Utils.getOption(initOptions, 'smallerVersion', false),
+        // smaller version of label (to fit in smaller resolutions)
+        var smallerVersion = Utils.getOption(initOptions, 'smallerVersion', false);
 
-            // saves the (old) styles in case of switching to small version
-            savedStyle = null;
+        // saves the (old) styles in case of switching to small version
+        var savedStyle = null;
 
         // base constructor ---------------------------------------------------
 
-        Group.call(this, initOptions);
+        Group.call(this, windowId, initOptions);
         CaptionMixin.call(this, labelNode);
         WidthMixin.call(this, labelNode, initOptions);
 
