@@ -31,6 +31,12 @@ define('io.ox/office/tk/control/radiogroup', [
      *
      * @extends ButtonGroup
      *
+     * @param {String|Object} windowId
+     *  The identifier of the root window of the context application owning the
+     *  radio group object, or an object with a method 'getWindowId' that
+     *  returns such a window identifier. Used for debugging and logging of
+     *  running timers in automated test environments.
+     *
      * @param {Object} [initOptions]
      *  Optional parameters. Supports all options of the base class
      *  ButtonGroup. Additionally, the following options are supported:
@@ -47,26 +53,26 @@ define('io.ox/office/tk/control/radiogroup', [
      *      selected option buttons). By default, the selected state will be
      *      visualized by a background fill effect.
      */
-    function RadioGroup(initOptions) {
+    function RadioGroup(windowId, initOptions) {
 
-        var // self reference
-            self = this,
+        // self reference
+        var self = this;
 
-            // comparator for list item values
-            matcher = Utils.getFunctionOption(initOptions, 'matcher'),
+        // comparator for list item values
+        var matcher = Utils.getFunctionOption(initOptions, 'matcher');
 
-            // fall-back value for toggle click
-            toggleValue = Utils.getOption(initOptions, 'toggleValue'),
+        // fall-back value for toggle click
+        var toggleValue = Utils.getOption(initOptions, 'toggleValue');
 
-            // show radio icons instead of selection style
-            design = Utils.getBooleanOption(initOptions, 'radioIcons', false) ? 'radio' : 'select',
+        // show radio icons instead of selection style
+        var design = Utils.getBooleanOption(initOptions, 'radioIcons', false) ? 'radio' : 'select';
 
-            // whether the radiobutton-value should change it's value or not
-            active = true;
+        // whether the radiobutton-value should change it's value or not
+        var active = true;
 
         // base constructor ---------------------------------------------------
 
-        ButtonGroup.call(this, Utils.extendOptions({ role: 'radiogroup' }, initOptions));
+        ButtonGroup.call(this, windowId, Utils.extendOptions({ role: 'radiogroup' }, initOptions));
 
         // private methods ----------------------------------------------------
 
@@ -80,11 +86,11 @@ define('io.ox/office/tk/control/radiogroup', [
          */
         function updateHandler(value) {
 
-            var // all existing option buttons
-                optionButtons = self.getOptionButtons();
+            // all existing option buttons
+            var optionButtons = self.getOptionButtons();
 
             // set all buttons to ambiguous state for null value
-            if (_.isNull(value)) {
+            if (value === null) {
                 Forms.checkButtonNodes(optionButtons, null, { design: design, ambiguous: true });
             } else {
                 Forms.checkMatchingButtonNodes(optionButtons, value, { matcher: matcher, design: design });
@@ -114,10 +120,10 @@ define('io.ox/office/tk/control/radiogroup', [
             // change the value of the radiobutton
             if (!active) { active = true; return; }
 
-            var // check whether a click on a selected button toggles state back
-                toggleClick = Forms.isCheckedButtonNode(this) && !_.isNull(toggleValue) && !_.isUndefined(toggleValue),
-                // the new control value
-                value = toggleClick ? toggleValue : Forms.getButtonValue(this);
+            // check whether a click on a selected button toggles state back
+            var toggleClick = Forms.isCheckedButtonNode(this) && (toggleValue !== null) && !_.isUndefined(toggleValue);
+            // the new control value
+            var value = toggleClick ? toggleValue : Forms.getButtonValue(this);
 
             self.triggerChange(value, { sourceEvent: event });
         });
