@@ -36,6 +36,12 @@ define('io.ox/office/tk/control/radiolist', [
      * @extends WidthMixin
      * @extends MenuMixin
      *
+     * @param {String|Object} windowId
+     *  The identifier of the root window of the context application owning the
+     *  radio list object, or an object with a method 'getWindowId' that
+     *  returns such a window identifier. Used for debugging and logging of
+     *  running timers in automated test environments.
+     *
      * @param {Object} [initOptions]
      *  Optional parameters. Supports all options of the Group base class, of
      *  the MenuMixin mix-in class, the ListMenu class used for the drop-down
@@ -94,56 +100,56 @@ define('io.ox/office/tk/control/radiolist', [
      *      If specified, the radio list will know how it should act, if there
      *      is not enough free place to show normal view.
      */
-    function RadioList(initOptions) {
+    function RadioList(windowId, initOptions) {
 
-        var // self reference
-            self = this,
+        // self reference
+        var self = this;
 
-            // whether to highlight the drop-down menu button
-            highlight = Utils.getBooleanOption(initOptions, 'highlight', false),
+        // whether to highlight the drop-down menu button
+        var highlight = Utils.getBooleanOption(initOptions, 'highlight', false);
 
-            // custom predicate callback for drop-down menu button highlighting
-            highlightHandler = Utils.getFunctionOption(initOptions, 'highlight'),
+        // custom predicate callback for drop-down menu button highlighting
+        var highlightHandler = Utils.getFunctionOption(initOptions, 'highlight');
 
-            // fall-back value for toggle click
-            toggleValue = Utils.getOption(initOptions, 'toggleValue'),
+        // fall-back value for toggle click
+        var toggleValue = Utils.getOption(initOptions, 'toggleValue');
 
-            // value of the split button
-            splitValue = Utils.getOption(initOptions, 'splitValue'),
+        // value of the split button
+        var splitValue = Utils.getOption(initOptions, 'splitValue');
 
-            // which parts of a list item caption will be copied to the menu button
-            updateCaptionMode = Utils.getStringOption(initOptions, 'updateCaptionMode', 'all'),
+        // which parts of a list item caption will be copied to the menu button
+        var updateCaptionMode = Utils.getStringOption(initOptions, 'updateCaptionMode', 'all');
 
-            // separate split button in split mode
-            splitButton = (!_.isUndefined(splitValue) && !_.isNull(splitValue)) ? $(Forms.createButtonMarkup(initOptions)) : $(),
+        // separate split button in split mode
+        var splitButton = (!_.isUndefined(splitValue) && !_.isNull(splitValue)) ? $(Forms.createButtonMarkup(initOptions)) : $();
 
-            // the options for the drop-down button
-            menuButtonOptions = ((splitButton.length === 0) ? initOptions : { tooltip: Utils.getOption(initOptions, 'tooltip', '') }),
+        // the options for the drop-down button
+        var menuButtonOptions = ((splitButton.length === 0) ? initOptions : { tooltip: Utils.getOption(initOptions, 'tooltip', '') });
 
-            // the drop-down button
-            menuButton = $(Forms.createButtonMarkup(menuButtonOptions)),
+        // the drop-down button
+        var menuButton = $(Forms.createButtonMarkup(menuButtonOptions));
 
-            // the target node for the caption (icon and label text)
-            captionButton = (splitButton.length > 0) ? splitButton : menuButton,
+        // the target node for the caption (icon and label text)
+        var captionButton = (splitButton.length > 0) ? splitButton : menuButton;
 
-            // the drop-down menu instance (must be created after Group base constructor!)
-            menu = null,
+        // the drop-down menu instance (must be created after Group base constructor!)
+        var menu = null;
 
-            // smaller version of the radio list (to fit in smaller resolutions)
-            smallerVersion = Utils.getOption(initOptions, 'smallerVersion', false),
+        // smaller version of the radio list (to fit in smaller resolutions)
+        var smallerVersion = Utils.getOption(initOptions, 'smallerVersion', false);
 
-            // saves the (old) styles in case of switching to small version
-            savedStyles = {},
+        // saves the (old) styles in case of switching to small version
+        var savedStyles = {};
 
-            // special options for a drop-down-version of this radio list
-            dropDownVersion = Utils.getObjectOption(initOptions, 'dropDownVersion');
+        // special options for a drop-down-version of this radio list
+        var dropDownVersion = Utils.getObjectOption(initOptions, 'dropDownVersion');
 
         // base constructors --------------------------------------------------
 
-        Group.call(this, initOptions);
+        Group.call(this, windowId, initOptions);
         CaptionMixin.call(this, captionButton);
         WidthMixin.call(this, captionButton, initOptions);
-        menu = new ListMenu(Utils.extendOptions({ expandWidth: true }, initOptions, { anchor: this.getNode() }));
+        menu = new ListMenu(windowId, Utils.extendOptions({ expandWidth: true }, initOptions, { anchor: this.getNode() }));
         MenuMixin.call(this, menu, Utils.extendOptions(initOptions, { button: menuButton }));
 
         // private methods ----------------------------------------------------
@@ -235,14 +241,6 @@ define('io.ox/office/tk/control/radiolist', [
             scrollToListItem(menu.getSelectedItemNodes().first());
         }
 
-        /**
-         * Clean up data stored in button nodes, before the entire menu node
-         * will be cleared.
-         */
-        function popupBeforeClearHandler() {
-            menu.getItemNodes().data('options', null).off();
-        }
-
         /**
          * Activates or deactivates a smaller version of the radio list.
          *
@@ -368,7 +366,7 @@ define('io.ox/office/tk/control/radiolist', [
          *  A reference to this instance.
          */
         this.createOptionButton = function (value, options) {
-            menu.createItemNode(value, options).data('options', options);
+            menu.createItemNode(value, options);
             return this;
         };
 
@@ -445,13 +443,10 @@ define('io.ox/office/tk/control/radiolist', [
         // register event handlers
         this.listenTo(menu, 'popup:beforeshow', popupBeforeShowHandler);
         this.listenTo(menu, 'popup:show', popupShowHandler);
-        this.listenTo(menu, 'popup:beforeclear', popupBeforeClearHandler);
         this.listenTo(menu, 'create:item', function () { self.refresh(); });
 
         // destroy all class members on destruction
         this.registerDestructor(function () {
-            popupBeforeClearHandler(); // clean up data stored in button nodes
-
             initOptions = self = menuButton = splitButton = menuButtonOptions = highlightHandler = menu = null;
         });
 
