@@ -18,15 +18,300 @@ define('io.ox/office/tk/control/textfield', [
     'io.ox/office/tk/forms',
     'io.ox/office/tk/locale/localedata',
     'io.ox/office/tk/locale/parser',
-    'io.ox/office/tk/object/baseobject',
+    'io.ox/office/tk/locale/formatter',
     'io.ox/office/tk/control/group',
     'io.ox/office/tk/control/widthmixin'
-], function (Utils, KeyCodes, Forms, LocaleData, Parser, BaseObject, Group, WidthMixin) {
+], function (Utils, KeyCodes, Forms, LocaleData, Parser, Formatter, Group, WidthMixin) {
 
     'use strict';
 
-    var // default validator without any restrictions on the field text
-        defaultValidator = null;
+    // private global functions ===============================================
+
+    /**
+     * Returns a regular expression that matches numeric input strings, as used
+     * by the NumberValidator class.
+     *
+     * @param {Boolean} neg
+     *  Whether the regular expression will accept a leading minus sign.
+     *
+     * @param {Boolean} int
+     *  Whether the regular expression will accept integers only.
+     *
+     * @returns {RegExp}
+     *  A regular expression that matches numeric input strings.
+     */
+    var getNumberRE = (function () {
+
+        // RE pattern for fractional part
+        var FRAC_PATTERN = '(' + _.escapeRegExp(LocaleData.DEC) + '[0-9]*)?';
+        // regular expression for non-negative integers (including empty string)
+        var POS_INT_RE = /^[0-9]*$/;
+        // regular expression for integers (including empty string)
+        var NEG_INT_RE = /^-?[0-9]*$/;
+        // regular expression for non-negative floating-point numbers (including empty string)
+        var POS_NUM_RE = new RegExp('^[0-9]*' + FRAC_PATTERN + '$');
+        // regular expression for floating-point numbers (including empty string)
+        var NEG_NUM_RE = new RegExp('^-?[0-9]*' + FRAC_PATTERN + '$');
+
+        return function (neg, int) {
+            return int ? (neg ? NEG_INT_RE : POS_INT_RE) : (neg ? NEG_NUM_RE : POS_NUM_RE);
+        };
+    }());
+
+    // class Validator ========================================================
+
+    /**
+     * Base class for text field validators used to convert between values and
+     * field texts, and to validate the text field while editing. Provides a
+     * default implementation of all methods that do not restrict editing.
+     *
+     * @constructor
+     */
+    var Validator = _.makeExtendable(function () {});
+
+    // public methods ---------------------------------------------------------
+
+    /**
+     * Converts the passed value to a text string to be inserted into a text
+     * field. Intended to be overwritten by derived classes. This default
+     * implementation returns the passed value, if it is a string, otherwise an
+     * empty string.
+     *
+     * @param {Any} value
+     *  The value to be converted to a text.
+     *
+     * @returns {String}
+     *  The text converted from the passed value, or an empty string, if the
+     *  passed value cannot be converted to text.
+     */
+    Validator.prototype.valueToText = function (value) {
+        return (typeof value === 'string') ? value : '';
+    };
+
+    /**
+     * Converts the passed text to a value that will be passed to all event
+     * listeners of a text field. Intended to be overwritten by derived
+     * classes. This default implementation returns the unmodified text.
+     *
+     * @param {String} text
+     *  The text to be converted to a value.
+     *
+     * @returns {Any}
+     *  The value converted from the passed text. The value null indicates that
+     *  the text cannot be converted to a valid value.
+     */
+    Validator.prototype.textToValue = function (text) {
+        return text;
+    };
+
+    /**
+     * Validates the passed text that has been changed while editing a text
+     * field. It is possible to return a new string value that will be inserted
+     * into the text field, or a boolean value indicating whether to restore
+     * the old state of the text field. Intended to be overwritten by derived
+     * classes. This default implementation does not change the text field.
+     *
+     * @param {String} text
+     *  The current contents of the text field to be validated.
+     *
+     * @returns {String|Boolean}
+     *  When returning a string, the text field will be updated to contain the
+     *  returned value while restoring its selection (browsers may destroy the
+     *  selection when changing the text). When returning the value false, the
+     *  previous state of the text field (as it was after the last validation)
+     *  will be restored. Otherwise, the value of the text field is considered
+     *  to be valid and will not be modified.
+     */
+    Validator.prototype.validate = _.noop;
+
+    // class TextValidator ====================================================
+
+    /**
+     * A validator for text fields that restricts the allowed values according
+     * to the passed options.
+     *
+     * @constructor
+     *
+     * @extends Validator
+     *
+     * @param {Object} [initOptions]
+     *  Optional parameters:
+     *  @param {Number} [initOptions.maxLength=0x7FFFFFFF]
+     *      The maximum number of characters to be inserted into the text
+     *      field. All attempts to insert more characters will be rejected.
+     */
+    var TextValidator = Validator.extend({ constructor: function (initOptions) {
+
+        // maximum length
+        this._maxLength = Utils.getIntegerOption(initOptions, 'maxLength', 0x7FFFFFFF, 0, 0x7FFFFFFF);
+
+        // base constructor
+        Validator.call(this);
+
+    } }); // class TextValidator
+
+    // public methods ---------------------------------------------------------
+
+    /**
+     * Converts the passed value to a text string that will be restricted to
+     * the size passed to the constructor of this instance.
+     *
+     * @param {Any} value
+     *  The value to be converted to a text.
+     *
+     * @returns {String}
+     *  The text converted from the passed value (shortened to the maximum
+     *  length), or an empty string, if the passed value cannot be converted to
+     *  text.
+     */
+    TextValidator.prototype.valueToText = function (value) {
+        return (typeof value === 'string') ? value.substr(0, this._maxLength) : '';
+    };
+
+    /**
+     * Returns whether the length of the passed text does not exceed the
+     * maximum text length of this instance.
+     *
+     * @param {String} text
+     *  The current contents of the text field to be validated.
+     *
+     * @returns {Boolean}
+     *  Whether the length of the passed text does not exceed the maximum text
+     *  length of this instance.
+     */
+    TextValidator.prototype.validate = function (text) {
+        return text.length <= this._maxLength;
+    };
+
+    // class NumberValidator ==================================================
+
+    /**
+     * A validator for text fields that restricts the allowed values to
+     * floating-point numbers.
+     *
+     * @constructor
+     *
+     * @extends Validator
+     *
+     * @param {Object} [initOptions]
+     *  Optional parameters:
+     *  @param {Number} [initOptions.min=-Number.MAX_VALUE]
+     *      The minimum value allowed to enter.
+     *  @param {Number} [initOptions.max=Number.MAX_VALUE]
+     *      The maximum value allowed to enter.
+     *  @param {Number} [initOptions.precision=1]
+     *      The precision used to round the current number. The number will be
+     *      rounded to multiples of this value. If omitted, the default
+     *      precision 1 will round to integers. Must be positive.
+     */
+    var NumberValidator = Validator.extend({ constructor: function (initOptions) {
+
+        // minimum, maximum, and precision
+        this._min = Utils.getNumberOption(initOptions, 'min', -Number.MAX_VALUE, -Number.MAX_VALUE, Number.MAX_VALUE);
+        this._max = Utils.getNumberOption(initOptions, 'max', Number.MAX_VALUE, this._min, Number.MAX_VALUE);
+        this._prec = Utils.getNumberOption(initOptions, 'precision', 1, 0);
+        this._regex = getNumberRE(this._min < 0, this._prec === Math.round(this._prec));
+
+        // base constructor
+        Validator.call(this);
+
+    } }); // NumberValidator
+
+    // public methods ---------------------------------------------------------
+
+    /**
+     * Converts the passed value to a text string to be inserted into a text
+     * field.
+     *
+     * @param {Any} value
+     *  The value to be converted to a text. If not a finite number, this
+     *  method returns an empty string.
+     *
+     * @returns {String}
+     *  The text converted from the passed number, or an empty string, if the
+     *  passed value is not a finite number.
+     */
+    NumberValidator.prototype.valueToText = function (value) {
+        return Utils.isFiniteNumber(value) ? Formatter.formatDecimal(Utils.round(value, this._prec)) : '';
+    };
+
+    /**
+     * Tries to convert the passed text to a number.
+     *
+     * @param {String} text
+     *  The text to be converted to a number.
+     *
+     * @returns {Number|Null}
+     *  The number converted from the passed text; or null to indicate that the
+     *  text cannot be converted to a number.
+     */
+    NumberValidator.prototype.textToValue = function (text) {
+        var number = Parser.parseDecimal(text);
+        return (isFinite(number) && (this._min <= number) && (number <= this._max)) ? Utils.round(number, this._prec) : null;
+    };
+
+    /**
+     * Returns whether the passed text can be converted to a number.
+     *
+     * @param {String} text
+     *  The current contents of the text field to be validated.
+     *
+     * @returns {Boolean}
+     *  Whether the passed text is empty, or can be converted to a number.
+     */
+    NumberValidator.prototype.validate = function (text) {
+        return this._regex.test(text);
+    };
+
+    /**
+     * Returns the lower limit of this validator.
+     *
+     * @returns {Number}
+     *  The lower limit of this validator.
+     */
+    NumberValidator.prototype.getMin = function () {
+        return this._min;
+    };
+
+    /**
+     * Returns the upper limit of this validator.
+     *
+     * @returns {Number}
+     *  The upper limit of this validator.
+     */
+    NumberValidator.prototype.getMax = function () {
+        return this._max;
+    };
+
+    /**
+     * Returns the precision of this validator used to round numbers.
+     *
+     * @returns {Number}
+     *  The precision of this validator used to round numbers.
+     */
+    NumberValidator.prototype.getPrecision = function () {
+        return this._prec;
+    };
+
+    /**
+     * Returns the passed number bound to the lower and upper limit.
+     *
+     * @param {Any} value
+     *  The value to be converted. If not a finite number, it will be returned
+     *  as passed.
+     *
+     * @returns {Any}
+     *  The passed number bound to the lower and upper limit. Values of other
+     *  types will be returned as passed.
+     */
+    NumberValidator.prototype.restrictValue = function (value) {
+        return Utils.isFiniteNumber(value) ? Utils.minMax(value, this._min, this._max) : value;
+    };
+
+    // global singletons ======================================================
+
+    // global instance of the default validator
+    var defaultValidator = new Validator();
 
     // class TextField ========================================================
 
@@ -38,6 +323,12 @@ define('io.ox/office/tk/control/textfield', [
      * @extends Group
      * @extends WidthMixin
      *
+     * @param {String|Object} windowId
+     *  The identifier of the root window of the context application owning the
+     *  text field object, or an object with a method 'getWindowId' that
+     *  returns such a window identifier. Used for debugging and logging of
+     *  running timers in automated test environments.
+     *
      * @param {Object} [initOptions]
      *  Optional parameters. Supports all options of the Group base class
      *  constructor, all formatting options for input elements supported by the
@@ -48,7 +339,7 @@ define('io.ox/office/tk/control/textfield', [
      *      field has been clicked, or if the method TextField.grabFocus() has
      *      been called. The text will always be selected (independently from
      *      this option), if the text field gets focus via keyboard navigation.
-     *  @param {TextField.Validator} [initOptions.validator]
+     *  @param {Validator} [initOptions.validator]
      *      A text validator that will be used to convert the values from the
      *      control values (passed to the Group.setValue() method) to the text
      *      representation used in this text field, to validate the text while
@@ -62,60 +353,44 @@ define('io.ox/office/tk/control/textfield', [
      *  @param {Boolean} [initOptions.showClearButton=false]
      *      If set to true, a clear button is visible to clear the text in the
      */
-    function TextField(initOptions) {
+    function TextField(windowId, initOptions) {
 
-        var // self reference
-            self = this,
+        // self reference
+        var self = this;
 
-            // the <input> element
-            inputNode = $(Forms.createInputMarkup(initOptions)),
+        // the <input> element
+        var inputNode = $(Forms.createInputMarkup(initOptions));
 
-            // create the wrapper node for the input field (IE renders input fields with padding wrong)
-            wrapperNode = $('<div>').addClass('input-wrapper').append(inputNode),
+        // create the wrapper node for the input field (IE renders input fields with padding wrong)
+        var wrapperNode = $('<div class="input-wrapper">').append(inputNode);
 
-            // whether to select the entire text on click
-            select = Utils.getBooleanOption(initOptions, 'select', false),
+        // whether to select the entire text on click
+        var select = Utils.getBooleanOption(initOptions, 'select', false);
 
-            // the validator used to convert and validate values
-            validator = Utils.getObjectOption(initOptions, 'validator', defaultValidator),
+        // the validator used to convert and validate values
+        var validator = Utils.getObjectOption(initOptions, 'validator', defaultValidator);
 
-            // saved state of the text field, used to restore while validating
-            inputState = null,
+        // saved state of the text field, used to restore while validating
+        var inputState = null;
 
-            // initial value of text field when focused, needed for ESCAPE key handling
-            initialText = null,
+        // initial value of text field when focused, needed for ESCAPE key handling
+        var initialText = null;
 
-            // whether the group is focused (needed to detect whether to restore selection after focus change inside the group)
-            groupFocused = false,
+        // whether the group is focused (needed to detect whether to restore selection after focus change inside the group)
+        var groupFocused = false;
 
-            // saves the (old) styles in case of switching to small version
-            savedStyles = {},
+        // saves the (old) styles in case of switching to small version
+        var savedStyles = {};
 
-            // smaller version of group (to fit in smaller resolutions)
-            smallerVersion = Utils.getOption(initOptions, 'smallerVersion', false),
+        // smaller version of group (to fit in smaller resolutions)
+        var smallerVersion = Utils.getOption(initOptions, 'smallerVersion', false);
 
-            // wheter the clear button is visible in the text box
-            showClearButton = Utils.getBooleanOption(initOptions, 'showClearButton', false),
-
-            // the clear button to clear the textbox
-            clearButton;
-
-        if (showClearButton) {
-            clearButton = $('<i>').addClass('fa fa-times-circle clear-button');
-            inputNode.css('padding-right', '12px');
-            clearButton.hide();
-            wrapperNode.append(clearButton);
-
-            clearButton.on('click', function (event) {
-                clearButton.hide();
-                inputNode.val(initialText);
-                self.triggerChange('', { sourceEvent: event });
-            });
-        }
+        // the clear button to clear the textbox
+        var clearButtonNode = null;
 
         // base constructor ---------------------------------------------------
 
-        Group.call(this, initOptions);
+        Group.call(this, windowId, initOptions);
         WidthMixin.call(this, wrapperNode, initOptions);
 
         // private methods ----------------------------------------------------
@@ -136,11 +411,30 @@ define('io.ox/office/tk/control/textfield', [
             Forms.setInputSelection(inputNode, inputState.start, inputState.end);
         }
 
+        /**
+         * Selects the entire text of the input node.
+         */
+        function selectAll() {
+
+            // Bug 43829: Workaround to select the whole text when 'touching' in the input field on iOS,
+            // because select() doesn't work. It's an iOS problem.
+            // see http://stackoverflow.com/questions/3272089/programmatically-selecting-text-in-an-input-field-on-ios-devices-mobile-safari
+            if (Utils.IOS) {
+                self.executeDelayed(function () {
+                    inputNode[0].setSelectionRange(0, 9999);
+                }, 'TextField.selectAll', 1);
+                return;
+            }
+
+            // this is how selecting the whole text is supposed to work
+            inputNode.select();
+        }
+
         /**
          * The update handler for this text field.
          */
         function updateHandler(value) {
-            value = _.isNull(value) ? '' : validator.valueToText(value);
+            value = (value === null) ? '' : validator.valueToText(value);
             // do not access the input element if the value does not change (browsers will destroy current selection)
             if (inputNode.val() !== value && initialText !== value) {
                 inputNode.val(value);
@@ -219,28 +513,16 @@ define('io.ox/office/tk/control/textfield', [
                 // remove previous 'mouseup' handler (see below)
                 inputNode.off('mouseup');
 
-                // always select entire text when reaching the field with keyboard
-                if (_.isObject(keyEvent)) {
-                    inputNode.select();
-                } else if (select) {
-                    // select entire text on mouse click when specified via option
+                // always select entire text when reaching the field with keyboard, or when specified via option
+                if (keyEvent || select) {
+                    selectAll();
 
-                    // BugFix for 43829: Workaround to select the whole text
-                    // when 'touching' in the input field on iOS, because select() doesn't work.
-                    // It's an iOS problem.
-                    if (Utils.IOS) {
-                        // see http://stackoverflow.com/questions/3272089/programmatically-selecting-text-in-an-input-field-on-ios-devices-mobile-safari
-                        self.executeDelayed(function () {
-                            inputNode[0].setSelectionRange(0, 9999);
-                        }, { delay: 1, infoString: 'TextField: globalFocusHandler' });
-
-                    // this is how selecting the whole text is supposed to work
-                    } else {
-                        inputNode.select();
+                    // Bug 53025: Suppress next 'mouseup' event to prevent that the browser (especially MS Edge, see
+                    // https://developer.microsoft.com/en-us/microsoft-edge/platform/issues/8229660/) changes the selection
+                    // to a cursor. Simply preventing default browser action ('preventDefault') does not work though.
+                    if (!keyEvent) {
+                        inputNode.one('mouseup', selectAll);
                     }
-
-                    // suppress next 'mouseup' event to prevent that the browser changes the selection
-                    inputNode.one('mouseup', false);
                 }
 
                 // save current contents and selection
@@ -259,11 +541,7 @@ define('io.ox/office/tk/control/textfield', [
          * Handles enable/disable events of the group.
          */
         function enableHandler(event, state) {
-            if (state) {
-                inputNode.removeAttr('readonly');
-            } else {
-                inputNode.attr('readonly', 'readonly');
-            }
+            inputNode.attr('readonly', state ? null : 'readonly');
         }
 
         /**
@@ -308,26 +586,20 @@ define('io.ox/office/tk/control/textfield', [
          */
         function inputHandler() {
 
-            var // current text in the input element
-                currText = inputNode.val(),
-                // previous text contents of the input element
-                prevText = inputState.text,
-                // result of the text field validation
-                result = null;
+            // current text in the input element
+            var currText = inputNode.val();
+            // previous text contents of the input element
+            var prevText = inputState.text;
 
-            if (showClearButton) {
-                if (currText.length > 0) {
-                    clearButton.show();
-                } else {
-                    clearButton.hide();
-                }
+            if (clearButtonNode) {
+                clearButtonNode.toggle(currText.length > 0);
             }
 
             // do not perform validation if nothing has changed
             if (currText === prevText) { return; }
 
             // validate the current field text
-            result = validator.validate(currText);
+            var result = validator.validate(currText);
 
             // update the text field according to the validation result
             if (result === false) {
@@ -378,7 +650,7 @@ define('io.ox/office/tk/control/textfield', [
             }
         }
 
-        // methods ------------------------------------------------------------
+        // public methods -----------------------------------------------------
 
         /**
          * Returns the text control element, as jQuery object.
@@ -414,14 +686,6 @@ define('io.ox/office/tk/control/textfield', [
             return this;
         };
 
-        /**
-         * Is applying a new validator
-         */
-        this.setValidator = function (value) {
-            validator = value;
-            return this;
-        };
-
         /**
          * Converts the passed value to a text using the validator of this
          * control group.
@@ -466,6 +730,19 @@ define('io.ox/office/tk/control/textfield', [
 
         // initialization -----------------------------------------------------
 
+        if (Utils.getBooleanOption(initOptions, 'showClearButton', false)) {
+            clearButtonNode = $(Forms.createIconMarkup('fa-times-circle', { classes: 'clear-button' }));
+            inputNode.css('padding-right', '12px');
+            clearButtonNode.hide();
+            wrapperNode.append(clearButtonNode);
+
+            clearButtonNode.on('click', function (event) {
+                clearButtonNode.hide();
+                inputNode.val(initialText);
+                self.triggerChange('', { sourceEvent: event });
+            });
+        }
+
         Forms.setToolTip(this.getNode(), initOptions);
 
         // add special marker class used to adjust formatting
@@ -505,194 +782,18 @@ define('io.ox/office/tk/control/textfield', [
 
         // destroy all class members on destruction
         this.registerDestructor(function () {
-            initOptions = self = inputNode = wrapperNode = validator = null;
+            initOptions = self = inputNode = wrapperNode = validator = clearButtonNode = null;
         });
 
     } // class TextField
 
-    // class TextField.Validator ==============================================
-
-    /**
-     * Base class for text field validators used to convert between values and
-     * field texts, and to validate the text field while editing. Provides a
-     * default implementation of all methods that do not restrict editing.
-     *
-     * @constructor
-     *
-     * @extends BaseObject
-     */
-    TextField.Validator = BaseObject.extend({ constructor: function () {
-
-        // methods ------------------------------------------------------------
-
-        /**
-         * Converts the passed value to a text string to be inserted into a
-         * text field. Intended to be overwritten by derived classes. This
-         * default implementation returns the passed value, if it is a string,
-         * otherwise an empty string.
-         *
-         * @param {Any} value
-         *  The value to be converted to a text.
-         *
-         * @returns {String}
-         *  The text converted from the passed value, or an empty string, if
-         *  the passed value cannot be converted to text.
-         *
-         */
-        this.valueToText = function (value) {
-            return _.isString(value) ? value : '';
-        };
-
-        /**
-         * Converts the passed text to a value that will be passed to all event
-         * listeners of a text field. Intended to be overwritten by derived
-         * classes. This default implementation returns the unmodified text.
-         *
-         * @param {String} text
-         *  The text to be converted to a value.
-         *
-         * @returns {Any}
-         *  The value converted from the passed text. The value null indicates
-         *  that the text cannot be converted to a valid value.
-         */
-        this.textToValue = function (text) {
-            return text;
-        };
-
-        /**
-         * Validates the passed text that has been changed while editing a text
-         * field. It is possible to return a new string value that will be
-         * inserted into the text field, or a boolean value indicating whether
-         * to restore the old state of the text field. Intended to be
-         * overwritten by derived classes. This default implementation does not
-         * change the text field.
-         *
-         * @param {String} text
-         *  The current contents of the text field to be validated.
-         *
-         * @returns {String|Boolean}
-         *  When returning a string, the text field will be updated to contain
-         *  the returned value while restoring its selection (browsers may
-         *  destroy the selection when changing the text). When returning the
-         *  boolean value false, the previous state of the text field (as it
-         *  was after the last validation) will be restored. Otherwise, the
-         *  value of the text field is considered to be valid and will not be
-         *  modified.
-         */
-        this.validate = $.noop;
-
-    } }); // class TextField.Validator
-
-    // global instance of the default validator
-    defaultValidator = new TextField.Validator();
-
-    // class TextField.TextValidator ==========================================
-
-    /**
-     * A validator for text fields that restricts the allowed values according
-     * to the passed options.
-     *
-     * @constructor
-     *
-     * @extends TextField.Validator
-     *
-     * @param {Object} [initOptions]
-     *  Optional parameters:
-     *  @param {Number} [initOptions.maxLength=0x7FFFFFFF]
-     *      The maximum number of characters to be inserted into the text
-     *      field. All attempts to insert more characters will be rejected.
-     */
-    TextField.TextValidator = TextField.Validator.extend({ constructor: function (initOptions) {
-
-        var // maximum length
-            maxLength = Utils.getIntegerOption(initOptions, 'maxLength', 0x7FFFFFFF, 0, 0x7FFFFFFF);
-
-        // base constructor ---------------------------------------------------
-
-        TextField.Validator.call(this);
-
-        // methods ------------------------------------------------------------
-
-        this.valueToText = function (value) {
-            return _.isString(value) ? value.substr(0, maxLength) : '';
-        };
-
-        this.validate = function (text) {
-            return text.length <= maxLength;
-        };
-
-    } }); // class TextField.TextValidator
-
-    // class TextField.NumberValidator ========================================
-
-    /**
-     * A validator for text fields that restricts the allowed values to
-     * floating-point numbers.
-     *
-     * @constructor
-     *
-     * @extends TextField.Validator
-     *
-     * @param {Object} [initOptions]
-     *  Optional parameters:
-     *  @param {Number} [initOptions.min]
-     *      The minimum value allowed to enter. If omitted, defaults to
-     *      -Number.MAX_VALUE.
-     *  @param {Number} [initOptions.max]
-     *      The maximum value allowed to enter. If omitted, defaults to
-     *      Number.MAX_VALUE.
-     *  @param {Number} [initOptions.precision=1]
-     *      The precision used to round the current number. The number will be
-     *      rounded to multiples of this value. If omitted, the default
-     *      precision 1 will round to integers. Must be positive.
-     */
-    TextField.NumberValidator = TextField.Validator.extend({ constructor: function (initOptions) {
-
-        var // minimum, maximum, and precision
-            min = Utils.getNumberOption(initOptions, 'min', -Number.MAX_VALUE, -Number.MAX_VALUE, Number.MAX_VALUE),
-            max = Utils.getNumberOption(initOptions, 'max', Number.MAX_VALUE, min, Number.MAX_VALUE),
-            precision = Utils.getNumberOption(initOptions, 'precision', 1, 0),
-            regex = new RegExp('^' + ((min < 0) ? '-?' : '') + '[0-9]*' + ((precision !== Math.round(precision)) ? ('(' + _.escapeRegExp(LocaleData.DEC)  + '[0-9]*)?') : '') + '$');
-
-        // base constructor ---------------------------------------------------
-
-        TextField.Validator.call(this);
-
-        // methods ------------------------------------------------------------
-
-        this.valueToText = function (value) {
-            return _.isFinite(value) ? Parser.numberToString(Utils.round(value, precision)) : '';
-        };
-
-        this.textToValue = function (text) {
-            var value = Parser.stringToNumber(text);
-            return (_.isFinite(value) && (min <= value) && (value <= max)) ? Utils.round(value, precision) : null;
-        };
-
-        this.validate = function (text) {
-            return regex.test(text);
-        };
-
-        this.getMin = function () {
-            return min;
-        };
-
-        this.getMax = function () {
-            return max;
-        };
-
-        this.getPrecision = function () {
-            return precision;
-        };
-
-        this.restrictValue = function (value) {
-            return _.isFinite(value) ? Utils.minMax(value, min, max) : value;
-        };
-
-    } }); // class TextField.NumberValidator
-
     // exports ================================================================
 
+    // export validators as child classes
+    TextField.Validator = Validator;
+    TextField.TextValidator = TextValidator;
+    TextField.NumberValidator = NumberValidator;
+
     // derive this class from class Group
     return Group.extend({ constructor: TextField });
 
