@@ -17,10 +17,10 @@ define('io.ox/office/tk/dialogs', [
     'io.ox/office/tk/utils',
     'io.ox/office/tk/forms',
     'io.ox/office/tk/keycodes',
+    'io.ox/office/tk/utils/scheduler',
     'io.ox/office/tk/utils/driveutils',
-    'io.ox/office/tk/utils/deferredutils',
     'gettext!io.ox/office/tk/main'
-], function (CoreDialogs, Utils, Forms, KeyCodes, DriveUtils, DeferredUtils, gt) {
+], function (CoreDialogs, Utils, Forms, KeyCodes, Scheduler, DriveUtils, gt) {
 
     'use strict';
 
@@ -90,6 +90,12 @@ define('io.ox/office/tk/dialogs', [
      *
      * @extends CoreDialogs.ModalDialog
      *
+     * @param {String|Object} windowId
+     *  The identifier of the root window of the context application that is
+     *  creating the dialog, or an object with a method 'getWindowId' that
+     *  returns such a window identifier. Used for debugging and logging of
+     *  running timers in automated test environments.
+     *
      * @param {Object} [initOptions]
      *  Optional parameters that control the appearance and behavior of the
      *  dialog. The following options are supported:
@@ -123,7 +129,7 @@ define('io.ox/office/tk/dialogs', [
      *  @param {JQuery} [initOptions.container]
      *      The container node for the modal dialog, otherwise the container is $('#io-ox-core')
      */
-    Dialogs.ModalDialog = _.makeExtendable(CoreDialogs.ModalDialog).extend({ constructor: function (initOptions) {
+    Dialogs.ModalDialog = _.makeExtendable(CoreDialogs.ModalDialog).extend({ constructor: function (windowId, initOptions) {
 
         // self reference
         var self = this;
@@ -285,7 +291,7 @@ define('io.ox/office/tk/dialogs', [
             // - the promise returned by show() will not resolve/reject when triggering an action
             // - the generic 'action' event does not send the action identifier
             // solution is to process all dialog events and look for an action button to resolve/reject the own promise
-            var def = DeferredUtils.createDeferred(null, 'Dialogs: show');
+            var def = Scheduler.createDeferred(windowId, 'ModalDialog.show');
 
             // event handler for all events triggered by this dialog, resolves/rejects
             // the own deferred object after activating an action button
@@ -422,12 +428,18 @@ define('io.ox/office/tk/dialogs', [
      *
      * @extends ModalDialog
      *
+     * @param {String|Object} windowId
+     *  The identifier of the root window of the context application that is
+     *  creating the dialog, or an object with a method 'getWindowId' that
+     *  returns such a window identifier. Used for debugging and logging of
+     *  running timers in automated test environments.
+     *
      * @param {Object} [initOptions]
      *  Optional parameters that control the appearance and behavior of the
      *  dialog. Supports all options also supported by the base class
      *  ModalDialog.
      */
-    Dialogs.ModalTabDialog = Dialogs.ModalDialog.extend({ constructor: function (initOptions) {
+    Dialogs.ModalTabDialog = Dialogs.ModalDialog.extend({ constructor: function (windowId, initOptions) {
 
         // self reference
         var self = this;
@@ -449,7 +461,7 @@ define('io.ox/office/tk/dialogs', [
 
         // base constructor ---------------------------------------------------
 
-        Dialogs.ModalDialog.call(this, initOptions);
+        Dialogs.ModalDialog.call(this, windowId, initOptions);
 
         // private methods ----------------------------------------------------
 
@@ -625,7 +637,7 @@ define('io.ox/office/tk/dialogs', [
 
     } }); // class ModalTabDialog
 
-    // class ModalQueryDialog =================================================
+    // class ModalMessageDialog ===============================================
 
     /**
      * Creates a simple dialog with a message text and an OK button.
@@ -634,6 +646,12 @@ define('io.ox/office/tk/dialogs', [
      *
      * @extends ModalDialog
      *
+     * @param {String|Object} windowId
+     *  The identifier of the root window of the context application that is
+     *  creating the dialog, or an object with a method 'getWindowId' that
+     *  returns such a window identifier. Used for debugging and logging of
+     *  running timers in automated test environments.
+     *
      * @param {String} message
      *  The message text shown in the dialog body element.
      *
@@ -643,11 +661,11 @@ define('io.ox/office/tk/dialogs', [
      *  ModalDialog. The option 'cancelLabel' will be ignored (the Cancel
      *  button of the dialog will always be hidden).
      */
-    Dialogs.ModalMessageDialog = Dialogs.ModalDialog.extend({ constructor: function (message, initOptions) {
+    Dialogs.ModalMessageDialog = Dialogs.ModalDialog.extend({ constructor: function (windowId, message, initOptions) {
 
         // base constructor ---------------------------------------------------
 
-        Dialogs.ModalDialog.call(this, Utils.extendOptions({ width: 400 }, initOptions));
+        Dialogs.ModalDialog.call(this, windowId, Utils.extendOptions({ width: 400 }, initOptions));
 
         // initialization -----------------------------------------------------
 
@@ -683,6 +701,12 @@ define('io.ox/office/tk/dialogs', [
      *
      * @extends ModalDialog
      *
+     * @param {String|Object} windowId
+     *  The identifier of the root window of the context application that is
+     *  creating the dialog, or an object with a method 'getWindowId' that
+     *  returns such a window identifier. Used for debugging and logging of
+     *  running timers in automated test environments.
+     *
      * @param {String} message
      *  The message text shown in the dialog body element.
      *
@@ -698,14 +722,14 @@ define('io.ox/office/tk/dialogs', [
      *      buttons. See comments above about the behavioral changes for this
      *      case.
      */
-    Dialogs.ModalQueryDialog = Dialogs.ModalDialog.extend({ constructor: function (message, initOptions) {
+    Dialogs.ModalQueryDialog = Dialogs.ModalDialog.extend({ constructor: function (windowId, message, initOptions) {
 
         // whether to show an additional Cancel button
         var cancelMode = Utils.getBooleanOption(initOptions, 'cancel', false);
 
         // base constructor ---------------------------------------------------
 
-        Dialogs.ModalDialog.call(this, Utils.extendOptions({
+        Dialogs.ModalDialog.call(this, windowId, Utils.extendOptions({
             width: 400
         }, initOptions, {
             okLabel: YES_LABEL,
@@ -758,6 +782,12 @@ define('io.ox/office/tk/dialogs', [
      *
      * @extends ModalDialog
      *
+     * @param {String|Object} windowId
+     *  The identifier of the root window of the context application that is
+     *  creating the dialog, or an object with a method 'getWindowId' that
+     *  returns such a window identifier. Used for debugging and logging of
+     *  running timers in automated test environments.
+     *
      * @param {Object} [initOptions]
      *  Optional parameters that control the appearance and behavior of the
      *  dialog. Supports all options also supported by the base class
@@ -775,7 +805,7 @@ define('io.ox/office/tk/dialogs', [
      *  @param {Boolean} [initOptions.maxLength]
      *      If specified, the maximum number of characters that can be entered.
      */
-    Dialogs.ModalInputDialog = Dialogs.ModalDialog.extend({ constructor: function (initOptions) {
+    Dialogs.ModalInputDialog = Dialogs.ModalDialog.extend({ constructor: function (windowId, initOptions) {
 
         // self reference
         var self = this;
@@ -800,7 +830,7 @@ define('io.ox/office/tk/dialogs', [
 
         // base constructor ---------------------------------------------------
 
-        Dialogs.ModalDialog.call(this, initOptions);
+        Dialogs.ModalDialog.call(this, windowId, initOptions);
 
         // private functions --------------------------------------------------
 
@@ -891,6 +921,18 @@ define('io.ox/office/tk/dialogs', [
      *
      * @extends ModalDialog
      *
+     * @param {String|Object} windowId
+     *  The identifier of the root window of the context application that is
+     *  creating the dialog, or an object with a method 'getWindowId' that
+     *  returns such a window identifier. Used for debugging and logging of
+     *  running timers in automated test environments.
+     *
+     * @param {TriggerObject} pickerControl
+     *  An implementation of a list control that provides the methods getNode()
+     *  returning the DOM structure of the file/folder list, and the method
+     *  getSelectedFiole() that returns the descriptor of the file/folder
+     *  currently selected.
+     *
      * @param {Object} [initOptions]
      *  Optional parameters that control the appearance and behavior of the
      *  dialog. Supports all options also supported by the base class
@@ -903,15 +945,13 @@ define('io.ox/office/tk/dialogs', [
      *      the assigned DriveUtil from the DriveUtils class
      *      can be: FolderPicker, FlatFolderPicker & FilePicker
      */
-    Dialogs.ModalDriveDialog = Dialogs.ModalDialog.extend({ constructor: function (initOptions) {
+    Dialogs.ModalDriveDialog = Dialogs.ModalDialog.extend({ constructor: function (windowId, pickerControl, initOptions) {
 
         var self = this;
 
-        var driveUtil = Utils.getOption(initOptions, 'driveUtil');
-
         // base constructor ---------------------------------------------------
 
-        Dialogs.ModalDialog.call(this, initOptions);
+        Dialogs.ModalDialog.call(this, windowId, initOptions);
 
         // public methods -----------------------------------------------------
 
@@ -922,14 +962,14 @@ define('io.ox/office/tk/dialogs', [
          *  but all are optional
          */
         this.getSelectedFile = function () {
-            return driveUtil.getSelectedFile();
+            return pickerControl.getSelectedFile();
         };
 
         // initialization -----------------------------------------------------
 
-        this.getPopup().find('.modal-body').append(driveUtil.getNode());
+        this.getPopup().find('.modal-body').append(pickerControl.getNode());
 
-        driveUtil.on('change', function () {
+        pickerControl.on('change', function () {
             self.trigger('change');
         });
 
@@ -951,24 +991,22 @@ define('io.ox/office/tk/dialogs', [
      *  @param {String} [initOptions.preselect]
      *      Drive-File-Id to preselect a folder
      */
-    Dialogs.ModalFolderPicker = Dialogs.ModalDriveDialog.extend({ constructor: function (initOptions) {
+    Dialogs.ModalFolderPicker = Dialogs.ModalDriveDialog.extend({ constructor: function (windowId, initOptions) {
 
-        var driveUtil = new DriveUtils.FolderPicker(initOptions);
+        var folderPicker = new DriveUtils.FolderPicker(windowId, initOptions);
 
         // base constructor ---------------------------------------------------
 
-        Dialogs.ModalDriveDialog.call(this, Utils.extendOptions({
-            driveUtil: driveUtil
-        }, initOptions));
+        Dialogs.ModalDriveDialog.call(this, windowId, folderPicker, initOptions);
 
         // public methods -----------------------------------------------------
 
         /**
-         * @returns {String}
+         * @returns {String|Undefined}
          *  The current folder identifier.
          */
         this.getSelectedFolderId = function () {
-            var selectedFile = this.getSelectedFile();
+            var selectedFile = folderPicker.getSelectedFile();
             if (selectedFile) {
                 return selectedFile.folder_id;
             }
