@@ -21,39 +21,39 @@ define('io.ox/office/tk/forms', [
 
     'use strict';
 
-    var // CSS classes added to localized bitmap icons
-        DOCS_ICON_CLASSES = 'lc-' + Config.LOCALE + ' lc-' + Config.LANGUAGE + (Utils.RETINA ? ' retina' : ''),
+    // CSS classes added to localized bitmap icons
+    var DOCS_ICON_CLASSES = 'lc-' + Config.LOCALE + ' lc-' + Config.LANGUAGE + (Utils.RETINA ? ' retina' : '');
 
-        // CSS class name for caption elements
-        CAPTION_CLASS = 'caption',
+    // CSS class name for caption elements
+    var CAPTION_CLASS = 'caption';
 
-        // CSS selector for caption elements in control nodes
-        CAPTION_SELECTOR = '>.' + CAPTION_CLASS,
+    // CSS selector for caption elements in control nodes
+    var CAPTION_SELECTOR = '>.' + CAPTION_CLASS;
 
-        // CSS selector for icon elements in control captions
-        ICON_SELECTOR = '>i',
+    // CSS selector for icon elements in control captions
+    var ICON_SELECTOR = '>i';
 
-        // CSS selector for text spans in control captions
-        SPAN_SELECTOR = '>span',
+    // CSS selector for text spans in control captions
+    var SPAN_SELECTOR = '>span';
 
-        // CSS class for buttons with ambiguous value
-        AMBIGUOUS_CLASS = 'ambiguous',
+    // CSS class for buttons with ambiguous value
+    var AMBIGUOUS_CLASS = 'ambiguous';
 
-        // CSS class name for check marks in check boxes
-        CHECK_MARK_CLASS = 'check-mark',
+    // CSS class name for check marks in check boxes
+    var CHECK_MARK_CLASS = 'check-mark';
 
-        // attribute name for selected/checked buttons
-        DATA_CHECKED_ATTR = 'data-checked',
+    // attribute name for selected/checked buttons
+    var DATA_CHECKED_ATTR = 'data-checked';
 
-        // CSS selector for selected buttons
-        DATA_CHECKED_SELECTOR = '[' + DATA_CHECKED_ATTR + '="true"]',
+    // CSS selector for selected buttons
+    var DATA_CHECKED_SELECTOR = '[' + DATA_CHECKED_ATTR + '="true"]';
 
-        // icon sets for checked/unchecked icons (arrays with 'false', 'true', and 'ambiguous' icons)
-        CHECK_ICON_SETS = {
-            check: ['fa-none', 'fa-check', 'fa-minus'],
-            boxed: ['fa-square-o', 'fa-check-square-o', 'fa-minus-square-o'],
-            radio: ['fa-circle-o', 'fa-dot-circle-o', 'fa-circle-o']
-        };
+    // icon sets for checked/unchecked icons (arrays with 'false', 'true', and 'ambiguous' icons)
+    var CHECK_ICON_SETS = {
+        check: ['fa-none', 'fa-check', 'fa-minus'],
+        boxed: ['fa-square-o', 'fa-check-square-o', 'fa-minus-square-o'],
+        radio: ['fa-circle-o', 'fa-dot-circle-o', 'fa-circle-o']
+    };
 
     // private global functions ===============================================
 
@@ -100,27 +100,34 @@ define('io.ox/office/tk/forms', [
     }
 
     /**
-     * Adds attributes to an existing attributes object which disables autocorrection for input fields.
-     * At the moment this should only affects iOS.
+     * Adds generic attributes for an <input> element or a <textarea> element
+     * to the passed set of DOM element attributes.
      *
-     *  @param {Object} attributesObj
-     *  An object which contains attributes that will be attached to an DOM element.
+     * @param {Object} attributes
+     *  A map with DOM element attributes to be extended.
      *
-     *  @param {Boolean} autoCorrection
-     *  A flag if auto correction should be on or off.
+     * @param {Object} [options]
+     *  Optional parameters passed to the methods Forms.createInputMarkup() or
+     *  Forms.createTextAreaMarkup().
      */
-    function setAutoCorrectionAttributes(attributesObj, autoCorrection) {
-        if (Utils.IOS && (autoCorrection === false)) {
-            // 'autocorrect' and 'autocapitalize' are defined by apple
-            attributesObj.autocorrect = 'off';
-            attributesObj.autocapitalize = 'none';
+    function setGenericInputAttributes(attributes, options) {
+
+        var placeHolder = Utils.getStringOption(options, 'placeholder', null);
+        if (placeHolder) { attributes.placeholder = placeHolder; }
+
+        var maxLength = Utils.getIntegerOption(options, 'maxLength', 0);
+        if (maxLength > 0) { attributes.maxlength = maxLength; }
+
+        if (Utils.IOS && !Utils.getBooleanOption(options, 'autoCorrection', false)) {
+            attributes.autocorrect = 'off';
+            attributes.autocapitalize = 'none';
         }
     }
 
     // static class Forms =====================================================
 
-    var // the exported Forms class
-        Forms = {};
+    // the exported Forms class
+    var Forms = {};
 
     // constants --------------------------------------------------------------
 
@@ -241,21 +248,12 @@ define('io.ox/office/tk/forms', [
     Forms.DEFAULT_CLICK_TYPE = Utils.TOUCHDEVICE ? 'tap' : 'click';
 
     /**
-     * CSS class for application bound tooltip.
-     * (Events will be handled by BaseApplication & AppTooltipMixin)
+     * CSS class name for elements that show the global tool tip while hovered.
      *
      * @constant
      */
     Forms.APP_TOOLTIP_CLASS = 'app-tooltip';
 
-    /**
-     * CSS selector for application bound tooltip.
-     * (Events will be handled by BaseApplication)
-     *
-     * @constant
-     */
-    Forms.APP_TOOLTIP_SELECTOR = '.' + Forms.APP_TOOLTIP_CLASS;
-
     // generic helpers --------------------------------------------------------
 
     /**
@@ -285,8 +283,8 @@ define('io.ox/office/tk/forms', [
      */
     Forms.createElementMarkup = function (nodeName, options) {
 
-        var // the HTML mark-up
-            markup = '<' + nodeName;
+        // the HTML mark-up
+        var markup = '<' + nodeName;
 
         // add the attributes
         _.each(Utils.getObjectOption(options, 'attributes'), function (value, name) {
@@ -331,68 +329,49 @@ define('io.ox/office/tk/forms', [
     };
 
     /**
-     * Adds a tool tip to the specified elements.
+     * Enables or disables the tooltips of the specified DOM elements.
      *
-     * @param {HTMLElement|jQuery} node
-     *  The element to be manipulated. If this object is a jQuery collection,
-     *  sets the tool tip for all nodes it contains.
+     * @param {HTMLElement|jQuery} nodes
+     *  The DOM elements to be manipulated. If this object is a jQuery
+     *  collection, uses all nodes it contains.
      *
-     * @param {Object} [options]
+     * @param {Boolean} state
+     *  Whether to enable (true) or disable (false) the tooltips.
+     */
+    Forms.enableToolTip = function (nodes, state) {
+        if (!Utils.TOUCHDEVICE) {
+            $(nodes).toggleClass(Forms.APP_TOOLTIP_CLASS, state);
+        }
+    };
+
+    /**
+     * Adds a tooltip to the specified DOM elements.
+     *
+     * @param {HTMLElement|jQuery} nodes
+     *  The DOM elements to be manipulated. If this object is a jQuery
+     *  collection, uses all nodes it contains.
+     *
+     * @param {Object|String} [options]
      *  Optional parameters:
-     *  @param {String} [options.tooltip='']
-     *      Tool tip text shown when the mouse hovers one of the nodes. If
-     *      omitted, the nodes will not show a tool tip anymore.
-     *  @param {Boolean} [options.forceTouch=false]
-     *      If set to true, the tooltip is set also on touch devices.
+     *  @param {String} [options.tooltip=null]
+     *      The text for the tooltip text shown when the mouse hovers one of
+     *      the nodes. If omitted or set to an empty string, the nodes will not
+     *      show a tooltip anymore.
+     *  If the parameter is a simple string, it will be set directly as the
+     *  tooltip.
      */
-    Forms.setToolTip = function (node, options) {
+    Forms.setToolTip = function (nodes, options) {
 
-        var tooltip = Utils.getStringOption(options, 'tooltip', ''),
-            forceTouch = null;
+        var tooltip = (typeof options === 'string') ? options : Utils.getStringOption(options, 'tooltip', '');
 
-        node = $(node);
-
-        if (!_.isString(tooltip) || (tooltip.length === 0)) {
-            node.removeAttr('data-original-title title aria-label');
-            Forms.disableToolTip(node);
+        if (tooltip.length === 0) {
+            $(nodes).removeAttr('data-original-title title aria-label');
+            Forms.enableToolTip(nodes, false);
+        } else if (Utils.TOUCHDEVICE) {
+            $(nodes).attr({ title: tooltip });
         } else {
-            forceTouch = Utils.getBooleanOption(options, 'forceTouch', false);
-
-            if (Utils.TOUCHDEVICE && !forceTouch) {
-                node.attr({ title: tooltip });
-            } else {
-                node.attr({
-                    'aria-label': tooltip,
-                    'data-original-title': tooltip
-                });
-                Forms.enableToolTip(node);
-            }
-        }
-    };
-
-    /**
-     * disables the tooltip for assigned node if node is inited as tooltip (Froms.setToolTip)
-     *
-     * @param {HTMLElement|jQuery} node
-     *  The elements to be manipulated. If this object is a jQuery collection,
-     *  changes the tool tip states for all nodes it contains.
-     */
-    Forms.disableToolTip = function (node) {
-        if (!Utils.TOUCHDEVICE) {
-            node.removeClass(Forms.APP_TOOLTIP_CLASS);
-        }
-    };
-
-    /**
-     * enables the tooltip for assigned node if node is inited as tooltip (Froms.setToolTip)
-     *
-     * @param {HTMLElement|jQuery} node
-     *  The elements to be manipulated. If this object is a jQuery collection,
-     *  changes the tool tip states for all nodes it contains.
-     */
-    Forms.enableToolTip = function (node) {
-        if (!Utils.TOUCHDEVICE) {
-            node.addClass(Forms.APP_TOOLTIP_CLASS);
+            $(nodes).attr({ 'aria-label': tooltip, 'data-original-title': tooltip });
+            Forms.enableToolTip(nodes, true);
         }
     };
 
@@ -499,7 +478,7 @@ define('io.ox/office/tk/forms', [
     Forms.showNodes = function (nodes, state) {
         nodes = $(nodes);
         nodes.toggleClass(Forms.HIDDEN_CLASS, !state);
-        if (state) { nodes.removeAttr('aria-hidden'); } else { nodes.attr('aria-hidden', true); }
+        nodes.attr('aria-hidden', state ? null : true);
     };
 
     /**
@@ -555,7 +534,7 @@ define('io.ox/office/tk/forms', [
     Forms.enableNodes = function (nodes, state) {
         nodes = $(nodes);
         nodes.toggleClass(Forms.DISABLED_CLASS, !state);
-        if (state) { nodes.removeAttr('aria-disabled'); } else { nodes.attr('aria-disabled', true); }
+        nodes.attr('aria-disabled', state ? null : true);
     };
 
     /**
@@ -722,12 +701,12 @@ define('io.ox/office/tk/forms', [
      */
     Forms.enableCursorFocusNavigation = function (rootNode, options) {
 
-        var // whether to use HOME/END keys
-            homeEnd = Utils.getBooleanOption(options, 'homeEnd', false),
-            // anchor node for vertical movement
-            anchorVertNode = null,
-            // anchor node for horizontal movement
-            anchorHorNode = null;
+        // whether to use HOME/END keys
+        var homeEnd = Utils.getBooleanOption(options, 'homeEnd', false);
+        // anchor node for vertical movement
+        var anchorVertNode = null;
+        // anchor node for horizontal movement
+        var anchorHorNode = null;
 
         function setFocus(focusNode, resetAnchor) {
             Utils.setFocus(focusNode);
@@ -737,16 +716,16 @@ define('io.ox/office/tk/forms', [
 
         function moveFocus(focusNode, direction) {
 
-            var // all focusable nodes contained in the root node
-                focusableNodes = Forms.findFocusableNodes(rootNode),
-                // the index of the focused node
-                focusIndex = focusableNodes.index(focusNode),
-                // whether to move forward
-                forward = /^(right|down)$/.test(direction),
-                // whether to move up/down
-                vertical = /^(up|down)$/.test(direction),
-                // position and size of the focused node
-                focusPosition = null;
+            // all focusable nodes contained in the root node
+            var focusableNodes = Forms.findFocusableNodes(rootNode);
+            // the index of the focused node
+            var focusIndex = focusableNodes.index(focusNode);
+            // whether to move forward
+            var forward = /^(right|down)$/.test(direction);
+            // whether to move up/down
+            var vertical = /^(up|down)$/.test(direction);
+            // position and size of the focused node
+            var focusPosition = null;
 
             // any other node was focused (e.g. the root node itself): start with first/last available node
             if (focusIndex < 0) {
@@ -755,7 +734,7 @@ define('io.ox/office/tk/forms', [
             }
 
             // resolve the positions and sizes of all focus nodes
-            focusableNodes = _.map(focusableNodes.get(), function (node) {
+            focusableNodes = focusableNodes.get().map(function (node) {
                 var position = Utils.getNodePositionInPage(node);
                 return _.extend(position, {
                     node: node,
@@ -768,7 +747,7 @@ define('io.ox/office/tk/forms', [
             focusPosition = focusableNodes[focusIndex];
 
             // filter out all nodes that are not reachable in the specified direction
-            focusableNodes = _.filter(focusableNodes, function (nodePosition) {
+            focusableNodes = focusableNodes.filter(function (nodePosition) {
                 switch (direction) {
                     case 'left':
                         return nodePosition.left + nodePosition.width <= focusPosition.left + 1; // add 1 pixel to avoid browser rounding effects
@@ -786,8 +765,8 @@ define('io.ox/office/tk/forms', [
 
             // insert the centered anchor position into the focus position, if available
             (function () {
-                var anchorNode = vertical ? anchorVertNode : anchorHorNode,
-                    anchorPosition = anchorNode ? Utils.getNodePositionInPage(anchorNode) : null;
+                var anchorNode = vertical ? anchorVertNode : anchorHorNode;
+                var anchorPosition = anchorNode ? Utils.getNodePositionInPage(anchorNode) : null;
                 if (anchorPosition) {
                     if (vertical) {
                         focusPosition.centerX = anchorPosition.left + anchorPosition.width / 2;
@@ -894,8 +873,8 @@ define('io.ox/office/tk/forms', [
      */
     Forms.createIconMarkup = function (icon, options) {
 
-        var // the CSS class names to be added to the node
-            classes = Utils.getStringOption(options, 'classes', '');
+        // the CSS class names to be added to the node
+        var classes = Utils.getStringOption(options, 'classes', '');
 
         if (classes.length) { classes = ' ' + classes; }
         classes = Forms.getIconClasses(icon) + classes;
@@ -932,10 +911,10 @@ define('io.ox/office/tk/forms', [
      */
     Forms.createSpanMarkup = function (text, options) {
 
-        var // the CSS class names to be added to the node
-            classes = Utils.getStringOption(options, 'classes'),
-            // the element attributes
-            attributes = classes ? { class: classes } : null;
+        // the CSS class names to be added to the node
+        var classes = Utils.getStringOption(options, 'classes');
+        // the element attributes
+        var attributes = classes ? { class: classes } : null;
 
         return Forms.createElementMarkup('span', {
             attributes: attributes,
@@ -966,20 +945,18 @@ define('io.ox/office/tk/forms', [
 
         if (!source) { Utils.error('Forms.createImageMarkup(): image source URL missing'); }
 
-        var // the CSS class names to be added to the node
-            classes = Utils.getStringOption(options, 'classes'),
-            // alternate text for the image element
-            altText = Utils.getStringOption(options, 'alt', null),
-            // custom picture height
-            pictureHeight = Utils.getIntegerOption(options, 'pictureHeight', 48),
-            // custom picture width
-            pictureWidth = Utils.getIntegerOption(options, 'pictureWidth', 48),
-            // the element attributes
-            attributes = { src: source, class: classes ? classes : '', width: pictureWidth, height: pictureHeight, alt: altText };
+        // the CSS class names to be added to the node
+        var classes = Utils.getStringOption(options, 'classes');
+        // alternate text for the image element
+        var altText = Utils.getStringOption(options, 'alt', null);
+        // custom picture height
+        var pictureHeight = Utils.getIntegerOption(options, 'pictureHeight', 48);
+        // custom picture width
+        var pictureWidth = Utils.getIntegerOption(options, 'pictureWidth', 48);
+        // the element attributes
+        var attributes = { src: source, class: classes ? classes : '', width: pictureWidth, height: pictureHeight, alt: altText };
 
-        return Forms.createElementMarkup('img', {
-            attributes: attributes
-        });
+        return Forms.createElementMarkup('img', { attributes: attributes });
     };
 
     /**
@@ -1020,12 +997,12 @@ define('io.ox/office/tk/forms', [
      */
     Forms.createCaptionMarkup = function (options) {
 
-        var // the icon mark-up
-            icon = Utils.getStringOption(options, 'icon', ''),
-            // the label mark-up
-            label = Utils.getStringOption(options, 'label', ''),
-            // the position of the icon
-            iconPos = Utils.getStringOption(options, 'iconPos', 'leading');
+        // the icon mark-up
+        var icon = Utils.getStringOption(options, 'icon', '');
+        // the label mark-up
+        var label = Utils.getStringOption(options, 'label', '');
+        // the position of the icon
+        var iconPos = Utils.getStringOption(options, 'iconPos', 'leading');
 
         // create the icon mark-up
         if (icon) {
@@ -1086,13 +1063,13 @@ define('io.ox/office/tk/forms', [
      */
     Forms.setCaptionIcon = function (controlNodes, icon, options) {
 
-        var iconMarkup = Forms.createIconMarkup(icon, options),
-            iconPos = Utils.getStringOption(options, 'pos', 'auto');
+        var iconMarkup = Forms.createIconMarkup(icon, options);
+        var iconPos = Utils.getStringOption(options, 'pos', 'auto');
 
         $(controlNodes).each(function () {
 
-            var captionNode = $(this).find(CAPTION_SELECTOR),
-                iconNode = captionNode.find(ICON_SELECTOR);
+            var captionNode = $(this).find(CAPTION_SELECTOR);
+            var iconNode = captionNode.find(ICON_SELECTOR);
 
             if ((iconPos === 'auto') && (iconNode.length > 0)) {
                 iconNode.after(iconMarkup);
@@ -1156,13 +1133,13 @@ define('io.ox/office/tk/forms', [
      */
     Forms.setCaptionText = function (controlNodes, text, options) {
 
-        var spanMarkup = Forms.createSpanMarkup(text, options),
-            spanPos = Utils.getStringOption(options, 'pos', 'auto');
+        var spanMarkup = Forms.createSpanMarkup(text, options);
+        var spanPos = Utils.getStringOption(options, 'pos', 'auto');
 
         $(controlNodes).each(function () {
 
-            var captionNode = $(this).find(CAPTION_SELECTOR),
-                spanNode = captionNode.find(SPAN_SELECTOR);
+            var captionNode = $(this).find(CAPTION_SELECTOR);
+            var spanNode = captionNode.find(SPAN_SELECTOR);
 
             if ((spanPos === 'auto') && (spanNode.length > 0)) {
                 spanNode.after(spanMarkup);
@@ -1211,8 +1188,8 @@ define('io.ox/office/tk/forms', [
      */
     Forms.setCaption = function (controlNodes, options) {
 
-        var captionMarkup = Forms.createCaptionMarkup(options),
-            captionPos = Utils.getStringOption(options, 'pos', 'auto');
+        var captionMarkup = Forms.createCaptionMarkup(options);
+        var captionPos = Utils.getStringOption(options, 'pos', 'auto');
 
         $(controlNodes).each(function () {
 
@@ -1246,8 +1223,8 @@ define('io.ox/office/tk/forms', [
      */
     Forms.createLabelMarkup = function (options) {
 
-        var captionMarkup = Forms.createCaptionMarkup(options),
-            contentMarkup = Utils.getStringOption(options, 'content', '');
+        var captionMarkup = Forms.createCaptionMarkup(options);
+        var contentMarkup = Utils.getStringOption(options, 'content', '');
 
         // A11Y: use <div> instead of <label> to fulfill WCAG 2.0 Success Criteria - labels must reference an input via the 'for' attribute.
         return Forms.createElementMarkup('div', Utils.extendOptions(options, { content: captionMarkup + contentMarkup, attributes: { class: 'label' } }));
@@ -1303,10 +1280,10 @@ define('io.ox/office/tk/forms', [
      */
     Forms.createCheckMarkMarkup = function (state, design, options) {
 
-        var // special icon for ambiguous state
-            ambiguous = Utils.getBooleanOption(options, 'ambiguous', false),
-            // the icon class name
-            index = (state === true) ? 1 : (ambiguous && _.isNull(state)) ? 2 : 0;
+        // special icon for ambiguous state
+        var ambiguous = Utils.getBooleanOption(options, 'ambiguous', false);
+        // the icon class name
+        var index = (state === true) ? 1 : (ambiguous && _.isNull(state)) ? 2 : 0;
 
         return '<span class="' + CHECK_MARK_CLASS + '">' + Forms.createIconMarkup(CHECK_ICON_SETS[design][index]) + '</span>';
     };
@@ -1332,15 +1309,15 @@ define('io.ox/office/tk/forms', [
      */
     Forms.createButtonMarkup = function (options) {
 
-        var nodeName = Utils.getStringOption(options, 'nodeName', 'a'),
-            attributes = Utils.getObjectOption(options, 'attributes'),
-            classes = Utils.getStringOption(attributes, 'class', ''),
-            focusable = Utils.getBooleanOption(options, 'focusable', true),
-            captionMarkup = Forms.createCaptionMarkup(options),
-            contentMarkup = Utils.getStringOption(options, 'content', ''),
-            href = Utils.getStringOption(options, 'href', ''),
-            target = Utils.getStringOption(options, 'target', '_blank'),
-            ariaOwns = Utils.getStringOption(options, 'aria-owns');
+        var nodeName = Utils.getStringOption(options, 'nodeName', 'a');
+        var attributes = Utils.getObjectOption(options, 'attributes');
+        var classes = Utils.getStringOption(attributes, 'class', '');
+        var focusable = Utils.getBooleanOption(options, 'focusable', true);
+        var captionMarkup = Forms.createCaptionMarkup(options);
+        var contentMarkup = Utils.getStringOption(options, 'content', '');
+        var href = Utils.getStringOption(options, 'href', '');
+        var target = Utils.getStringOption(options, 'target', '_blank');
+        var ariaOwns = Utils.getStringOption(options, 'aria-owns');
 
         // add more element attributes, return the mark-up
         attributes = _.extend({ tabindex: focusable ? 0 : -1, role: 'button' }, attributes);
@@ -1412,11 +1389,7 @@ define('io.ox/office/tk/forms', [
         if (!_.isString(dataValue) && !_.isFunction(value) && !_.isUndefined(value)) {
             dataValue = JSON.stringify(value).replace(/"/g, '');
         }
-        if (dataValue) {
-            buttonNodes.attr('data-value', dataValue);
-        } else {
-            buttonNodes.removeAttr('data-value');
-        }
+        buttonNodes.attr('data-value', dataValue || null);
     };
 
     /**
@@ -1518,14 +1491,14 @@ define('io.ox/office/tk/forms', [
      */
     Forms.checkButtonNodes = function (buttonNodes, state, options) {
 
-        var // the design mode
-            design = Utils.getStringOption(options, 'design', 'select'),
-            // whether to use special formatting for the ambiguous state
-            ambiguous = Utils.getBooleanOption(options, 'ambiguous', false),
+        // the design mode
+        var design = Utils.getStringOption(options, 'design', 'select');
+        // whether to use special formatting for the ambiguous state
+        var ambiguous = Utils.getBooleanOption(options, 'ambiguous', false);
 
-            haspopup = Utils.getBooleanOption(options, 'haspopup', false),
-            // Boolean selected state (without ambiguous state)
-            selected = state === true;
+        var haspopup = Utils.getBooleanOption(options, 'haspopup', false);
+        // Boolean selected state (without ambiguous state)
+        var selected = state === true;
 
         // remove old check mark icons (if ever someone switches between icon design and selection design)
         buttonNodes = $(buttonNodes);
@@ -1540,10 +1513,11 @@ define('io.ox/office/tk/forms', [
         }
 
         // update generic attributes
+        buttonNodes.attr(DATA_CHECKED_ATTR, selected);
         if (haspopup) {
-            buttonNodes.attr(DATA_CHECKED_ATTR, selected).attr({ 'aria-haspopup': true, 'aria-expanded': selected });
+            buttonNodes.attr({ 'aria-haspopup': true, 'aria-expanded': selected });
         } else {
-            buttonNodes.attr(DATA_CHECKED_ATTR, selected).attr({ 'aria-pressed': selected, 'aria-checked': selected });
+            buttonNodes.attr({ 'aria-pressed': selected, 'aria-checked': selected });
         }
     };
 
@@ -1578,10 +1552,10 @@ define('io.ox/office/tk/forms', [
      */
     Forms.checkMatchingButtonNodes = function (buttonNodes, value, options) {
 
-        var // the matcher predicate function
-            matcher = Utils.getFunctionOption(options, 'matcher', _.isEqual),
-            multiSelect = Utils.getBooleanOption(options, 'multiSelect', true),
-            firstMatched = false;
+        // the matcher predicate function
+        var matcher = Utils.getFunctionOption(options, 'matcher', _.isEqual);
+        var multiSelect = Utils.getBooleanOption(options, 'multiSelect', true);
+        var firstMatched = false;
 
         $(buttonNodes).each(function () {
             var state = matcher(value, Forms.getButtonValue(this));
@@ -1619,10 +1593,10 @@ define('io.ox/office/tk/forms', [
      */
     Forms.setButtonKeyHandler = function (nodes, options) {
 
-        var // whether to listen to the TAB key
-            tab = Utils.getBooleanOption(options, 'tab', false),
-            // target node of the last caught 'keydown' event
-            lastKeyDownTarget = null;
+        // whether to listen to the TAB key
+        var tab = Utils.getBooleanOption(options, 'tab', false);
+        // target node of the last caught 'keydown' event
+        var lastKeyDownTarget = null;
 
         // Bug 28528: ENTER key must be handled explicitly, <a> elements without
         // 'href' attribute do not trigger click events. The 'href' attribute
@@ -1632,8 +1606,8 @@ define('io.ox/office/tk/forms', [
         // handler for the 'keyup' events
         function keyHandler(event) {
 
-            var // whether the target of a 'keyup' event matches the target of preceding 'keydown'
-                isKeyUpWithMatchingTarget = false;
+            // whether the target of a 'keyup' event matches the target of preceding 'keydown'
+            var isKeyUpWithMatchingTarget = false;
 
             // Bug 37870: Remember target node of a 'keydown' event, check that 'keyup' event is for the
             // same target. Needed to prevent triggering a click event when pressing ENTER one one node,
@@ -1681,11 +1655,10 @@ define('io.ox/office/tk/forms', [
      *  Whether to enable (true) or disable (false) the button elements.
      */
     Forms.enableBSButton = function (buttonNode, state) {
-        if (state) {
-            buttonNode.removeAttr('disabled').removeAttr('aria-disabled');
-        } else {
-            buttonNode.attr({ disabled: 'disabled', 'aria-disabled': true });
-        }
+        buttonNode.attr({
+            disabled: state ? null : 'disabled',
+            'aria-disabled': state ? null : true
+        });
     };
 
     // text input elements ----------------------------------------------------
@@ -1710,28 +1683,23 @@ define('io.ox/office/tk/forms', [
      *      If specified and a positive number, sets the 'maxLength' attribute
      *      of the text field, used to restrict the maximum length of the text
      *      that can be inserted into the text field.
-     *  @param {Boolean} [options.autoCorrection]
+     *  @param {Boolean} [options.autoCorrection=false]
      *      Only for iOs. This option has been introduced with Bug 43868.
      *      By default the autocorrection is off for input fields
      *      in iOS. When setting this to true, the autocorrection is enabled.
      *
-     * @returns {jQuery}
-     *  A jQuery object containing the new text field element.
+     * @returns {String}
+     *  The HTML mark-up for the new text field element.
      */
     Forms.createInputMarkup = function (options) {
 
-        var type = Utils.TOUCHDEVICE ? Utils.getStringOption(options, 'keyboard', 'text') : 'text',
-            attributes = Utils.getObjectOption(options, 'attributes', {}),
-            tabIndex = Utils.getIntegerOption(options, 'tabindex', 0),
-            placeHolder = Utils.getStringOption(options, 'placeholder'),
-            maxLength = Utils.getIntegerOption(options, 'maxLength'),
-            autoCorrection = Utils.getBooleanOption(options, 'autoCorrection', false);
+        var type = Utils.TOUCHDEVICE ? Utils.getStringOption(options, 'keyboard', 'text') : 'text';
+        var attributes = Utils.getObjectOption(options, 'attributes', {});
+        var tabIndex = Utils.getIntegerOption(options, 'tabindex', 0);
 
         // add more element attributes, return the mark-up
         attributes = _.extend({ type: type, tabindex: tabIndex }, attributes);
-        if (_.isString(placeHolder) && (placeHolder.length > 0)) { attributes.placeholder = placeHolder; }
-        if (_.isNumber(maxLength) && (maxLength > 0)) { attributes.maxlength = maxLength; }
-        setAutoCorrectionAttributes(attributes, autoCorrection);
+        setGenericInputAttributes(attributes, options);
         return Forms.createElementMarkup('input', Utils.extendOptions(options, { attributes: attributes, content: null }));
     };
 
@@ -1748,27 +1716,22 @@ define('io.ox/office/tk/forms', [
      *      If specified and a positive number, sets the 'maxLength' attribute
      *      of the text area, used to restrict the maximum length of the text
      *      that can be inserted into the text area.
-     *  @param {Boolean} [options.autoCorrection]
+     *  @param {Boolean} [options.autoCorrection=false]
      *      Only for iOs. This option has been introduced with Bug 43868.
      *      By default the autocorrection is off for input fields
      *      in iOS. When setting this to true, the autocorrection is enabled.
      *
-     * @returns {jQuery}
-     *  A jQuery object containing the new text area element.
+     * @returns {String}
+     *  The HTML mark-up for the new text area element.
      */
     Forms.createTextAreaMarkup = function (options) {
 
-        var attributes = Utils.getObjectOption(options, 'attributes', {}),
-            tabIndex = Utils.getIntegerOption(options, 'tabindex', 0),
-            placeHolder = Utils.getStringOption(options, 'placeholder'),
-            maxLength = Utils.getIntegerOption(options, 'maxLength'),
-            autoCorrection = Utils.getBooleanOption(options, 'autoCorrection', false);
+        var attributes = Utils.getObjectOption(options, 'attributes', {});
+        var tabIndex = Utils.getIntegerOption(options, 'tabindex', 0);
 
         // add more element attributes, return the mark-up
         attributes = _.extend({ tabindex: tabIndex }, attributes);
-        if (_.isString(placeHolder) && (placeHolder.length > 0)) { attributes.placeholder = placeHolder; }
-        if (_.isNumber(maxLength) && (maxLength > 0)) { attributes.maxlength = maxLength; }
-        setAutoCorrectionAttributes(attributes, autoCorrection);
+        setGenericInputAttributes(attributes, options);
         return Forms.createElementMarkup('textarea', Utils.extendOptions(options, { attributes: attributes, content: null }));
     };
 
@@ -1793,6 +1756,23 @@ define('io.ox/office/tk/forms', [
         }
     };
 
+    /**
+     * Returns whether the current selection in the passed text input control
+     * is a simple text cursor (no characters selected).
+     *
+     * @param {HTMLElement|jQuery} inputNode
+     *  A text input element (an HTML <input> or <textarea> element). If this
+     *  object is a jQuery collection, used the first DOM node it contains.
+     *
+     * @returns {Boolean}
+     *  Whether the current selection in the passed text input control is a
+     *  simple text cursor (no characters selected).
+     */
+    Forms.isCursorSelection = function (inputNode) {
+        var selection = Forms.getInputSelection(inputNode);
+        return selection.start === selection.end;
+    };
+
     /**
      * Changes the current selection in the passed text input control.
      *
@@ -1830,8 +1810,8 @@ define('io.ox/office/tk/forms', [
      */
     Forms.replaceTextInInputSelection = function (inputNode, text) {
 
-        var node = Utils.getDomNode(inputNode),
-            start = node.selectionStart;
+        var node = Utils.getDomNode(inputNode);
+        var start = node.selectionStart;
 
         text = _.isString(text) ? text : '';
         node.value = Utils.replaceSubString(node.value, start, node.selectionEnd, text);
@@ -2074,25 +2054,25 @@ define('io.ox/office/tk/forms', [
      *
      */
     Forms.touchAwareListener = function (options, handler) {
-        var // the node to which the eventl istener should be attached
-            node = options.node,
-            // a possible jQuery selector for delegation
-            delegate = options.delegate;
 
-        var fn = handler;
+        // the node to which the eventl istener should be attached
+        var node = options.node;
+        // a possible jQuery selector for delegation
+        var delegate = options.delegate;
+
+        var listener = handler;
+
         if (Forms.DEFAULT_CLICK_TYPE === 'tap') {
-            fn = function (e) {
+            listener = function (e) {
                 handler.call(this, e);
                 e.preventDefault();
             };
         }
 
-        // when there is no delegate selector use this...
-        if (!delegate) {
-            node.on(Forms.DEFAULT_CLICK_TYPE, fn);
-        // with a delegate selector use this...
+        if (delegate) {
+            node.on(Forms.DEFAULT_CLICK_TYPE, delegate, listener);
         } else {
-            node.on(Forms.DEFAULT_CLICK_TYPE, delegate, fn);
+            node.on(Forms.DEFAULT_CLICK_TYPE, listener);
         }
     };
 
@@ -2111,10 +2091,10 @@ define('io.ox/office/tk/forms', [
      */
     Forms.createLoggingTooltipMarkup = function (value) {
 
-        var // the resulting mark-up, as array of strings
-            markup = [],
-            // the current line indentation
-            indent = 0;
+        // the resulting mark-up, as array of strings
+        var markup = [];
+        // the current line indentation
+        var indent = 0;
 
         function isAtomic(val) {
             return _.isNumber(val) || _.isBoolean(val) || _.isNull(val) || _.isUndefined(val);
