@@ -36,15 +36,15 @@ define('io.ox/office/tk/locale/formatter', [
     // (310 zeros are enough for all available floating point numbers, maximum exponent is 307)
     var ZEROS = Utils.repeatString('0000000000', 31);
 
-    // values of roman numbers, mapped by roman digit
-    var ROMAN_DIGIT_MAP = { M: 1000, D: 500, C: 100, L: 50, X: 10, V: 5, I: 1 };
-
     // digits of roman numbers, and their decimal values, sorted descending
-    var ROMAN_DIGITS = _.chain(ROMAN_DIGIT_MAP)
+    var ROMAN_DIGITS = _.chain(LocaleData.ROMAN_DIGITS)
             .map(function (value, char) { return { char: char, value: value }; })
             .sortBy(function (digit) { return -digit.value; })
             .value();
 
+    // the number of available roman digits
+    var ROMAN_DIGITS_COUNT = ROMAN_DIGITS.length;
+
     // private static functions ===============================================
 
     /**
@@ -168,40 +168,46 @@ define('io.ox/office/tk/locale/formatter', [
      *
      * @extends BaseObject
      *
+     * @param {String|Object} windowId
+     *  The identifier of the root window of the context application owning the
+     *  instances of this class, or an object with a method 'getWindowId' that
+     *  returns such a window identifier. Used for debugging and logging of
+     *  running timers and pending promises in automated test environments.
+     *
      * @param {Object} [initOptions]
      *  Optional parameters:
-     *  @param {String} [initOptions.dec=LocaleData.DEC]
+     *  - {String} [initOptions.dec=LocaleData.DEC]
      *      The decimal separator character. If omitted, the decimal separator
      *      of the current UI language will be used.
-     *  @param {String} [initOptions.group=LocaleData.GROUP]
+     *  - {String} [initOptions.group=LocaleData.GROUP]
      *      The group separator (a.k.a. thousands separator) character. If
      *      omitted, the group separator of the current UI language will be
      *      used.
-     *  @param {Date|Number} [initOptions.nullDate]
+     *  - {Date|Number} [initOptions.nullDate]
      *      The null date used by this formatter (i.e. the date that will be
      *      formatted for the serial number 0), as UTC date object or as number
      *      of milliseconds as returned by Date.UTC(). By default, the date
      *      1899-11-30 will be used as null date.
-     *  @param {Boolean} [initOptions.leapYearBug=false]
+     *  - {Boolean} [initOptions.leapYearBug=false]
      *      Whether to implement the faulty behavior that 1900 was a yeap year
      *      for compatibility with other spreadsheet applications, i.e. whether
      *      to treat 1900-02-29 as a valid date.
-     *  @param {Number} [initOptions.centuryThreshold=30]
+     *  - {Number} [initOptions.centuryThreshold=30]
      *      An integer in the range 0 to 100 that specifies how to convert a
      *      number below 100 to a 4-digit year. See DateUtils.expandYear() for
      *      more details.
-     *  @param {Boolean} [initOptions.negativeDates=false]
+     *  - {Boolean} [initOptions.negativeDates=false]
      *      Whether to support negative date values (for example, the number -1
      *      result in the day before the null date). If set to false or
      *      omitted, negative numbers cannot be converted to dates, and dates
      *      before the null date cannot be converted to numbers.
-     *  @param {Number} [initOptions.generalLength=11]
+     *  - {Number} [initOptions.generalLength=11]
      *      Maximum number of characters used to format a number with the
      *      'General' format code token, including the decimal separator and
      *      the complete exponent in scientific notation, but without the minus
      *      sign.
      */
-    function Formatter(initOptions) {
+    function Formatter(windowId, initOptions) {
 
         // self reference
         var self = this;
@@ -235,7 +241,7 @@ define('io.ox/office/tk/locale/formatter', [
 
         // base constructor ---------------------------------------------------
 
-        BaseObject.call(this);
+        BaseObject.call(this, windowId);
 
         // private methods ----------------------------------------------------
 
@@ -870,7 +876,7 @@ define('io.ox/office/tk/locale/formatter', [
          *
          * @param {Object} [options]
          *  Optional parameters:
-         *  @param {Boolean} [options.complete=false]
+         *  - {Boolean} [options.complete=false]
          *      If set to true, the entire passed string must represent a valid
          *      date. No remaining 'garbage' text will be accepted.
          *
@@ -900,7 +906,7 @@ define('io.ox/office/tk/locale/formatter', [
          *
          * @param {Object} [options]
          *  Optional parameters:
-         *  @param {Boolean} [options.complete=false]
+         *  - {Boolean} [options.complete=false]
          *      If set to true, the entire passed string must represent a valid
          *      time. No remaining 'garbage' text will be accepted.
          *
@@ -920,107 +926,6 @@ define('io.ox/office/tk/locale/formatter', [
             });
         };
 
-        /**
-         * Converts the passed decimal number to a roman number string.
-         *
-         * @param {Number} number
-         *  The number to be converted.
-         *
-         * @param {Number} [depth=0]
-         *  The degree of simplification made for the decimal digits 4 and 9.
-         *  MUST be a number in the range 0 to 4.
-         *
-         * @returns {String|Null}
-         *  The roman number representation of the passed number (an empty
-         *  string for the number zero); or null, if the passed number is not
-         *  in the supported range.
-         */
-        this.formatRoman = function (number, depth) {
-
-            number = Math.floor(number);
-            if ((number < 0) || (number > 3999)) { return null; }
-
-            depth = depth || 0;
-
-            var result = '';
-            for (var index = 0; (index < ROMAN_DIGITS.length) && (number > 0); index += 2) {
-
-                // current decimal digit of the number to be processed
-                var digit = Math.floor(number / ROMAN_DIGITS[index].value);
-
-                // Special handling for digits 4 and 9: Put a smaller roman digit before a larger one,
-                // for example IV which means 5 - 1 = 4; or XM which means 1000 - 10 = 990.
-                if ((digit % 5) === 4) {
-
-                    // get the nerest larger roman digit (e.g., 100 for 99, or 500 for 490)
-                    var prevDigit = ROMAN_DIGITS[index - ((digit === 4) ? 1 : 2)];
-                    // array index to the smaller roman digit (e.g., 50 for 99, or 100 for 490)
-                    var nextIndex = index;
-                    // try to find a smaller roman digit according to the passed depth
-                    var remaining = Math.min(depth, ROMAN_DIGITS.length - index - 1);
-
-                    // try to find a smaller roman digit so that the difference does not exceed the
-                    // remaining number; but stop searching if the passed depth has been reached
-                    while (remaining > 0) {
-                        remaining -= 1;
-                        if (number < prevDigit.value - ROMAN_DIGITS[nextIndex + 1].value) { break; }
-                        nextIndex += 1;
-                    }
-
-                    // add the combination of roman digits to the result, and reduce the number
-                    var nextDigit = ROMAN_DIGITS[nextIndex];
-                    result += nextDigit.char + prevDigit.char;
-                    number += nextDigit.value - prevDigit.value;
-
-                } else {
-
-                    // decimal digit is in range 5 to 8: add the roman digit for 5, 50, or 500
-                    if (digit > 4) { result += ROMAN_DIGITS[index - 1].char; }
-
-                    // repeat the digit for the current power of 10, and reduce the number
-                    result += Utils.repeatString(ROMAN_DIGITS[index].char, digit % 5);
-                    number %= ROMAN_DIGITS[index].value;
-                }
-            }
-            return result;
-        };
-
-        /**
-         * Tries to parse the passed text as a roman number.
-         *
-         * @param {String} text
-         *  The text to be parsed as a roman number (case-insensitive).
-         *
-         * @returns {Number|Null}
-         *  The decimal value of the roman number; or null, if the passed text
-         *  contains any invalid characters.
-         */
-        this.parseRoman = function (text) {
-
-            // the intermediate result
-            var result = 0;
-            // the largest roman digit found so far
-            var max = 1;
-
-            // process all roman digits in reversed order
-            Utils.iterateArray(text.toUpperCase(), function (digit) {
-
-                // convert digit to the decimal number, exit on invalid characters
-                var value = ROMAN_DIGIT_MAP[digit];
-                if (!value) {
-                    result = null;
-                    return Utils.BREAK;
-                }
-
-                // if the digit is less than the maximum digit found so far, subtract it from the result
-                result += (value < max) ? -value : value;
-                max = Math.max(max, value);
-
-            }, { reverse: true });
-
-            return result;
-        };
-
         /**
          * Returns the display string of the passed number formatted with the
          * standard number format, fitting into the specified text length.
@@ -1037,7 +942,7 @@ define('io.ox/office/tk/locale/formatter', [
          *
          * @param {Object} [options]
          *  Optional parameters:
-         *  @param {Number} [options.expLength=2]
+         *  - {Number} [options.expLength=2]
          *      The minimum number of characters for the exponent in scientific
          *      notation. If the resulting exponent is shorter, it will be
          *      filled with leading zero digits. MUST be a positive integer;
@@ -1142,7 +1047,7 @@ define('io.ox/office/tk/locale/formatter', [
          *
          * @param {Object} [options]
          *  Optional parameters:
-         *  @param {Number} [options.generalLength]
+         *  - {Number} [options.generalLength]
          *      Maximum number of characters used to format a number for the
          *      'General' format code token. If omitted, the default length
          *      specified in the constructor option will be used.
@@ -1496,6 +1401,178 @@ define('io.ox/office/tk/locale/formatter', [
 
     } // class Formatter
 
+    // static methods ---------------------------------------------------------
+
+    /**
+     * Converts the passed number to a string, using the decimal separator of
+     * the current UI locale. This is a simple method that uses JavaScript's
+     * conversion from numbers to strings.
+     *
+     * @param {Number} number
+     *  The number to be converted.
+     *
+     * @returns {String}
+     *  The passed number, converted to string, with the decimal separator of
+     *  the current UI locale.
+     */
+    Formatter.formatDecimal = function (number) {
+        return String(number).replace(/\./g, LocaleData.DEC);
+    };
+
+    /**
+     * Converts the passed decimal number to an alphabetic number string. The
+     * numbers 1 to 26 will be converted to single letters 'A' to 'Z'
+     * respectively. The numbers 27 to 52 will be converted to multi-letter
+     * numbers using specific conversion methods.
+     *
+     * @param {Number} number
+     *  The number to be converted. Will be truncated to an integer.
+     *
+     * @param {String} method
+     *  The conversion method to be used. Must be one of the following values:
+     *  - 'digit': The letters will be used as independent digits. The numbers
+     *      27 to 52 will be converted to the alphabetic numbers 'AA' to 'AZ'
+     *      respectively. The numbers 53 to 78 will be converted to 'BA' to
+     *      'BZ', and so on (up to 'ZZ' for the number 702, followed by 'AAA',
+     *      'AAB', ...).
+     *  - 'repeat': A single letter will be repeated in the result. The numbers
+     *      27 to 52 will be converted to the alphabetic numbers 'AA' to 'ZZ'
+     *      respectively. The numbers 53 to 78 will be converted to the strings
+     *      'AAA' to 'ZZZ', and so on.
+     *
+     * @param {Object} [options]
+     *  Optional parameters:
+     *  - {Boolean} [options.lower=false]
+     *      If ste to true, the resulting alphabetic number will consist of
+     *      lower-case lettrers.
+     *
+     * @returns {String}
+     *  The alphabetic number representation of the passed number; or an empty
+     *  string for the number zero or negative numbers, or if the conversion
+     *  method name is invalid.
+     */
+    Formatter.formatAlphabetic = function (number, method, options) {
+
+        number = Math.floor(number);
+        if (number <= 0) { return ''; }
+
+        var result = '';
+        switch (method) {
+
+            case 'digit':
+                for (number -= 1; number >= 0; number = Math.floor(number / 26) - 1) {
+                    result = String.fromCharCode(65 + number % 26) + result;
+                }
+                break;
+
+            case 'repeat':
+                number -= 1;
+                result = Utils.repeatString(String.fromCharCode(65 + number % 26), Math.floor(number / 26) + 1);
+                break;
+
+            default:
+                Utils.error('Formatter.formatAlphabetic(): unknown conversion method "' + method + '"');
+                return '';
+        }
+
+        // convert to lower-case if specified
+        return Utils.getBooleanOption(options, 'lower', false) ? result.toLowerCase() : result;
+    };
+
+    /**
+     * Converts the passed decimal number to a roman number string.
+     *
+     * @param {Number} number
+     *  The number to be converted. Will be truncated to an integer. Must be
+     *  non-negative and less than 4000 in order to produce a valid result.
+     *
+     * @param {Number} depth
+     *  The degree of simplification made for the decimal digits 4 and 9. MUST
+     *  be an integer in the range from -1 to 4, with the following behavior:
+     *  - -1: The decimal digits 4 and 9 will not be simplified, e.g. the
+     *      decimal number 499 will be converted to 'CCCCLXXXXVIIII' ('4 times
+     *      100, plus 50, plus 4 times 10, plus 5, plus 4 times 1').
+     *  - 0: The decimal digits 4 and 9 will be replaced with the respective
+     *      roman '1-less-5' or '1-less-10' combination, e.g. the decimal
+     *      number 499 will be converted to 'CDXCIX' ('100 less than 500, plus
+     *      10 less than 100, plus 1 less than 10').
+     *  - 1: The decimal numbers will be simplified using roman numbers with
+     *      '1-less-' or '5-less-' combinations, e.g. the decimal number 499
+     *      will be converted to 'LDVLIV' ('50 less than 500, plus 5 less than
+     *      50, plus 1 less than 5').
+     *  - 2: The degree of simplification will be increased to the respective
+     *      '1-less-50' or '1-less-100' combinations, e.g. the decimal number
+     *      499 will be converted to 'XDIX' ('10 less than 500, plus 1 less
+     *      than 10').
+     *  - 3: The degree of simplification will be increased to '5-less-500' or
+     *      '5-less-1000' combinations, e.g. the decimal number 499 will be
+     *      converted to 'VDIV' ('5 less than 500, plus 1 less than 5').
+     *  - 4: The degree of simplification will be increased to '1-less-500' or
+     *      '1-less-1000' combinations, e.g. the decimal number 499 will be
+     *      converted to 'ID' ('1 less than 500').
+     *
+     * @param {Object} [options]
+     *  Optional parameters:
+     *  - {Boolean} [options.lower=false]
+     *      If ste to true, the resulting roman number will consist of
+     *      lower-case lettrers.
+     *
+     * @returns {String}
+     *  The roman number representation of the passed number; or an empty
+     *  string, if the passed number is not in the supported range.
+     */
+    Formatter.formatRoman = function (number, depth, options) {
+
+        number = Math.floor(number);
+        if ((number <= 0) || (number > 3999)) { return ''; }
+
+        var result = '';
+        for (var index = 0; (index < ROMAN_DIGITS_COUNT) && (number > 0); index += 2) {
+
+            // the letter and value of the current roman digit
+            var digitData = ROMAN_DIGITS[index];
+            // current decimal digit of the number to be processed
+            var digit = Math.floor(number / digitData.value);
+
+            // Special handling for digits 4 and 9: Put a smaller roman digit before a larger one,
+            // for example IV which means 5 - 1 = 4; or XM which means 1000 - 10 = 990.
+            if ((depth >= 0) && (digit % 5 === 4)) {
+
+                // get the nerest larger roman digit (e.g., 100 for 99, or 500 for 490)
+                var prevDigit = ROMAN_DIGITS[index - ((digit === 4) ? 1 : 2)];
+                // array index to the smaller roman digit (e.g., 50 for 99, or 100 for 490)
+                var nextIndex = index;
+                // try to find a smaller roman digit according to the passed depth
+                var remaining = Math.min(depth, ROMAN_DIGITS_COUNT - index - 1);
+
+                // try to find a smaller roman digit so that the difference does not exceed the
+                // remaining number; but stop searching if the passed depth has been reached
+                while (remaining > 0) {
+                    remaining -= 1;
+                    if (number < prevDigit.value - ROMAN_DIGITS[nextIndex + 1].value) { break; }
+                    nextIndex += 1;
+                }
+
+                // add the combination of roman digits to the result, and reduce the number
+                var nextDigit = ROMAN_DIGITS[nextIndex];
+                result += nextDigit.char + prevDigit.char;
+                number += nextDigit.value - prevDigit.value;
+
+            } else {
+
+                // decimal digit is in range 5 to 9: add the roman digit for 5, 50, or 500
+                if (digit >= 5) { result += ROMAN_DIGITS[index - 1].char; }
+
+                // repeat the digit for the current power of 10, and reduce the number
+                result += Utils.repeatString(digitData.char, digit % 5);
+                number %= digitData.value;
+            }
+        }
+
+        // convert to lower-case if specified
+        return Utils.getBooleanOption(options, 'lower', false) ? result.toLowerCase() : result;
+    };
+
     // exports ================================================================
 
     return BaseObject.extend({ constructor: Formatter });
