@@ -16,9 +16,9 @@ define.async('io.ox/office/tk/locale/localedata', [
     'io.ox/office/tk/config',
     'io.ox/office/tk/utils',
     'io.ox/office/tk/io',
-    'io.ox/office/tk/container/simplemap',
+    'io.ox/office/tk/container/valuemap',
     'gettext!io.ox/office/tk/main'
-], function (Config, Utils, IO, SimpleMap, gt) {
+], function (Config, Utils, IO, ValueMap, gt) {
 
     'use strict';
 
@@ -32,7 +32,7 @@ define.async('io.ox/office/tk/locale/localedata', [
     var localeData = null;
 
     // static cache for JSON resources already loaded, mapped by resource module name and locale name
-    var resourceCache = new SimpleMap();
+    var resourceCache = new ValueMap();
 
     // regular expression to split language and optional region from a locale identifier
     var LOCALE_ID_RE = /^([a-z]+)(?:_([A-Z]+))?$/;
@@ -359,6 +359,25 @@ define.async('io.ox/office/tk/locale/localedata', [
      */
     var LocaleData = {};
 
+    // constants --------------------------------------------------------------
+
+    /**
+     * The values of all available roman digits, mapped by the respective roman
+     * digit letter.
+     *
+     * @constant
+     * @type Object<String,Number>
+     */
+    LocaleData.ROMAN_DIGITS = {
+        M: 1000,
+        D: 500,
+        C: 100,
+        L: 50,
+        X: 10,
+        V: 5,
+        I: 1
+    };
+
     // static methods ---------------------------------------------------------
 
     /**
