@@ -70,67 +70,6 @@ define('io.ox/office/tk/locale/parser', [
         return returnVal;
     }());
 
-    // creates and caches the regular expressions to detect currency formats
-    var getCurrencyMatchingRegExp = _.memoize(function (options) {
-        var sign = _.escapeRegExp(LocaleData.CURRENCY),
-            code = _.escapeRegExp(LocaleData.ISO_CURRENCY);
-
-        if (Utils.getBooleanOption(options, 'leading', true)) {
-            // checks a complete string and searches a leading currency symbol e.g. "$ 213" or "$ string"
-            // (means: "[currency][string]")
-            return new RegExp('^(' + sign + '|' + code + '])\\s*(.*)$');
-        } else {
-            // checks only remaining strings like " $" from "12 $"
-            // (means: "[space][currency]"")
-            return new RegExp('^\\s*(' + sign + '|' + code + ')$');
-        }
-
-    }, function (options) {
-        return Utils.getBooleanOption(options, 'leading', true);
-    });
-
-    // creates and caches the regular expressions to detect date formats
-    var getMonthRegExp = _.memoize(function (monthName, options) {
-
-        function generator(monthName, options) {
-            // monthName in lower case
-            monthName = monthName.toLowerCase();
-
-            var end             = Utils.getBooleanOption(options, 'monthGroupEnd', false) ? '$' : '',
-                get             = Utils.getBooleanOption(options, 'monthGroupGet', true) ? '' : '?:',
-                mon             = monthName,
-                regex           = [],
-                letterRegEx     = null,
-                index           = 0;
-
-            do {
-                mon = mon.substr(0, (monthName.length - index));
-                regex[index] = mon;
-                index++;
-            } while (mon.length > 3);
-
-            letterRegEx = (regex.length > 0) ? '(?:' + regex.join('|') + ')' + end : '';
-
-            // return part of regex
-            // e.g. = "(jan(?:uary|uar|ua|u)?$)"
-            return '(' + get + letterRegEx + ')';
-        }
-
-        // empty month-string means returning all months
-        if (monthName === '') {
-            return LocaleData.LONG_MONTHS.map(function (monthName) {
-                return generator(monthName, options);
-            }).join('|');
-        }
-
-        return generator(monthName, options);
-
-    }, function (monthName, options) {
-        var end = Utils.getBooleanOption(options, 'monthGroupEnd', false) ? 0 : 1;
-        var get = Utils.getBooleanOption(options, 'monthGroupGet', true) ? 0 : 1;
-        return monthName.toLowerCase() + ':' + end + ':' + get;
-    });
-
     // all codes for grammar 'op', this means the original english key
     // and all codes for 'ui', this means all translated codes
     var CODES = (function () {
@@ -228,6 +167,69 @@ define('io.ox/office/tk/locale/parser', [
         };
     }());
 
+    // private global functions ===============================================
+
+    // creates and caches the regular expressions to detect currency formats
+    var getCurrencyMatchingRegExp = _.memoize(function (options) {
+        var sign = _.escapeRegExp(LocaleData.CURRENCY),
+            code = _.escapeRegExp(LocaleData.ISO_CURRENCY);
+
+        if (Utils.getBooleanOption(options, 'leading', true)) {
+            // checks a complete string and searches a leading currency symbol e.g. "$ 213" or "$ string"
+            // (means: "[currency][string]")
+            return new RegExp('^(' + sign + '|' + code + '])\\s*(.*)$');
+        } else {
+            // checks only remaining strings like " $" from "12 $"
+            // (means: "[space][currency]"")
+            return new RegExp('^\\s*(' + sign + '|' + code + ')$');
+        }
+
+    }, function (options) {
+        return Utils.getBooleanOption(options, 'leading', true);
+    });
+
+    // creates and caches the regular expressions to detect date formats
+    var getMonthRegExp = _.memoize(function (monthName, options) {
+
+        function generator(monthName, options) {
+            // monthName in lower case
+            monthName = monthName.toLowerCase();
+
+            var end             = Utils.getBooleanOption(options, 'monthGroupEnd', false) ? '$' : '',
+                get             = Utils.getBooleanOption(options, 'monthGroupGet', true) ? '' : '?:',
+                mon             = monthName,
+                regex           = [],
+                letterRegEx     = null,
+                index           = 0;
+
+            do {
+                mon = mon.substr(0, (monthName.length - index));
+                regex[index] = mon;
+                index++;
+            } while (mon.length > 3);
+
+            letterRegEx = (regex.length > 0) ? '(?:' + regex.join('|') + ')' + end : '';
+
+            // return part of regex
+            // e.g. = "(jan(?:uary|uar|ua|u)?$)"
+            return '(' + get + letterRegEx + ')';
+        }
+
+        // empty month-string means returning all months
+        if (monthName === '') {
+            return LocaleData.LONG_MONTHS.map(function (monthName) {
+                return generator(monthName, options);
+            }).join('|');
+        }
+
+        return generator(monthName, options);
+
+    }, function (monthName, options) {
+        var end = Utils.getBooleanOption(options, 'monthGroupEnd', false) ? 0 : 1;
+        var get = Utils.getBooleanOption(options, 'monthGroupGet', true) ? 0 : 1;
+        return monthName.toLowerCase() + ':' + end + ':' + get;
+    });
+
     // class FormatToken ======================================================
 
     /**
@@ -1068,10 +1070,10 @@ define('io.ox/office/tk/locale/parser', [
         if (this.syntaxError) { return null; }
 
         // return text section for strings
-        if (_.isString(value)) { return this.textSection; }
+        if (typeof value === 'string') { return this.textSection; }
 
         // reject other values than finite numbers
-        if (!_.isNumber(value) || !isFinite(value)) { return null; }
+        if (!Utils.isFiniteNumber(value)) { return null; }
 
         // pick first matching section for numbers
         return this.numberSections.find(function (s) { return s.contains(value); });
@@ -1167,22 +1169,6 @@ define('io.ox/office/tk/locale/parser', [
 
     // static methods ---------------------------------------------------------
 
-    /**
-     * Converts the passed number to a string, using the decimal separator of
-     * the current UI locale. This is a simple method that uses JavaScript's
-     * conversion from numbers to strings.
-     *
-     * @param {Number} number
-     *  The number to be converted.
-     *
-     * @returns {String}
-     *  The passed number, converted to string, with the decimal separator of
-     *  the current UI locale.
-     */
-    Parser.numberToString = function (number) {
-        return String(number).replace(/\./g, LocaleData.DEC);
-    };
-
     /**
      * Converts the passed string to a number, using the decimal separator of
      * the current UI locale. This is a simple method that uses JavaScript's
@@ -1198,10 +1184,96 @@ define('io.ox/office/tk/locale/parser', [
      *  leading number will be returned (same behavior as JavaScript's native
      *  parseFloat() function).
      */
-    Parser.stringToNumber = function (text) {
+    Parser.parseDecimal = function (text) {
         return parseFloat(text.replace(LocaleData.DEC, '.'));
     };
 
+    /**
+     * Tries to parse the passed text as an alphabetically encoded number.
+     *
+     * @param {String} text
+     *  The text to be parsed as an alphabetic number (case-insensitive).
+     *
+     * @param {String} method
+     *  The encoding method of the passed alphaberic number. Must be one of the
+     *  following values:
+     *  - 'digit': The letters in the passed alphabetic number are used as
+     *      independent digits. The alphabetic numbers 'A' to 'Z' represent the
+     *      decimal numbers 1 to 26 respectively. The alphabetic numbers 'AA'
+     *      to 'AZ' represent the numbers 27 to 52, the numbers 'BA' to 'BZ'
+     *      represent the numbers 53 to 78, and so on (up to 'ZZ' for the
+     *      number 702, followed by 'AAA', 'AAB', ...).
+     *  - 'repeat': The letters in the passed alphabetic number must be equal.
+     *      The alphabetic numbers 'A' to 'Z' represent the decimal numbers 1
+     *      to 26 respectively. The numbers 'AA' to 'ZZ' represent the numbers
+     *      27 to 52, the numbers 'AAA' to 'ZZZ' represent the numbers 53 to
+     *      78, and so on.
+     *
+     * @returns {Number|Null}
+     *  The decimal value of the passed alphabetic number (zero for the empty
+     *  string); or null, if the passed text contains any invalid characters.
+     */
+    Parser.parseAlphabetic = function (text, method) {
+
+        // accept empty strings
+        if (text.length === 0) { return 0; }
+
+        text = text.toUpperCase();
+        switch (method) {
+
+            case 'digit':
+                if (!/^[A-Z]+$/.test(text)) { return null; }
+                var result = 0;
+                for (var ichar = 0; ichar < text.length; ichar += 1) {
+                    result = result * 26 + text.charCodeAt(ichar) - 64;
+                }
+                return result;
+
+            case 'repeat':
+                if (!/^([A-Z])\1*$/.test(text)) { return null; }
+                return (text.length - 1) * 26 + text.charCodeAt(0) - 64;
+        }
+
+        Utils.error('Parser.parseAlphabetic(): unknown conversion method "' + method + '"');
+        return null;
+    };
+
+    /**
+     * Tries to parse the passed text as a roman number.
+     *
+     * @param {String} text
+     *  The text to be parsed as a roman number (case-insensitive).
+     *
+     * @returns {Number|Null}
+     *  The decimal value of the passed roman number (zero for the empty
+     *  string); or null, if the passed text contains any invalid characters.
+     */
+    Parser.parseRoman = function (text) {
+
+        // the intermediate result
+        var result = 0;
+        // the largest roman digit found so far
+        var max = 1;
+
+        // process all roman digits in reversed order
+        Utils.iterateArray(text.toUpperCase(), function (digit) {
+
+            // convert digit to the decimal number, exit on invalid characters
+            var value = LocaleData.ROMAN_DIGITS[digit];
+            if (!value) {
+                result = null;
+                return Utils.BREAK;
+            }
+
+            // if the digit is less than the maximum digit found so far, subtract it from the result
+            result += (value < max) ? -value : value;
+            max = Math.max(max, value);
+
+        }, { reverse: true });
+
+        return result;
+    };
+
     /**
      * Tries to find a currency expression from the following part of the
      * passed string.
@@ -1210,30 +1282,23 @@ define('io.ox/office/tk/locale/parser', [
      *  The text potentially ends with a currency expression.
      *
      * @returns {Boolean}
-     *  If a currency expression found at the end, return true. Otherwise false.
+     *  Whether a currency expression found at the end.
      */
     Parser.checkFollowingCurrency = (function () {
-        var currencyTest = getCurrencyMatchingRegExp({ leading: false });
-
-        function parseFollowingCurrency(text) {
-            return (currencyTest.exec(text) !== null);
-        }
-
-        return parseFollowingCurrency;
+        var currencyTestRE = getCurrencyMatchingRegExp({ leading: false });
+        return function (text) { return currencyTestRE.test(text); };
     }());
 
-    Parser.parseLeadingCurrency = (function () {
-        return function (string, options) {
-            var sign = Utils.getStringOption(options, 'sign', LocaleData.CURRENCY),
-                code = Utils.getStringOption(options, 'code', LocaleData.ISO_CURRENCY),
-                regExSign = _.escapeRegExp(sign),
-                regExCode = _.escapeRegExp(code),
-                regEx = new RegExp('^([-+]*)\\s*(' + regExSign + '|' + regExCode + ')\\s*(.+)$'),
-                result = regEx.exec(string);
+    Parser.parseLeadingCurrency = function (string, options) {
+        var sign = Utils.getStringOption(options, 'sign', LocaleData.CURRENCY),
+            code = Utils.getStringOption(options, 'code', LocaleData.ISO_CURRENCY),
+            regExSign = _.escapeRegExp(sign),
+            regExCode = _.escapeRegExp(code),
+            regEx = new RegExp('^([-+]*)\\s*(' + regExSign + '|' + regExCode + ')\\s*(.+)$'),
+            result = regEx.exec(string);
 
-            return result ? [result[0], result[1] + result[3], result[2]] : null;
-        };
-    }());
+        return result ? [result[0], result[1] + result[3], result[2]] : null;
+    };
 
     Parser.parseLeadingPercent = (function () {
         var regEx = /^([+-]?)\s*%\s*(.+)$/;
@@ -1368,7 +1433,7 @@ define('io.ox/office/tk/locale/parser', [
             // parse the floating-point number
             var number = parseFloat(numberText.replace(dec, '.'));
 
-            if (!_.isFinite(number)) { return null; }
+            if (!isFinite(number)) { return null; }
             if (signText === '-') { number = -number; }
 
             // build the result descriptor
@@ -1529,12 +1594,12 @@ define('io.ox/office/tk/locale/parser', [
 
             // convert the matched date components to numbers
             _.each(comps, function (comp, index) {
-                var parsedVal = parseInt(matches[index + 1], 10);
-                result[comp] = (_.isFinite(parsedVal)) ? parsedVal : matches[index + 1];
+                var number = parseInt(matches[index + 1], 10);
+                result[comp] = isFinite(number) ? number : matches[index + 1];
             });
 
             // zero-based month (by convention, as used everywhere else, e.g. in class Date)
-            if (_.isFinite(result.M)) { result.M -= 1; }
+            if (Utils.isFiniteNumber(result.M)) { result.M -= 1; }
 
             return result;
         }
