@@ -22,11 +22,11 @@ define('io.ox/office/tk/popup/basemenu', [
 
     'use strict';
 
-    var // events registered at the document while the menu is open
-        DOCUMENT_EVENTS = 'mousedown touchstart',
+    // events registered at the document while the menu is open
+    var DOCUMENT_EVENTS = 'mousedown touchstart';
 
-        // whether pop-up nodes remain open when losing focus (for debugging)
-        DEBUG_STICKY_POPUPS = Config.getDebugUrlFlag('office:sticky-popups');
+    // whether pop-up nodes remain open when losing focus (for debugging)
+    var DEBUG_STICKY_POPUPS = Config.getDebugUrlFlag('office:sticky-popups');
 
     // class BaseMenu =========================================================
 
@@ -44,6 +44,12 @@ define('io.ox/office/tk/popup/basemenu', [
      *
      * @extends BasePopup
      *
+     * @param {String|Object} windowId
+     *  The identifier of the root window of the context application owning the
+     *  pop-up menu object, or an object with a method 'getWindowId' that
+     *  returns such a window identifier. Used for debugging and logging of
+     *  running timers in automated test environments.
+     *
      * @param {Object} [initOptions]
      *  Initial options to control the properties of the pop-up menu element.
      *  Supports all options also supported by the base class BasePopup.
@@ -75,29 +81,29 @@ define('io.ox/office/tk/popup/basemenu', [
      *      called with the DOM node bound to the symbol 'this'. See the jQuery
      *      API documentation at http://api.jquery.com/filter for details.
      */
-    function BaseMenu(initOptions) {
+    function BaseMenu(windowId, initOptions) {
 
-        var // self reference
-            self = this,
+        // self reference
+        var self = this;
 
-            // whether to focus the menu after it has been opened
-            autoFocus = Utils.getBooleanOption(initOptions, 'autoFocus', true),
+        // whether to focus the menu after it has been opened
+        var autoFocus = Utils.getBooleanOption(initOptions, 'autoFocus', true);
 
-            // whether to close the menu automatically after losing focus
-            autoClose = Utils.getBooleanOption(initOptions, 'autoClose', true),
+        // whether to close the menu automatically after losing focus
+        var autoClose = Utils.getBooleanOption(initOptions, 'autoClose', true);
 
-            // static collection of DOM elements preventing auto-close of the menu
-            focusableNodes = $(),
+        // static collection of DOM elements preventing auto-close of the menu
+        var focusableNodes = $();
 
-            // dynamic callbacks for additional focusable DOM elements preventing auto-close
-            focusableNodeResolvers = [],
+        // dynamic callbacks for additional focusable DOM elements preventing auto-close
+        var focusableNodeResolvers = [];
 
-            // filter selector for preferred focusable elements
-            preferFocusFilter = Utils.getOption(initOptions, 'preferFocusFilter');
+        // filter selector for preferred focusable elements
+        var preferFocusFilter = Utils.getOption(initOptions, 'preferFocusFilter');
 
         // base constructor ---------------------------------------------------
 
-        BasePopup.call(this, initOptions);
+        BasePopup.call(this, windowId, initOptions);
 
         // private methods ----------------------------------------------------
 
@@ -111,11 +117,11 @@ define('io.ox/office/tk/popup/basemenu', [
             // bug 33548: treat IE's focus helper node as focusable node (see Utils.clearBrowserSelection() for details)
             if ($(node).is('.focus-helper')) { return true; }
 
-            var // all focusable nodes (start with static nodes)
-                allFocusableNodes = focusableNodes;
+            // all focusable nodes (start with static nodes)
+            var allFocusableNodes = focusableNodes;
 
             // add dynamic focusable nodes
-            _.each(focusableNodeResolvers, function (resolver) {
+            focusableNodeResolvers.forEach(function (resolver) {
                 allFocusableNodes = allFocusableNodes.add(resolver.call(self));
             });
 
@@ -145,9 +151,7 @@ define('io.ox/office/tk/popup/basemenu', [
         function autoFocusContentNode() {
 
             if (autoFocus && (!Utils.isSoftKeyboardOpen() || Utils.shouldHideSoftKeyboard())) {
-
                 Utils.setFocus(self.getContentNode());
-
             }
         }
 
@@ -196,7 +200,7 @@ define('io.ox/office/tk/popup/basemenu', [
                 if (self.isVisible()) {
                     self.listenTo($(document), DOCUMENT_EVENTS, globalClickHandler);
                 }
-            }, { infoString: 'BaseMenu: popupShowHandler' });
+            }, 'BaseMenu.popupShowHandler');
         }
 
         /**
@@ -268,12 +272,12 @@ define('io.ox/office/tk/popup/basemenu', [
             // do nothing if a descendant of the content node is already focused
             if (Forms.containsFocus(this.getContentNode())) { return this; }
 
-            var // all focusable control elements
-                focusNodes = Forms.findFocusableNodes(this.getNode()),
-                // the preferred controls returned by the callback function
-                preferredNodes = preferFocusFilter ? focusNodes.filter(preferFocusFilter) : focusNodes,
-                // whether to select the last control
-                bottom = Utils.getBooleanOption(options, 'bottom', false);
+            // all focusable control elements
+            var focusNodes = Forms.findFocusableNodes(this.getNode());
+            // the preferred controls returned by the callback function
+            var preferredNodes = preferFocusFilter ? focusNodes.filter(preferFocusFilter) : focusNodes;
+            // whether to select the last control
+            var bottom = Utils.getBooleanOption(options, 'bottom', false);
 
             // fall back to all focusable controls if no preferred controls are available
             if (preferredNodes.length === 0) {
