@@ -13,12 +13,13 @@
  */
 
 define('io.ox/office/tk/popup/listmenu', [
+    'io.ox/office/tk/config',
     'io.ox/office/tk/utils',
     'io.ox/office/tk/keycodes',
     'io.ox/office/tk/forms',
     'io.ox/office/tk/popup/basemenu',
-    'settings!io.ox/office'
-], function (Utils, KeyCodes, Forms, BaseMenu, Settings) {
+    'gettext!io.ox/office/tk/main'
+], function (Config, Utils, KeyCodes, Forms, BaseMenu, gt) {
 
     'use strict';
 
@@ -31,6 +32,20 @@ define('io.ox/office/tk/popup/listmenu', [
     // The internal identifier for the most recently used section.
     var MRU_SECTION_ID = '__MRU__';
 
+    // private global functions ===============================================
+
+    /**
+     * Returns the negated current time stamp, used as sorting index for list
+     * entries in the MRU list, to pull the most recently used entry to the top
+     * of the list.
+     *
+     * @returns {Number}
+     *  A sorting index for the MRU list.
+     */
+    function createMRUSortIndex() {
+        return -_.now();
+    }
+
     // class ListMenu =========================================================
 
     /**
@@ -72,6 +87,12 @@ define('io.ox/office/tk/popup/listmenu', [
      *
      * @extends BaseMenu
      *
+     * @param {String|Object} windowId
+     *  The identifier of the root window of the context application owning the
+     *  list menu object, or an object with a method 'getWindowId' that returns
+     *  such a window identifier. Used for debugging and logging of running
+     *  timers in automated test environments.
+     *
      * @param {Object} [initOptions]
      *  Initial options for the item list menu element. Supports all options
      *  also supported by the base class BaseMenu. Additionally, the following
@@ -81,11 +102,11 @@ define('io.ox/office/tk/popup/listmenu', [
      *      selected, deselected, or kept unmodified according to a specific
      *      value. Receives an arbitrary value as first parameter, and the
      *      value of the current list item element as second parameter. The
-     *      function must return the Boolean value true to select the
-     *      respective list item element, the Boolean value false to deselect
-     *      the list item element, or any other value to leave the list item
-     *      element unmodified. If omitted, uses _.isEqual() which compares
-     *      arrays and objects deeply, and does not skip any list item.
+     *      function must return true to select the respective list item
+     *      element, false to deselect the list item element, or any other
+     *      value to leave the list item element unmodified. If omitted, uses
+     *      _.isEqual() which compares arrays and objects deeply, and does not
+     *      skip any list item.
      *  @param {Boolean} [options.multiSelect=true]
      *      If set to false, only the first matching element will be selected.
      *  @param {String} [options.title]
@@ -102,7 +123,8 @@ define('io.ox/office/tk/popup/listmenu', [
      *      If set to true, the list items will be sorted according to the sort
      *      order that has been specified via the 'sortIndex' options of each
      *      inserted list item (see method ListMenu.createItemNode() for
-     *      details).
+     *      details). This value can be overridden for single menu sections by
+     *      passing this option to the method ListMenu.createSectionNode().
      *  @param {Number} [options.gridColumns=10]
      *      The default number of columns in each menu section in 'grid' design
      *      mode (see option 'itemDesign' above). This value can be overridden
@@ -111,14 +133,13 @@ define('io.ox/office/tk/popup/listmenu', [
      *  @param {Number} [options.mruSize=0]
      *      The maximum number of entries shown in the most recently used list.
      *      If the list size is exceeded, the first added item will be removed.
+     *  @param {Boolean} [options.mruLabel=false]
+     *      If set to true, the most recently used list will have a title.
      *  @param {String} [options.mruSettingsKey]
      *      If specified, the contents of the most recently used list will be
      *      stored into the user settings under that key.
-     *  @param {Array<String>} [options.mruBlackList]
-     *      The item values which should not be added to the most recently used
-     *      list.
      */
-    function ListMenu(initOptions) {
+    function ListMenu(windowId, initOptions) {
 
         // self reference
         var self = this;
@@ -133,7 +154,7 @@ define('io.ox/office/tk/popup/listmenu', [
         var design = Utils.getStringOption(initOptions, 'itemDesign', 'list');
 
         // whether the list items will be sorted
-        var sorted = Utils.getBooleanOption(initOptions, 'sortItems', false);
+        var defSorted = Utils.getBooleanOption(initOptions, 'sortItems', false);
 
         // default number of columns in each section node ('grid' design mode)
         var defColumns = Utils.getIntegerOption(initOptions, 'gridColumns', 10, 1);
@@ -141,23 +162,21 @@ define('io.ox/office/tk/popup/listmenu', [
         // the maximum size of the MRU list
         var mruSize = Utils.getIntegerOption(initOptions, 'mruSize', 0);
 
+        // label text for the MRU section
+        var mruLabel = Utils.getBooleanOption(initOptions, 'mruLabel', false) ? gt('Recently used') : null;
+
         // the key to store the MRU list in the user settings
         var mruSettingsKey = Utils.getStringOption(initOptions, 'mruSettingsKey', null);
 
-        // values of all items not to be added to the MRU list
-        var mruBlackList = Utils.getArrayOption(initOptions, 'mruBlackList', []);
-
-        // label text for the recently used section
-        var mruLabel = Utils.getStringOption(initOptions, 'mruLabel', '');
+        // the comperator to sort the list items.
+        var itemComparator = Utils.getFunctionOption(initOptions, 'itemComparator', null);
 
         // the actual list of most recently used items
         var mruList = null;
 
-        var selectedItemsOnBeforeOpen;
-
         // base constructor ---------------------------------------------------
 
-        BaseMenu.call(this, Utils.extendOptions({
+        BaseMenu.call(this, windowId, Utils.extendOptions({
             scrollPadding: 5,
             preferFocusFilter: Forms.SELECTED_SELECTOR
         }, initOptions, {
@@ -178,10 +197,10 @@ define('io.ox/office/tk/popup/listmenu', [
                 return;
             }
 
-            var // all section nodes
-                sectionNodes = self.getSectionNodes(),
-                // the total width needed to show all sections with evenly sized columns
-                totalWidth = 0;
+            // all section nodes
+            var sectionNodes = self.getSectionNodes();
+            // the total width needed to show all sections with evenly sized columns
+            var totalWidth = 0;
 
             // remove explicit widths
             self.getItemNodes().css('width', '');
@@ -189,13 +208,12 @@ define('io.ox/office/tk/popup/listmenu', [
             // calculate required width of all sections
             sectionNodes.each(function () {
 
-                var // all button nodes in the current section
-                    buttonNodes = $(this).find(Forms.BUTTON_SELECTOR),
-                    // maximum width of the button elements, used as grid column width
-                    //maxWidth = _.max(buttonNodes.get(), function (node) { return Utils.getCeilNodeSize(node).width; });
-                    maxWidth = _.max(_.map(buttonNodes.get(), function (node) {
-                        return Utils.getCeilNodeSize(node).width;
-                    }));
+                // all button nodes in the current section
+                var buttonNodes = $(this).find(Forms.BUTTON_SELECTOR);
+                // maximum width of the button elements, used as grid column width
+                var maxWidth = _.max(buttonNodes.get().map(function (node) {
+                    return Utils.getCeilNodeSize(node).width;
+                }));
 
                 // update total width with the width requited by the current section
                 totalWidth = Math.max(totalWidth, maxWidth * $(this).data('grid-columns'));
@@ -212,11 +230,12 @@ define('io.ox/office/tk/popup/listmenu', [
          */
         var sortSectionNode = (function () {
 
-            var // all section nodes to be sorted
-                sectionNodes = $();
+            // all section nodes to be sorted
+            var sectionNodes = $();
 
             // direct callback: register a section node
             function registerSectionNode(sectionNode) {
+                if (typeof sectionNode === 'string') { sectionNode = self.getSectionNode(sectionNode); }
                 // jQuery keeps the collection unique
                 sectionNodes = sectionNodes.add(sectionNode);
             }
@@ -230,18 +249,23 @@ define('io.ox/office/tk/popup/listmenu', [
                     // process all registered section nodes
                     sectionNodes.each(function () {
 
-                        var // the current section node
-                            sectionNode = $(this),
-                            // all existing item buttons in the section, as plain array (for sorting)
-                            buttonNodes = sectionNode.find(Forms.BUTTON_SELECTOR).get(),
-                            // cell nodes in grid design
-                            cellNodes = null;
+                        // the current section node
+                        var sectionNode = $(this);
+                        // all existing item buttons in the section, as plain array (for sorting)
+                        var buttonNodes = sectionNode.find(Forms.BUTTON_SELECTOR).get();
+                        // cell nodes in grid design
+                        var cellNodes = null;
 
-                        // sort by fixed index, default to label text of the button
-                        buttonNodes = _.sortBy(buttonNodes, function (btnNode) {
-                            var index = $(btnNode).data('index');
-                            return _.isNull(index) ? $(btnNode).text().toLowerCase() : index;
-                        });
+                        if (itemComparator) {
+                            // sort the nodes by a special item comparator
+                            buttonNodes = buttonNodes.sort(itemComparator);
+                        } else {
+                            // sort by fixed index, default to label text of the button
+                            buttonNodes = _.sortBy(buttonNodes, function (btnNode) {
+                                var index = Utils.getOption($(btnNode).data('options'), 'sortIndex', null);
+                                return (index === null) ? $(btnNode).text().toLowerCase() : index;
+                            });
+                        }
 
                         // insert button nodes depending on design mode
                         switch (design) {
@@ -250,7 +274,7 @@ define('io.ox/office/tk/popup/listmenu', [
                                 break;
                             case 'grid':
                                 cellNodes = sectionNode.find('>.grid-row>.grid-cell');
-                                _.each(buttonNodes, function (btnNode, index) {
+                                buttonNodes.forEach(function (btnNode, index) {
                                     cellNodes.eq(index).append(btnNode);
                                 });
                                 break;
@@ -262,7 +286,7 @@ define('io.ox/office/tk/popup/listmenu', [
                 });
             }
 
-            return self.createDebouncedMethod(registerSectionNode, sortAllSectionNodes, { infoString: 'ListMenu sortSectionNode()' });
+            return self.createDebouncedMethod('ListMenu.sortSectionNode', registerSectionNode, sortAllSectionNodes);
         }());
 
         /**
@@ -270,8 +294,8 @@ define('io.ox/office/tk/popup/listmenu', [
          */
         function keyDownHandler(event) {
 
-            var // the list item to be focused
-                targetNode = self.getItemNodeForKeyEvent(event, $(event.target));
+            // the list item to be focused
+            var targetNode = self.getItemNodeForKeyEvent(event, $(event.target));
 
             // stop event propagation for all supported keys
             if (targetNode.length > 0) {
@@ -308,70 +332,34 @@ define('io.ox/office/tk/popup/listmenu', [
         }
 
         /**
-         * Check if the item is stored in the most recently list.
-         * @param {String} value the value for check
-         * @returns {Boolean} true an item the given value is stored to the list, otherwise false
+         * Pushes the passed value into the MRU list, and saves the entire list
+         * to the user configuration.
+         *
+         * @param {Any} value
+         *  The value to be added to the MRU list.
          */
-        function containsMostRecentlyItem(value) {
-            return _.findWhere(mruList, { value: value });
-        }
-
-        /**
-         * Add a value to the most recently list and create a node for the most recently used section.
-         * If the item size is reached, the first added item will be removed.
-         * @param {String} value see@ createItemNode(value, options)
-         * @param {Object} options see@ createItemNode(value, options)
-         */
-        function addValueToMRUList(value, options) {
-            if (mruList && value && !_.contains(mruBlackList, value) && !_.isEmpty(options) && !containsMostRecentlyItem(value)) {
-                options.section = MRU_SECTION_ID;
-                options.append = false;
-                if (mruList.length >= mruSize) {
-                    self.deleteItemNodes(mruList.shift().value, MRU_SECTION_ID);
-                }
-                mruList.push({ value: value, options: options });
-                self.createItemNode(value, options);
-                return true;
+        function pushMRUValue(value) {
+            mruList.push(value);
+            if (mruSettingsKey) {
+                Config.set(mruSettingsKey, mruList);
             }
-            return false;
         }
 
         /**
-         * Fills the most recently used list with the words from the settings
-         * and add the items to the most recently used section. If the section
-         * for the most recently items is not created, the section will be
-         * added.
+         * Creates a list item in the MRU list section.
+         *
+         * @param {Any} mruValue
+         *  The value of the list item.
          */
-        function initializeMRUList() {
+        function createMRUItemNode(value) {
 
-            mruList = [];
+            // obtain the formatting options of an existing button node, needed to create a new button node
+            var origOptions = self.findItemNodes(value).first().data('options');
+            // modify options for insertion into the MRU section
+            var mruOptions = Utils.extendOptions(origOptions || {}, { section: MRU_SECTION_ID, sortIndex: createMRUSortIndex() });
 
-            // resolve predefined list entries from configuration
-            var mruValues = mruSettingsKey ? Settings.get(mruSettingsKey, []) : null;
-            if (!_.isArray(mruValues)) { return; }
-
-            mruValues.forEach(function (item) {
-                var itemNodes = self.findItemNodes(item.value);
-                if (itemNodes.length > 0) {
-                    var data = itemNodes.data();
-                    addValueToMRUList(data.value, data.options);
-                }
-            });
-        }
-
-        function updateMRUList() {
-            _.each(self.getSelectedItemNodes(), function (obj, i, item) {
-
-                if (!_.find(selectedItemsOnBeforeOpen, function (itemBefore) {
-                    return item.data().value === $(itemBefore).data().value;
-                })) {
-
-                    var added = addValueToMRUList(item.data().value, item.data().options);
-                    if (added && mruSettingsKey) {
-                        Settings.set(mruSettingsKey, mruList).save();
-                    }
-                }
-            });
+            // create the button node in the MRU section
+            self.createItemNode(value, mruOptions);
         }
 
         // public methods -----------------------------------------------------
@@ -390,10 +378,10 @@ define('io.ox/office/tk/popup/listmenu', [
          */
         this.guardFocusedListItem = function (callback, context) {
 
-            var // the focused list item
-                focusNode = this.getItemNodes().filter(':focus'),
-                // value of the focused list item (bug 33737, 33747: preserve browser focus)
-                value = Forms.getButtonValue(focusNode.first());
+            // the focused list item
+            var focusNode = this.getItemNodes().filter(':focus');
+            // value of the focused list item (bug 33737, 33747: preserve browser focus)
+            var value = Forms.getButtonValue(focusNode.first());
 
             // invoke passed callback function
             callback.call(context);
@@ -421,6 +409,12 @@ define('io.ox/office/tk/popup/listmenu', [
          *  Optional parameters:
          *  @param {String} [options.label]
          *      If specified, a heading label will be created for the section.
+         *  @param {Boolean} [initOptions.sortItems]
+         *      Whether the list items will be sorted according to the sort
+         *      order that has been specified via the 'sortIndex' options of
+         *      each inserted list item (see method ListMenu.createItemNode()
+         *      for details). If omitted, the default value for this option as
+         *      specified in the constructor options will be used.
          *  @param {Number} [options.gridColumns]
          *      The number of columns in the menu section, if this menu is in
          *      'grid' design mode (see option 'itemDesign' passed to the
@@ -432,8 +426,8 @@ define('io.ox/office/tk/popup/listmenu', [
          */
         this.createSectionNode = function (sectionId, options) {
 
-            var // try to find an existing section node
-                sectionNode = this.getSectionNode(sectionId);
+            // try to find an existing section node
+            var sectionNode = this.getSectionNode(sectionId);
 
             if (sectionNode.length === 0) {
 
@@ -446,7 +440,8 @@ define('io.ox/office/tk/popup/listmenu', [
                 // create the section root node
                 sectionNode = $('<div class="' + SECTION_CLASS + ' group ' + Forms.HIDDEN_CLASS + '" data-section="' + sectionId + '">' + headerMarkup + '</div>');
 
-                // add the number of grid columns as jQuery data attribute
+                // add the sort state and the number of grid columns as jQuery data attribute
+                sectionNode.data('sort-items', Utils.getBooleanOption(options, 'sortItems', defSorted));
                 sectionNode.data('grid-columns', Utils.getIntegerOption(options, 'gridColumns', defColumns, 1));
 
                 // add ARIA role for grid design
@@ -508,21 +503,22 @@ define('io.ox/office/tk/popup/listmenu', [
          *      of the 'value' parameter will be used instead (all double-quote
          *      characters will be removed from the string though), unless the
          *      value is a function.
-         *  @param {Boolean} [options.append=true]
-         *      If TRUE append (default) append the Node to the list, otherwise
-         *      prepend the Node to the list.
+         *  @param {Number|String} [options.sortIndex=0]
+         *      Sorting index for the new list item. All items will be sorted
+         *      relatively to their index. Sorting will be stable, multiple
+         *      items with the same index will remain in insertion order.
          *
          * @returns {jQuery}
-         *  The button element representing the new list item, as jQuery
-         *  object.
+         *  The DOM button element representing the new list item, as jQuery
+         *  object. The options passed to this method have been stored as
+         *  jQuery data property 'options'.
          */
         this.createItemNode = function (value, options) {
 
-            var // the root node of the menu section
-                sectionNode = this.createSectionNode(Utils.getStringOption(options, 'section', '')),
-                // create the button element representing the item
-                buttonNode = $(Forms.createButtonMarkup(options)),
-                append = Utils.getBooleanOption(options, 'append', true);
+            // the root node of the menu section
+            var sectionNode = this.createSectionNode(Utils.getStringOption(options, 'section', ''));
+            // create the button element representing the item
+            var buttonNode = $(Forms.createButtonMarkup(options));
 
             // make section node visible (initially hidden)
             Forms.showNodes(sectionNode, true);
@@ -530,17 +526,13 @@ define('io.ox/office/tk/popup/listmenu', [
             // initialize button node
             Forms.setButtonValue(buttonNode, value, options);
             Forms.setToolTip(buttonNode, options);
-            buttonNode.data('index', Utils.getOption(options, 'sortIndex', null));
+            buttonNode.data('options', options);
             buttonNode.attr('role', 'option');
 
             // insert the new button according to the design mode
             switch (design) {
                 case 'list':
-                    if (append) {
-                        sectionNode.append(buttonNode);
-                    } else {
-                        sectionNode.prepend(buttonNode);
-                    }
+                    sectionNode.append(buttonNode);
                     break;
                 case 'grid':
                     // create a new row element for the button if required
@@ -550,16 +542,12 @@ define('io.ox/office/tk/popup/listmenu', [
                     }
                     // append the button to the row (wrap into a helper node for ARIA)
                     var cellNode = $('<div class="grid-cell" role="gridcell">').attr('aria-label', buttonNode.attr('aria-label') || '').append(buttonNode);
-                    if (append) {
-                        rowNode.append(cellNode);
-                    } else {
-                        rowNode.prepend(cellNode);
-                    }
+                    rowNode.append(cellNode);
                     break;
             }
 
             // sort the button nodes in the section
-            if (sorted) {
+            if (sectionNode.data('sort-items')) {
                 sortSectionNode(sectionNode);
             }
 
@@ -575,29 +563,25 @@ define('io.ox/office/tk/popup/listmenu', [
          *  The value associated to the list item. MUST NOT be null.
          *
          * @param {String} [sectionId]
-         *  The unique identifier of the menu section, to delete only the buttons in
-         *  the given section, if the value is not unique. Otherwise delete all buttons
-         *  with the given value.
+         *  The unique identifier of a menu section to delete the list item
+         *  from. If omitted, all list items with the passed value will be
+         *  deleted.
          *
          * @returns {ListMenu}
          *  A reference to this instance.
          */
         this.deleteItemNodes = function (value, sectionId) {
 
-            var // all item buttons to be deleted
-                buttonNodes = this.findItemNodes(value),
-                // all modified section nodes
-                sectionNodes = $();
+            // all item buttons to be deleted
+            var buttonNodes = this.findItemNodes(value, sectionId);
+            // all modified section nodes
+            var sectionNodes = $();
 
             // collect modified section nodes, notify listeners
-            buttonNodes = buttonNodes.filter(function () {
+            buttonNodes.each(function () {
                 var buttonNode = $(this);
-                if (!_.isString(sectionId) || buttonNode.parents().filter('[data-section="' + sectionId + '"]').length > 0) {
-                    sectionNodes = sectionNodes.add(buttonNode.closest('.' + SECTION_CLASS));
-                    self.trigger('delete:item', buttonNode, value);
-                    return true;
-                }
-                return false;
+                sectionNodes = sectionNodes.add(buttonNode.closest('.' + SECTION_CLASS));
+                self.trigger('delete:item', buttonNode, value);
             });
 
             // remove button nodes from DOM
@@ -606,8 +590,8 @@ define('io.ox/office/tk/popup/listmenu', [
             // update nodes in grid design mode, hide empty sections
             sectionNodes.each(function () {
 
-                var // current section node
-                    sectionNode = $(this);
+                // current section node
+                var sectionNode = $(this);
 
                 // all existing buttons in the section
                 buttonNodes = sectionNode.find(Forms.BUTTON_SELECTOR);
@@ -615,8 +599,8 @@ define('io.ox/office/tk/popup/listmenu', [
                 // reinsert buttons in grid design mode
                 if (design === 'grid') {
                     // redistribute all buttons without moving the cell nodes
-                    var rowNodes = sectionNode.find('>.grid-row'),
-                        cellNodes = rowNodes.find('>.grid-cell');
+                    var rowNodes = sectionNode.find('>.grid-row');
+                    var cellNodes = rowNodes.find('>.grid-cell');
                     buttonNodes.each(function (index) {
                         cellNodes.eq(index).append(this);
                     });
@@ -636,12 +620,17 @@ define('io.ox/office/tk/popup/listmenu', [
          * Returns all button elements representing the menu items of this
          * list.
          *
+         * @param {String} [sectionId]
+         *  The unique identifier of a menu section. If omitted, all existing
+         *  sections will be searched for the item nodes.
+         *
          * @returns {jQuery}
          *  All button elements representing the menu items in this item list,
          *  as jQuery collection.
          */
-        this.getItemNodes = function () {
-            return this.getNode().find(Forms.BUTTON_SELECTOR);
+        this.getItemNodes = function (sectionId) {
+            var sectionNodes = sectionId ? this.getSectionNode(sectionId) : this.getSectionNodes();
+            return sectionNodes.find(Forms.BUTTON_SELECTOR);
         };
 
         /**
@@ -651,24 +640,32 @@ define('io.ox/office/tk/popup/listmenu', [
          * @param {Any} value
          *  The value whose list item buttons will be returned.
          *
+         * @param {String} [sectionId]
+         *  The unique identifier of a menu section to search in. If omitted,
+         *  all existing sections will be searched for the item nodes.
+         *
          * @returns {jQuery}
          *  The button elements representing the list items with the specified
          *  value, as jQuery collection.
          */
-        this.findItemNodes = function (value) {
-            return Forms.filterButtonNodes(this.getItemNodes(), value, { matcher: itemMatcher, multiSelect: multiSelect });
+        this.findItemNodes = function (value, sectionId) {
+            return Forms.filterButtonNodes(this.getItemNodes(sectionId), value, { matcher: itemMatcher, multiSelect: multiSelect });
         };
 
         /**
          * Returns the button elements representing all selected list items in
          * this list menu.
          *
+         * @param {String} [sectionId]
+         *  The unique identifier of a menu section. If omitted, all existing
+         *  sections will be searched for selected item nodes.
+         *
          * @returns {jQuery}
          *  The button elements representing all selected list items, as jQuery
          *  collection.
          */
-        this.getSelectedItemNodes = function () {
-            return Forms.filterCheckedButtonNodes(this.getItemNodes());
+        this.getSelectedItemNodes = function (sectionId) {
+            return Forms.filterCheckedButtonNodes(this.getItemNodes(sectionId));
         };
 
         /**
@@ -763,8 +760,8 @@ define('io.ox/office/tk/popup/listmenu', [
          */
         this.getItemNodeForKeyEvent = function (keyEvent, buttonNode) {
 
-            var // all visible button nodes
-                buttonNodes = Forms.filterVisibleNodes(self.getItemNodes());
+            // all visible button nodes
+            var buttonNodes = Forms.filterVisibleNodes(self.getItemNodes());
 
             // returns the number of list items currently visible
             function getListPageSize() {
@@ -775,8 +772,8 @@ define('io.ox/office/tk/popup/listmenu', [
             // returns the previous or next item node according to the passed distance
             function getNextItemNode(diff, wrap) {
 
-                var // index of the focused button
-                    index = buttonNodes.index(buttonNode);
+                // index of the focused button
+                var index = buttonNodes.index(buttonNode);
 
                 if (index < 0) {
                     index = (diff < 0) ? (buttonNodes.length - 1) : 0;
@@ -809,20 +806,20 @@ define('io.ox/office/tk/popup/listmenu', [
             // returns the item node in the previous or next row in 'grid' design
             function getItemNodeInNextRow(diff) {
 
-                var // the cell node containing the focused button
-                    cellNode = buttonNode.parent(),
-                    // the row node containing the focused button
-                    rowNode = cellNode.parent(),
-                    // all button elements in the focused row
-                    rowButtonNodes = rowNode.children().children(),
-                    // all row nodes in all sections
-                    rowNodes = self.getSectionNodes().find('>.grid-row'),
-                    // the column index of the cell in the row
-                    colIndex = cellNode.index(),
-                    // the global row index of the cell
-                    rowIndex = rowNodes.index(rowNode),
-                    // the relative column index of the cell
-                    colRatio = (colIndex >= 0) ? (colIndex / rowButtonNodes.length) : 0;
+                // the cell node containing the focused button
+                var cellNode = buttonNode.parent();
+                // the row node containing the focused button
+                var rowNode = cellNode.parent();
+                // all button elements in the focused row
+                var rowButtonNodes = rowNode.children().children();
+                // all row nodes in all sections
+                var rowNodes = self.getSectionNodes().find('>.grid-row');
+                // the column index of the cell in the row
+                var colIndex = cellNode.index();
+                // the global row index of the cell
+                var rowIndex = rowNodes.index(rowNode);
+                // the relative column index of the cell
+                var colRatio = (colIndex >= 0) ? (colIndex / rowButtonNodes.length) : 0;
 
                 if ((rowNodes.length === 0) || (rowIndex < 0)) {
                     return (diff < 0) ? buttonNodes.last() : buttonNodes.first();
@@ -878,11 +875,51 @@ define('io.ox/office/tk/popup/listmenu', [
         /**
          * Returns the contents of the MRU list.
          *
-         * @returns {Array<Any>}
-         *  The contents of the MRU list.
+         * @returns {Array<Any>|Null}
+         *  The contents of the MRU list, as plain array; or null, if the MRU
+         *  list is not enabled for this list pop-up node. The last element of
+         *  the array is the entry that has been added most recently to the
+         *  list.
          */
-        this.getMRUListEntries = function () {
-            return mruList ? _.pluck(mruList, 'value') : [];
+        this.getMRUList = function () {
+            return mruList ? mruList.slice() : null;
+        };
+
+        /**
+         * Registers the specified value as most recently used, and updates the
+         * MRU section of this list pop-up node.
+         *
+         * @param {Any} value
+         *  The value to be registered as most recently used.
+         *
+         * @returns {ListMenu}
+         *  A reference to this instance.
+         */
+        this.setMRUValue = function (value) {
+
+            // nothing to do without MRU list support
+            if (!mruList) { return this; }
+
+            // try to find an existing MRU list entry, pull it to the front of the MRU list
+            var listIndex = _.findIndex(mruList, function (mruValue) { return itemMatcher(value, mruValue); });
+            var itemNode = this.findItemNodes(value, MRU_SECTION_ID).first();
+            if ((listIndex >= 0) && (itemNode.length === 1)) {
+                mruList.splice(listIndex, 1);
+                pushMRUValue(value);
+                itemNode.data('options').sortIndex = createMRUSortIndex();
+                sortSectionNode(MRU_SECTION_ID);
+                return this;
+            }
+
+            // remove the last item from the MRU list if necessary
+            if (mruList.length === mruSize) {
+                this.deleteItemNodes(mruList.shift(), MRU_SECTION_ID);
+            }
+
+            // create a new list item in the MRU list
+            pushMRUValue(value);
+            createMRUItemNode(value);
+            return this;
         };
 
         // initialization -----------------------------------------------------
@@ -899,12 +936,16 @@ define('io.ox/office/tk/popup/listmenu', [
         // initialize the title section
         initializeTitle();
 
+        // store all MRU lists in a specific subfolder of the configuration
+        mruSettingsKey = mruSettingsKey ? ('mru/' + mruSettingsKey) : null;
+
         // initialize the MRU list
         if (mruSize > 0) {
-            this.createSectionNode(MRU_SECTION_ID, { label: mruLabel });
+            this.createSectionNode(MRU_SECTION_ID, { label: mruLabel, sortItems: true });
             multiSelect = false;
-            this.one('popup:beforeshow', initializeMRUList);
-            this.on('popup:beforehide', updateMRUList);
+            mruList = mruSettingsKey ? Config.get(mruSettingsKey, null) : null;
+            mruList = _.isArray(mruList) ? mruList.slice(0, mruSize) : [];
+            this.one('popup:beforeshow', function () { mruList.forEach(createMRUItemNode); });
         }
 
         // destroy all class members on destruction
