@@ -16,8 +16,9 @@ define('io.ox/office/tk/render/canvas', [
     'io.ox/office/tk/utils',
     'io.ox/office/tk/object/baseobject',
     'io.ox/office/tk/render/colorutils',
-    'io.ox/office/tk/render/path'
-], function (Utils, BaseObject, ColorUtils, Path) {
+    'io.ox/office/tk/render/path',
+    'io.ox/office/tk/render/rectangle'
+], function (Utils, BaseObject, ColorUtils, Path, Rectangle) {
 
     'use strict';
 
@@ -27,6 +28,9 @@ define('io.ox/office/tk/render/canvas', [
     var isArray = _.isArray;
     var RGBModel = ColorUtils.RGBModel;
 
+    // color byte array for full transparence
+    var TRANSPARENT = [0, 0, 0, 0];
+
     // temporary canvas element used for content relocation
     var relocateCanvas = null;
 
@@ -45,27 +49,6 @@ define('io.ox/office/tk/render/canvas', [
         return isObject(rectangle) && (rectangle.width > 0) && (rectangle.height > 0);
     }
 
-    /**
-     * Returns a scaled clone of the passed rectangle.
-     *
-     * @param {Object} rectangle
-     *  The rectangle to be scaled.
-     *
-     * @param {Number} scale
-     *  The scaling factor, as floating-point value.
-     *
-     * @returns {Object}
-     *  The scaled rectangle.
-     */
-    function getScaledRectangle(rectangle, scale) {
-        return {
-            left: rectangle.left * scale,
-            top: rectangle.top * scale,
-            width: rectangle.width * scale,
-            height: rectangle.height * scale
-        };
-    }
-
     /**
      * Adds the passed color stops to the canvas gradient, and catches any
      * exceptions that may occur due to invalid input values.
@@ -203,7 +186,7 @@ define('io.ox/office/tk/render/canvas', [
      *
      * @constructor
      *
-     * @param {CanvasRenderingContext2D} context
+     * @param {CanvasRenderingContext2D} renderContext
      *  The wrapped rendering context of a canvas element.
      *
      * @param {Number} x0
@@ -214,14 +197,14 @@ define('io.ox/office/tk/render/canvas', [
      *  The global translation on the Y axis that will be applied to all path
      *  operations.
      */
-    function ContextWrapper(context, x0, y0) {
+    function ContextWrapper(renderContext, x0, y0) {
 
-        this._context = context;
+        this._context = renderContext;
         this._x0 = x0;
         this._y0 = y0;
 
         // generator for native paths in the rendering context
-        this._pathGenerator = new PathGenerator(context, x0, y0);
+        this._pathGenerator = new PathGenerator(renderContext, x0, y0);
 
         // current font settings
         this._fontStyle = {
@@ -546,6 +529,21 @@ define('io.ox/office/tk/render/canvas', [
         return this;
     };
 
+    /**
+     * Sets the global composite operation for all drawing operations (fill,
+     * stroke, text, and images).
+     *
+     * @param {String} operation
+     *  The composite operation.
+     *
+     * @returns {ContextWrapper}
+     *  A reference to this instance.
+     */
+    ContextWrapper.prototype.setGlobalComposite = function (operation) {
+        this._context.globalCompositeOperation = operation;
+        return this;
+    };
+
     /**
      * Changes the translation of the coordinate system.
      *
@@ -622,9 +620,8 @@ define('io.ox/office/tk/render/canvas', [
      * rectangular clipping region, invokes the passed callback function, and
      * restores the saved context state afterwards.
      *
-     * @param {Object|Null} rectangle
-     *  The clipping rectangle, with the numeric properties 'left', 'top',
-     *  'width', and 'height'. For convenience, can be set to null, if no
+     * @param {Rectangle|Object|Null} rectangle
+     *  The clipping rectangle. For convenience, can be set to null, if no
      *  clipping rectangle is available (conditional clipping without having to
      *  repeat the code executed in the callback).
      *
@@ -722,7 +719,7 @@ define('io.ox/office/tk/render/canvas', [
     /**
      * Renders a rectangle into the wrapped canvas element.
      *
-     * @param {Number|Object} x
+     * @param {Number|Rectangle|Object} x
      *  The X coordinate of the starting point of the rectangle, or a complete
      *  rectangle with the numeric properties 'left', 'top', 'width', and
      *  'height'.
@@ -809,7 +806,7 @@ define('io.ox/office/tk/render/canvas', [
      * Clears a rectangle (sets all pixels to full transparency) in the wrapped
      * canvas element.
      *
-     * @param {Number|Object} x
+     * @param {Number|Rectangle|Object} x
      *  The X coordinate of the starting point of the rectangle, or a complete
      *  rectangle with the numeric properties 'left', 'top', 'width', and
      *  'height'.
@@ -972,7 +969,7 @@ define('io.ox/office/tk/render/canvas', [
      *
      * @constructor
      *
-     * @param {CanvasRenderingContext2D} context
+     * @param {CanvasRenderingContext2D} renderContext
      *  The wrapped rendering context of a canvas element.
      *
      * @param {Number} x0
@@ -983,17 +980,17 @@ define('io.ox/office/tk/render/canvas', [
      *  The global translation on the Y axis that will be applied to all path
      *  operations.
      */
-    function PixelWrapper(context, x0, y0) {
+    function PixelWrapper(renderContext, x0, y0) {
 
-        this._context = context;
+        this._context = renderContext;
         this._x0 = x0;
         this._y0 = y0;
 
-        this._w = context.canvas.width;
-        this._h = context.canvas.height;
+        this._w = renderContext.canvas.width;
+        this._h = renderContext.canvas.height;
 
-        this._data = context.getImageData(0, 0, this._w, this._h);
-        this._color = [0, 0, 0, 0];
+        this._data = renderContext.getImageData(0, 0, this._w, this._h);
+        this._color = TRANSPARENT;
 
     } // class PixelWrapper
 
@@ -1003,9 +1000,19 @@ define('io.ox/office/tk/render/canvas', [
         return 4 * ((y - this._y0) * this._w + x - this._x0);
     };
 
-    PixelWrapper.prototype._writePixel = function (offset) {
+    PixelWrapper.prototype._writePixel = function (offset, color) {
         for (var i = 0; i < 4; offset += 1, i += 1) {
-            this._data.data[offset] = this._color[i];
+            this._data.data[offset] = color[i];
+        }
+    };
+
+    PixelWrapper.prototype._writeRect = function (x, y, w, h, color) {
+        if (isObject(x)) { y = x.top; w = x.width; h = x.height; x = x.left; }
+        for (var y1 = y, y2 = y + h; y1 < y2; y1 += 1) {
+            var offset = this._getOffset(x, y1);
+            for (var i = 0; i < w; i += 1, offset += 4) {
+                this._writePixel(offset, color);
+            }
         }
     };
 
@@ -1064,7 +1071,7 @@ define('io.ox/office/tk/render/canvas', [
      */
     PixelWrapper.prototype.setColor = function (color) {
         var colorDesc = ColorUtils.parseColor(color);
-        this._color = colorDesc ? colorDesc.bytes : [0, 0, 0, 0];
+        this._color = colorDesc ? colorDesc.bytes : TRANSPARENT;
     };
 
     /**
@@ -1080,7 +1087,24 @@ define('io.ox/office/tk/render/canvas', [
      *  A reference to this instance.
      */
     PixelWrapper.prototype.drawPixel = function (x, y) {
-        this._writePixel(this._getOffset(x, y));
+        this._writePixel(this._getOffset(x, y), this._color);
+        return this;
+    };
+
+    /**
+     * Sets the specified pixel to full transparence.
+     *
+     * @param {Number} x
+     *  The X coordinate of the pixel.
+     *
+     * @param {Number} y
+     *  The Y coordinate of the pixel.
+     *
+     * @returns {PixelWrapper}
+     *  A reference to this instance.
+     */
+    PixelWrapper.prototype.clearPixel = function (x, y) {
+        this._writePixel(this._getOffset(x, y), TRANSPARENT);
         return this;
     };
 
@@ -1088,15 +1112,14 @@ define('io.ox/office/tk/render/canvas', [
      * Sets all pixels in the specified rectangle to the current pixel color of
      * this instance.
      *
-     * @param {Number|Object} x
+     * @param {Number|Rectangle|Object} x
      *  The X coordinate of the starting point of the rectangle, or a complete
      *  rectangle with the numeric properties 'left', 'top', 'width', and
      *  'height'.
      *
-     * @param {Number|String} y
-     *  The Y coordinate of the starting point of the rectangle. If the
-     *  parameter 'x' is a rectangle object, this parameter will be used as the
-     *  optional parameter 'mode' (see below).
+     * @param {Number} y
+     *  The Y coordinate of the starting point of the rectangle. If parameter
+     *  'x' is a rectangle object, this parameter will be ignored.
      *
      * @param {Number} w
      *  The width of the rectangle. If parameter 'x' is a rectangle object,
@@ -1110,13 +1133,35 @@ define('io.ox/office/tk/render/canvas', [
      *  A reference to this instance.
      */
     PixelWrapper.prototype.fillRect = function (x, y, w, h) {
-        if (isObject(x)) { y = x.top; w = x.width; h = x.height; x = x.left; }
-        for (var y1 = y, y2 = y + h; y1 < y2; y1 += 1) {
-            var offset = this._getOffset(x, y1);
-            for (var i = 0; i < w; i += 1, offset += 4) {
-                this._writePixel(offset);
-            }
-        }
+        this._writeRect(x, y, w, h, this._color);
+        return this;
+    };
+
+    /**
+     * Sets all pixels in the specified rectangle to full transparence.
+     *
+     * @param {Number|Rectangle|Object} x
+     *  The X coordinate of the starting point of the rectangle, or a complete
+     *  rectangle with the numeric properties 'left', 'top', 'width', and
+     *  'height'.
+     *
+     * @param {Number} y
+     *  The Y coordinate of the starting point of the rectangle. If parameter
+     *  'x' is a rectangle object, this parameter will be ignored.
+     *
+     * @param {Number} w
+     *  The width of the rectangle. If parameter 'x' is a rectangle object,
+     *  this parameter will be ignored.
+     *
+     * @param {Number} h
+     *  The height of the rectangle. If parameter 'x' is a rectangle object,
+     *  this parameter will be ignored.
+     *
+     * @returns {PixelWrapper}
+     *  A reference to this instance.
+     */
+    PixelWrapper.prototype.clearRect = function (x, y, w, h) {
+        this._writeRect(x, y, w, h, TRANSPARENT);
         return this;
     };
 
@@ -1130,6 +1175,12 @@ define('io.ox/office/tk/render/canvas', [
      *
      * @extends BaseObject
      *
+     * @param {String|Object} windowId
+     *  The identifier of the root window of the context application owning the
+     *  instances of this class, or an object with a method 'getWindowId' that
+     *  returns such a window identifier. Used for debugging and logging of
+     *  running timers and pending promises in automated test environments.
+     *
      * @param {Object} [initOptions]
      *  Optional parameters:
      *  @param {HTMLCanvasElement|jQuery} [initOptions.node]
@@ -1140,35 +1191,40 @@ define('io.ox/office/tk/render/canvas', [
      *      Additional CSS classes (space-separated list) that will be added to
      *      the passed or created <canvas> element.
      */
-    var Canvas = BaseObject.extend({ constructor: function (initOptions) {
+    var Canvas = BaseObject.extend({ constructor: function (windowId, initOptions) {
 
         // self reference
         var self = this;
 
+        // external canvas node wrapped by this instance
+        var wrappedNode = Utils.getOption(initOptions, 'node', null);
+
         // the canvas DOM element, as jQuery object
-        var $canvas = $(Utils.getOption(initOptions, 'node', '<canvas width="0" height="0">'));
+        var $canvasNode = $(wrappedNode || '<canvas width="0" height="0">');
 
         // the canvas DOM element
-        var canvas = $canvas[0];
+        var canvasNode = $canvasNode[0];
 
         // the rendering context of the canvas
-        var context = canvas.getContext('2d');
+        var renderContext = canvasNode.getContext('2d');
 
         // additional classes for the canvas element
         var classes = Utils.getStringOption(initOptions, 'classes');
 
-        // the current rectangle represented by the canvas element
+        // the current offset of the rectangle represented by the canvas element
         var x0 = 0;
         var y0 = 0;
-        var width = canvas.width;
-        var height = canvas.height;
+
+        // the current size of the rectangle represented by the canvas element (bitmap size, not CSS size)
+        var width = canvasNode.width;
+        var height = canvasNode.height;
 
         // pixel resolution (physical pixels per canvas pixel in one direction)
         var res = 1;
 
         // base constructor ---------------------------------------------------
 
-        BaseObject.call(this);
+        BaseObject.call(this, windowId);
 
         // public methods -----------------------------------------------------
 
@@ -1179,7 +1235,7 @@ define('io.ox/office/tk/render/canvas', [
          *  The wrapped canvas DOM element, as jQuery object.
          */
         this.getNode = function () {
-            return $canvas;
+            return $canvasNode;
         };
 
         /**
@@ -1197,11 +1253,11 @@ define('io.ox/office/tk/render/canvas', [
         /**
          * Returns the rectangle currently represented by this canvas wrapper.
          *
-         * @returns {Object}
+         * @returns {Rectangle}
          *  The rectangle currently represented by this canvas wrapper.
          */
         this.getRectangle = function () {
-            return { left: x0, top: y0, width: width, height: height };
+            return new Rectangle(x0, y0, width, height);
         };
 
         /**
@@ -1211,16 +1267,16 @@ define('io.ox/office/tk/render/canvas', [
          *  A data URL with the current contents of the canvas.
          */
         this.getDataURL = function () {
-            return canvas.toDataURL();
+            return canvasNode.toDataURL();
         };
 
         /**
          * Changes the size and global translation of the canvas element, and
          * clears all its contents.
          *
-         * @param {Object} rectangle
-         *  The new rectangle represented by the canvas DOM element, with the
-         *  following properties:
+         * @param {Rectangle|Object} rectangle
+         *  The new rectangle represented by the canvas DOM element (with
+         *  optional start position), with the following properties:
          *  @param {Number} [rectangle.left=0]
          *      Global horizontal translation, in pixels. A pixel drawn at this
          *      position will appear at the left border of the canvas area.
@@ -1244,7 +1300,9 @@ define('io.ox/office/tk/render/canvas', [
         this.initialize = function (rectangle, resolution) {
 
             // rescue old settings for performance optimizations
-            var oldWidth = width, oldHeight = height, oldRes = res;
+            var oldCssWidth = $canvasNode.width();
+            var oldCssHeight = $canvasNode.height();
+            var oldRes = res;
 
             // set global translation
             x0 = Utils.getIntegerOption(rectangle, 'left', 0);
@@ -1258,64 +1316,66 @@ define('io.ox/office/tk/render/canvas', [
             // the new internal size of the canvas bitmap, according to pixel resolution
             var canvasWidth = Math.ceil(width * res);
             var canvasHeight = Math.ceil(height * res);
-            var changedBitmapSize = (canvas.width !== canvasWidth) || (canvas.height !== canvasHeight);
+            var changedBitmapSize = (canvasNode.width !== canvasWidth) || (canvasNode.height !== canvasHeight);
 
             // do not touch canvas bitmap size, if it remains the same (may improve performance)
             if (changedBitmapSize) {
-                canvas.width = canvasWidth;
-                canvas.height = canvasHeight;
+                canvasNode.width = canvasWidth;
+                canvasNode.height = canvasHeight;
             }
 
             // initialize the visible size of the canvas element
-            if ((oldWidth !== width) || (oldHeight !== height)) {
-                $canvas.css({ width: width, height: height });
+            if ((oldCssWidth !== width) || (oldCssHeight !== height)) {
+                $canvasNode.css({ width: width, height: height });
             }
 
             // initialize global transformation (has been reset after changing canvas size)
             if (changedBitmapSize || (oldRes !== res)) {
                 try {
-                    context.setTransform(res, 0, 0, res, 0, 0);
+                    renderContext.setTransform(res, 0, 0, res, 0, 0);
                 } catch (ex) {
                     Utils.error('Canvas.initialize(): context.setTransform failed (' + res + '): ' + ex.stack);
                 }
             }
 
             // always clear all contents
-            context.clearRect(0, 0, width, height);
-            return this;
+            return this.clear();
         };
 
         /**
-         * Changes the rectangle represented by this canvas element. Moves the
-         * existing bitmap contents to the new position, if the current
-         * rectangle and the passed rectangle overlap each other.
+         * Changes the location covered by this canvas element. Moves the
+         * bitmap contents of the canvas to the new location, if the current
+         * location and the passed location overlap each other.
          *
-         * @param {Object} rectangle
-         *  The new rectangle represented by this canvas element. See
-         *  description of the method Canvas.initialize() for details.
+         * @param {Rectangle|Object} rectangle
+         *  The new location covered by this canvas element. See description
+         *  of the method Canvas.initialize() for details.
          *
          * @param {Number} [scale=1]
          *  The scaling factor used when copying the old bitmap contents of
-         *  this canvas element to the passed target rectangle.
+         *  this canvas element to the passed target location.
          *
-         * @returns {Array<Object>}
-         *  The positions of all remaining rectangles that could not be filled
-         *  with the old contents of the canvas element.
+         * @returns {Array<Rectangle>}
+         *  The locations of all remaining canvas areas that could not be
+         *  filled with the old contents of the canvas element.
          */
         this.relocate = function (rectangle, scale) {
 
+            // convert parameter to an instance of Rectangle
+            rectangle = Rectangle.from(rectangle);
+
             // effective scaling factor
             var scaleFactor = ((typeof scale === 'number') && (scale > 0)) ? scale : 1;
             // the old rectangle in the source canvas (previous zoom state)
             var sourceOldRectangle = this.getRectangle();
             // the new rectangle in the source canvas (scaled back to the previous zoom state)
-            var sourceNewRectangle = getScaledRectangle(rectangle, 1 / scaleFactor);
+            var sourceNewRectangle = rectangle.clone().scaleSelf(1 / scaleFactor, 1 / scaleFactor);
             // the common part of old and new rectangle in source canvas (previous zoom state)
-            var sourceCommonRectangle = Utils.getIntersectionRectangle(sourceOldRectangle, sourceNewRectangle);
+            var sourceCommonRectangle = sourceOldRectangle.intersect(sourceNewRectangle);
             // the old rectangle in target canvas (scaled to the new zoom state)
-            var targetOldRectangle = getScaledRectangle(sourceOldRectangle, scaleFactor);
+            var targetOldRectangle = sourceOldRectangle.clone().scaleSelf(scaleFactor, scaleFactor);
             // the common part of old and new rectangle in target canvas (current zoom state)
-            var targetCommonRectangle = Utils.getIntersectionRectangle(targetOldRectangle, rectangle);
+            var targetCommonRectangle = targetOldRectangle.intersect(rectangle);
 
             // if possible, copy common areas to secondary canvas, and swap the canvases
             if (isValidRectangle(sourceCommonRectangle) && isValidRectangle(targetCommonRectangle)) {
@@ -1332,7 +1392,7 @@ define('io.ox/office/tk/render/canvas', [
                 });
 
                 // return the remaining empty areas in the canvas
-                return Utils.getRemainingRectangles(rectangle, targetOldRectangle);
+                return rectangle.remaining(targetOldRectangle);
             }
 
             // nothing to copy (no common areas)
@@ -1342,15 +1402,26 @@ define('io.ox/office/tk/render/canvas', [
             return [rectangle];
         };
 
+        /**
+         * Clears the contents of the entire canvas, i.e. fills the canvas with
+         * fully transparent pixels.
+         *
+         * @returns {Canvas}
+         *  A reference to this instance.
+         */
+        this.clear = function () {
+            renderContext.clearRect(0, 0, width, height);
+            return this;
+        };
+
         /**
          * Saves the current state of the canvas (colors, transformation,
          * clipping, etc.), invokes the passed callback function, and restores
          * the canvas state afterwards.
          *
-         * @param {Object} [clipRect]
-         *  An optional clipping rectangle, with the numeric properties 'left',
-         *  'top', 'width', and 'height'. Can be omitted completely (instead of
-         *  being set to null or undefined).
+         * @param {Rectangle|Object} [clipRect]
+         *  An optional clipping rectangle. Can be omitted completely (instead
+         *  of being set to null or undefined).
          *
          * @param {Function} callback
          *  The callback function to be invoked. Receives the following
@@ -1373,17 +1444,17 @@ define('io.ox/office/tk/render/canvas', [
          */
         this.render = function (clipRect, callback, ctxt) {
 
-            // Do not set the global translation at the native canvas element  for large offsets, to workaround
+            // Do not set the global translation at the native canvas element for large offsets, to workaround
             // the limited floating-point precision provided by the canvas. Browsers usually only implement
             // single-precision instead of double-precision as required by the W3C (see bug 35653, and
             // http://stackoverflow.com/a/8874802).
             var translateManually = (Math.abs(x0) > 4e6) || (Math.abs(y0) > 4e6);
             var globalX0 = translateManually ? x0 : 0;
             var globalY0 = translateManually ? y0 : 0;
-            if (!translateManually) { context.translate(-x0, -y0); }
+            if (!translateManually) { renderContext.translate(-x0, -y0); }
 
             // the context wrapper for this invocation
-            var contextWrapper = new ContextWrapper(context, globalX0, globalY0);
+            var contextWrapper = new ContextWrapper(renderContext, globalX0, globalY0);
 
             // adjust arguments (missing clipping rectangle)
             if (isFunction(clipRect)) {
@@ -1398,7 +1469,7 @@ define('io.ox/office/tk/render/canvas', [
                     return callback.call(ctxt, contextWrapper, width, height);
                 });
             } finally {
-                if (!translateManually) { context.translate(x0, y0); }
+                if (!translateManually) { renderContext.translate(x0, y0); }
             }
         };
 
@@ -1426,7 +1497,7 @@ define('io.ox/office/tk/render/canvas', [
         this.renderPixels = function (callback, ctxt) {
 
             // the image data wrapper for this invocation
-            var pixelWrapper = new PixelWrapper(context, x0, y0);
+            var pixelWrapper = new PixelWrapper(renderContext, x0, y0);
 
             // invoke callback function, and flush the pixel data
             try {
@@ -1439,11 +1510,11 @@ define('io.ox/office/tk/render/canvas', [
         // initialization -----------------------------------------------------
 
         // add CSS class names passed to the constructor
-        if (classes) { $canvas.addClass(classes); }
+        if (classes) { $canvasNode.addClass(classes); }
 
         // add polyfills for missing native CanvasRenderingContext2D methods
-        if (!isFunction(context.ellipse)) {
-            context.ellipse = function (x, y, rx, ry, a0, a1, a2, ccw) {
+        if (!isFunction(renderContext.ellipse)) {
+            renderContext.ellipse = function (x, y, rx, ry, a0, a1, a2, ccw) {
                 this.translate(x, y);
                 this.rotate(a0);
                 this.scale(rx, ry);
@@ -1456,8 +1527,8 @@ define('io.ox/office/tk/render/canvas', [
 
         // destroy all class members on destruction
         this.registerDestructor(function () {
-            $canvas.remove();
-            self = initOptions = $canvas = canvas = context = null;
+            if (!wrappedNode) { $canvasNode.remove(); }
+            self = initOptions = wrappedNode = $canvasNode = canvasNode = renderContext = null;
         });
 
     } }); // class Canvas
@@ -1465,7 +1536,7 @@ define('io.ox/office/tk/render/canvas', [
     // global initialization ==================================================
 
     // create a global canvas object for relocation
-    relocateCanvas = new Canvas();
+    relocateCanvas = new Canvas(BaseObject.SINGLETON);
 
     // exports ================================================================
 
