@@ -18,6 +18,13 @@ define('io.ox/office/tk/render/colorutils', [
 
     'use strict';
 
+    // convenience shortcuts
+    var round = Math.round;
+    var abs = Math.abs;
+    var min = Math.min;
+    var max = Math.max;
+    var pow = Math.pow;
+
     // threshold luma for dark colors
     var Y_DARK = 0.4;
 
@@ -87,7 +94,7 @@ define('io.ox/office/tk/render/colorutils', [
 
     // converts the passed string representing a decimal value
     function parseDec(dec, quot) {
-        return Math.min(1, parseInt(dec, 10) / quot);
+        return min(1, parseInt(dec, 10) / quot);
     }
 
     function formatHex(dec, length) {
@@ -110,7 +117,7 @@ define('io.ox/office/tk/render/colorutils', [
     var AlphaModel = _.makeExtendable(function (a) {
 
         // public properties
-        this.a = a;
+        this.a = Utils.minMax(a, 0, 1);
 
     }); // class AlphaModel
 
@@ -129,17 +136,11 @@ define('io.ox/office/tk/render/colorutils', [
      * @param {Number} value
      *  The new value of the color channel.
      *
-     * @param {Number} [cycle]
-     *  If specified, the size of the channel interval (the valid numbers for
-     *  the channel). The channel value passed in the parameter 'value' will be
-     *  adjusted to the channel size by calculating the modulo. If omitted, the
-     *  passed value will be reduced to the interval [0,1].
-     *
      * @returns {AlphaModel}
      *  A reference to this instance.
      */
-    AlphaModel.prototype.set = function (channel, value, cycle) {
-        this[channel] = (typeof cycle === 'number') ? Utils.mod(value, cycle) : Utils.minMax(value, 0, 1);
+    AlphaModel.prototype.set = function (channel, value) {
+        this[channel] = Utils.minMax(value, 0, 1);
         return this;
     };
 
@@ -157,17 +158,11 @@ define('io.ox/office/tk/render/colorutils', [
      * @param {Number} factor
      *  The modulation factor. MUST be non-negative.
      *
-     * @param {Number} [cycle]
-     *  If specified, the size of the channel interval (the valid numbers for
-     *  the channel). The resulting channel value will be adjusted to the
-     *  channel size by calculating the modulo. If omitted, the resulting value
-     *  will be reduced to the interval [0,1].
-     *
      * @returns {AlphaModel}
      *  A reference to this instance.
      */
-    AlphaModel.prototype.modulate = function (channel, factor, cycle) {
-        return this.set(channel, this[channel] * factor, cycle);
+    AlphaModel.prototype.modulate = function (channel, factor) {
+        return this.set(channel, this[channel] * factor);
     };
 
     /**
@@ -184,17 +179,11 @@ define('io.ox/office/tk/render/colorutils', [
      * @param {Number} shift
      *  The value to be added to the color channel.
      *
-     * @param {Number} [cycle]
-     *  If specified, the size of the channel interval (the valid numbers for
-     *  the channel). The resulting channel value will be adjusted to the
-     *  channel size by calculating the modulo. If omitted, the resulting value
-     *  will be reduced to the interval [0,1].
-     *
      * @returns {AlphaModel}
      *  A reference to this instance.
      */
-    AlphaModel.prototype.offset = function (channel, shift, cycle) {
-        return this.set(channel, this[channel] + shift, cycle);
+    AlphaModel.prototype.offset = function (channel, shift) {
+        return this.set(channel, this[channel] + shift);
     };
 
     // class RGBModel =========================================================
@@ -223,9 +212,9 @@ define('io.ox/office/tk/render/colorutils', [
         AlphaModel.call(this, a);
 
         // public properties
-        this.r = r;
-        this.g = g;
-        this.b = b;
+        this.r = Utils.minMax(r, 0, 1);
+        this.g = Utils.minMax(g, 0, 1);
+        this.b = Utils.minMax(b, 0, 1);
 
     } }); // class RGBModel
 
@@ -322,12 +311,12 @@ define('io.ox/office/tk/render/colorutils', [
      */
     RGBModel.prototype.toHSL = function () {
 
-        var max = Math.max(this.r, this.g, this.b);
-        var min = Math.min(this.r, this.g, this.b);
-        var diff = max - min;
-        var sum = max + min;
+        var mx = max(this.r, this.g, this.b);
+        var mn = min(this.r, this.g, this.b);
+        var diff = mx - mn;
+        var sum = mx + mn;
 
-        var h = (diff === 0) ? 0 : (max === this.r) ? Utils.mod((this.g - this.b) / diff * 60, 360) : (max === this.g) ? ((this.b - this.r) / diff * 60 + 120) : ((this.r - this.g) / diff * 60 + 240);
+        var h = (diff === 0) ? 0 : (mx === this.r) ? Utils.mod((this.g - this.b) / diff * 60, 360) : (mx === this.g) ? ((this.b - this.r) / diff * 60 + 120) : ((this.r - this.g) / diff * 60 + 240);
         var s = ((sum === 0) || (sum === 2)) ? 0 : (sum < 1) ? (diff / sum) : (diff / (2 - sum));
         var l = sum / 2;
 
@@ -345,10 +334,10 @@ define('io.ox/office/tk/render/colorutils', [
     RGBModel.prototype.toBytes = function () {
 
         // double rounding to workaround rounding errors during RGB/HSL conversion
-        var r8 = Math.round(Math.round(this.r * 25500000) / 100000);
-        var g8 = Math.round(Math.round(this.g * 25500000) / 100000);
-        var b8 = Math.round(Math.round(this.b * 25500000) / 100000);
-        var a8 = Math.round(this.a * 255);
+        var r8 = round(round(this.r * 25500000) / 100000);
+        var g8 = round(round(this.g * 25500000) / 100000);
+        var b8 = round(round(this.b * 25500000) / 100000);
+        var a8 = round(this.a * 255);
 
         return [r8, g8, b8, a8];
     };
@@ -380,9 +369,9 @@ define('io.ox/office/tk/render/colorutils', [
      *  A reference to this instance.
      */
     RGBModel.prototype.gamma = function (gamma) {
-        this.r = Math.pow(this.r, gamma);
-        this.g = Math.pow(this.g, gamma);
-        this.b = Math.pow(this.b, gamma);
+        this.r = pow(this.r, gamma);
+        this.g = pow(this.g, gamma);
+        this.b = pow(this.b, gamma);
         return this;
     };
 
@@ -410,6 +399,122 @@ define('io.ox/office/tk/render/colorutils', [
         return this;
     };
 
+    /**
+     * Changes the specified color channel to the specified value, and applies
+     * a gamma correction.
+     *
+     * @param {String} channel
+     *  The name of the color channel (one of 'r', 'g', or 'b').
+     *
+     * @param {Number} value
+     *  The new value of the color channel.
+     *
+     * @param {Number} gamma
+     *  The gamma shift to be applied to the passed channel value.
+     *
+     * @returns {RGBModel}
+     *  A reference to this instance.
+     */
+    RGBModel.prototype.setGamma = function (channel, value, gamma) {
+        return this.set(channel, pow(max(0, value), gamma));
+    };
+
+    /**
+     * Modulates the specified color channel (multiplies the color channel with
+     * the specified factor), and applies a gamma correction.
+     *
+     * @param {String} channel
+     *  The name of the color channel (one of 'r', 'g', or 'b').
+     *
+     * @param {Number} factor
+     *  The modulation factor. MUST be non-negative.
+     *
+     * @param {Number} gamma
+     *  The gamma shift to be applied to the passed channel value before
+     *  (inverse gamma) and after modulation.
+     *
+     * @returns {RGBModel}
+     *  A reference to this instance.
+     */
+    RGBModel.prototype.modulateGamma = function (channel, factor, gamma) {
+        return this.setGamma(channel, pow(this[channel], 1 / gamma) * factor, gamma);
+    };
+
+    /**
+     * Shifts the specified color channel (adds the specified value to the
+     * color channel), and applies a gamma correction.
+     *
+     * @param {String} channel
+     *  The name of the color channel (one of 'r', 'g', or 'b').
+     *
+     * @param {Number} shift
+     *  The value to be added to the color channel.
+     *
+     * @param {Number} gamma
+     *  The gamma shift to be applied to the passed channel value before
+     *  (inverse gamma) and after shifting.
+     *
+     * @returns {RGBModel}
+     *  A reference to this instance.
+     */
+    RGBModel.prototype.offsetGamma = function (channel, shift, gamma) {
+        return this.setGamma(channel, pow(this[channel], 1 / gamma) + shift, gamma);
+    };
+
+    /**
+     * Changes this color model to its inverse RGB color with gamma correction.
+     *
+     * @returns {RGBModel}
+     *  A reference to this instance.
+     */
+    RGBModel.prototype.invGamma = function (gamma) {
+        return this.gamma(1 / gamma).inv().gamma(gamma);
+    };
+
+    /**
+     * Darkens this color by decreasing the values of the RGB color channels
+     * according to the passed value with gamma correction.
+     *
+     * @param {Number} value
+     *  The amount to darken this color, in the closed interval [0;1]. The
+     *  number 0 will not modify this color, the number 1 will change this
+     *  color to black, all numbers inside the interval will darken this color
+     *  accordingly.
+     *
+     * @param {Number} gamma
+     *  The gamma shift to be applied to the RGB color channel values before
+     *  (inverse gamma) and after darkening.
+     *
+     * @returns {RGBModel}
+     *  A reference to this instance.
+     */
+    RGBModel.prototype.darkenGamma = function (value, gamma) {
+        var factor = Utils.minMax(1 - value, 0, 1);
+        return this.gamma(1 / gamma).modulate('r', factor).modulate('g', factor).modulate('b', factor).gamma(gamma);
+    };
+
+    /**
+     * Lightens this color by increasing the values of the RGB color channels
+     * according to the passed value with gamma correction.
+     *
+     * @param {Number} value
+     *  The amount to lighten this color, in the closed interval [0;1]. The
+     *  number 0 will not modify this color, the number 1 will change this
+     *  color to white, all numbers inside the interval will lighten this color
+     *  accordingly.
+     *
+     * @param {Number} gamma
+     *  The gamma shift to be applied to the RGB color channel values before
+     *  (inverse gamma) and after lightening.
+     *
+     * @returns {RGBModel}
+     *  A reference to this instance.
+     */
+    RGBModel.prototype.lightenGamma = function (value, gamma) {
+        var factor = Utils.minMax(1 - value, 0, 1);
+        return this.gamma(1 / gamma).inv().modulate('r', factor).modulate('g', factor).modulate('b', factor).inv().gamma(gamma);
+    };
+
     // class HSLModel =========================================================
 
     /**
@@ -440,9 +545,9 @@ define('io.ox/office/tk/render/colorutils', [
         AlphaModel.call(this, a);
 
         // public properties
-        this.h = h;
-        this.s = s;
-        this.l = l;
+        this.h = Utils.mod(h, 360);
+        this.s = Utils.minMax(s, 0, 1);
+        this.l = Utils.minMax(l, 0, 1);
 
     } }); // class HSLModel
 
@@ -469,9 +574,9 @@ define('io.ox/office/tk/render/colorutils', [
     HSLModel.prototype.toRGB = function () {
 
         var h = this.h / 60;
-        var r = (Utils.minMax(Math.abs(h - 3) - 1, 0, 1) - 0.5) * this.s + 0.5;
-        var g = (Utils.minMax(2 - Math.abs(2 - h), 0, 1) - 0.5) * this.s + 0.5;
-        var b = (Utils.minMax(2 - Math.abs(4 - h), 0, 1) - 0.5) * this.s + 0.5;
+        var r = (Utils.minMax(abs(h - 3) - 1, 0, 1) - 0.5) * this.s + 0.5;
+        var g = (Utils.minMax(2 - abs(2 - h), 0, 1) - 0.5) * this.s + 0.5;
+        var b = (Utils.minMax(2 - abs(4 - h), 0, 1) - 0.5) * this.s + 0.5;
         var l = 0;
 
         if (this.l < 0.5) {
@@ -512,53 +617,60 @@ define('io.ox/office/tk/render/colorutils', [
         if (this.a <= 0) { return 'transparent'; }
 
         // opaque color: return hsl() function style; otherwise return hsla() function style
-        var hsl = Math.round(this.h) + ',' + Math.round(this.s * 100) + '%,' + Math.round(this.l * 100) + '%';
+        var hsl = round(this.h) + ',' + round(this.s * 100) + '%,' + round(this.l * 100) + '%';
         return (this.a >= 1) ? ('hsl(' + hsl + ')') : ('hsla(' + hsl + ',' + Utils.round(this.a, 0.001) + ')');
     };
 
     /**
-     * Darkens this color according to the passed value.
+     * Changes the hue channel to the specified value.
      *
-     * @param {Number} factor
-     *  The factor to darken this color, in the closed interval [0;1]. The
-     *  number 0 will not modify this color, the number 1 will change this
-     *  color to black, all numbers inside the interval will darken this color
-     *  accordingly.
+     * @param {Number} hue
+     *  The new value of the hue channel, in degrees.
      *
      * @returns {HSLModel}
      *  A reference to this instance.
      */
-    HSLModel.prototype.darken = function (factor) {
-        this.l *= Utils.minMax(1 - factor, 0, 1);
+    HSLModel.prototype.setH = function (hue) {
+        this.h = Utils.minMax(hue, 0, 360) % 360;
         return this;
     };
 
     /**
-     * Lightens this color according to the passed value.
+     * Modulates the hue channel (multiplies the hue value with the specified
+     * factor).
      *
      * @param {Number} factor
-     *  The factor to lighten this color, in the closed interval [0;1]. The
-     *  number 0 will not modify this color, the number 1 will change this
-     *  color to white, all numbers inside the interval will lighten this color
-     *  accordingly.
+     *  The modulation factor. MUST be non-negative.
      *
      * @returns {HSLModel}
      *  A reference to this instance.
      */
-    HSLModel.prototype.lighten = function (factor) {
-        this.l += (1 - this.l) * Utils.minMax(factor, 0, 1);
-        return this;
+    HSLModel.prototype.modulateH = function (factor) {
+        return this.setH(this.h * factor);
     };
 
     /**
-     * Changes this color model to its complement color (rotates the hue by
-     * 180 degrees).
+     * Shifts the hue channel (adds the specified value to the hue value).
+     *
+     * @param {Number} shift
+     *  The value to be added to the hue channel.
+     *
+     * @returns {HSLModel}
+     *  A reference to this instance.
+     */
+    HSLModel.prototype.offsetH = function (shift) {
+        return this.setH(this.h + shift);
+    };
+
+    /**
+     * Changes this color model to its inverse hue value.
      *
      * @returns {HSLModel}
      *  A reference to this instance.
      */
     HSLModel.prototype.comp = function () {
-        return this.offset('h', 180, 360);
+        this.h = (this.h + 180) % 360;
+        return this;
     };
 
     // class ColorDescriptor ==================================================
