@@ -51,7 +51,7 @@ define('io.ox/office/tk/render/font', [
 
     // global canvas for font width calculation
     var TEXTWIDTH_CANVAS = (function () {
-        var canvas = new Canvas();
+        var canvas = new Canvas(Canvas.SINGLETON);
         // Chrome reports different/wrong text widths, if the canvas element remains detached... :-O
         Utils.insertHiddenNodes(canvas.getNode());
         return canvas;
