@@ -362,7 +362,7 @@ define('io.ox/office/tk/render/path', function () {
      * Adds a new subpath consisting of a closed rectangle. After that, opens
      * another new subpath at the starting corner of the rectangle.
      *
-     * @param {Number|Object} x
+     * @param {Number|Rectangle|Object} x
      *  The X coordinate of the starting point of the rectangle, or a complete
      *  rectangle with the numeric properties 'left', 'top', 'width', and
      *  'height'.
@@ -383,7 +383,7 @@ define('io.ox/office/tk/render/path', function () {
      *  A reference to this instance.
      */
     Path.prototype.pushRect = function (x, y, w, h) {
-        if (_.isObject(x)) { y = x.top; w = x.width; h = x.height; x = x.left; }
+        if (typeof x === 'object') { y = x.top; w = x.width; h = x.height; x = x.left; }
         return this.pushPolygon(x, y, x + w, y, x + w, y + h, x, y + h);
     };
 
