@@ -21,10 +21,9 @@ define('io.ox/office/tk/utils/driveutils', [
     'io.ox/core/permissions/permissions',
     'io.ox/office/tk/utils',
     'io.ox/office/tk/keycodes',
-    'io.ox/office/tk/utils/scheduler',
     'io.ox/office/tk/object/triggerobject',
     'settings!io.ox/files'
-], function (FilesAPI, FolderAPI, FolderNode, TreeView, Selection, Permissions, Utils, KeyCodes, Scheduler, TriggerObject, DriveSettings) {
+], function (FilesAPI, FolderAPI, FolderNode, TreeView, Selection, Permissions, Utils, KeyCodes, TriggerObject, DriveSettings) {
 
     'use strict';
 
@@ -207,7 +206,7 @@ define('io.ox/office/tk/utils/driveutils', [
     /**
      * returns the corresponding backbone based file model ('io.ox/files/api').
      *
-     * already used by file ['io.ox/presenter/main'] > 'start-presentation' > getFileSuccess
+     * already used by file ['io.ox/office/presenter/main'] > 'start-presentation' > getFileSuccess
      *
      * @returns {Deferred} Deferred with FileAPI.Model as result
      */
@@ -279,22 +278,77 @@ define('io.ox/office/tk/utils/driveutils', [
      *  @param {String} [initOptions.preselect]
      *      Drive-File-Id to preselect a folder
      */
-    DriveUtils.FlatFolderPicker = TriggerObject.extend({ constructor: function (initOptions) {
+    DriveUtils.FlatFolderPicker = TriggerObject.extend({ constructor: function (windowId, initOptions) {
 
         var self = this;
 
-        TriggerObject.call(this);
+        TriggerObject.call(this, windowId);
 
         var preselect = Utils.getStringOption(initOptions, 'preselect');
         var folderTree = $('<div class="folder-tree visible-selection dropzone" role="navigation" data-dropzones=".selectable">');
         var selectedFolder = null;
 
+        // private methods ----------------------------------------------------
+
         function selectNode() {
             selectedFolder = folderTree.find('.folder.selected').attr('data-id');
             self.trigger('change');
         }
 
-        // methods --------------------------------------------------------
+        /**
+         * gives a fake FolderNode, which look similar like the FolderNode of
+         * the FolderPicker and its TreeView.
+         * But it is not used for a tree, it is used for a flat view.
+         *
+         * Reacts on KeyUp and KeyDown to select only one FolderNode at once and iss clickable.
+         *
+         * @returns {Object}
+         *  fake FolderNode
+         */
+        function newGroupNode(title) {
+            var node = new TriggerObject(windowId);
+            var el = $('<li class="section folder selectable"><div class="folder-node" role="presentation" style="padding-left: 0px;"><div class="folder-arrow"><i class="fa fa-caret-down"></i></div><div class="folder-icon"><i class="fa fa-fw"></i></div><div class="folder-label" style="font-weight: bold;"><div>' + title + '</div></div></div></li>');
+            bindFolderNodeHandlers(el, node);
+            var arrow = el.find('.folder-arrow>i');
+
+            function open() {
+                el.parent().find('li.folder').show();
+                arrow.removeClass('fa-caret-right');
+                arrow.addClass('fa-caret-down');
+            }
+
+            function close() {
+                el.parent().find('li.folder:not(.section)').hide();
+                arrow.removeClass('fa-caret-down');
+                arrow.addClass('fa-caret-right');
+            }
+
+            el.on('keydown', function (evt) {
+                if (evt.keyCode === KeyCodes.LEFT_ARROW) {
+                    close();
+                } else if (evt.keyCode === KeyCodes.RIGHT_ARROW) {
+                    open();
+                }
+            });
+
+            arrow.parent().on('click', function () {
+                if (arrow.hasClass('fa-caret-down')) {
+                    close();
+                } else {
+                    open();
+                }
+            });
+
+            node.render = function () {
+                return {
+                    $el: el
+                };
+            };
+
+            return node;
+        }
+
+        // public methods -----------------------------------------------------
 
         /**
          * adds a new group of folders
@@ -312,7 +366,7 @@ define('io.ox/office/tk/utils/driveutils', [
             var treeContainer = $('<ul class="tree-container f6-target" role="tree">');
             treeContainer.appendTo(folderTree);
 
-            var head = DriveUtils.newGroupNode(name);
+            var head = newGroupNode(name);
             head.on('select', selectNode);
             head.render().$el.appendTo(treeContainer);
 
@@ -394,12 +448,12 @@ define('io.ox/office/tk/utils/driveutils', [
      *  @param {String} [initOptions.preselect]
      *      Drive-File-Id to preselect a folder
      */
-    DriveUtils.FolderPicker = TriggerObject.extend({ constructor: function (initOptions) {
+    DriveUtils.FolderPicker = TriggerObject.extend({ constructor: function (windowId, initOptions) {
 
         var self = this;
         var selectedFolder = null;
 
-        TriggerObject.call(this);
+        TriggerObject.call(this, windowId);
 
         var preselect = Utils.getStringOption(initOptions, 'preselect');
 
@@ -591,6 +645,10 @@ define('io.ox/office/tk/utils/driveutils', [
      *  return true if user can edit current file
      */
     DriveUtils.canModify = function (file) {
+        if (!file) {
+            Utils.error('DriveUtils.canModify() no file assigned');
+            return false;
+        }
         var model = FilesAPI.pool.get('detail').get(_.cid(file));
 
         if (DriveUtils.isGuest()) {
@@ -607,6 +665,10 @@ define('io.ox/office/tk/utils/driveutils', [
     };
 
     DriveUtils.isShareable = function (file) {
+        if (!file) {
+            Utils.error('DriveUtils.isShareable() no file assigned');
+            return false;
+        }
         var folderModel = FolderAPI.pool.models[file.folder_id];
         if (!folderModel) {
             Utils.warn('DriveUtils.isShareable() is called too early, folder is not cached yet. better call DriveUtils.getWriteState() file: ' + file);
@@ -777,59 +839,6 @@ define('io.ox/office/tk/utils/driveutils', [
         return node;
     };
 
-    /**
-     * gives a fake FolderNode, which look similar like the FolderNode of
-     * the FolderPicker and its TreeView.
-     * But it is not used for a tree, it is used for a flat view.
-     *
-     * Reacts on KeyUp and KeyDown to select only one FolderNode at once and iss clickable.
-     *
-     * @returns {Object}
-     *  fake FolderNode
-     */
-    DriveUtils.newGroupNode = function (title) {
-        var node = new TriggerObject();
-        var el = $('<li class="section folder selectable"><div class="folder-node" role="presentation" style="padding-left: 0px;"><div class="folder-arrow"><i class="fa fa-caret-down"></i></div><div class="folder-icon"><i class="fa fa-fw"></i></div><div class="folder-label" style="font-weight: bold;"><div>' + title + '</div></div></div></li>');
-        bindFolderNodeHandlers(el, node);
-        var arrow = el.find('.folder-arrow>i');
-
-        function open() {
-            el.parent().find('li.folder').show();
-            arrow.removeClass('fa-caret-right');
-            arrow.addClass('fa-caret-down');
-        }
-
-        function close() {
-            el.parent().find('li.folder:not(.section)').hide();
-            arrow.removeClass('fa-caret-down');
-            arrow.addClass('fa-caret-right');
-        }
-
-        el.on('keydown', function (evt) {
-            if (evt.keyCode === KeyCodes.LEFT_ARROW) {
-                close();
-            } else if (evt.keyCode === KeyCodes.RIGHT_ARROW) {
-                open();
-            }
-        });
-
-        arrow.parent().on('click', function () {
-            if (arrow.hasClass('fa-caret-down')) {
-                close();
-            } else {
-                open();
-            }
-        });
-
-        node.render = function () {
-            return {
-                $el: el
-            };
-        };
-
-        return node;
-    };
-
     /**
      * if the assigned title is longer than assigned length,
      * it returns a new String with "..." in the middle,
@@ -928,7 +937,7 @@ define('io.ox/office/tk/utils/driveutils', [
 
         //FIXME: stupid hacks
         treeView.once('appear', open);
-        timeout = Scheduler.setTimeout(open, 250, null, 'DriveUtils preselectFolder');
+        timeout = window.setTimeout(open, 250);
     };
 
     DriveUtils.preparePath = function (paths) {
