@@ -20,83 +20,80 @@ define('io.ox/office/tk/utils/tracking', [
 
     'use strict';
 
-    var // the map of all mouse events to be bound to a node to start tracking
-        MOUSE_START_EVENT_MAP = {
-            mousedown: mouseDownHandler
-        },
+    // the map of all mouse events to be bound to a node to start tracking
+    var MOUSE_START_EVENT_MAP = {
+        mousedown: mouseDownHandler
+    };
 
-        // the map of all touch events to be bound to a node to start tracking
-        TOUCH_START_EVENT_MAP = {
-            touchstart: touchStartHandler
-        },
+    // the map of all touch events to be bound to a node to start tracking
+    var TOUCH_START_EVENT_MAP = {
+        touchstart: touchStartHandler
+    };
 
-        // the map of all events to be bound to the document when tracking starts
-        DOCUMENT_EVENT_MAP = {
-            mousemove: mouseMoveHandler,
-            mouseup: mouseUpHandler,
-            touchmove: touchMoveHandler,
-            touchend: touchEndHandler,
-            touchcancel: cancelTracking,
-            keydown: keyDownHandler,
-            keyup: keyUpHandler
-        },
+    // the map of all events to be bound to the document when tracking starts
+    var DOCUMENT_EVENT_MAP = {
+        mousemove: mouseMoveHandler,
+        mouseup: mouseUpHandler,
+        touchmove: touchMoveHandler,
+        touchend: touchEndHandler,
+        touchcancel: cancelTracking,
+        keydown: keyHandler,
+        keyup: keyHandler
+    };
 
-    /*    // the map of all events to be bound to the document after tracking has started
-        DEFERRED_EVENT_MAP = {
-            mousedown: cancelTracking,
-            touchstart: cancelTracking
-        },
-    */
-        // the node that is currently tracked and receives the tracking events
-        trackingNode = null,
+    // the node that is currently tracked and receives the tracking events
+    var trackingNode = null;
 
-        // the options of the node that is currently tracked
-        trackingOptions = null,
+    // the options of the node that is currently tracked
+    var trackingOptions = null;
 
-        // the tracking type ('mouse' or 'touch')
-        trackingType = '',
+    // the tracking type ('mouse' or 'touch')
+    var trackingType = '';
 
-        // the time stamp of the 'tracking:start' event
-        startTime = 0,
+    // whether to generate tracking:move events when modifier keys are changing
+    var trackModifiers = false;
 
-        // the initial tracking position
-        startX = 0, startY = 0,
+    // the time stamp of the 'tracking:start' event
+    var startTime = 0;
 
-        // the tracking position passed to the last event
-        lastX = 0, lastY = 0,
+    // the initial tracking position
+    var startX = 0, startY = 0;
 
-        // last states of all modifier keys
-        lastModifiers = null,
+    // the tracking position passed to the last event
+    var lastX = 0, lastY = 0;
 
-        // the real target node that has started a tracking cycle
-        lastTargetNode = null,
+    // last states of all modifier keys received from a browser event
+    var lastModifiers = null;
 
-        // data about the last complete start/end cycle
-        lastClickData = null,
+    // the real target node that has started a tracking cycle
+    var lastTargetNode = null;
 
-        // whether the mouse or touch point has been moved after tracking has started
-        moved = false,
+    // data about the last complete start/end cycle
+    var lastClickData = null;
 
-        // the overlay node to preserve the mouse pointer while tracking
-        overlayNode = $('<div>').addClass('abs').css('z-index', 10000),
+    // whether the mouse or touch point has been moved after tracking has started
+    var moved = false;
 
-        // the global mouse pointer style while tracking is active
-        overlayCursor = '',
+    // the overlay node to preserve the mouse pointer while tracking
+    var overlayNode = $('<div>').addClass('abs').css('z-index', 10000);
 
-        // whether tracking is currently finishing (prevent conflicts when calling cancelTracking() from event handlers)
-        finishing = false,
+    // the global mouse pointer style while tracking is active
+    var overlayCursor = '';
 
-        // the browser timer used for initial auto-repetition
-        repeatDelayTimer = null,
+    // whether tracking is currently finishing (prevent conflicts when calling cancelTracking() from event handlers)
+    var finishing = false;
 
-        // the browser interval timer used for auto-repetition
-        repeatIntervalTimer = null,
+    // the browser timer used for initial auto-repetition
+    var repeatDelayTimer = null;
 
-        // the browser timer used for auto-scrolling
-        scrollIntervalTimer = null,
+    // the browser interval timer used for auto-repetition
+    var repeatIntervalTimer = null;
 
-        // debug console logger
-        logger = new Logger({ enable: 'office:log-tracking', prefix: 'TRACKING' });
+    // the browser timer used for auto-scrolling
+    var scrollIntervalTimer = null;
+
+    // debug console logger
+    var logger = new Logger({ enable: 'office:log-tracking', prefix: 'TRACKING' });
 
     // private global functions ===============================================
 
@@ -106,10 +103,10 @@ define('io.ox/office/tk/utils/tracking', [
      */
     function registerStartTrackingHandlers(nodes, options) {
 
-        var // jQuery selector to filter for descendant nodes
-            selector = Utils.getStringOption(options, 'selector'),
-            // which source events are supported
-            sourceEvents = Utils.getStringOption(options, 'sourceEvents', 'all');
+        // jQuery selector to filter for descendant nodes
+        var selector = Utils.getStringOption(options, 'selector');
+        // which source events are supported
+        var sourceEvents = Utils.getStringOption(options, 'sourceEvents', 'all');
 
         // register supported events
         if ((sourceEvents === 'mouse') || (sourceEvents === 'all')) {
@@ -140,14 +137,14 @@ define('io.ox/office/tk/utils/tracking', [
      *  to pass the state of additional modifier keys (SHIFT, ALT, CTRL, META)
      *  to the event listeners.
      *
-     * @param {Object} [data]
+     * @param {Object} [eventData]
      *  Additional properties to be inserted into the event object passed to
      *  all event listeners.
      */
-    function triggerEvent(type, sourceEvent, data) {
+    function triggerEvent(type, sourceEvent, eventData) {
 
-        var // the event object passed to all listeners
-            event = _.extend({ startX: startX, startY: startY, target: lastTargetNode }, data);
+        // the event object passed to all listeners
+        var event = _.extend({ startX: startX, startY: startY, target: lastTargetNode }, eventData);
 
         // extend with specific tracking data
         _.extend(event, {
@@ -166,10 +163,13 @@ define('io.ox/office/tk/utils/tracking', [
                 ctrlKey: sourceEvent.ctrlKey,
                 metaKey: sourceEvent.metaKey
             });
+        } else {
+            _.extend(event, lastModifiers);
         }
 
         // trigger the event
         event = new $.Event(type, event);
+        event.cancelTracking = cancelTracking;
         logger.log('type="' + type + '" event=', event);
         trackingNode.trigger(event);
 
@@ -191,7 +191,7 @@ define('io.ox/office/tk/utils/tracking', [
 
         // returns whether the absolute distance between the page positions is small enough
         function isSmallDistance(position) {
-            return Math.sqrt(Math.pow(pageX - position.x, 2) + Math.pow(pageY - position.y, 2)) <= 3;
+            return Utils.radius(pageX - position.x, pageY - position.y) <= 3;
         }
 
         // check validity of the 'dblClick' tracking option
@@ -222,7 +222,7 @@ define('io.ox/office/tk/utils/tracking', [
      * event object.
      */
     function getModifiers(event) {
-        return { shift: !!event.shiftKey, alt: !!event.altKey, ctrl: !!event.ctrlKey, meta: !!event.metaKey };
+        return { shiftKey: !!event.shiftKey, altKey: !!event.altKey, ctrlKey: !!event.ctrlKey, metaKey: !!event.metaKey };
     }
 
     /**
@@ -231,42 +231,42 @@ define('io.ox/office/tk/utils/tracking', [
      */
     function initAutoMode(event) {
 
-        var // whether auto-repetition is enabled
-            autoRepeat = Utils.getBooleanOption(trackingOptions, 'autoRepeat', false),
-            // the time in milliseconds for first 'tracking:repeat' event
-            repeatDelay = Utils.getIntegerOption(trackingOptions, 'repeatDelay', 700, 10),
-            // the time in milliseconds between 'tracking:repeat' events
-            repeatInterval = Utils.getIntegerOption(trackingOptions, 'repeatInterval', 100, 10),
+        // whether auto-repetition is enabled
+        var autoRepeat = Utils.getBooleanOption(trackingOptions, 'autoRepeat', false);
+        // the time in milliseconds for first 'tracking:repeat' event
+        var repeatDelay = Utils.getIntegerOption(trackingOptions, 'repeatDelay', 700, 10);
+        // the time in milliseconds between 'tracking:repeat' events
+        var repeatInterval = Utils.getIntegerOption(trackingOptions, 'repeatInterval', 100, 10);
 
-            // whether horizontal auto-scrolling is enabled
-            scrollHorizontal = Utils.getBooleanOption(trackingOptions, 'autoScroll', false) || (Utils.getStringOption(trackingOptions, 'autoScroll') === 'horizontal'),
-            // whether vertical auto-scrolling is enabled
-            scrollVertical = Utils.getBooleanOption(trackingOptions, 'autoScroll', false) || (Utils.getStringOption(trackingOptions, 'autoScroll') === 'vertical'),
-            // the time in milliseconds between 'tracking:scroll' events
-            scrollInterval = Utils.getIntegerOption(trackingOptions, 'scrollInterval', 100, 100),
+        // whether horizontal auto-scrolling is enabled
+        var scrollHorizontal = Utils.getBooleanOption(trackingOptions, 'autoScroll', false) || (Utils.getStringOption(trackingOptions, 'autoScroll') === 'horizontal');
+        // whether vertical auto-scrolling is enabled
+        var scrollVertical = Utils.getBooleanOption(trackingOptions, 'autoScroll', false) || (Utils.getStringOption(trackingOptions, 'autoScroll') === 'vertical');
+        // the time in milliseconds between 'tracking:scroll' events
+        var scrollInterval = Utils.getIntegerOption(trackingOptions, 'scrollInterval', 100, 100);
 
-            // the border node for auto-scrolling
-            borderNode = ('borderNode' in trackingOptions) ? $(trackingOptions.borderNode).first() : trackingNode,
-            // the margin around the border box where auto-scrolling becomes active
-            borderMargin = Utils.getIntegerOption(trackingOptions, 'borderMargin', 0),
-            // the size of the border around the scrolling border box for acceleration
-            borderSize = Utils.getIntegerOption(trackingOptions, 'borderSize', 30, 0),
+        // the border node for auto-scrolling
+        var borderNode = ('borderNode' in trackingOptions) ? $(trackingOptions.borderNode).first() : trackingNode;
+        // the margin around the border box where auto-scrolling becomes active
+        var borderMargin = Utils.getIntegerOption(trackingOptions, 'borderMargin', 0);
+        // the size of the border around the scrolling border box for acceleration
+        var borderSize = Utils.getIntegerOption(trackingOptions, 'borderSize', 30, 0);
 
-            // the minimum scrolling speed
-            minSpeed = Utils.getIntegerOption(trackingOptions, 'minSpeed', 10, 1),
-            // the maximum scrolling speed
-            maxSpeed = Utils.getIntegerOption(trackingOptions, 'maxSpeed', Math.max(100, minSpeed), minSpeed),
-            // the speed acceleration between two 'tracking:scroll' events
-            acceleration = Utils.getNumberOption(trackingOptions, 'acceleration', 1.2, 1.05),
+        // the minimum scrolling speed
+        var minSpeed = Utils.getIntegerOption(trackingOptions, 'minSpeed', 10, 1);
+        // the maximum scrolling speed
+        var maxSpeed = Utils.getIntegerOption(trackingOptions, 'maxSpeed', Math.max(100, minSpeed), minSpeed);
+        // the speed acceleration between two 'tracking:scroll' events
+        var acceleration = Utils.getNumberOption(trackingOptions, 'acceleration', 1.2, 1.05);
 
-            // the last scroll increment, in horizontal and vertical direction
-            scrollX = 0, scrollY = 0;
+        // the last scroll increment, in horizontal and vertical direction
+        var scrollX = 0, scrollY = 0;
 
         // returns the current outer border box
         function getBorderBox() {
 
-            var // the current screen position of the border node
-                borderBox = Utils.getNodePositionInPage(borderNode);
+            // the current screen position of the border node
+            var borderBox = Utils.getNodePositionInPage(borderNode);
 
             // add border margin
             borderBox.left -= borderMargin;
@@ -281,8 +281,8 @@ define('io.ox/office/tk/utils/tracking', [
         // callback for the auto-repetition timers
         function autoRepeatHandler() {
 
-            var // the current screen position of the border node
-                borderBox = getBorderBox();
+            // the current screen position of the border node
+            var borderBox = getBorderBox();
 
             // trigger event if tracking position hovers border box
             if ((borderBox.left <= lastX) && (lastX < borderBox.left + borderBox.width) && (borderBox.top <= lastY) && (lastY < borderBox.top + borderBox.height)) {
@@ -298,17 +298,17 @@ define('io.ox/office/tk/utils/tracking', [
         // callback for the auto-scrolling interval timer
         function autoScrollHandler() {
 
-            var // the current screen position of the border node
-                borderBox = getBorderBox(),
-                // the distances from border box to tracking position
-                leftDist = scrollHorizontal ? (borderBox.left - lastX) : 0,
-                rightDist = scrollHorizontal ? (lastX - (borderBox.left + borderBox.width)) : 0,
-                topDist = scrollVertical ? (borderBox.top - lastY) : 0,
-                bottomDist = scrollVertical ? (lastY - (borderBox.top + borderBox.height)) : 0;
-
             // start auto-scrolling after the first 'tracking:move' event
             if (!moved) { return; }
 
+            // the current screen position of the border node
+            var borderBox = getBorderBox();
+            // the distances from border box to tracking position
+            var leftDist = scrollHorizontal ? (borderBox.left - lastX) : 0;
+            var rightDist = scrollHorizontal ? (lastX - (borderBox.left + borderBox.width)) : 0;
+            var topDist = scrollVertical ? (borderBox.top - lastY) : 0;
+            var bottomDist = scrollVertical ? (lastY - (borderBox.top + borderBox.height)) : 0;
+
             // calculate new horizontal increment
             if (leftDist > 0) {
                 scrollX = (scrollX > -minSpeed) ? -minSpeed : Math.max(scrollX * acceleration, -getMaxSpeed(leftDist));
@@ -333,9 +333,9 @@ define('io.ox/office/tk/utils/tracking', [
             }
         }
 
-        if (Utils.getBooleanOption(trackingOptions, 'trackModifiers', false)) {
-            lastModifiers = getModifiers(event);
-        }
+        // handling of modifier keys
+        trackModifiers = Utils.getBooleanOption(trackingOptions, 'trackModifiers', false);
+        lastModifiers = getModifiers(event);
 
         if (autoRepeat) {
             repeatDelayTimer = window.setTimeout(function () {
@@ -381,21 +381,9 @@ define('io.ox/office/tk/utils/tracking', [
         overlayCursor = Utils.getStringOption(trackingOptions, 'cursor', '');
         if (!overlayCursor) { overlayCursor = $(event.target).css('cursor'); }
 
-        // register event listeners
+        // register event listeners (capture ESCAPE key before it propagates into the DOM)
+        document.addEventListener('keydown', escapeHandler, true);
         $(document).on(DOCUMENT_EVENT_MAP);
-        /*
-        // Attach deferred events that would otherwise interfere with tracking
-        // start event (e.g. another 'mousedown' event or a 'focusout' event
-        // that causes canceling tracking otherwise). Check that tracking is
-        // still active, a 'mouseup' event may be triggered before the deferred
-        // code actually runs.
-        window.setTimeout(function () {
-            if (trackingNode) {
-                // fail-save: prevent double registration of the handlers
-                $(document).off(DEFERRED_EVENT_MAP).on(DEFERRED_EVENT_MAP);
-            }
-        }, 0);
-        */
 
         // unregister event handlers at tracking node, this helps to work with
         // Chrome's touch emulation (sends touch and mouse events simultaneously)
@@ -409,10 +397,14 @@ define('io.ox/office/tk/utils/tracking', [
      * Deinitializes tracking mode after is has been finished or canceled.
      */
     function deinitTracking() {
-    //    $(document).off(DOCUMENT_EVENT_MAP).off(DEFERRED_EVENT_MAP);
+
+        // remove all event listaners at the document node
+        document.removeEventListener('keydown', escapeHandler, true);
         $(document).off(DOCUMENT_EVENT_MAP);
+
         // register event handlers at tracking node (removed in initTracking())
         registerStartTrackingHandlers(trackingNode, trackingOptions);
+
         trackingNode = trackingOptions = null;
         overlayNode.detach();
         deinitAutoMode();
@@ -455,13 +447,14 @@ define('io.ox/office/tk/utils/tracking', [
         if (trackingNode && (force || (moveX !== 0) || (moveY !== 0))) {
 
             // insert overlay node on first move event
-            if (!Utils.TOUCH && overlayNode.parent().length === 0) {
+            if (!Utils.TOUCHDEVICE && overlayNode.parent().length === 0) {
                 $('body').append(overlayNode.css('cursor', overlayCursor));
             }
 
             triggerEvent('tracking:move', event, { pageX: pageX, pageY: pageY, moveX: moveX, moveY: moveY, offsetX: pageX - startX, offsetY: pageY - startY });
             lastX = pageX;
             lastY = pageY;
+            lastModifiers = getModifiers(event);
             moved = true;
         }
     }
@@ -512,8 +505,8 @@ define('io.ox/office/tk/utils/tracking', [
      * Event handler for 'touchstart' browser events.
      */
     function touchStartHandler(event) {
-        var touches = event.originalEvent.touches,
-            changed = event.originalEvent.changedTouches;
+        var touches = event.originalEvent.touches;
+        var changed = event.originalEvent.changedTouches;
         if ((touches.length === 1) && (changed.length === 1)) {
             trackingStart(event, 'touch', changed[0].pageX, changed[0].pageY);
         } else {
@@ -525,8 +518,8 @@ define('io.ox/office/tk/utils/tracking', [
      * Event handler for 'touchmove' browser events.
      */
     function touchMoveHandler(event) {
-        var touches = event.originalEvent.touches,
-            changed = event.originalEvent.changedTouches;
+        var touches = event.originalEvent.touches;
+        var changed = event.originalEvent.changedTouches;
         if ((touches.length === 1) && (changed.length === 1)) {
             trackingMove(event, changed[0].pageX, changed[0].pageY);
         } else {
@@ -538,8 +531,8 @@ define('io.ox/office/tk/utils/tracking', [
      * Event handler for 'touchend' browser events.
      */
     function touchEndHandler(event) {
-        var touches = event.originalEvent.touches,
-            changed = event.originalEvent.changedTouches;
+        var touches = event.originalEvent.touches;
+        var changed = event.originalEvent.changedTouches;
         if ((touches.length === 0) && (changed.length === 1)) {
             trackingEnd(event, changed[0].pageX, changed[0].pageY);
         } else {
@@ -555,30 +548,22 @@ define('io.ox/office/tk/utils/tracking', [
      */
     function keyHandler(event) {
         var newModifiers = getModifiers(event);
-        if (_.isObject(lastModifiers) && !_.isEqual(lastModifiers, newModifiers)) {
+        if (!_.isEqual(lastModifiers, newModifiers)) {
             lastModifiers = newModifiers;
-            trackingMove(event, lastX, lastY, true);
+            if (trackModifiers) { trackingMove(event, lastX, lastY, true); }
         }
     }
 
     /**
-     * Event handler for 'keydown' browser events.
+     * Event handler for 'keydown' browser events in capturing phase.
      */
-    function keyDownHandler(event) {
+    function escapeHandler(event) {
         if (event.keyCode === KeyCodes.ESCAPE) {
+            event.stopPropagation();
             cancelTracking();
-        } else {
-            keyHandler(event);
         }
     }
 
-    /**
-     * Event handler for 'keyup' browser events.
-     */
-    function keyUpHandler(event) {
-        keyHandler(event);
-    }
-
     // static class Tracking ==================================================
 
     var Tracking = {};
@@ -708,6 +693,14 @@ define('io.ox/office/tk/utils/tracking', [
      * properties:
      *  - {String} event.trackingType
      *      The tracking type, either 'mouse' or 'touch'.
+     *  - {Boolean} event.shiftKey
+     *      The state of the SHIFT key, copied from the original GUI event.
+     *  - {Boolean} event.altKey
+     *      The state of the ALT key, copied from the original GUI event.
+     *  - {Boolean} event.ctrlKey
+     *      The state of the CTRL key, copied from the original GUI event.
+     *  - {Boolean} event.metaKey
+     *      The state of the META key, copied from the original GUI event.
      *  - {String} event.cursor
      *      The current mouse pointer CSS style. Event handler can modify this
      *      value to dynamically change the mouse pointer while tracking is
@@ -724,14 +717,6 @@ define('io.ox/office/tk/utils/tracking', [
      * following properties and methods:
      *  - {Event} event.originalEvent
      *      The original browser GUI event (mouse or touch event).
-     *  - {Boolean} event.shiftKey
-     *      The state of the SHIFT key, copied from the original GUI event.
-     *  - {Boolean} event.altKey
-     *      The state of the ALT key, copied from the original GUI event.
-     *  - {Boolean} event.ctrlKey
-     *      The state of the CTRL key, copied from the original GUI event.
-     *  - {Boolean} event.metaKey
-     *      The state of the META key, copied from the original GUI event.
      *  - {Function} event.preventDefault
      *      Prevents the default action of the original GUI event.
      *  - {Function} event.stopPropagation
