@@ -6,7 +6,8 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
-  * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Daniel Rentz <daniel.rentz@open-xchange.com>
  */
@@ -153,7 +154,7 @@ module.exports = function (grunt) {
             // a pattern for a valid part of a localized name
             var NAME_PATTERN = LEADING_CHAR_PATTERN + OTHER_CHAR_PATTERN + '*';
             // a regular expression to validate error codes
-            var ERROR_RE = new RegExp('^#[\xa1\xbf]?' + NAME_PATTERN + '([_/]' + OTHER_CHAR_PATTERN + '+)*[!?]?$');
+            var ERROR_RE = new RegExp('^#[\xa1\xbf]?' + NAME_PATTERN + '\\.?([_/]' + OTHER_CHAR_PATTERN + '+\\.?)*[!?]?$');
             // a regular expression to validate functions
             var FUNCTION_RE = new RegExp('^' + NAME_PATTERN + '([._]' + OTHER_CHAR_PATTERN + '+)*\\.?$');
             // a regular expression to validate region names for table ranges
@@ -168,7 +169,7 @@ module.exports = function (grunt) {
                 errors:     { object: true,  re: ERROR_RE,     upper: true },
                 regions:    { object: true,  re: REGION_RE,    upper: false },
                 functions:  { object: true,  re: FUNCTION_RE,  upper: true },
-                cellParams: { object: true,  re: /./,          upper: false },
+                cellParams: { object: true,  re: null,         upper: false },
                 FALSE:      { object: false, re: BOOLEAN_RE,   upper: true },
                 TRUE:       { object: false, re: BOOLEAN_RE,   upper: true },
                 RC:         { object: false, re: RC_PREFIX_RE, upper: true }
@@ -177,7 +178,7 @@ module.exports = function (grunt) {
             // checks the validity of the passed name, according to the regular expression for the passed map entry
             function checkName(regExpData, name, logKey) {
                 Utils.ensureStringNE(name, resPath + ': Invalid resource entry, expecting a string value at key "' + logKey + '".');
-                Utils.ensure(regExpData.re.test(name), resPath + ': Invalid name "' + name + '" for resource entry at key "' + logKey + '".');
+                Utils.ensure(!regExpData.re || regExpData.re.test(name), resPath + ': Invalid name "' + name + '" for resource entry at key "' + logKey + '".');
                 Utils.ensure(!regExpData.upper || (name === name.toUpperCase()), resPath + ': Invalid resource entry, expecting an uppercase name at key "' + logKey + '".');
             }
 
