@@ -7,6 +7,42 @@ module.exports = function (config) {
 
     'use strict';
 
+    // define the list of files used for the test run.
+    // note : f you get something like "mtime is undefined" on the command line ...
+    // it means that one of the search pattern do not result within a real file list ...
+    // and karma calls "files.search(pattern).mtime" ...
+    // So it's up to you to define right pattern here ;-)
+    var files4Test = [
+        '../node_modules/underscore/underscore.js',
+        '../bower_components/jquery/dist/jquery.js',
+        'spec/lib/**/*.js',
+        { pattern: 'apps/**/*.@(js|json)', included: false }, // included false means : included in search path ... but excluded from 'execution' path
+        { pattern: 'spec/globals/**/*.js', included: false },
+        { pattern: 'spec/**/*_spec.js', included: false }
+    ];
+
+    // HACK : global.TEST_MODULE is define within grunt task 'karma.js' !
+    if (global.TEST_MODULE !== undefined && global.TEST_MODULE !== null) {
+        files4Test.push('spec/test-' + global.TEST_MODULE + '.js');
+    } else {
+        files4Test.push('spec/test-all.js');
+    }
+
+    // possible values: config.LOG_DISABLE || config.LOG_ERROR || config.LOG_WARN || config.LOG_INFO || config.LOG_DEBUG
+    var karmaLogLevel = config.LOG_ERROR;
+
+    if (global.LOG_LEVEL !== undefined && global.LOG_LEVEL !== null) {
+        if (global.LOG_LEVEL === 'debug') {
+            karmaLogLevel = config.LOG_DEBUG;
+        } else if (global.LOG_LEVEL === 'info') {
+            karmaLogLevel = config.LOG_INFO;
+        } else if (global.LOG_LEVEL === 'warn') {
+            karmaLogLevel = config.LOG_WARN;
+        } else {
+            karmaLogLevel = config.LOG_ERROR;
+        }
+    }
+
     config.set({
 
         // base path that will be used to resolve all patterns (eg. files, exclude)
@@ -20,15 +56,7 @@ module.exports = function (config) {
         frameworks: ['mocha', 'requirejs', 'chai', 'sinon'],
 
         // list of files / patterns to load in the browser
-        files: [
-            '../node_modules/underscore/underscore.js',
-            '../bower_components/jquery/dist/jquery.js',
-            'spec/lib/**/*.js',
-            'spec/test-all.js',
-            { pattern: 'apps/**/*.@(json|js)', included: false }, // Pattern explanation, see: https://realguess.net/tags/minimatch/
-            { pattern: 'spec/globals/**/*.js', included: false },
-            { pattern: 'spec/**/*_spec.js', included: false }
-        ],
+        files: files4Test,
 
         // list of files to exclude
         exclude: [
@@ -51,8 +79,7 @@ module.exports = function (config) {
         colors: true,
 
         // level of logging
-        // possible values: config.LOG_DISABLE || config.LOG_ERROR || config.LOG_WARN || config.LOG_INFO || config.LOG_DEBUG
-        logLevel: config.LOG_ERROR,
+        logLevel: karmaLogLevel,
 
         // enable / disable watching file and executing tests whenever any file changes
         autoWatch: false,
