@@ -14,7 +14,7 @@
 
 define('globals/apphelper', [
     'globals/sheethelper',
-    'io.ox/office/tk/object/timermixin',
+    'io.ox/office/tk/object/baseobject',
     'io.ox/office/editframework/model/editmodel',
     'io.ox/office/editframework/view/editview',
     'io.ox/office/text/model/model',
@@ -23,13 +23,16 @@ define('globals/apphelper', [
     'io.ox/office/spreadsheet/view/view',
     'io.ox/office/presentation/model/model',
     'io.ox/office/presentation/view/view'
-], function (SheetHelper, TimerMixin, EditModel, EditView, TextModel, TextView, SpreadsheetModel, SpreadsheetView, PresentationModel, PresentationView) {
+], function (SheetHelper, BaseObject, EditModel, EditView, TextModel, TextView, SpreadsheetModel, SpreadsheetView, PresentationModel, PresentationView) {
 
     'use strict';
 
     // helper function that does nothing but returns the calling context
     function noop() { return this; }
 
+    // fake the core root node
+    $('body').append('<div id="io-ox-core" class="abs">');
+
     // class MockBaseView =====================================================
 
     /**
@@ -52,7 +55,7 @@ define('globals/apphelper', [
         this.getToolBarTabs = _.constant({ handleActiveToolbarTab: _.noop });
         this.createClipboardNode = function () { return $('<div class="clipboard">'); };
         this.grabFocus = noop;
-        this.getZoomFactor = _.constant(100);
+        this.getZoomFactor = _.constant(1);
         this.enterBusy = noop;
         this.leaveBusy = noop;
         this.updateBusyProgress = noop;
@@ -92,7 +95,7 @@ define('globals/apphelper', [
 
     function MockSpreadsheetView(app, docModel) {
 
-        MockBaseView.call(this, app, docModel);
+        MockTextFrameworkView.call(this, app, docModel);
 
     } // class MockSpreadsheetView
 
@@ -104,8 +107,8 @@ define('globals/apphelper', [
 
         this.getSlidePane = _.constant({
             setSidePaneWidthDuringLoad: noop,
-            getSlidePaneSelection: $.noop,
-            getSlidePaneContainer: $.noop // no return value like 'noop'
+            getSlidePaneSelection: _.noop,
+            getSlidePaneContainer: _.noop // no return value like 'noop'
         });
 
         this.enableVerticalScrollBar = noop;
@@ -166,7 +169,17 @@ define('globals/apphelper', [
         app.isActive = _.constant(true);
         app.getRootNode = _.constant(winRootNode);
 
-        app.registerDestructor = noop;
+        // provide (most of) the API of a real BaseObject instance (taken from baseapplication.js)
+        var baseContext = new BaseObject(app.getWindowId());
+        (function () {
+            var excludeNames = ['getWindowId', 'getUid', 'listenTo', 'listenOnceTo', 'stopListeningTo', 'destroy'];
+            _.each(BaseObject.prototype, function (method, name) {
+                if (excludeNames.indexOf(name) < 0) {
+                    app[name] = method.bind(baseContext);
+                }
+            });
+        }());
+
         app.onInit = function (callback, context) { initDef.done(callback.bind(context)); };
         app.isImportStarted = function () { return initDef.state() !== 'pending'; };
         app.getImportStartPromise = _.constant(initDef.promise());
@@ -180,12 +193,15 @@ define('globals/apphelper', [
         app.getShortFileName = _.constant('testfile');
         app.getFileExtension = _.constant('xyz');
         app.getFilePath = _.constant(['path', 'to']);
+        app.getFileDescriptor = function () { return { id: '1', folder_id: '1' }; };
         app.registerVisibleStateHandler = noop;
 
         app.setState = noop;
+        app.isEditable = _.constant(true);
         app.isInternalError = _.constant(false);
         app.setInternalError = function () { throw new Error('internal error'); };
         app.isLocallyModified = _.constant(true);
+        app.isOperationsBlockActive = _.constant(false);
         app.setUserState = noop;
         app.sendLogMessage = noop;
 
@@ -194,7 +210,13 @@ define('globals/apphelper', [
         app.addAuthors = noop;
         app.getAuthorColorIndex = _.constant(1);
         app.isMultiSelectionApplication = _.constant(appBaseName !== 'text');
+        app.isSnapshotApp = _.constant(appBaseName !== 'spreadsheet');
         app.getActiveClients = _.constant([]);
+        app.updateUserData = noop;
+
+        app.isTextApp = function () { return (moduleName === 'io.ox/office/text'); };
+        app.isPresentationApp = function () { return (moduleName === 'io.ox/office/presentation'); };
+        app.isSpreadsheetApp = function () { return (moduleName === 'io.ox/office/spreadsheet'); };
 
         app.createImageNode = function (url) {
             var def = new $.Deferred();
@@ -212,18 +234,12 @@ define('globals/apphelper', [
         app.quit = function () {
             docView.destroy();
             docModel.destroy();
-            docModel = docView = docController = null;
-        };
-
-        app.waitForEvent = function (object, event) {
-            var deferred = $.Deferred();
-            $(object).on(event, function () { deferred.resolve(); });
-            return deferred.promise();
+            baseContext.destroy();
+            docModel = docView = docController = baseContext = null;
         };
 
         // synchronous launcher
         app.setLauncher(function () {
-            TimerMixin.call(app);
             docModel = new ModelClass(app);
             var CurrViewClass = (options && options.realView) ? ViewClass : MockViewClass;
             docView = new CurrViewClass(app, docModel);
@@ -333,7 +349,6 @@ define('globals/apphelper', [
             var docModel = app.getModel();
 
             return docModel.updateDocumentFormatting().then(function () {
-                docModel.setEditMode(true);
                 docModel.getSelection().setTextSelection([0, 0]);
                 docModel.setDefaultPaperFormat();
                 return app;
@@ -407,10 +422,7 @@ define('globals/apphelper', [
             app.launch();
 
             var docModel = app.getModel();
-            return docModel.postProcessImport().then(function () {
-                docModel.setEditMode(true);
-                return app;
-            });
+            return docModel.postProcessImport().then(_.constant(app));
         });
     };
 
@@ -432,10 +444,7 @@ define('globals/apphelper', [
             app.launch();
 
             var docModel = app.getModel();
-            return docModel.updateDocumentFormatting().then(function () {
-                docModel.setEditMode(true);
-                return app;
-            });
+            return docModel.updateDocumentFormatting().then(_.constant(app));
         });
     };
 
