@@ -14,12 +14,10 @@
 
 define([
     'globals/apphelper',
-    'io.ox/office/tk/utils/deferredutils',
-    'io.ox/office/tk/object/baseobject',
-    'io.ox/office/tk/object/timermixin',
+    'io.ox/office/tk/utils/scheduler',
     'io.ox/office/editframework/app/seleniumwrapper',
     'io.ox/office/textframework/utils/position'
-], function (AppHelper, DeferredUtils, BaseObject, TimerMixin, SeleniumWrapper, Position) {
+], function (AppHelper, Scheduler, SeleniumWrapper, Position) {
 
     'use strict';
 
@@ -31,6 +29,8 @@ define([
             expect(SeleniumWrapper).to.be.an('object');
         });
 
+        var logMessage = 'test message';
+
         // static methods -----------------------------------------------------
 
         describe('method "getAllFilesInFolder"', function () {
@@ -182,57 +182,45 @@ define([
                 });
 
                 it('should log deferred objects', function (done) {
-                    var infoString = '123-test-infostring';
-                    var testdef = DeferredUtils.createDeferred(docModel.getApp(), infoString);
+                    var deferred = Scheduler.createDeferred('window-1', logMessage);
 
                     testWrappedFn('getRunningJobs', {}).always(function (jobs1) {
                         var index1 = _.findIndex(jobs1.deferred, function (el) {
-                            return el.key === infoString;
+                            return el.logMessage === logMessage;
                         });
-                        expect(index1 >= 0).to.be.true;
+                        expect(index1 >= 0).to.equal(true);
 
-                        testdef.resolve();
+                        deferred.resolve();
 
                         testWrappedFn('getRunningJobs', {}).always(function (jobs2) {
                             var index2 = _.findIndex(jobs2.deferred, function (el) {
-                                return el.key === infoString;
+                                return el.logMessage === logMessage;
                             });
-                            expect(index2 < 0).to.be.true;
+                            expect(index2 < 0).to.equal(true);
                             done();
                         });
                     });
                 });
 
                 it('should log timers', function (done) {
-
-                    var infoString = '123-test-infostring';
-
-                    function TimerClass() {
-                        BaseObject.call(this);
-                        TimerMixin.call(this);
-                    }
-
-                    var obj = new TimerClass();
-                    var timer = obj.executeDelayed(function () {}, { delay: 20, infoString: infoString });
+                    var timer = Scheduler.setTimeout(_.noop, 20, 'window-1', logMessage);
 
                     testWrappedFn('getRunningJobs', {}).always(function (jobs1) {
                         var index1 = _.findIndex(jobs1.timer, function (el) {
-                            return el.key === infoString;
+                            return el.uid === timer;
                         });
-                        expect(index1 >= 0).to.be.true;
+                        expect(index1 >= 0).to.equal(true);
 
                         window.setTimeout(function () {
 
-                            expect(timer.state()).to.equal('resolved');
-
                             testWrappedFn('getRunningJobs', {}).always(function (jobs2) {
                                 var index2 = _.findIndex(jobs2.timer, function (el) {
-                                    return el.key === infoString;
+                                    return el.logMessage === logMessage;
                                 });
-                                expect(index2 < 0).to.be.true;
+                                expect(index2 < 0).to.equal(true);
                                 done();
                             });
-                        }, 20);
+                        }, 30);
                     });
                 });
             });
