@@ -14,11 +14,11 @@
 
 define([
     'globals/apphelper',
-    'io.ox/office/editframework/utils/operationcontext',
     'io.ox/office/editframework/utils/operationerror',
+    'io.ox/office/editframework/model/operationcontext',
     'io.ox/office/editframework/model/autostylecollection',
     'io.ox/office/editframework/model/stylecollection'
-], function (AppHelper, OperationContext, OperationError, AutoStyleCollection, StyleCollection) {
+], function (AppHelper, OperationError, OperationContext, AutoStyleCollection, StyleCollection) {
 
     'use strict';
 
@@ -43,9 +43,9 @@ define([
         var styleSheets2 = null, autoStyles2 = null;
         AppHelper.createEditApp('ooxml').done(function (app) {
             docModel = app.getModel();
-            docModel.registerAttributeDefinitions('A', A_ATTRS);
-            docModel.registerAttributeDefinitions('B', B_ATTRS);
-            docModel.registerAttributeDefinitions('C', C_ATTRS);
+            docModel.registerAttributes('A', A_ATTRS);
+            docModel.registerAttributes('B', B_ATTRS);
+            docModel.registerAttributes('C', C_ATTRS);
             docModel.addStyleCollection(styleSheets1 = new StyleCollection(docModel, 'A', { families: 'B C' }));
             docModel.addStyleCollection(styleSheets2 = new StyleCollection(docModel, 'B', { families: 'A C' }));
             docModel.addAutoStyleCollection(autoStyles1 = new AutoStyleCollection(docModel, 'A', { standardPrefix: 'as', strictMode: true }));
