@@ -98,6 +98,12 @@ define([
             expect(colorDesc).to.have.a.property('css', expCSS);
         }
 
+        function verifyRgbTransformation(css, type, value, expR, expG, expB) {
+            var colorDesc = Color.parseCSS(css).transform(type, value).resolve('', theme);
+            verifyRGB(colorDesc, expR, expG, expB, 1);
+            verifyChannel(colorDesc, 'a', 1);
+        }
+
         // constants ----------------------------------------------------------
 
         describe('constant "AUTO"', function () {
@@ -108,7 +114,25 @@ define([
 
         describe('constant "HYPERLINK"', function () {
             it('should exist', function () {
-                expect(Color.HYPERLINK).to.have.a.property('type');
+                expect(Color.HYPERLINK).to.have.a.property('type', 'scheme');
+            });
+        });
+
+        describe('constant "PLACEHOLDER"', function () {
+            it('should exist', function () {
+                expect(Color.PLACEHOLDER).to.have.a.property('type', 'scheme');
+            });
+        });
+
+        describe('constant "BLACK"', function () {
+            it('should exist', function () {
+                expect(Color.BLACK).to.have.a.property('type');
+            });
+        });
+
+        describe('constant "WHITE"', function () {
+            it('should exist', function () {
+                expect(Color.WHITE).to.have.a.property('type');
             });
         });
 
@@ -239,17 +263,17 @@ define([
                 expect(Color.parseCSS('rgba(64,128,192,2)')).to.equal(null);
             });
             it('should parse function-style HSL(A) color', function () {
-                expect(Color.parseCSS('hsl(60,100%,50%)').toJSON()).to.deep.equal({ type: 'hsl', value: { h: 60000, s: 100000, l: 50000 } });
+                expect(Color.parseCSS('hsl(60,100%,50%)').toJSON()).to.deep.equal({ type: 'hsl', value: { h: 3600000, s: 100000, l: 50000 } });
                 expect(Color.parseCSS('hsl( 0 , 0% , 0% )').toJSON()).to.deep.equal({ type: 'hsl', value: { h: 0, s: 0, l: 0 } });
-                expect(Color.parseCSS('hsla(60,100%,50%,1)').toJSON()).to.deep.equal({ type: 'hsl', value: { h: 60000, s: 100000, l: 50000 } });
-                expect(Color.parseCSS('hsla( 60 , 100% , 50% , 0.42 )').toJSON()).to.deep.equal({ type: 'hsl', value: { h: 60000, s: 100000, l: 50000 }, transformations: [{ type: 'alpha', value: 42000 }] });
-                expect(Color.parseCSS('hsla(60,100%,50%,0)').toJSON()).to.deep.equal({ type: 'hsl', value: { h: 60000, s: 100000, l: 50000 }, transformations: [{ type: 'alpha', value: 0 }] });
+                expect(Color.parseCSS('hsla(60,100%,50%,1)').toJSON()).to.deep.equal({ type: 'hsl', value: { h: 3600000, s: 100000, l: 50000 } });
+                expect(Color.parseCSS('hsla( 60 , 100% , 50% , 0.42 )').toJSON()).to.deep.equal({ type: 'hsl', value: { h: 3600000, s: 100000, l: 50000 }, transformations: [{ type: 'alpha', value: 42000 }] });
+                expect(Color.parseCSS('hsla(60,100%,50%,0)').toJSON()).to.deep.equal({ type: 'hsl', value: { h: 3600000, s: 100000, l: 50000 }, transformations: [{ type: 'alpha', value: 0 }] });
                 expect(Color.parseCSS('hsla(60,100%,50%,0)', true).toJSON()).to.deep.equal({ type: 'auto' });
                 expect(Color.parseCSS('hsl(60,100%)')).to.equal(null);
                 expect(Color.parseCSS('hsl(60,100%,50%,1)')).to.equal(null);
                 expect(Color.parseCSS('hsl(60,100%,50)')).to.equal(null);
                 expect(Color.parseCSS('hsl(60%,100%,50%)')).to.equal(null);
-                expect(Color.parseCSS('hsl(420,200%,50%)').toJSON()).to.deep.equal({ type: 'hsl', value: { h: 60000, s: 100000, l: 50000 } });
+                expect(Color.parseCSS('hsl(420,200%,50%)').toJSON()).to.deep.equal({ type: 'hsl', value: { h: 3600000, s: 100000, l: 50000 } });
                 expect(Color.parseCSS('hsl(60,100%,ff%)')).to.equal(null);
                 expect(Color.parseCSS('hsla(60,100%,50%)')).to.equal(null);
                 expect(Color.parseCSS('hsla(60,100%,50%,1,1)')).to.equal(null);
@@ -301,8 +325,10 @@ define([
                 expect(new Color('rgb', '4080c0').equals(new Color('rgb', '4080C0'))).to.equal(true);
                 expect(new Color('hsl', { h: 25000, s: 50000, l: 75000 }).equals(new Color('hsl', { h: 25000, s: 50000, l: 75000 }))).to.equal(true);
                 expect(new Color('crgb', { r: 25000, g: 50000, b: 75000 }).equals(new Color('crgb', { r: 25000, g: 50000, b: 75000 }))).to.equal(true);
-                expect(new Color('system', 'menu').equals(new Color('system', 'Menu'))).to.equal(true);
-                expect(new Color('preset', 'black').equals(new Color('preset', 'Black'))).to.equal(true);
+                expect(new Color('system', 'menu').equals(new Color('system', 'Menu'))).to.equal(false);
+                expect(new Color('system', 'menu').equals(new Color('system', 'menu'))).to.equal(true);
+                expect(new Color('preset', 'black').equals(new Color('preset', 'Black'))).to.equal(false);
+                expect(new Color('preset', 'black').equals(new Color('preset', 'black'))).to.equal(true);
                 expect(new Color('scheme', 'accent1').equals(new Color('scheme', 'Accent1'))).to.equal(false);
                 expect(new Color('scheme', 'accent1').equals(new Color('scheme', 'accent1'))).to.equal(true);
                 expect(new Color('rgb', '4080c0', [{ type: 'gray' }]).equals(new Color('rgb', '4080C0').transform('gray'))).to.equal(true);
@@ -424,28 +450,28 @@ define([
             });
             it('should return color descriptor for HSL colors', function () {
                 verifyColor('hsl', { h: 0, s: 0, l: 0 }, 0, 0, 0, 0, 0, 0, 1, 0, '000000', 'hsl(0,0%,0%)');
-                verifyColor('hsl', { h: 90000, s: 0, l: 0 }, 0, 0, 0, 90, 0, 0, 1, 0, '000000', 'hsl(90,0%,0%)');
-                verifyColor('hsl', { h: 180000, s: 0, l: 0 }, 0, 0, 0, 180, 0, 0, 1, 0, '000000', 'hsl(180,0%,0%)');
-                verifyColor('hsl', { h: 270000, s: 0, l: 0 }, 0, 0, 0, 270, 0, 0, 1, 0, '000000', 'hsl(270,0%,0%)');
+                verifyColor('hsl', { h: 5400000, s: 0, l: 0 }, 0, 0, 0, 90, 0, 0, 1, 0, '000000', 'hsl(90,0%,0%)');
+                verifyColor('hsl', { h: 10800000, s: 0, l: 0 }, 0, 0, 0, 180, 0, 0, 1, 0, '000000', 'hsl(180,0%,0%)');
+                verifyColor('hsl', { h: 16200000, s: 0, l: 0 }, 0, 0, 0, 270, 0, 0, 1, 0, '000000', 'hsl(270,0%,0%)');
                 verifyColor('hsl', { h: 0, s: 25000, l: 0 }, 0, 0, 0, 0, 0.25, 0, 1, 0, '000000', 'hsl(0,25%,0%)');
-                verifyColor('hsl', { h: 90000, s: 50000, l: 0 }, 0, 0, 0, 90, 0.5, 0, 1, 0, '000000', 'hsl(90,50%,0%)');
-                verifyColor('hsl', { h: 180000, s: 75000, l: 0 }, 0, 0, 0, 180, 0.75, 0, 1, 0, '000000', 'hsl(180,75%,0%)');
-                verifyColor('hsl', { h: 270000, s: 100000, l: 0 }, 0, 0, 0, 270, 1, 0, 1, 0, '000000', 'hsl(270,100%,0%)');
+                verifyColor('hsl', { h: 5400000, s: 50000, l: 0 }, 0, 0, 0, 90, 0.5, 0, 1, 0, '000000', 'hsl(90,50%,0%)');
+                verifyColor('hsl', { h: 10800000, s: 75000, l: 0 }, 0, 0, 0, 180, 0.75, 0, 1, 0, '000000', 'hsl(180,75%,0%)');
+                verifyColor('hsl', { h: 16200000, s: 100000, l: 0 }, 0, 0, 0, 270, 1, 0, 1, 0, '000000', 'hsl(270,100%,0%)');
                 verifyColor('hsl', { h: 0, s: 0, l: 25000 }, 0.25, 0.25, 0.25, 0, 0, 0.25, 1, 0.25, '404040', 'hsl(0,0%,25%)');
-                verifyColor('hsl', { h: 90000, s: 0, l: 50000 }, 0.5, 0.5, 0.5, 90, 0, 0.5, 1, 0.5, '808080', 'hsl(90,0%,50%)');
-                verifyColor('hsl', { h: 180000, s: 0, l: 75000 }, 0.75, 0.75, 0.75, 180, 0, 0.75, 1, 0.75, 'bfbfbf', 'hsl(180,0%,75%)');
-                verifyColor('hsl', { h: 270000, s: 0, l: 100000 }, 1, 1, 1, 270, 0, 1, 1, 1, 'ffffff', 'hsl(270,0%,100%)');
+                verifyColor('hsl', { h: 5400000, s: 0, l: 50000 }, 0.5, 0.5, 0.5, 90, 0, 0.5, 1, 0.5, '808080', 'hsl(90,0%,50%)');
+                verifyColor('hsl', { h: 10800000, s: 0, l: 75000 }, 0.75, 0.75, 0.75, 180, 0, 0.75, 1, 0.75, 'bfbfbf', 'hsl(180,0%,75%)');
+                verifyColor('hsl', { h: 16200000, s: 0, l: 100000 }, 1, 1, 1, 270, 0, 1, 1, 1, 'ffffff', 'hsl(270,0%,100%)');
                 verifyColor('hsl', { h: 0, s: 50000, l: 100000 }, 1, 1, 1, 0, 0.5, 1, 1, 1, 'ffffff', 'hsl(0,50%,100%)');
-                verifyColor('hsl', { h: 180000, s: 100000, l: 100000 }, 1, 1, 1, 180, 1, 1, 1, 1, 'ffffff', 'hsl(180,100%,100%)');
-                verifyColor('hsl', { h: 10000, s: 20000, l: 20000 }, 0.24, 0.173, 0.16, 10, 0.2, 0.2, 1, 0.187, '3d2c29', 'hsl(10,20%,20%)');
-                verifyColor('hsl', { h: 50000, s: 20000, l: 50000 }, 0.6, 0.567, 0.4, 50, 0.2, 0.5, 1, 0.562, '999166', 'hsl(50,20%,50%)');
-                verifyColor('hsl', { h: 90000, s: 20000, l: 80000 }, 0.8, 0.84, 0.76, 90, 0.2, 0.8, 1, 0.826, 'ccd6c2', 'hsl(90,20%,80%)');
-                verifyColor('hsl', { h: 130000, s: 50000, l: 20000 }, 0.1, 0.3, 0.133, 130, 0.5, 0.2, 1, 0.245, '1a4d22', 'hsl(130,50%,20%)');
-                verifyColor('hsl', { h: 170000, s: 50000, l: 50000 }, 0.25, 0.75, 0.667, 170, 0.5, 0.5, 1, 0.638, '40bfaa', 'hsl(170,50%,50%)');
-                verifyColor('hsl', { h: 210000, s: 50000, l: 80000 }, 0.7, 0.8, 0.9, 210, 0.5, 0.8, 1, 0.786, 'b3cce6', 'hsl(210,50%,80%)');
-                verifyColor('hsl', { h: 250000, s: 80000, l: 20000 }, 0.093, 0.04, 0.36, 250, 0.8, 0.2, 1, 0.074, '180a5c', 'hsl(250,80%,20%)');
-                verifyColor('hsl', { h: 290000, s: 80000, l: 50000 }, 0.767, 0.1, 0.9, 290, 0.8, 0.5, 1, 0.299, 'c41ae6', 'hsl(290,80%,50%)');
-                verifyColor('hsl', { h: 330000, s: 80000, l: 80000 }, 0.96, 0.64, 0.8, 330, 0.8, 0.8, 1, 0.72, 'f5a3cc', 'hsl(330,80%,80%)');
+                verifyColor('hsl', { h: 10800000, s: 100000, l: 100000 }, 1, 1, 1, 180, 1, 1, 1, 1, 'ffffff', 'hsl(180,100%,100%)');
+                verifyColor('hsl', { h: 600000, s: 20000, l: 20000 }, 0.24, 0.173, 0.16, 10, 0.2, 0.2, 1, 0.187, '3d2c29', 'hsl(10,20%,20%)');
+                verifyColor('hsl', { h: 3000000, s: 20000, l: 50000 }, 0.6, 0.567, 0.4, 50, 0.2, 0.5, 1, 0.562, '999166', 'hsl(50,20%,50%)');
+                verifyColor('hsl', { h: 5400000, s: 20000, l: 80000 }, 0.8, 0.84, 0.76, 90, 0.2, 0.8, 1, 0.826, 'ccd6c2', 'hsl(90,20%,80%)');
+                verifyColor('hsl', { h: 7800000, s: 50000, l: 20000 }, 0.1, 0.3, 0.133, 130, 0.5, 0.2, 1, 0.245, '1a4d22', 'hsl(130,50%,20%)');
+                verifyColor('hsl', { h: 10200000, s: 50000, l: 50000 }, 0.25, 0.75, 0.667, 170, 0.5, 0.5, 1, 0.638, '40bfaa', 'hsl(170,50%,50%)');
+                verifyColor('hsl', { h: 12600000, s: 50000, l: 80000 }, 0.7, 0.8, 0.9, 210, 0.5, 0.8, 1, 0.786, 'b3cce6', 'hsl(210,50%,80%)');
+                verifyColor('hsl', { h: 15000000, s: 80000, l: 20000 }, 0.093, 0.04, 0.36, 250, 0.8, 0.2, 1, 0.074, '180a5c', 'hsl(250,80%,20%)');
+                verifyColor('hsl', { h: 17400000, s: 80000, l: 50000 }, 0.767, 0.1, 0.9, 290, 0.8, 0.5, 1, 0.299, 'c41ae6', 'hsl(290,80%,50%)');
+                verifyColor('hsl', { h: 19800000, s: 80000, l: 80000 }, 0.96, 0.64, 0.8, 330, 0.8, 0.8, 1, 0.72, 'f5a3cc', 'hsl(330,80%,80%)');
             });
             it('should return "dark" flag', function () {
                 expect(new Color('preset', 'black').resolve('')).to.have.a.property('dark', true);
@@ -478,94 +504,94 @@ define([
                 verifyTransformedColor('rgba(255,0,0,0.5)', 'alphaOff', 750000, 1, 0, 0, 0, 1, 0.5, 1, 0.213, 'ff0000', '#ff0000');
             });
             it('should resolve color with "red" transformation', function () {
-                verifyTransformedColor('#666666', 'red', 0, 0, 0.4, 0.4, 180, 1, 0.2, 1, 0.315, '006666', '#006666');
-                verifyTransformedColor('#666666', 'red', 20000, 0.2, 0.4, 0.4, 180, 0.333, 0.3, 1, 0.357, '336666', '#336666');
-                verifyTransformedColor('#666666', 'red', 40000, 0.4, 0.4, 0.4, 0, 0, 0.4, 1, 0.4, '666666', '#666666');
-                verifyTransformedColor('#666666', 'red', 60000, 0.6, 0.4, 0.4, 0, 0.2, 0.5, 1, 0.443, '996666', '#996666');
-                verifyTransformedColor('#666666', 'red', 80000, 0.8, 0.4, 0.4, 0, 0.5, 0.6, 1, 0.485, 'cc6666', '#cc6666');
-                verifyTransformedColor('#666666', 'red', 100000, 1, 0.4, 0.4, 0, 1, 0.7, 1, 0.528, 'ff6666', '#ff6666');
+                verifyRgbTransformation('#666666', 'red', 0, 0, 0.4, 0.4);
+                verifyRgbTransformation('#666666', 'red', 20000, 0.492, 0.4, 0.4);
+                verifyRgbTransformation('#666666', 'red', 40000, 0.668, 0.4, 0.4);
+                verifyRgbTransformation('#666666', 'red', 60000, 0.798, 0.4, 0.4);
+                verifyRgbTransformation('#666666', 'red', 80000, 0.906, 0.4, 0.4);
+                verifyRgbTransformation('#666666', 'red', 100000, 1, 0.4, 0.4);
             });
             it('should resolve color with "redMod" transformation', function () {
-                verifyTransformedColor('#666666', 'redMod', 0, 0, 0.4, 0.4, 180, 1, 0.2, 1, 0.315, '006666', '#006666');
-                verifyTransformedColor('#666666', 'redMod', 50000, 0.2, 0.4, 0.4, 180, 0.333, 0.3, 1, 0.357, '336666', '#336666');
-                verifyTransformedColor('#666666', 'redMod', 100000, 0.4, 0.4, 0.4, 0, 0, 0.4, 1, 0.4, '666666', '#666666');
-                verifyTransformedColor('#666666', 'redMod', 150000, 0.6, 0.4, 0.4, 0, 0.2, 0.5, 1, 0.443, '996666', '#996666');
-                verifyTransformedColor('#666666', 'redMod', 200000, 0.8, 0.4, 0.4, 0, 0.5, 0.6, 1, 0.485, 'cc6666', '#cc6666');
-                verifyTransformedColor('#666666', 'redMod', 250000, 1, 0.4, 0.4, 0, 1, 0.7, 1, 0.528, 'ff6666', '#ff6666');
-                verifyTransformedColor('#666666', 'redMod', 300000, 1, 0.4, 0.4, 0, 1, 0.7, 1, 0.528, 'ff6666', '#ff6666');
+                verifyRgbTransformation('#666666', 'redMod', 0, 0, 0.4, 0.4);
+                verifyRgbTransformation('#666666', 'redMod', 50000, 0.295, 0.4, 0.4);
+                verifyRgbTransformation('#666666', 'redMod', 100000, 0.4, 0.4, 0.4);
+                verifyRgbTransformation('#666666', 'redMod', 150000, 0.478, 0.4, 0.4);
+                verifyRgbTransformation('#666666', 'redMod', 200000, 0.543, 0.4, 0.4);
+                verifyRgbTransformation('#666666', 'redMod', 300000, 0.649, 0.4, 0.4);
+                verifyRgbTransformation('#666666', 'redMod', 500000, 0.813, 0.4, 0.4);
+                verifyRgbTransformation('#666666', 'redMod', 900000, 1, 0.4, 0.4);
             });
             it('should resolve color with "redOff" transformation', function () {
-                verifyTransformedColor('#666666', 'redOff', -60000, 0, 0.4, 0.4, 180, 1, 0.2, 1, 0.315, '006666', '#006666');
-                verifyTransformedColor('#666666', 'redOff', -40000, 0, 0.4, 0.4, 180, 1, 0.2, 1, 0.315, '006666', '#006666');
-                verifyTransformedColor('#666666', 'redOff', -20000, 0.2, 0.4, 0.4, 180, 0.333, 0.3, 1, 0.357, '336666', '#336666');
-                verifyTransformedColor('#666666', 'redOff', 0, 0.4, 0.4, 0.4, 0, 0, 0.4, 1, 0.4, '666666', '#666666');
-                verifyTransformedColor('#666666', 'redOff', 20000, 0.6, 0.4, 0.4, 0, 0.2, 0.5, 1, 0.443, '996666', '#996666');
-                verifyTransformedColor('#666666', 'redOff', 40000, 0.8, 0.4, 0.4, 0, 0.5, 0.6, 1, 0.485, 'cc6666', '#cc6666');
-                verifyTransformedColor('#666666', 'redOff', 60000, 1, 0.4, 0.4, 0, 1, 0.7, 1, 0.528, 'ff6666', '#ff6666');
-                verifyTransformedColor('#666666', 'redOff', 80000, 1, 0.4, 0.4, 0, 1, 0.7, 1, 0.528, 'ff6666', '#ff6666');
+                verifyRgbTransformation('#666666', 'redOff', -20000, 0, 0.4, 0.4);
+                verifyRgbTransformation('#666666', 'redOff', -10000, 0.197, 0.4, 0.4);
+                verifyRgbTransformation('#666666', 'redOff', 0, 0.4, 0.4, 0.4);
+                verifyRgbTransformation('#666666', 'redOff', 10000, 0.518, 0.4, 0.4);
+                verifyRgbTransformation('#666666', 'redOff', 40000, 0.753, 0.4, 0.4);
+                verifyRgbTransformation('#666666', 'redOff', 70000, 0.919, 0.4, 0.4);
+                verifyRgbTransformation('#666666', 'redOff', 90000, 1, 0.4, 0.4);
             });
             it('should resolve color with "green" transformation', function () {
-                verifyTransformedColor('#666666', 'green', 0, 0.4, 0, 0.4, 300, 1, 0.2, 1, 0.114, '660066', '#660066');
-                verifyTransformedColor('#666666', 'green', 20000, 0.4, 0.2, 0.4, 300, 0.333, 0.3, 1, 0.257, '663366', '#663366');
-                verifyTransformedColor('#666666', 'green', 40000, 0.4, 0.4, 0.4, 0, 0, 0.4, 1, 0.4, '666666', '#666666');
-                verifyTransformedColor('#666666', 'green', 60000, 0.4, 0.6, 0.4, 120, 0.2, 0.5, 1, 0.543, '669966', '#669966');
-                verifyTransformedColor('#666666', 'green', 80000, 0.4, 0.8, 0.4, 120, 0.5, 0.6, 1, 0.686, '66cc66', '#66cc66');
-                verifyTransformedColor('#666666', 'green', 100000, 0.4, 1, 0.4, 120, 1, 0.7, 1, 0.829, '66ff66', '#66ff66');
+                verifyRgbTransformation('#666666', 'green', 0, 0.4, 0, 0.4);
+                verifyRgbTransformation('#666666', 'green', 20000, 0.4, 0.492, 0.4);
+                verifyRgbTransformation('#666666', 'green', 40000, 0.4, 0.668, 0.4);
+                verifyRgbTransformation('#666666', 'green', 60000, 0.4, 0.798, 0.4);
+                verifyRgbTransformation('#666666', 'green', 80000, 0.4, 0.906, 0.4);
+                verifyRgbTransformation('#666666', 'green', 100000, 0.4, 1, 0.4);
             });
             it('should resolve color with "greenMod" transformation', function () {
-                verifyTransformedColor('#666666', 'greenMod', 0, 0.4, 0, 0.4, 300, 1, 0.2, 1, 0.114, '660066', '#660066');
-                verifyTransformedColor('#666666', 'greenMod', 50000, 0.4, 0.2, 0.4, 300, 0.333, 0.3, 1, 0.257, '663366', '#663366');
-                verifyTransformedColor('#666666', 'greenMod', 100000, 0.4, 0.4, 0.4, 0, 0, 0.4, 1, 0.4, '666666', '#666666');
-                verifyTransformedColor('#666666', 'greenMod', 150000, 0.4, 0.6, 0.4, 120, 0.2, 0.5, 1, 0.543, '669966', '#669966');
-                verifyTransformedColor('#666666', 'greenMod', 200000, 0.4, 0.8, 0.4, 120, 0.5, 0.6, 1, 0.686, '66cc66', '#66cc66');
-                verifyTransformedColor('#666666', 'greenMod', 250000, 0.4, 1, 0.4, 120, 1, 0.7, 1, 0.829, '66ff66', '#66ff66');
-                verifyTransformedColor('#666666', 'greenMod', 300000, 0.4, 1, 0.4, 120, 1, 0.7, 1, 0.829, '66ff66', '#66ff66');
+                verifyRgbTransformation('#666666', 'greenMod', 0, 0.4, 0, 0.4);
+                verifyRgbTransformation('#666666', 'greenMod', 50000, 0.4, 0.295, 0.4);
+                verifyRgbTransformation('#666666', 'greenMod', 100000, 0.4, 0.4, 0.4);
+                verifyRgbTransformation('#666666', 'greenMod', 150000, 0.4, 0.478, 0.4);
+                verifyRgbTransformation('#666666', 'greenMod', 200000, 0.4, 0.543, 0.4);
+                verifyRgbTransformation('#666666', 'greenMod', 300000, 0.4, 0.649, 0.4);
+                verifyRgbTransformation('#666666', 'greenMod', 500000, 0.4, 0.813, 0.4);
+                verifyRgbTransformation('#666666', 'greenMod', 900000, 0.4, 1, 0.4);
             });
             it('should resolve color with "greenMod" transformation', function () {
-                verifyTransformedColor('#666666', 'greenOff', -60000, 0.4, 0, 0.4, 300, 1, 0.2, 1, 0.114, '660066', '#660066');
-                verifyTransformedColor('#666666', 'greenOff', -40000, 0.4, 0, 0.4, 300, 1, 0.2, 1, 0.114, '660066', '#660066');
-                verifyTransformedColor('#666666', 'greenOff', -20000, 0.4, 0.2, 0.4, 300, 0.333, 0.3, 1, 0.257, '663366', '#663366');
-                verifyTransformedColor('#666666', 'greenOff', 0, 0.4, 0.4, 0.4, 0, 0, 0.4, 1, 0.4, '666666', '#666666');
-                verifyTransformedColor('#666666', 'greenOff', 20000, 0.4, 0.6, 0.4, 120, 0.2, 0.5, 1, 0.543, '669966', '#669966');
-                verifyTransformedColor('#666666', 'greenOff', 40000, 0.4, 0.8, 0.4, 120, 0.5, 0.6, 1, 0.686, '66cc66', '#66cc66');
-                verifyTransformedColor('#666666', 'greenOff', 60000, 0.4, 1, 0.4, 120, 1, 0.7, 1, 0.829, '66ff66', '#66ff66');
-                verifyTransformedColor('#666666', 'greenOff', 80000, 0.4, 1, 0.4, 120, 1, 0.7, 1, 0.829, '66ff66', '#66ff66');
+                verifyRgbTransformation('#666666', 'greenOff', -20000, 0.4, 0, 0.4);
+                verifyRgbTransformation('#666666', 'greenOff', -10000, 0.4, 0.197, 0.4);
+                verifyRgbTransformation('#666666', 'greenOff', 0, 0.4, 0.4, 0.4);
+                verifyRgbTransformation('#666666', 'greenOff', 10000, 0.4, 0.518, 0.4);
+                verifyRgbTransformation('#666666', 'greenOff', 40000, 0.4, 0.753, 0.4);
+                verifyRgbTransformation('#666666', 'greenOff', 70000, 0.4, 0.919, 0.4);
+                verifyRgbTransformation('#666666', 'greenOff', 90000, 0.4, 1, 0.4);
             });
             it('should resolve color with "blue" transformation', function () {
-                verifyTransformedColor('#666666', 'blue', 0, 0.4, 0.4, 0, 60, 1, 0.2, 1, 0.371, '666600', '#666600');
-                verifyTransformedColor('#666666', 'blue', 20000, 0.4, 0.4, 0.2, 60, 0.333, 0.3, 1, 0.386, '666633', '#666633');
-                verifyTransformedColor('#666666', 'blue', 40000, 0.4, 0.4, 0.4, 0, 0, 0.4, 1, 0.4, '666666', '#666666');
-                verifyTransformedColor('#666666', 'blue', 60000, 0.4, 0.4, 0.6, 240, 0.2, 0.5, 1, 0.414, '666699', '#666699');
-                verifyTransformedColor('#666666', 'blue', 80000, 0.4, 0.4, 0.8, 240, 0.5, 0.6, 1, 0.429, '6666cc', '#6666cc');
-                verifyTransformedColor('#666666', 'blue', 100000, 0.4, 0.4, 1, 240, 1, 0.7, 1, 0.443, '6666ff', '#6666ff');
+                verifyRgbTransformation('#666666', 'blue', 0, 0.4, 0.4, 0);
+                verifyRgbTransformation('#666666', 'blue', 20000, 0.4, 0.4, 0.492);
+                verifyRgbTransformation('#666666', 'blue', 40000, 0.4, 0.4, 0.668);
+                verifyRgbTransformation('#666666', 'blue', 60000, 0.4, 0.4, 0.798);
+                verifyRgbTransformation('#666666', 'blue', 80000, 0.4, 0.4, 0.906);
+                verifyRgbTransformation('#666666', 'blue', 100000, 0.4, 0.4, 1);
             });
             it('should resolve color with "blueMod" transformation', function () {
-                verifyTransformedColor('#666666', 'blueMod', 0, 0.4, 0.4, 0, 60, 1, 0.2, 1, 0.371, '666600', '#666600');
-                verifyTransformedColor('#666666', 'blueMod', 50000, 0.4, 0.4, 0.2, 60, 0.333, 0.3, 1, 0.386, '666633', '#666633');
-                verifyTransformedColor('#666666', 'blueMod', 100000, 0.4, 0.4, 0.4, 0, 0, 0.4, 1, 0.4, '666666', '#666666');
-                verifyTransformedColor('#666666', 'blueMod', 150000, 0.4, 0.4, 0.6, 240, 0.2, 0.5, 1, 0.414, '666699', '#666699');
-                verifyTransformedColor('#666666', 'blueMod', 200000, 0.4, 0.4, 0.8, 240, 0.5, 0.6, 1, 0.429, '6666cc', '#6666cc');
-                verifyTransformedColor('#666666', 'blueMod', 250000, 0.4, 0.4, 1, 240, 1, 0.7, 1, 0.443, '6666ff', '#6666ff');
-                verifyTransformedColor('#666666', 'blueMod', 300000, 0.4, 0.4, 1, 240, 1, 0.7, 1, 0.443, '6666ff', '#6666ff');
+                verifyRgbTransformation('#666666', 'blueMod', 0, 0.4, 0.4, 0);
+                verifyRgbTransformation('#666666', 'blueMod', 50000, 0.4, 0.4, 0.295);
+                verifyRgbTransformation('#666666', 'blueMod', 100000, 0.4, 0.4, 0.4);
+                verifyRgbTransformation('#666666', 'blueMod', 150000, 0.4, 0.4, 0.478);
+                verifyRgbTransformation('#666666', 'blueMod', 200000, 0.4, 0.4, 0.543);
+                verifyRgbTransformation('#666666', 'blueMod', 300000, 0.4, 0.4, 0.649);
+                verifyRgbTransformation('#666666', 'blueMod', 500000, 0.4, 0.4, 0.813);
+                verifyRgbTransformation('#666666', 'blueMod', 900000, 0.4, 0.4, 1);
             });
             it('should resolve color with "blueOff" transformation', function () {
-                verifyTransformedColor('#666666', 'blueOff', -60000, 0.4, 0.4, 0, 60, 1, 0.2, 1, 0.371, '666600', '#666600');
-                verifyTransformedColor('#666666', 'blueOff', -40000, 0.4, 0.4, 0, 60, 1, 0.2, 1, 0.371, '666600', '#666600');
-                verifyTransformedColor('#666666', 'blueOff', -20000, 0.4, 0.4, 0.2, 60, 0.333, 0.3, 1, 0.386, '666633', '#666633');
-                verifyTransformedColor('#666666', 'blueOff', 0, 0.4, 0.4, 0.4, 0, 0, 0.4, 1, 0.4, '666666', '#666666');
-                verifyTransformedColor('#666666', 'blueOff', 20000, 0.4, 0.4, 0.6, 240, 0.2, 0.5, 1, 0.414, '666699', '#666699');
-                verifyTransformedColor('#666666', 'blueOff', 40000, 0.4, 0.4, 0.8, 240, 0.5, 0.6, 1, 0.429, '6666cc', '#6666cc');
-                verifyTransformedColor('#666666', 'blueOff', 60000, 0.4, 0.4, 1, 240, 1, 0.7, 1, 0.443, '6666ff', '#6666ff');
-                verifyTransformedColor('#666666', 'blueOff', 80000, 0.4, 0.4, 1, 240, 1, 0.7, 1, 0.443, '6666ff', '#6666ff');
+                verifyRgbTransformation('#666666', 'blueOff', -20000, 0.4, 0.4, 0);
+                verifyRgbTransformation('#666666', 'blueOff', -10000, 0.4, 0.4, 0.197);
+                verifyRgbTransformation('#666666', 'blueOff', 0, 0.4, 0.4, 0.4);
+                verifyRgbTransformation('#666666', 'blueOff', 10000, 0.4, 0.4, 0.518);
+                verifyRgbTransformation('#666666', 'blueOff', 40000, 0.4, 0.4, 0.753);
+                verifyRgbTransformation('#666666', 'blueOff', 70000, 0.4, 0.4, 0.919);
+                verifyRgbTransformation('#666666', 'blueOff', 90000, 0.4, 0.4, 1);
             });
             it('should resolve color with "hue" transformation', function () {
                 verifyTransformedColor('hsl(120,40%,40%)', 'hue', 0, 0.56, 0.24, 0.24, 0, 0.4, 0.4, 1, 0.308, '8f3d3d', 'hsl(0,40%,40%)');
-                verifyTransformedColor('hsl(120,40%,40%)', 'hue', 60000, 0.56, 0.56, 0.24, 60, 0.4, 0.4, 1, 0.537, '8f8f3d', 'hsl(60,40%,40%)');
-                verifyTransformedColor('hsl(120,40%,40%)', 'hue', 120000, 0.24, 0.56, 0.24, 120, 0.4, 0.4, 1, 0.469, '3d8f3d', 'hsl(120,40%,40%)');
-                verifyTransformedColor('hsl(120,40%,40%)', 'hue', 180000, 0.24, 0.56, 0.56, 180, 0.4, 0.4, 1, 0.492, '3d8f8f', 'hsl(180,40%,40%)');
-                verifyTransformedColor('hsl(120,40%,40%)', 'hue', 240000, 0.24, 0.24, 0.56, 240, 0.4, 0.4, 1, 0.263, '3d3d8f', 'hsl(240,40%,40%)');
-                verifyTransformedColor('hsl(120,40%,40%)', 'hue', 300000, 0.56, 0.24, 0.56, 300, 0.4, 0.4, 1, 0.331, '8f3d8f', 'hsl(300,40%,40%)');
-                verifyTransformedColor('hsl(120,40%,40%)', 'hue', 360000, 0.56, 0.24, 0.24, 0, 0.4, 0.4, 1, 0.308, '8f3d3d', 'hsl(0,40%,40%)');
+                verifyTransformedColor('hsl(120,40%,40%)', 'hue', 3600000, 0.56, 0.56, 0.24, 60, 0.4, 0.4, 1, 0.537, '8f8f3d', 'hsl(60,40%,40%)');
+                verifyTransformedColor('hsl(120,40%,40%)', 'hue', 7200000, 0.24, 0.56, 0.24, 120, 0.4, 0.4, 1, 0.469, '3d8f3d', 'hsl(120,40%,40%)');
+                verifyTransformedColor('hsl(120,40%,40%)', 'hue', 10800000, 0.24, 0.56, 0.56, 180, 0.4, 0.4, 1, 0.492, '3d8f8f', 'hsl(180,40%,40%)');
+                verifyTransformedColor('hsl(120,40%,40%)', 'hue', 14400000, 0.24, 0.24, 0.56, 240, 0.4, 0.4, 1, 0.263, '3d3d8f', 'hsl(240,40%,40%)');
+                verifyTransformedColor('hsl(120,40%,40%)', 'hue', 18000000, 0.56, 0.24, 0.56, 300, 0.4, 0.4, 1, 0.331, '8f3d8f', 'hsl(300,40%,40%)');
+                verifyTransformedColor('hsl(120,40%,40%)', 'hue', 21600000, 0.56, 0.24, 0.24, 0, 0.4, 0.4, 1, 0.308, '8f3d3d', 'hsl(0,40%,40%)');
             });
             it('should resolve color with "hueMod" transformation', function () {
                 verifyTransformedColor('hsl(120,40%,40%)', 'hueMod', 0, 0.56, 0.24, 0.24, 0, 0.4, 0.4, 1, 0.308, '8f3d3d', 'hsl(0,40%,40%)');
@@ -575,20 +601,18 @@ define([
                 verifyTransformedColor('hsl(120,40%,40%)', 'hueMod', 200000, 0.24, 0.24, 0.56, 240, 0.4, 0.4, 1, 0.263, '3d3d8f', 'hsl(240,40%,40%)');
                 verifyTransformedColor('hsl(120,40%,40%)', 'hueMod', 250000, 0.56, 0.24, 0.56, 300, 0.4, 0.4, 1, 0.331, '8f3d8f', 'hsl(300,40%,40%)');
                 verifyTransformedColor('hsl(120,40%,40%)', 'hueMod', 300000, 0.56, 0.24, 0.24, 0, 0.4, 0.4, 1, 0.308, '8f3d3d', 'hsl(0,40%,40%)');
-                verifyTransformedColor('hsl(120,40%,40%)', 'hueMod', 350000, 0.56, 0.56, 0.24, 60, 0.4, 0.4, 1, 0.537, '8f8f3d', 'hsl(60,40%,40%)');
+                verifyTransformedColor('hsl(120,40%,40%)', 'hueMod', 350000, 0.56, 0.24, 0.24, 0, 0.4, 0.4, 1, 0.308, '8f3d3d', 'hsl(0,40%,40%)');
             });
             it('should resolve color with "hueOff" transformation', function () {
-                verifyTransformedColor('hsl(120,40%,40%)', 'hueOff', -300000, 0.24, 0.56, 0.56, 180, 0.4, 0.4, 1, 0.492, '3d8f8f', 'hsl(180,40%,40%)');
-                verifyTransformedColor('hsl(120,40%,40%)', 'hueOff', -240000, 0.24, 0.24, 0.56, 240, 0.4, 0.4, 1, 0.263, '3d3d8f', 'hsl(240,40%,40%)');
-                verifyTransformedColor('hsl(120,40%,40%)', 'hueOff', -180000, 0.56, 0.24, 0.56, 300, 0.4, 0.4, 1, 0.331, '8f3d8f', 'hsl(300,40%,40%)');
-                verifyTransformedColor('hsl(120,40%,40%)', 'hueOff', -120000, 0.56, 0.24, 0.24, 0, 0.4, 0.4, 1, 0.308, '8f3d3d', 'hsl(0,40%,40%)');
-                verifyTransformedColor('hsl(120,40%,40%)', 'hueOff', -60000, 0.56, 0.56, 0.24, 60, 0.4, 0.4, 1, 0.537, '8f8f3d', 'hsl(60,40%,40%)');
+                verifyTransformedColor('hsl(120,40%,40%)', 'hueOff', -10800000, 0.56, 0.24, 0.24, 0, 0.4, 0.4, 1, 0.308, '8f3d3d', 'hsl(0,40%,40%)');
+                verifyTransformedColor('hsl(120,40%,40%)', 'hueOff', -7200000, 0.56, 0.24, 0.24, 0, 0.4, 0.4, 1, 0.308, '8f3d3d', 'hsl(0,40%,40%)');
+                verifyTransformedColor('hsl(120,40%,40%)', 'hueOff', -3600000, 0.56, 0.56, 0.24, 60, 0.4, 0.4, 1, 0.537, '8f8f3d', 'hsl(60,40%,40%)');
                 verifyTransformedColor('hsl(120,40%,40%)', 'hueOff', 0, 0.24, 0.56, 0.24, 120, 0.4, 0.4, 1, 0.469, '3d8f3d', 'hsl(120,40%,40%)');
-                verifyTransformedColor('hsl(120,40%,40%)', 'hueOff', 60000, 0.24, 0.56, 0.56, 180, 0.4, 0.4, 1, 0.492, '3d8f8f', 'hsl(180,40%,40%)');
-                verifyTransformedColor('hsl(120,40%,40%)', 'hueOff', 120000, 0.24, 0.24, 0.56, 240, 0.4, 0.4, 1, 0.263, '3d3d8f', 'hsl(240,40%,40%)');
-                verifyTransformedColor('hsl(120,40%,40%)', 'hueOff', 180000, 0.56, 0.24, 0.56, 300, 0.4, 0.4, 1, 0.331, '8f3d8f', 'hsl(300,40%,40%)');
-                verifyTransformedColor('hsl(120,40%,40%)', 'hueOff', 240000, 0.56, 0.24, 0.24, 0, 0.4, 0.4, 1, 0.308, '8f3d3d', 'hsl(0,40%,40%)');
-                verifyTransformedColor('hsl(120,40%,40%)', 'hueOff', 300000, 0.56, 0.56, 0.24, 60, 0.4, 0.4, 1, 0.537, '8f8f3d', 'hsl(60,40%,40%)');
+                verifyTransformedColor('hsl(120,40%,40%)', 'hueOff', 3600000, 0.24, 0.56, 0.56, 180, 0.4, 0.4, 1, 0.492, '3d8f8f', 'hsl(180,40%,40%)');
+                verifyTransformedColor('hsl(120,40%,40%)', 'hueOff', 7200000, 0.24, 0.24, 0.56, 240, 0.4, 0.4, 1, 0.263, '3d3d8f', 'hsl(240,40%,40%)');
+                verifyTransformedColor('hsl(120,40%,40%)', 'hueOff', 10800000, 0.56, 0.24, 0.56, 300, 0.4, 0.4, 1, 0.331, '8f3d8f', 'hsl(300,40%,40%)');
+                verifyTransformedColor('hsl(120,40%,40%)', 'hueOff', 14400000, 0.56, 0.24, 0.24, 0, 0.4, 0.4, 1, 0.308, '8f3d3d', 'hsl(0,40%,40%)');
+                verifyTransformedColor('hsl(120,40%,40%)', 'hueOff', 18000000, 0.56, 0.24, 0.24, 0, 0.4, 0.4, 1, 0.308, '8f3d3d', 'hsl(0,40%,40%)');
             });
             it('should resolve color with "sat" transformation', function () {
                 verifyTransformedColor('hsl(120,40%,40%)', 'sat', 0, 0.4, 0.4, 0.4, 120, 0, 0.4, 1, 0.4, '666666', 'hsl(120,0%,40%)');
@@ -645,20 +669,20 @@ define([
                 verifyTransformedColor('hsl(120,40%,40%)', 'lumOff', 80000, 1, 1, 1, 120, 0.4, 1, 1, 1, 'ffffff', 'hsl(120,40%,100%)');
             });
             it('should resolve color with "shade" transformation', function () {
-                verifyTransformedColor('hsl(120,40%,40%)', 'shade', 0, 0, 0, 0, 120, 0.4, 0, 1, 0, '000000', 'hsl(120,40%,0%)');
-                verifyTransformedColor('hsl(120,40%,40%)', 'shade', 25000, 0.06, 0.14, 0.06, 120, 0.4, 0.1, 1, 0.117, '0f240f', 'hsl(120,40%,10%)');
-                verifyTransformedColor('hsl(120,40%,40%)', 'shade', 50000, 0.12, 0.28, 0.12, 120, 0.4, 0.2, 1, 0.234, '1f471f', 'hsl(120,40%,20%)');
-                verifyTransformedColor('hsl(120,40%,40%)', 'shade', 75000, 0.18, 0.42, 0.18, 120, 0.4, 0.3, 1, 0.352, '2e6b2e', 'hsl(120,40%,30%)');
-                verifyTransformedColor('hsl(120,40%,40%)', 'shade', 100000, 0.24, 0.56, 0.24, 120, 0.4, 0.4, 1, 0.469, '3d8f3d', 'hsl(120,40%,40%)');
-                verifyTransformedColor('orange', 'shade', 50000, 0.5, 0.324, 0, 39, 1, 0.25, 1, 0.338, '805300', 'hsl(39,100%,25%)');
+                verifyRgbTransformation('#336699', 'shade', 0, 0, 0, 0);
+                verifyRgbTransformation('#336699', 'shade', 20000, 0.098, 0.197, 0.295);
+                verifyRgbTransformation('#336699', 'shade', 40000, 0.134, 0.267, 0.401);
+                verifyRgbTransformation('#336699', 'shade', 60000, 0.160, 0.319, 0.479);
+                verifyRgbTransformation('#336699', 'shade', 80000, 0.181, 0.363, 0.544);
+                verifyRgbTransformation('#336699', 'shade', 100000, 0.2, 0.4, 0.6);
             });
             it('should resolve color with "tint" transformation', function () {
-                verifyTransformedColor('hsl(120,40%,40%)', 'tint', 0, 1, 1, 1, 120, 0.4, 1, 1, 1, 'ffffff', 'hsl(120,40%,100%)');
-                verifyTransformedColor('hsl(120,40%,40%)', 'tint', 25000, 0.79, 0.91, 0.79, 120, 0.4, 0.85, 1, 0.876, 'c9e8c9', 'hsl(120,40%,85%)');
-                verifyTransformedColor('hsl(120,40%,40%)', 'tint', 50000, 0.58, 0.82, 0.58, 120, 0.4, 0.7, 1, 0.752, '94d194', 'hsl(120,40%,70%)');
-                verifyTransformedColor('hsl(120,40%,40%)', 'tint', 75000, 0.37, 0.73, 0.37, 120, 0.4, 0.55, 1, 0.627, '5eba5e', 'hsl(120,40%,55%)');
-                verifyTransformedColor('hsl(120,40%,40%)', 'tint', 100000, 0.24, 0.56, 0.24, 120, 0.4, 0.4, 1, 0.469, '3d8f3d', 'hsl(120,40%,40%)');
-                verifyTransformedColor('orange', 'tint', 50000, 1, 0.824, 0.5, 39, 1, 0.75, 1, 0.838, 'ffd280', 'hsl(39,100%,75%)');
+                verifyRgbTransformation('#336699', 'tint', 0, 1, 1, 1);
+                verifyRgbTransformation('#336699', 'tint', 20000, 0.909, 0.919, 0.937);
+                verifyRgbTransformation('#336699', 'tint', 40000, 0.805, 0.827, 0.868);
+                verifyRgbTransformation('#336699', 'tint', 60000, 0.679, 0.720, 0.792);
+                verifyRgbTransformation('#336699', 'tint', 80000, 0.514, 0.588, 0.704);
+                verifyRgbTransformation('#336699', 'tint', 100000, 0.2, 0.4, 0.6);
             });
             it('should resolve color with "gamma" transformation', function () {
                 verifyTransformedColor('rgb(200,100,50)', 'gamma', null, 0.899, 0.662, 0.488, 25, 0.669, 0.693, 1, 0.7, 'e5a97c', '#e5a97c');
@@ -673,8 +697,8 @@ define([
                 verifyTransformedColor('hsl(135,40%,40%)', 'comp', null, 0.56, 0.24, 0.48, 315, 0.4, 0.4, 1, 0.325, '8f3d7a', 'hsl(315,40%,40%)');
             });
             it('should resolve color with "inv" transformation', function () {
-                verifyTransformedColor('rgb(200,100,50)', 'inv', null, 0.216, 0.608, 0.804, 200, 0.6, 0.51, 1, 0.539, '379bcd', '#379bcd');
-                verifyTransformedColor('hsl(135,40%,40%)', 'inv', null, 0.76, 0.44, 0.68, 315, 0.4, 0.6, 1, 0.525, 'c270ad', '#c270ad');
+                verifyRgbTransformation('#336699', 'inv', null, 0.989, 0.943, 0.847);
+                verifyRgbTransformation('#00f0ff', 'inv', null, 1, 0.405, 0);
             });
             it('should resolve color with "gray" transformation', function () {
                 verifyTransformedColor('rgb(200,100,50)', 'gray', null, 0.461, 0.461, 0.461, 0, 0, 0.461, 1, 0.461, '767676', '#767676');
