@@ -79,16 +79,18 @@ define([
             selection.setDrawingResizeHandler(DrawingResize.drawDrawingSelection);
         });
 
-        function triggerTrackingEvent(node, type, x, y, copy) {
-            var startX =  parseFloat(node.css('left'));
-            var startY =  parseFloat(node.css('top'));
+        function triggerTrackingEvent(node, type, x, y, options) {
+            var isCopy = Utils.getBooleanOption(options, 'copy', false);
+            var positionNode = Utils.getObjectOption(options, 'drawingNode', node);
+            var startX = parseFloat(positionNode.css('left'));
+            var startY = parseFloat(positionNode.css('top'));
             var event = new $.Event(type, {
                 which: 1,
                 startX: startX,
                 startY: startY,
                 pageX: x + startX,
                 pageY: y + startY,
-                ctrlKey: copy || false
+                ctrlKey: isCopy
             });
             node.trigger(event);
         }
@@ -109,7 +111,7 @@ define([
 
             it('move drawing with "tracking.js" should work fine', function () {
 
-                selection.setTextSelection([0, 0]);
+                selection.setTextSelection([0, 0], [0, 1]);
                 var activeSlide = model.getSlideById(model.getActiveSlideId());
                 var drawingsOnSlide = activeSlide.children(DOM.ABSOLUTE_DRAWING_SELECTOR);
 
@@ -141,7 +143,7 @@ define([
 
             it('copy drawing with "tracking.js" should work fine', function () {
 
-                selection.setTextSelection([1, 0]);
+                selection.setTextSelection([0, 1], [0, 2]);
                 var activeSlide = model.getSlideById(model.getActiveSlideId());
                 var drawingsOnSlide = activeSlide.children(DOM.ABSOLUTE_DRAWING_SELECTOR);
 
@@ -156,9 +158,9 @@ define([
 
                 DrawingResize.drawDrawingSelection(app, secondDrawing);
 
-                triggerTrackingEvent(secondDrawing, 'tracking:start', 0, 0, true);
-                triggerTrackingEvent(secondDrawing, 'tracking:move', 10, 35, true);
-                triggerTrackingEvent(secondDrawing, 'tracking:end', 10, 35, true);
+                triggerTrackingEvent(secondDrawing, 'tracking:start', 0, 0, { copy: true });
+                triggerTrackingEvent(secondDrawing, 'tracking:move', 10, 35, { copy: true });
+                triggerTrackingEvent(secondDrawing, 'tracking:end', 10, 35, { copy: true });
 
                 drawingsOnSlide = activeSlide.children(DOM.ABSOLUTE_DRAWING_SELECTOR);
                 var newDrawing = $(drawingsOnSlide[2]);
@@ -179,6 +181,54 @@ define([
 
             });
 
+            it('should flip drawing horizontally on resize', function () {
+                selection.setTextSelection([0, 2], [0, 3]);
+                var activeSlide = model.getSlideById(model.getActiveSlideId());
+                var drawingsOnSlide = activeSlide.children(DOM.ABSOLUTE_DRAWING_SELECTOR);
+                var lastDrawing = $(drawingsOnSlide[2]);
+                var oldAttributes = lastDrawing.data('attributes');
+
+                expect(oldAttributes.drawing.flipH).not.to.be.equal(true);
+                DrawingResize.drawDrawingSelection(app, lastDrawing);
+
+                var selectionDrawingNode = model.getNode().children('.drawingselection-overlay').children('.selectiondrawing').first();
+                var leftResizer = selectionDrawingNode.find('.resizers > [data-pos="l"]');
+
+                triggerTrackingEvent(leftResizer, 'tracking:start', 0, 0, { drawingNode: lastDrawing });
+                triggerTrackingEvent(leftResizer, 'tracking:move', 500, 0, { drawingNode: lastDrawing });
+                triggerTrackingEvent(leftResizer, 'tracking:end', 500, 0, { drawingNode: lastDrawing });
+                var newAttributes = lastDrawing.data('attributes');
+
+                expect(newAttributes.drawing.height).to.be.closeTo(oldAttributes.drawing.height, 20);
+                expect(newAttributes.drawing.width).not.to.be.equal(oldAttributes.drawing.width);
+                expect(newAttributes.drawing.width).to.be.closeTo(Utils.convertLengthToHmm(500, 'px') - oldAttributes.drawing.width, 20);
+                expect(newAttributes.drawing.flipH).to.be.equal(true).and.not.to.be.equal(oldAttributes.drawing.flipH);
+            });
+
+            it('should flip drawing vertically on resize', function () {
+                selection.setTextSelection([2, 0]);
+                var activeSlide = model.getSlideById(model.getActiveSlideId());
+                var drawingsOnSlide = activeSlide.children(DOM.ABSOLUTE_DRAWING_SELECTOR);
+                var lastDrawing = $(drawingsOnSlide[2]);
+                var oldAttributes = lastDrawing.data('attributes');
+
+                expect(oldAttributes.drawing.flipV).not.to.be.equal(true);
+                DrawingResize.drawDrawingSelection(app, lastDrawing);
+
+                var selectionDrawingNode = model.getNode().children('.drawingselection-overlay').children('.selectiondrawing').first();
+                var topResizer = selectionDrawingNode.find('.resizers > [data-pos="t"]');
+
+                triggerTrackingEvent(topResizer, 'tracking:start', 0, 0, { drawingNode: lastDrawing });
+                triggerTrackingEvent(topResizer, 'tracking:move', 0, 500, { drawingNode: lastDrawing });
+                triggerTrackingEvent(topResizer, 'tracking:end', 0, 500, { drawingNode: lastDrawing });
+                var newAttributes = lastDrawing.data('attributes');
+
+                expect(newAttributes.drawing.width).to.be.closeTo(oldAttributes.drawing.width, 20);
+                expect(newAttributes.drawing.height).not.to.be.equal(oldAttributes.drawing.height);
+                expect(newAttributes.drawing.height).to.be.closeTo(Utils.convertLengthToHmm(500, 'px') - oldAttributes.drawing.height, 20);
+                expect(newAttributes.drawing.flipV).to.be.equal(true).and.not.to.be.equal(oldAttributes.drawing.flipV);
+            });
+
         });
 
     });
