@@ -265,9 +265,7 @@ define([
             it('should paste some text into a new created text frame, if the browser selection is in the clipboard', function (done) {
                 var followingDrawings = drawing.nextAll('div.drawing').length;
                 expect(drawing.nextAll('div.drawing').length).to.equal(followingDrawings);
-                expect(model.getSelection().getClipboardNode().css('display')).to.equal('none');
                 model.getSelection().setTextSelection([0, 0]);
-                expect(model.getSelection().getClipboardNode().css('display')).to.equal('block');
                 clipboardPromise = model.pasteInternalClipboard();
                 clipboardPromise.always(function () {
                     expect(drawing.nextAll('div.drawing').length).to.equal(followingDrawings + 1);
