@@ -62,7 +62,7 @@ define([
             var sheetModel = createSheet(data);
             var cellCollection = sheetModel.getCellCollection();
 
-            var generator = sheetModel.createOperationsGenerator({ applyImmediately: true });
+            var generator = sheetModel.createOperationGenerator({ applyImmediately: true });
             var promise = cellCollection.generateAutoFormulaOperations(generator, 'SUM', r(range));
             promise.always(function (targetRange) {
                 expect(promise.state()).to.equal('resolved');
