@@ -15,8 +15,9 @@
 define([
     'globals/apphelper',
     'globals/sheethelper',
-    'io.ox/office/tk/utils/iteratorutils'
-], function (AppHelper, SheetHelper, IteratorUtils) {
+    'io.ox/office/tk/utils/iteratorutils',
+    'io.ox/office/spreadsheet/utils/sheetutils'
+], function (AppHelper, SheetHelper, IteratorUtils, SheetUtils) {
 
     'use strict';
 
@@ -24,6 +25,7 @@ define([
     var a = SheetHelper.a;
     var r = SheetHelper.r;
     var ra = SheetHelper.ra;
+    var MoveMode = SheetUtils.MoveMode;
 
     // class CellCollection ===================================================
 
@@ -36,6 +38,7 @@ define([
             { name: 'setDocumentAttributes', attrs: { document: { cols: 16384, rows: 1048576 } } },
             { name: 'insertAutoStyle', type: 'cell', styleId: 'a0', attrs: {}, default: true },
             { name: 'insertName', label: 'global', formula: 'Sheet1!E2+Sheet1!$E$2+Sheet2!E2+Sheet2!$E$2' },
+            { name: 'insertName', label: 'global2', formula: 'global' },
 
             { name: 'insertSheet', sheet: 0, sheetName: 'Sheet1' },
             { name: 'changeCells', sheet: 0, start: 'B2', contents: [
@@ -52,6 +55,7 @@ define([
             ] },
             { name: 'changeCells', sheet: 0, start: 'B11', contents: [['Col1', 'Col2'], [1, 2]] }, // table range
             { name: 'changeCells', sheet: 0, start: 'A13', contents: [[{ v: 12, f: 'SUM(Table1[],Table2[],Table1[Col1],Table1[Col2],Table2[Col1],Table2[Col2],Table2[[Col1]:[Col2]])' }]] },
+            { name: 'changeCells', sheet: 0, start: 'A14', contents: [[{ v: 32, f: 'SUM(global,global2)' }]] },
             { name: 'insertValidation', sheet: 0, index: 0, ranges: 'B8:C9', type: 'between', value1: 'B2+Sheet2!B2', value2: 'B11+Sheet2!B11' },
             { name: 'insertCFRule', sheet: 0, id: '0', ranges: 'B8:C9', type: 'between', value1: 'B2+Sheet2!B2', value2: 'B11+Sheet2!B11', priority: 1, attrs: {} },
             { name: 'insertTable', sheet: 0, table: 'Table1', start: 'B11', end: 'C12', attrs: { table: { headerRow: true } } },
@@ -68,10 +72,10 @@ define([
             { name: 'insertTable', sheet: 1, table: 'Table2', start: 'B11', end: 'C12', attrs: { table: { headerRow: true } } },
 
             { name: 'insertSheet', sheet: 2, sheetName: 'Sheet3' },
-            { name: 'insertDrawing', start: [2, 0], type: 'chart', attrs: { drawing: { anchorType: 'twoCell', startCol: 0, startRow: 0, endCol: 1, endRow: 1 }, chart: { type: 'column2d' } } },
-            { name: 'insertChartDataSeries', start: [2, 0], series: 0, attrs: { series: { title: 'Sheet1!$J$1', names: 'Sheet1!$I$2:$I$3', values: 'Sheet1!$J$2:$J$3' } } },
-            { name: 'insertChartDataSeries', start: [2, 0], series: 1, attrs: { series: { title: 'Sheet1!$K$1', names: 'Sheet1!$I$2:$I$3', values: 'Sheet1!$K$2:$K$3' } } },
-            { name: 'insertChartDataSeries', start: [2, 0], series: 2, attrs: { series: { title: 'Sheet2!$K$1', names: 'Sheet1!$I$2:$I$3', values: 'Sheet2!$K$2:$K$3' } } },
+            { name: 'insertDrawing', start: [2, 0], type: 'chart', attrs: { drawing: { anchorType: 'twoCell', startCol: 0, startRow: 0, endCol: 1, endRow: 1 } } },
+            { name: 'insertChartDataSeries', start: [2, 0], series: 0, attrs: { series: { type: 'column2d', title: 'Sheet1!$J$1', names: 'Sheet1!$I$2:$I$3', values: 'Sheet1!$J$2:$J$3' } } },
+            { name: 'insertChartDataSeries', start: [2, 0], series: 1, attrs: { series: { type: 'column2d', title: 'Sheet1!$K$1', names: 'Sheet1!$I$2:$I$3', values: 'Sheet1!$K$2:$K$3' } } },
+            { name: 'insertChartDataSeries', start: [2, 0], series: 2, attrs: { series: { type: 'column2d', title: 'Sheet2!$K$1', names: 'Sheet1!$I$2:$I$3', values: 'Sheet2!$K$2:$K$3' } } },
             { name: 'setChartTitleAttributes', start: [2, 0], axis: 'main', attrs: { text: { link: 'Sheet1!$J$10:$J$11' } } },
             { name: 'setChartTitleAttributes', start: [2, 0], axis: 'x', attrs: { text: { link: 'Sheet1!$K$10:$K$11' } } },
             { name: 'setChartTitleAttributes', start: [2, 0], axis: 'y', attrs: { text: { link: 'Sheet2!$K$10:$K$11' } } }
@@ -165,18 +169,19 @@ define([
             expect(getRuleModel(sheet, id)).to.equal(null);
         }
 
-        function getNameModel(label) {
-            return docModel.getNameCollection().getName(label);
+        function getNameModel(sheet, label) {
+            var parentModel = (sheet === null) ? docModel : docModel.getSheetModel(sheet);
+            return parentModel.getNameCollection().getName(label);
         }
 
-        function expectName(label, expFormula) {
-            var nameModel = getNameModel(label);
+        function expectName(sheet, label, expFormula) {
+            var nameModel = getNameModel(sheet, label);
             expect(nameModel).to.be.an('object');
             expect(nameModel.getFormula('op')).to.equal(expFormula);
         }
 
         function getChartModel(sheet, pos) {
-            return docModel.getSheetModel(sheet).getDrawingCollection().findModel([pos]);
+            return docModel.getSheetModel(sheet).getDrawingCollection().getModel([pos]);
         }
 
         function getChartSeriesModel(sheet, pos, series) {
@@ -352,7 +357,7 @@ define([
 
         describe('method "generateCellContentOperations"', function () {
             it('should update shared formula when shortening the bounding range', function (done) {
-                var generator = sheetModel1.createOperationsGenerator({ applyImmediately: true });
+                var generator = sheetModel1.createOperationGenerator({ applyImmediately: true });
                 var promise = cellCollection1.generateCellContentOperations(generator, a('B6'), [{ c: [{ f: '1+1' }, { f: null }] }]);
                 promise.always(function () {
                     expect(promise.state()).to.equal('resolved');
@@ -367,7 +372,7 @@ define([
                 });
             });
             it('should update shared formula when expanding the bounding range', function (done) {
-                var generator = sheetModel1.createOperationsGenerator({ applyImmediately: true });
+                var generator = sheetModel1.createOperationGenerator({ applyImmediately: true });
                 var promise = cellCollection1.generateCellContentOperations(generator, a('B7'), { si: 0 });
                 promise.always(function () {
                     expect(promise.state()).to.equal('resolved');
@@ -380,7 +385,7 @@ define([
                 });
             });
             it('should update shared formula when deleting the anchor cell', function (done) {
-                var generator = sheetModel1.createOperationsGenerator({ applyImmediately: true });
+                var generator = sheetModel1.createOperationGenerator({ applyImmediately: true });
                 var promise = cellCollection1.generateCellContentOperations(generator, a('E5'), { f: null });
                 promise.always(function () {
                     expect(promise.state()).to.equal('resolved');
@@ -396,12 +401,12 @@ define([
 
         describe('method "generateMoveCellsOperations"', function () {
             it('should fail to split or shorten matrix formulas', function (done) {
-                var generator = sheetModel1.createOperationsGenerator({ applyImmediately: true });
-                var promise = cellCollection1.generateMoveCellsOperations(generator, r('C1:C1048576'), 'right');
+                var generator = sheetModel1.createOperationGenerator({ applyImmediately: true });
+                var promise = cellCollection1.generateMoveCellsOperations(generator, r('C1:C1048576'), MoveMode.RIGHT);
                 promise.always(function (result) {
                     expect(promise.state()).to.equal('rejected');
                     expect(result).to.deep.equal({ cause: 'formula:matrix:insert' });
-                    promise = cellCollection1.generateMoveCellsOperations(generator, r('C1:C1048576'), 'left');
+                    promise = cellCollection1.generateMoveCellsOperations(generator, r('C1:C1048576'), MoveMode.LEFT);
                     promise.always(function (result) {
                         expect(promise.state()).to.equal('rejected');
                         expect(result).to.deep.equal({ cause: 'formula:matrix:delete' });
@@ -410,8 +415,8 @@ define([
                 });
             });
             it('should move all formula cells and defined names when inserting columns', function (done) {
-                var generator = sheetModel1.createOperationsGenerator({ applyImmediately: true });
-                var promise = cellCollection1.generateMoveCellsOperations(generator, r('A1:B1048576'), 'right');
+                var generator = sheetModel1.createOperationGenerator({ applyImmediately: true });
+                var promise = cellCollection1.generateMoveCellsOperations(generator, r('A1:B1048576'), MoveMode.RIGHT);
                 promise.always(function () {
                     expect(promise.state()).to.equal('resolved');
                     expectFormulaCell(0, 'D2', 'G2+1', null, null, null);
@@ -424,7 +429,7 @@ define([
                     expectFormulaCell(0, 'H6', null, 1, null, null);
                     expectFormulaCell(0, 'D8', 'G2:H3', null, null, 'D8:E9');
                     expectFormulaCell(0, 'G8', 'Sheet2!E2:F3', null, null, 'G8:H9');
-                    expectName('global', 'Sheet1!E2+Sheet1!$G$2+Sheet2!E2+Sheet2!$E$2');
+                    expectName(null, 'global', 'Sheet1!E2+Sheet1!$G$2+Sheet2!E2+Sheet2!$E$2');
                     expect(docModel.applyOperations(generator, { undo: true })).to.equal(true);
                     expectFormulaCell(0, 'B2', 'E2+1', null, null, null);
                     expectFormulaCell(0, 'C3', 'F3+4', null, null, null);
@@ -440,13 +445,13 @@ define([
                     expectFormulaCell(0, 'F6', null, 1, null, null);
                     expectFormulaCell(0, 'B8', 'E2:F3', null, null, 'B8:C9');
                     expectFormulaCell(0, 'E8', 'Sheet2!E2:F3', null, null, 'E8:F9');
-                    expectName('global', 'Sheet1!E2+Sheet1!$E$2+Sheet2!E2+Sheet2!$E$2');
+                    expectName(null, 'global', 'Sheet1!E2+Sheet1!$E$2+Sheet2!E2+Sheet2!$E$2');
                     done();
                 });
             });
             it('should move all formula cells and defined names when deleting rows', function (done) {
-                var generator = sheetModel1.createOperationsGenerator({ applyImmediately: true });
-                var promise = cellCollection1.generateMoveCellsOperations(generator, ra('A2:XFD2 A5:XFD5'), 'up');
+                var generator = sheetModel1.createOperationGenerator({ applyImmediately: true });
+                var promise = cellCollection1.generateMoveCellsOperations(generator, ra('A2:XFD2 A5:XFD5'), MoveMode.UP);
                 promise.always(function () {
                     expect(promise.state()).to.equal('resolved');
                     expectFormulaCell(0, 'B2', 'E2+3', null, null, null);
@@ -455,7 +460,7 @@ define([
                     expectFormulaCell(0, 'E4', 'Sheet2!E3', 1, 'E4:F4', null);
                     expectFormulaCell(0, 'B6', 'E2:F2', null, null, 'B6:C7');
                     expectFormulaCell(0, 'E6', 'Sheet2!E2:F3', null, null, 'E6:F7');
-                    expectName('global', 'Sheet1!E2+Sheet1!#REF!+Sheet2!E2+Sheet2!$E$2');
+                    expectName(null, 'global', 'Sheet1!E2+Sheet1!#REF!+Sheet2!E2+Sheet2!$E$2');
                     expect(docModel.applyOperations(generator, { undo: true })).to.equal(true);
                     expectFormulaCell(0, 'B2', 'E2+1', null, null, null);
                     expectFormulaCell(0, 'C3', 'F3+4', null, null, null);
@@ -471,13 +476,13 @@ define([
                     expectFormulaCell(0, 'F6', null, 1, null, null);
                     expectFormulaCell(0, 'B8', 'E2:F3', null, null, 'B8:C9');
                     expectFormulaCell(0, 'E8', 'Sheet2!E2:F3', null, null, 'E8:F9');
-                    expectName('global', 'Sheet1!E2+Sheet1!$E$2+Sheet2!E2+Sheet2!$E$2');
+                    expectName(null, 'global', 'Sheet1!E2+Sheet1!$E$2+Sheet2!E2+Sheet2!$E$2');
                     done();
                 });
             });
             it('should split shared formulas when inserting cells inbetween', function (done) {
-                var generator = sheetModel1.createOperationsGenerator({ applyImmediately: true });
-                var promise = cellCollection1.generateMoveCellsOperations(generator, r('A6:XFD6'), 'down');
+                var generator = sheetModel1.createOperationGenerator({ applyImmediately: true });
+                var promise = cellCollection1.generateMoveCellsOperations(generator, r('A6:XFD6'), MoveMode.DOWN);
                 promise.always(function () {
                     expect(promise.state()).to.equal('resolved');
                     var si1 = expectFormulaCell(0, 'B5', 'E2', 'any', 'B5:C5', null).si;
@@ -497,8 +502,8 @@ define([
                 });
             });
             it('should update data validation and formatting rules when inserting rows', function (done) {
-                var generator = sheetModel2.createOperationsGenerator({ applyImmediately: true });
-                var promise = cellCollection2.generateMoveCellsOperations(generator, r('A10:XFD10'), 'down');
+                var generator = sheetModel2.createOperationGenerator({ applyImmediately: true });
+                var promise = cellCollection2.generateMoveCellsOperations(generator, r('A10:XFD10'), MoveMode.DOWN);
                 promise.always(function () {
                     expect(promise.state()).to.equal('resolved');
                     expectValidation(0, 0, 'B8:C9', 'B2+Sheet2!B2', 'B11+Sheet2!B12');
@@ -522,8 +527,8 @@ define([
                 });
             });
             it('should update data validation and formatting rules when deleting rows', function (done) {
-                var generator = sheetModel2.createOperationsGenerator({ applyImmediately: true });
-                var promise = cellCollection2.generateMoveCellsOperations(generator, r('A10:XFD10'), 'up');
+                var generator = sheetModel2.createOperationGenerator({ applyImmediately: true });
+                var promise = cellCollection2.generateMoveCellsOperations(generator, r('A10:XFD10'), MoveMode.UP);
                 promise.always(function () {
                     expect(promise.state()).to.equal('resolved');
                     expectValidation(0, 0, 'B8:C9', 'B2+Sheet2!B2', 'B11+Sheet2!B10');
@@ -547,8 +552,8 @@ define([
                 });
             });
             it('should update table references when deleting table', function (done) {
-                var generator = sheetModel1.createOperationsGenerator({ applyImmediately: true });
-                var promise = cellCollection1.generateMoveCellsOperations(generator, r('A11:XFD12'), 'up');
+                var generator = sheetModel1.createOperationGenerator({ applyImmediately: true });
+                var promise = cellCollection1.generateMoveCellsOperations(generator, r('A11:XFD12'), MoveMode.UP);
                 promise.always(function () {
                     expect(promise.state()).to.equal('resolved');
                     expectFormulaCell(0, 'A11', 'SUM(#REF!,Table2[],#REF!,#REF!,Table2[Col1],Table2[Col2],Table2[[Col1]:[Col2]])', null, null, null);
@@ -558,8 +563,8 @@ define([
                 });
             });
             it('should update table references when deleting columns', function (done) {
-                var generator = sheetModel2.createOperationsGenerator({ applyImmediately: true });
-                var promise = cellCollection2.generateMoveCellsOperations(generator, r('C1:C1048576'), 'left');
+                var generator = sheetModel2.createOperationGenerator({ applyImmediately: true });
+                var promise = cellCollection2.generateMoveCellsOperations(generator, r('C1:C1048576'), MoveMode.LEFT);
                 promise.always(function () {
                     expect(promise.state()).to.equal('resolved');
                     expectFormulaCell(0, 'A13', 'SUM(Table1[],Table2[],Table1[Col1],Table1[Col2],Table2[Col1],#REF!,#REF!)', null, null, null);
@@ -569,8 +574,8 @@ define([
                 });
             });
             it('should update chart source links when inserting rows', function (done) {
-                var generator = sheetModel1.createOperationsGenerator({ applyImmediately: true });
-                var promise = cellCollection1.generateMoveCellsOperations(generator, ra('A3:XFD3 A11:XFD11'), 'down');
+                var generator = sheetModel1.createOperationGenerator({ applyImmediately: true });
+                var promise = cellCollection1.generateMoveCellsOperations(generator, ra('A3:XFD3 A11:XFD11'), MoveMode.DOWN);
                 promise.always(function () {
                     expect(promise.state()).to.equal('resolved');
                     expectChartSeriesLinks(2, 0, 0, 'Sheet1!$J$1', 'Sheet1!$I$2:$I$4', 'Sheet1!$J$2:$J$4');
@@ -590,8 +595,8 @@ define([
                 });
             });
             it('should update chart source links when deleting columns', function (done) {
-                var generator = sheetModel1.createOperationsGenerator({ applyImmediately: true });
-                var promise = cellCollection1.generateMoveCellsOperations(generator, r('J1:J1048576'), 'left');
+                var generator = sheetModel1.createOperationGenerator({ applyImmediately: true });
+                var promise = cellCollection1.generateMoveCellsOperations(generator, r('J1:J1048576'), MoveMode.LEFT);
                 promise.always(function () {
                     expect(promise.state()).to.equal('resolved');
                     expectChartSeriesLinks(2, 0, 0, 'Sheet1!$J$1', 'Sheet1!$I$2:$I$3', 'Sheet1!$J$2:$J$3');
@@ -613,7 +618,7 @@ define([
 
         describe('method "generateUpdateFormulaOperations"', function () {
             it('should update formulas after renaming a sheet', function (done) {
-                var generator = docModel.createOperationsGenerator({ applyImmediately: true });
+                var generator = docModel.createSheetOperationGenerator({ applyImmediately: true });
                 var promise = docModel.generateRenameSheetOperations(generator, 1, 'Sheet99');
                 promise.always(function () {
                     expect(promise.state()).to.equal('resolved');
@@ -625,7 +630,7 @@ define([
                     expectValidation(1, 0, 'B8:C9', 'B2+Sheet1!B2', 'B11+Sheet1!B11');
                     expectRule(0, '0', 'B8:C9', 'B2+Sheet99!B2', 'B11+Sheet99!B11');
                     expectRule(1, '0', 'B8:C9', 'B2+Sheet1!B2', 'B11+Sheet1!B11');
-                    expectName('global', 'Sheet1!E2+Sheet1!$E$2+Sheet99!E2+Sheet99!$E$2');
+                    expectName(null, 'global', 'Sheet1!E2+Sheet1!$E$2+Sheet99!E2+Sheet99!$E$2');
                     expectChartSeriesLinks(2, 0, 0, 'Sheet1!$J$1', 'Sheet1!$I$2:$I$3', 'Sheet1!$J$2:$J$3');
                     expectChartSeriesLinks(2, 0, 1, 'Sheet1!$K$1', 'Sheet1!$I$2:$I$3', 'Sheet1!$K$2:$K$3');
                     expectChartSeriesLinks(2, 0, 2, 'Sheet99!$K$1', 'Sheet1!$I$2:$I$3', 'Sheet99!$K$2:$K$3');
@@ -641,7 +646,7 @@ define([
                     expectValidation(1, 0, 'B8:C9', 'B2+Sheet1!B2', 'B11+Sheet1!B11');
                     expectRule(0, '0', 'B8:C9', 'B2+Sheet2!B2', 'B11+Sheet2!B11');
                     expectRule(1, '0', 'B8:C9', 'B2+Sheet1!B2', 'B11+Sheet1!B11');
-                    expectName('global', 'Sheet1!E2+Sheet1!$E$2+Sheet2!E2+Sheet2!$E$2');
+                    expectName(null, 'global', 'Sheet1!E2+Sheet1!$E$2+Sheet2!E2+Sheet2!$E$2');
                     expectChartSeriesLinks(2, 0, 0, 'Sheet1!$J$1', 'Sheet1!$I$2:$I$3', 'Sheet1!$J$2:$J$3');
                     expectChartSeriesLinks(2, 0, 1, 'Sheet1!$K$1', 'Sheet1!$I$2:$I$3', 'Sheet1!$K$2:$K$3');
                     expectChartSeriesLinks(2, 0, 2, 'Sheet2!$K$1', 'Sheet1!$I$2:$I$3', 'Sheet2!$K$2:$K$3');
@@ -651,6 +656,19 @@ define([
                     done();
                 });
             });
+            it('should update formulas after relabeling a defined name', function (done) {
+                var generator = docModel.createSheetOperationGenerator({ applyImmediately: true });
+                var promise = docModel.getNameCollection().generateChangeNameOperations(generator, 'global', 'changed', null);
+                promise.always(function () {
+                    expect(promise.state()).to.equal('resolved');
+                    expectFormulaCell(0, 'A14', 'SUM(changed,global2)', null, null, null);
+                    expectName(null, 'global2', 'changed');
+                    expect(docModel.applyOperations(generator, { undo: true })).to.equal(true);
+                    expectFormulaCell(0, 'A14', 'SUM(global,global2)', null, null, null);
+                    expectName(null, 'global2', 'global');
+                    done();
+                });
+            });
         });
     });
 
