@@ -16,7 +16,7 @@ define([
     'globals/apphelper',
     'globals/sheethelper',
     'io.ox/office/tk/utils',
-    'io.ox/office/spreadsheet/utils/operationcontext',
+    'io.ox/office/spreadsheet/model/operationcontext',
     'io.ox/office/spreadsheet/model/colrowcollection'
 ], function (AppHelper, SheetHelper, Utils, OperationContext, ColRowCollection) {
 
