@@ -54,7 +54,7 @@ define([
 
     function testFormatCategory(desc) {
         if (!('format' in desc)) { return; }
-        expect(desc.type).to.match(/^(val|mat)$/);
+        expect(desc.type).to.match(/^(val|mat)/);
         expect(desc.format).to.match(/^(percent|currency|date|time|datetime|combine)$/);
     }
 
@@ -201,7 +201,7 @@ define([
                 testOperatorNameProperty(desc, key, format, namesMap);
                 expect(desc).to.have.a.property('minParams').that.is.a('number').within(1, 2);
                 expect(desc).to.have.a.property('maxParams').that.is.a('number').within(desc.minParams, 2);
-                expect(desc).to.have.a.property('type').that.match(/^(val|ref)$/);
+                expect(desc).to.have.a.property('type').that.match(/^(val:(num|str|bool|any)|ref)$/);
                 testFormatCategory(desc);
                 if ('recalc' in desc) { expect(desc.recalc).to.match(/^(always|once)$/); }
                 if ('signature' in desc) { expect(desc.signature).to.match(SIGNATURE_RE); }
@@ -214,7 +214,7 @@ define([
         });
         it('should have unique names', function () {
             _.forEach(namesMap, function (names) {
-                expect(names.length).to.equal(_.unique(names).length);
+                expect(names.length).to.equal(_.unique(names).length + 2); // unary and binary plus/minus
             });
         });
     });
@@ -245,7 +245,7 @@ define([
                 if ('maxParams' in desc) { expect(desc.maxParams).to.be.a('number').at.least(desc.minParams); }
                 if ('repeatParams' in desc) { expect(desc.repeatParams).to.be.a('number').at.least(1); }
                 expect(!('maxParams' in desc) || !('repeatParams' in desc)).to.equal(true);
-                expect(desc).to.have.a.property('type').that.match(/^(val|mat|ref|any)$/);
+                expect(desc).to.have.a.property('type').that.match(/^(val:(num|str|bool|err|date|comp|any)|mat|ref|any)$/);
                 testFormatCategory(desc);
                 if ('recalc' in desc) { expect(desc.recalc).to.match(/^(always|once)$/); }
                 if ('signature' in desc) { expect(desc.signature).to.match(SIGNATURE_RE); }
