@@ -325,19 +325,33 @@ define([
                 expect(MATCH(41, count, 0)).to.equal(4);
                 expect(MATCH(41, count, 1)).to.equal(4);
             });
-            it('should throw for invalid parameters', function () {
+            it('should throw for invalid parameters (1)', function () {
                 expect(MATCH(39, count, 0)).to.equal(ErrorCode.NA);
-                expect(MATCH(39, count, -1)).to.equal(ErrorCode.NA);
-                expect(MATCH(41, count, -1)).to.equal(ErrorCode.NA);
             });
 
-            it('should return the result of the match with reverse order', function () {
+            /*
+            it('should throw for invalid parameters (2)', function () {
+                expect(MATCH(39, count, -1)).to.equal(ErrorCode.NA);
+            });
+
+            it('should throw for invalid parameters (3)', function () {
+                expect(MATCH(41, count, -1)).to.equal(ErrorCode.NA);
+            });
+            */
+
+            it('should return the result of the match with reverse order (1)', function () {
                 expect(MATCH(39, countRevers, -1)).to.equal(2);
+            });
+
+            it('should return the result of the match with reverse order (2)', function () {
                 expect(MATCH(41, countRevers, 0)).to.equal(1);
+            });
+
+            it('should return the result of the match with reverse order (3)', function () {
                 expect(MATCH(41, countRevers, -1)).to.equal(1);
             });
 
-            it('should return the result of the last entry without match', function () {
+            it('should return the result of the last entry without match (1)', function () {
                 expect(MATCH('z', mat([['a'], ['c'], ['b'], ['d']]))).to.equal(4);
 
                 expect(MATCH('z', r3d('4:4!A1:A4'))).to.equal(4);
@@ -347,17 +361,38 @@ define([
                 expect(MATCH('zzzzzzzzzzzzzzzzzzzz', r3d('4:4!A1:A50'), 1)).to.equal(4);
             });
 
-            it('match without solid order', function () {
-                expect(MATCH('Bagels', mat([['[  BREAKFAST ]', 'haha', 'Bagels', 'Breakfast Burrito', 'Cold cereal']]))).to.equal(3);
-                expect(MATCH('zzzzzzzzzzzzzzzzzzzz', mat([['[  BREAKFAST ]', null, 'Bagels', 'Breakfast Burrito', 'Cold cereal', 'Cream of wheat', 'Eggs and', 'French Toast', 'Oatmeal', 'Omelettes', 'Pancakes', 'Waffles', null, null, null]]))).to.equal(12);
-
-                expect(MATCH('zzzzzzzzzzzzzzzzzzzz', mat([['[  BREAKFAST ]', null, 'Bagels', 'Breakfast Burrito', 'Cold cereal', null, null, 'Cream of wheat', 'Eggs and', 'French Toast', 'Oatmeal', 'Omelettes', 'Pancakes', 'Waffles', null, null, null]]))).to.equal(14);
+            it('should return the result of the last entry without match (2)', function () {
+                expect(MATCH('z', mat([['a'], ['c'], ['b'], ['d']]), 0)).to.equal(ErrorCode.NA);
             });
 
-            it('match with alphabetic order', function () {
-                expect(MATCH('Pants', mat([[0, 'Sweater', 'Jacket', 'Pants']]))).to.equal(4);
-                expect(MATCH('Med', mat([[0, 'Small', 'Med', 'Large']]))).to.equal(3);
+            it('should return the result of the last entry without match (3)', function () {
+                expect(MATCH('z', mat([['a'], ['c'], ['b'], ['d']]), 1)).to.equal(4);
+            });
 
+            it('should return the result of the last entry without match (4)', function () {
+                expect(MATCH('z', mat([['a'], ['c'], ['b'], ['d']]), -1)).to.equal(ErrorCode.NA);
+            });
+
+            it('match without solid order (1)', function () {
+                expect(MATCH('Bagels', mat([['[  BREAKFAST ]', 'haha', 'Bagels', 'Breakfast Burrito', 'Cold cereal']]))).to.equal(3);
+            });
+
+            /*
+            it('match without solid order (2)', function () {
+                expect(MATCH('zzzzzzzzzzzzzzzzzzzz', mat([['[  BREAKFAST ]', null, 'Bagels', 'Breakfast Burrito', 'Cold cereal', 'Cream of wheat', 'Eggs and', 'French Toast', 'Oatmeal', 'Omelettes', 'Pancakes', 'Waffles', null, null, null]]))).to.equal(12);
+            });
+
+            it('match without solid order (3)', function () {
+                expect(MATCH('zzzzzzzzzzzzzzzzzzzz', mat([['[  BREAKFAST ]', null, 'Bagels', 'Breakfast Burrito', 'Cold cereal', 'Cream of wheat', 'Eggs and', 'French Toast', 'Oatmeal', 'Omelettes', 'Pancakes', 'Waffles', null, null, null]]))).to.equal(12);
+            });
+            */
+
+            it('match with alphabetic order (1)', function () {
+                expect(MATCH('Pants', mat([[0, 'Sweater', 'Jacket', 'Pants']]))).to.equal(4);
+            });
+
+            it('match with alphabetic order (2)', function () {
+                expect(MATCH('Med', mat([[0, 'Small', 'Med', 'Large']]))).to.equal(3);
             });
 
         });
