@@ -216,13 +216,15 @@ define([
                     expect(collection.get('ge')).to.be.an('object');
                     expect(collection.get('eq')).to.be.an('object');
                     expect(collection.get('ne')).to.be.an('object');
+                    expect(collection.get('uplus')).to.be.an('object');
+                    expect(collection.get('uminus')).to.be.an('object');
+                    expect(collection.get('upct')).to.be.an('object');
                     expect(collection.get('add')).to.be.an('object');
                     expect(collection.get('sub')).to.be.an('object');
                     expect(collection.get('mul')).to.be.an('object');
                     expect(collection.get('div')).to.be.an('object');
                     expect(collection.get('pow')).to.be.an('object');
                     expect(collection.get('con')).to.be.an('object');
-                    expect(collection.get('pct')).to.be.an('object');
                     expect(collection.get('list')).to.be.an('object');
                     expect(collection.get('isect')).to.be.an('object');
                     expect(collection.get('range')).to.be.an('object');
