@@ -90,6 +90,16 @@ define([
             });
         });
 
+        describe('method "sub"', function () {
+            it('should exist', function () {
+                expect(MathUtils).itself.to.respondTo('sub');
+            });
+            it('should return the difference of two numbers', function () {
+                expect(MathUtils.sub(3, 2)).to.equal(1);
+                expect(MathUtils.sub(0, 2)).to.equal(-2);
+            });
+        });
+
         describe('method "mul"', function () {
             it('should exist', function () {
                 expect(MathUtils).itself.to.respondTo('mul');
@@ -446,6 +456,30 @@ define([
             });
         });
 
+        describe('method "factorial2"', function () {
+            it('should exist', function () {
+                expect(MathUtils).itself.to.respondTo('factorial2');
+            });
+            var factorial2 = MathUtils.factorial2;
+            it('should return the factorials of numbers', function () {
+                expect(factorial2(0)).to.equal(1);
+                expect(factorial2(1)).to.equal(1);
+                expect(factorial2(2)).to.equal(2);
+                expect(factorial2(3)).to.equal(3);
+                expect(factorial2(4)).to.equal(8);
+                expect(factorial2(5)).to.equal(15);
+                expect(factorial2(6)).to.equal(48);
+                expect(factorial2(7)).to.equal(105);
+            });
+            it('should round the input parameter', function () {
+                expect(factorial2(4.5)).to.equal(8);
+            });
+            it('should throw #NUM! error code for invalid numbers', function () {
+                expect(factorial2.bind(MathUtils, -1)).to.throw(ErrorCode).that.equals(ErrorCode.NUM);
+                expect(factorial2.bind(MathUtils, 1000)).to.throw(ErrorCode).that.equals(ErrorCode.NUM);
+            });
+        });
+
         describe('method "binomial"', function () {
             it('should exist', function () {
                 expect(MathUtils).itself.to.respondTo('binomial');
