@@ -6,15 +6,17 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
- * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Daniel Rentz <daniel.rentz@open-xchange.com>
  */
 
 define([
     'io.ox/office/spreadsheet/utils/errorcode',
+    'io.ox/office/spreadsheet/model/formula/utils/dimension',
     'io.ox/office/spreadsheet/model/formula/utils/matrix'
-], function (ErrorCode, Matrix) {
+], function (ErrorCode, Dimension, Matrix) {
 
     'use strict';
 
@@ -28,22 +30,43 @@ define([
 
         // private helpers ----------------------------------------------------
 
-        var a1 = [[1]],
-            a2 = [[1, 2], ['a', 'b'], [false, true]];
+        var a1 = [[1]];
+        var a2 = [[1, 2], ['a', 'b'], [false, true]];
 
-        // constructor --------------------------------------------------------
+        // constants ----------------------------------------------------------
 
-        describe('constructor', function () {
-            it('should create a matrix', function () {
-                var m1 = new Matrix(a1);
-                expect(m1).to.have.property('_array', a1);
-                var m2 = new Matrix(a2);
-                expect(m2).to.have.property('_array', a2);
+        describe('constant "MAX_SIZE"', function () {
+            it('should exist', function () {
+                expect(Matrix).to.have.a.property('MAX_SIZE').that.is.a('number').and.above(0);
             });
         });
 
         // static methods -----------------------------------------------------
 
+        describe('method "isValidDim"', function () {
+            it('should exist', function () {
+                expect(Matrix).itself.to.respondTo('isValidDim');
+            });
+            var rows = Math.floor(Math.sqrt(Matrix.MAX_SIZE));
+            var cols = Math.floor(Matrix.MAX_SIZE / rows);
+            it('should return true for valid matrix sizes', function () {
+                expect(Matrix.isValidDim(1, 1)).to.equal(true);
+                expect(Matrix.isValidDim(Matrix.MAX_SIZE, 1)).to.equal(true);
+                expect(Matrix.isValidDim(1, Matrix.MAX_SIZE)).to.equal(true);
+                expect(Matrix.isValidDim(rows, cols)).to.equal(true);
+                expect(Matrix.isValidDim(new Dimension(rows, cols))).to.equal(true);
+            });
+            it('should return false for invalid matrix sizes', function () {
+                expect(Matrix.isValidDim(0, 1)).to.equal(false);
+                expect(Matrix.isValidDim(1, 0)).to.equal(false);
+                expect(Matrix.isValidDim(Matrix.MAX_SIZE + 1, 1)).to.equal(false);
+                expect(Matrix.isValidDim(1, Matrix.MAX_SIZE + 1)).to.equal(false);
+                expect(Matrix.isValidDim(rows + 1, cols)).to.equal(false);
+                expect(Matrix.isValidDim(rows, cols + 1)).to.equal(false);
+                expect(Matrix.isValidDim(new Dimension(rows, cols + 1))).to.equal(false);
+            });
+        });
+
         describe('method "create"', function () {
             it('should exist', function () {
                 expect(Matrix).itself.to.respondTo('create');
@@ -51,10 +74,10 @@ define([
             it('should create a filled matrix', function () {
                 var m1 = Matrix.create(1, 1, 1);
                 expect(m1).to.be.an.instanceof(Matrix);
-                expect(m1._array).to.deep.equal([[1]]);
+                expect(m1.values()).to.deep.equal([[1]]);
                 var m2 = Matrix.create(3, 2, 'a');
                 expect(m2).to.be.an.instanceof(Matrix);
-                expect(m2._array).to.deep.equal([['a', 'a'], ['a', 'a'], ['a', 'a']]);
+                expect(m2.values()).to.deep.equal([['a', 'a'], ['a', 'a'], ['a', 'a']]);
             });
         });
 
@@ -65,16 +88,30 @@ define([
             it('should create a filled matrix', function () {
                 var m1 = Matrix.generate(1, 1, _.constant(1));
                 expect(m1).to.be.an.instanceof(Matrix);
-                expect(m1._array).to.deep.equal([[1]]);
+                expect(m1.values()).to.deep.equal([[1]]);
                 function generator(row, col) { return a2[row][col]; }
                 var spy = sinon.spy(generator), m2 = Matrix.generate(3, 2, spy, a1);
                 expect(m2).to.be.an.instanceof(Matrix);
-                expect(m2._array).to.deep.equal(a2);
+                expect(m2.values()).to.deep.equal(a2);
                 sinon.assert.callCount(spy, 6);
                 sinon.assert.alwaysCalledOn(spy, a1);
             });
         });
 
+        describe('method "identity"', function () {
+            it('should exist', function () {
+                expect(Matrix).itself.to.respondTo('identity');
+            });
+            it('should create an identity matrix', function () {
+                var m1 = Matrix.identity(1);
+                expect(m1).to.be.an.instanceof(Matrix);
+                expect(m1.values()).to.deep.equal([[1]]);
+                var m3 = Matrix.identity(3);
+                expect(m3).to.be.an.instanceof(Matrix);
+                expect(m3.values()).to.deep.equal([[1, 0, 0], [0, 1, 0], [0, 0, 1]]);
+            });
+        });
+
         describe('method "createRowVector"', function () {
             it('should exist', function () {
                 expect(Matrix).itself.to.respondTo('createRowVector');
@@ -82,7 +119,7 @@ define([
             it('should create a row vector', function () {
                 var m1 = Matrix.createRowVector([42, 'a', false]);
                 expect(m1).to.be.an.instanceof(Matrix);
-                expect(m1._array).to.deep.equal([[42, 'a', false]]);
+                expect(m1.values()).to.deep.equal([[42, 'a', false]]);
             });
         });
 
@@ -93,12 +130,28 @@ define([
             it('should create a column vector', function () {
                 var m1 = Matrix.createColVector([42, 'a', false]);
                 expect(m1).to.be.an.instanceof(Matrix);
-                expect(m1._array).to.deep.equal([[42], ['a'], [false]]);
+                expect(m1.values()).to.deep.equal([[42], ['a'], [false]]);
+            });
+        });
+
+        describe('method "getAddress"', function () {
+            it('should exist', function () {
+                expect(Matrix).itself.to.respondTo('getAddress');
             });
         });
 
         // public methods -----------------------------------------------------
 
+        describe('method "values"', function () {
+            it('should exist', function () {
+                expect(Matrix).to.respondTo('values');
+            });
+            var m2 = new Matrix(a2);
+            it('should return the internal arrays', function () {
+                expect(m2.values()).to.equal(a2);
+            });
+        });
+
         describe('method "clone"', function () {
             it('should exist', function () {
                 expect(Matrix).to.respondTo('clone');
@@ -107,8 +160,8 @@ define([
                 var m1 = new Matrix(a1);
                 var m2 = m1.clone();
                 expect(m2).to.be.an.instanceof(Matrix);
-                expect(m2._array).to.deep.equal(a1);
-                expect(m2._array).to.not.equal(a1);
+                expect(m2.values()).to.deep.equal(a1);
+                expect(m2.values()).to.not.equal(a1);
             });
         });
 
@@ -172,14 +225,14 @@ define([
                 expect(m4.get(1, 1)).to.equal(3);
                 expect(m4.get(1, 9)).to.equal(3);
             });
-            it('should throw #N/A on invalid indexes', function () {
-                expect(m2.get.bind(m2, 2, 2)).to.throw(ErrorCode).that.equals(ErrorCode.NA);
-                expect(m2.get.bind(m2, 3, 1)).to.throw(ErrorCode).that.equals(ErrorCode.NA);
-                expect(m2.get.bind(m2, 3, 2)).to.throw(ErrorCode).that.equals(ErrorCode.NA);
-                expect(m2.get.bind(m3, 0, 2)).to.throw(ErrorCode).that.equals(ErrorCode.NA);
-                expect(m2.get.bind(m3, 9, 2)).to.throw(ErrorCode).that.equals(ErrorCode.NA);
-                expect(m2.get.bind(m4, 2, 0)).to.throw(ErrorCode).that.equals(ErrorCode.NA);
-                expect(m2.get.bind(m4, 2, 9)).to.throw(ErrorCode).that.equals(ErrorCode.NA);
+            it('should return #N/A on invalid indexes', function () {
+                expect(m2.get(2, 2)).to.equal(ErrorCode.NA);
+                expect(m2.get(3, 1)).to.equal(ErrorCode.NA);
+                expect(m2.get(3, 2)).to.equal(ErrorCode.NA);
+                expect(m3.get(0, 2)).to.equal(ErrorCode.NA);
+                expect(m3.get(9, 2)).to.equal(ErrorCode.NA);
+                expect(m4.get(2, 0)).to.equal(ErrorCode.NA);
+                expect(m4.get(2, 9)).to.equal(ErrorCode.NA);
             });
         });
 
@@ -228,9 +281,9 @@ define([
             var m1 = Matrix.create(3, 2, 1);
             it('should change the specified element', function () {
                 m1.set(0, 0, 'a');
-                expect(m1._array[0][0]).to.equal('a');
+                expect(m1.values()[0][0]).to.equal('a');
                 m1.set(2, 1, true);
-                expect(m1._array[2][1]).to.equal(true);
+                expect(m1.values()[2][1]).to.equal(true);
             });
             it('should return itself', function () {
                 expect(m1.set(0, 0, 1)).to.equal(m1);
@@ -244,15 +297,93 @@ define([
             var m1 = Matrix.create(3, 2, 1);
             it('should change the specified element', function () {
                 m1.setByIndex(0, 'a');
-                expect(m1._array[0][0]).to.equal('a');
+                expect(m1.values()[0][0]).to.equal('a');
                 m1.setByIndex(5, true);
-                expect(m1._array[2][1]).to.equal(true);
+                expect(m1.values()[2][1]).to.equal(true);
             });
             it('should return itself', function () {
                 expect(m1.setByIndex(0, 1)).to.equal(m1);
             });
         });
 
+        describe('method "update"', function () {
+            it('should exist', function () {
+                expect(Matrix).to.respondTo('update');
+            });
+            var m1 = Matrix.create(3, 2, 1);
+            it('should update the specified element', function () {
+                m1.update(0, 0, function (n) { return n + 1; });
+                expect(m1.values()[0][0]).to.equal(2);
+                m1.update(2, 1, function (n) { return n - 1; });
+                expect(m1.values()[2][1]).to.equal(0);
+            });
+            it('should return itself', function () {
+                expect(m1.update(0, 0, _.identity)).to.equal(m1);
+            });
+        });
+
+        describe('method "updateByIndex"', function () {
+            it('should exist', function () {
+                expect(Matrix).to.respondTo('updateByIndex');
+            });
+            var m1 = Matrix.create(3, 2, 1);
+            it('should update the specified element', function () {
+                m1.updateByIndex(0, function (n) { return n + 1; });
+                expect(m1.values()[0][0]).to.equal(2);
+                m1.updateByIndex(5, function (n) { return n - 1; });
+                expect(m1.values()[2][1]).to.equal(0);
+            });
+            it('should return itself', function () {
+                expect(m1.updateByIndex(0, _.identity)).to.equal(m1);
+            });
+        });
+
+        describe('method "add"', function () {
+            it('should exist', function () {
+                expect(Matrix).to.respondTo('add');
+            });
+            var m1 = Matrix.create(3, 2, 1);
+            it('should update the specified element', function () {
+                m1.add(0, 0, 1);
+                expect(m1.values()[0][0]).to.equal(2);
+                m1.add(2, 1, -1);
+                expect(m1.values()[2][1]).to.equal(0);
+            });
+            it('should return itself', function () {
+                expect(m1.add(0, 0, 0)).to.equal(m1);
+            });
+        });
+
+        describe('method "addByIndex"', function () {
+            it('should exist', function () {
+                expect(Matrix).to.respondTo('addByIndex');
+            });
+            var m1 = Matrix.create(3, 2, 1);
+            it('should update the specified element', function () {
+                m1.addByIndex(0, 1);
+                expect(m1.values()[0][0]).to.equal(2);
+                m1.addByIndex(5, -1);
+                expect(m1.values()[2][1]).to.equal(0);
+            });
+            it('should return itself', function () {
+                expect(m1.addByIndex(0, 0)).to.equal(m1);
+            });
+        });
+
+        describe('method "fill"', function () {
+            it('should exist', function () {
+                expect(Matrix).to.respondTo('fill');
+            });
+            var m1 = Matrix.create(4, 4, 1);
+            it('should change the specified elements', function () {
+                m1.fill(0, 1, 2, 3, 42);
+                expect(m1.values()).to.deep.equal([[1, 42, 42, 42], [1, 42, 42, 42], [1, 42, 42, 42], [1, 1, 1, 1]]);
+            });
+            it('should return itself', function () {
+                expect(m1.fill(0, 0, 0, 0, 1)).to.equal(m1);
+            });
+        });
+
         describe('method "iterator"', function () {
             it('should exist', function () {
                 expect(Matrix).to.respondTo('iterator');
@@ -287,6 +418,34 @@ define([
             });
         });
 
+        describe('method "map"', function () {
+            it('should exist', function () {
+                expect(Matrix).to.respondTo('map');
+            });
+            it('should create a new matrix', function () {
+                var m1 = new Matrix([[1, 2], [3, 4]]), m2 = m1.map(function (e) { return e + 1; });
+                expect(m2).to.be.an.instanceof(Matrix);
+                expect(m1.values()).to.not.equal(m2.values());
+                expect(m2.values()).to.deep.equal([[2, 3], [4, 5]]);
+            });
+        });
+
+        describe('method "reduce"', function () {
+            it('should exist', function () {
+                expect(Matrix).to.respondTo('reduce');
+            });
+            it('should reduce all matrix elements to a value', function () {
+                var m = new Matrix([[1, 2], [3, 4]]), spy = sinon.spy(function (a, e) { return a + e; });
+                expect(m.reduce(0, spy, a1)).to.equal(10);
+                sinon.assert.callCount(spy, 4);
+                sinon.assert.alwaysCalledOn(spy, a1);
+                sinon.assert.calledWithExactly(spy.getCall(0), 0, 1, 0, 0);
+                sinon.assert.calledWithExactly(spy.getCall(1), 1, 2, 0, 1);
+                sinon.assert.calledWithExactly(spy.getCall(2), 3, 3, 1, 0);
+                sinon.assert.calledWithExactly(spy.getCall(3), 6, 4, 1, 1);
+            });
+        });
+
         describe('method "transform"', function () {
             it('should exist', function () {
                 expect(Matrix).to.respondTo('transform');
@@ -294,7 +453,7 @@ define([
             it('should modify all matrix elements', function () {
                 var m = new Matrix([[1, 2], [3, 4]]), spy = sinon.spy(function (e) { return e * e; });
                 expect(m.transform(spy, a1)).to.equal(m);
-                expect(m._array).to.deep.equal([[1, 4], [9, 16]]);
+                expect(m.values()).to.deep.equal([[1, 4], [9, 16]]);
                 sinon.assert.callCount(spy, 4);
                 sinon.assert.alwaysCalledOn(spy, a1);
                 sinon.assert.calledWithExactly(spy.getCall(0), 1, 0, 0);
@@ -304,6 +463,52 @@ define([
             });
         });
 
+        describe('method "swapRows"', function () {
+            it('should exist', function () {
+                expect(Matrix).to.respondTo('swapRows');
+            });
+            it('should swap the row elements of a matrix', function () {
+                var m = new Matrix([[1, 2, 3], [4, 5, 6], [7, 8, 9]]);
+                expect(m.swapRows(1, 2)).to.equal(m);
+                expect(m.values()).to.deep.equal([[1, 2, 3], [7, 8, 9], [4, 5, 6]]);
+            });
+        });
+
+        describe('method "scaleRow"', function () {
+            it('should exist', function () {
+                expect(Matrix).to.respondTo('scaleRow');
+            });
+            it('should scale the row elements of a matrix', function () {
+                var m = new Matrix([[1, 2, 3], [4, 5, 6], [7, 8, 9]]);
+                expect(m.scaleRow(1, 2)).to.equal(m);
+                expect(m.values()).to.deep.equal([[1, 2, 3], [8, 10, 12], [7, 8, 9]]);
+            });
+        });
+
+        describe('method "addScaledRow"', function () {
+            it('should exist', function () {
+                expect(Matrix).to.respondTo('addScaledRow');
+            });
+            it('should add the scaled row elements of a matrix', function () {
+                var m = new Matrix([[1, 2, 3], [4, 5, 6], [7, 8, 9]]);
+                expect(m.addScaledRow(1, 2, -2)).to.equal(m);
+                expect(m.values()).to.deep.equal([[1, 2, 3], [-10, -11, -12], [7, 8, 9]]);
+            });
+        });
+
+        describe('method "transpose"', function () {
+            it('should exist', function () {
+                expect(Matrix).to.respondTo('transpose');
+            });
+            it('should transpose a matrix', function () {
+                var m1 = new Matrix(_.copy(a2, true)), m2 = m1.transpose();
+                expect(m2).to.be.an.instanceOf(Matrix);
+                expect(m2).to.not.equal(m1);
+                expect(m1.values()).to.deep.equal(a2);
+                expect(m2.values()).to.deep.equal([[1, 'a', false], [2, 'b', true]]);
+            });
+        });
+
         describe('method "toString"', function () {
             it('should exist', function () {
                 expect(Matrix).to.respondTo('toString');
