@@ -15,10 +15,10 @@
 define([
     'globals/apphelper',
     'globals/sheethelper',
-    'io.ox/office/spreadsheet/utils/rangearray',
-    'io.ox/office/spreadsheet/utils/operationcontext',
+    'io.ox/office/spreadsheet/utils/sheetutils',
+    'io.ox/office/spreadsheet/model/operationcontext',
     'io.ox/office/spreadsheet/model/hyperlinkcollection'
-], function (AppHelper, SheetHelper, RangeArray, OperationContext, HyperlinkCollection) {
+], function (AppHelper, SheetHelper, SheetUtils, OperationContext, HyperlinkCollection) {
 
     'use strict';
 
@@ -26,6 +26,9 @@ define([
     var a = SheetHelper.a;
     var r = SheetHelper.r;
     var ra = SheetHelper.ra;
+    var MoveMode = SheetUtils.MoveMode;
+    var MergeMode = SheetUtils.MergeMode;
+    var RangeArray = SheetUtils.RangeArray;
 
     // class HyperlinkCollection ==============================================
 
@@ -182,7 +185,7 @@ define([
             });
 
             it('should insert hyperlinks with correct splitting', function (done) {
-                var generator1 = sheetModel.createOperationsGenerator({ applyImmediately: true });
+                var generator1 = sheetModel.createOperationGenerator({ applyImmediately: true });
                 var promise1 = hyperlinkCollection.generateHyperlinkOperations(generator1, ra('A1:C3 E1:G4'), 'http://www.example.org');
                 promise1.always(function () {
                     expect(promise1.state()).to.equal('resolved');
@@ -192,7 +195,7 @@ define([
                     expect(ranges1[0].url).to.equal('http://www.example.org');
                     expect(ranges1[1].url).to.equal('http://www.example.org');
 
-                    var generator2 = sheetModel.createOperationsGenerator({ applyImmediately: true });
+                    var generator2 = sheetModel.createOperationGenerator({ applyImmediately: true });
                     var promise2 = hyperlinkCollection.generateHyperlinkOperations(generator2, r('B2:F6'), 'http://www.test.de');
                     promise2.always(function () {
                         expect(promise2.state()).to.equal('resolved');
@@ -221,12 +224,12 @@ define([
             });
 
             it('should create the correct hyperlinks on autofill', function (done) {
-                var generator1 = sheetModel.createOperationsGenerator({ applyImmediately: true });
+                var generator1 = sheetModel.createOperationGenerator({ applyImmediately: true });
                 var promise1 = hyperlinkCollection.generateHyperlinkOperations(generator1, r('A1:B2'), 'http://www.example.org');
                 promise1.always(function () {
                     expect(promise1.state()).to.equal('resolved');
 
-                    var generator2 = sheetModel.createOperationsGenerator({ applyImmediately: true });
+                    var generator2 = sheetModel.createOperationGenerator({ applyImmediately: true });
                     var promise2 = hyperlinkCollection.generateAutoFillOperations(generator2, r('A1:B4'), r('A5:B10'), true, false);
                     promise2.always(function () {
                         expect(promise2.state()).to.equal('resolved');
@@ -252,13 +255,13 @@ define([
             });
 
             it('should generate correct moveCells operations (insert column)', function (done) {
-                var generator1 = sheetModel.createOperationsGenerator({ applyImmediately: true });
+                var generator1 = sheetModel.createOperationGenerator({ applyImmediately: true });
                 var promise1 = hyperlinkCollection.generateHyperlinkOperations(generator1, ra('A1:B2 A5:A6 C5:D6'), 'http://www.example.org');
                 promise1.always(function () {
                     expect(promise1.state()).to.equal('resolved');
 
-                    var generator2 = sheetModel.createOperationsGenerator({ applyImmediately: true });
-                    var promise2 = cellCollection.generateMoveCellsOperations(generator2, r('B1:B1048576'), 'right');
+                    var generator2 = sheetModel.createOperationGenerator({ applyImmediately: true });
+                    var promise2 = cellCollection.generateMoveCellsOperations(generator2, r('B1:B1048576'), MoveMode.RIGHT);
                     promise2.always(function () {
                         expect(promise2.state()).to.equal('resolved');
                         expect(getLinkRanges(hyperlinkCollection)).to.stringifyTo('A1:C2,A5:A6,D5:E6');
@@ -274,13 +277,13 @@ define([
             });
 
             it('should generate correct moveCells operations (delete column)', function (done) {
-                var generator1 = sheetModel.createOperationsGenerator({ applyImmediately: true });
+                var generator1 = sheetModel.createOperationGenerator({ applyImmediately: true });
                 var promise1 = hyperlinkCollection.generateHyperlinkOperations(generator1, ra('A1:B2 B5:B6 D5:E6'), 'http://www.example.org');
                 promise1.always(function () {
                     expect(promise1.state()).to.equal('resolved');
 
-                    var generator2 = sheetModel.createOperationsGenerator({ applyImmediately: true });
-                    var promise2 = cellCollection.generateMoveCellsOperations(generator2, r('B1:B1048576'), 'left');
+                    var generator2 = sheetModel.createOperationGenerator({ applyImmediately: true });
+                    var promise2 = cellCollection.generateMoveCellsOperations(generator2, r('B1:B1048576'), MoveMode.LEFT);
                     promise2.always(function () {
                         expect(promise2.state()).to.equal('resolved');
                         expect(getLinkRanges(hyperlinkCollection)).to.stringifyTo('A1:A2,C5:D6');
@@ -302,13 +305,13 @@ define([
             });
 
             it('should generate correct merge cells operations', function (done) {
-                var generator1 = sheetModel.createOperationsGenerator({ applyImmediately: true });
+                var generator1 = sheetModel.createOperationGenerator({ applyImmediately: true });
                 var promise1 = hyperlinkCollection.generateHyperlinkOperations(generator1, ra('A1:B2 A5:B6 A9:B10'), 'http://www.example.org');
                 promise1.always(function () {
                     expect(promise1.state()).to.equal('resolved');
 
-                    var generator2 = sheetModel.createOperationsGenerator({ applyImmediately: true });
-                    var promise2 = mergeCollection.generateMergeCellsOperations(generator2, r('B2:F10'), 'merge');
+                    var generator2 = sheetModel.createOperationGenerator({ applyImmediately: true });
+                    var promise2 = mergeCollection.generateMergeCellsOperations(generator2, r('B2:F10'), MergeMode.MERGE);
                     promise2.always(function () {
                         expect(promise2.state()).to.equal('resolved');
                         expect(getLinkRanges(hyperlinkCollection)).to.stringifyTo('A1:B1,A2:A2,B2:F10,A5:A6,A9:A10');
@@ -324,13 +327,13 @@ define([
             });
 
             it('should generate correct merge cells operations #2', function (done) {
-                var generator1 = sheetModel.createOperationsGenerator({ applyImmediately: true });
+                var generator1 = sheetModel.createOperationGenerator({ applyImmediately: true });
                 var promise1 = hyperlinkCollection.generateHyperlinkOperations(generator1, ra('A1:B2 A5:B6 A9:B10'), 'http://www.example.org');
                 promise1.always(function () {
                     expect(promise1.state()).to.equal('resolved');
 
-                    var generator2 = sheetModel.createOperationsGenerator({ applyImmediately: true });
-                    var promise2 = mergeCollection.generateMergeCellsOperations(generator2, r('A2:F10'), 'merge');
+                    var generator2 = sheetModel.createOperationGenerator({ applyImmediately: true });
+                    var promise2 = mergeCollection.generateMergeCellsOperations(generator2, r('A2:F10'), MergeMode.MERGE);
                     promise2.always(function () {
                         expect(promise2.state()).to.equal('resolved');
                         expect(getLinkRanges(hyperlinkCollection)).to.stringifyTo('A1:B1,A2:F10');
@@ -346,13 +349,13 @@ define([
             });
 
             it('should generate correct merge cells operations #3', function (done) {
-                var generator1 = sheetModel.createOperationsGenerator({ applyImmediately: true });
+                var generator1 = sheetModel.createOperationGenerator({ applyImmediately: true });
                 var promise1 = hyperlinkCollection.generateHyperlinkOperations(generator1, ra('A1:B2 A5:B6 A9:B10'), 'http://www.example.org');
                 promise1.always(function () {
                     expect(promise1.state()).to.equal('resolved');
 
-                    var generator2 = sheetModel.createOperationsGenerator({ applyImmediately: true });
-                    var promise2 = mergeCollection.generateMergeCellsOperations(generator2, r('B3:F10'), 'merge');
+                    var generator2 = sheetModel.createOperationGenerator({ applyImmediately: true });
+                    var promise2 = mergeCollection.generateMergeCellsOperations(generator2, r('B3:F10'), MergeMode.MERGE);
                     promise2.always(function () {
                         expect(promise2.state()).to.equal('resolved');
                         expect(getLinkRanges(hyperlinkCollection)).to.stringifyTo('A1:B2,A5:A6,A9:A10');
