@@ -25,6 +25,7 @@ define([
     var a = SheetHelper.a;
     var r = SheetHelper.r;
     var ra = SheetHelper.ra;
+    var MergeMode = SheetUtils.MergeMode;
     var Address = SheetUtils.Address;
 
     // class MergeCollection ==================================================
@@ -246,8 +247,8 @@ define([
             it('should merge cell ranges and move first value cells', function (done) {
                 var sheetModel = docModel.getSheetModel(0);
                 var mergeCollection = sheetModel.getMergeCollection();
-                var generator = sheetModel.createOperationsGenerator({ applyImmediately: true });
-                var promise = mergeCollection.generateMergeCellsOperations(generator, ra('A5:C7 E5:G7'), 'merge');
+                var generator = sheetModel.createOperationGenerator({ applyImmediately: true });
+                var promise = mergeCollection.generateMergeCellsOperations(generator, ra('A5:C7 E5:G7'), MergeMode.MERGE);
                 promise.always(function () {
                     expect(promise.state()).to.equal('resolved');
                     expectMergedRanges(0, 'A5:C7,E5:G7');
@@ -268,8 +269,8 @@ define([
             it('should merge cell ranges horizontally and move first value cells', function (done) {
                 var sheetModel = docModel.getSheetModel(0);
                 var mergeCollection = sheetModel.getMergeCollection();
-                var generator = sheetModel.createOperationsGenerator({ applyImmediately: true });
-                var promise = mergeCollection.generateMergeCellsOperations(generator, ra('A5:C7 E5:G7'), 'horizontal');
+                var generator = sheetModel.createOperationGenerator({ applyImmediately: true });
+                var promise = mergeCollection.generateMergeCellsOperations(generator, ra('A5:C7 E5:G7'), MergeMode.HORIZONTAL);
                 promise.always(function () {
                     expect(promise.state()).to.equal('resolved');
                     expectMergedRanges(0, 'A5:C5,E5:G5,A6:C6,E6:G6,A7:C7,E7:G7');
@@ -290,8 +291,8 @@ define([
             it('should merge cell ranges vertically and move first value cells', function (done) {
                 var sheetModel = docModel.getSheetModel(0);
                 var mergeCollection = sheetModel.getMergeCollection();
-                var generator = sheetModel.createOperationsGenerator({ applyImmediately: true });
-                var promise = mergeCollection.generateMergeCellsOperations(generator, ra('A5:C7 E5:G7'), 'vertical');
+                var generator = sheetModel.createOperationGenerator({ applyImmediately: true });
+                var promise = mergeCollection.generateMergeCellsOperations(generator, ra('A5:C7 E5:G7'), MergeMode.VERTICAL);
                 promise.always(function () {
                     expect(promise.state()).to.equal('resolved');
                     expectMergedRanges(0, 'A5:A7,B5:B7,C5:C7,E5:E7,F5:F7,G5:G7');
@@ -312,8 +313,8 @@ define([
             it('should unmerge cell ranges', function (done) {
                 var sheetModel = docModel.getSheetModel(1);
                 var mergeCollection = sheetModel.getMergeCollection();
-                var generator = sheetModel.createOperationsGenerator({ applyImmediately: true });
-                var promise = mergeCollection.generateMergeCellsOperations(generator, r('D6:F6'), 'unmerge');
+                var generator = sheetModel.createOperationGenerator({ applyImmediately: true });
+                var promise = mergeCollection.generateMergeCellsOperations(generator, r('D6:F6'), MergeMode.UNMERGE);
                 promise.always(function () {
                     expect(promise.state()).to.equal('resolved');
                     expectMergedRanges(1, 'A5:C7');
@@ -328,8 +329,8 @@ define([
             it('should unmerge cell ranges implicitly when merging', function (done) {
                 var sheetModel = docModel.getSheetModel(1);
                 var mergeCollection = sheetModel.getMergeCollection();
-                var generator = sheetModel.createOperationsGenerator({ applyImmediately: true });
-                var promise = mergeCollection.generateMergeCellsOperations(generator, r('D6:F6'), 'merge');
+                var generator = sheetModel.createOperationGenerator({ applyImmediately: true });
+                var promise = mergeCollection.generateMergeCellsOperations(generator, r('D6:F6'), MergeMode.MERGE);
                 promise.always(function () {
                     expect(promise.state()).to.equal('resolved');
                     expectMergedRanges(1, 'A5:C7,D6:F6');
@@ -372,8 +373,8 @@ define([
                 mergedRanges = mergeCollection.getMergedRanges(checkRange);
                 expect(mergedRanges.length).to.equal(0);
 
-                var generator   = sheetModel.createOperationsGenerator({ applyImmediately: true });
-                var promise     = mergeCollection.generateMergeCellsOperations(generator, doMerge, 'merge');
+                var generator   = sheetModel.createOperationGenerator({ applyImmediately: true });
+                var promise     = mergeCollection.generateMergeCellsOperations(generator, doMerge, MergeMode.MERGE);
 
                 promise.always(function () {
                     expect(promise.state()).to.equal('resolved');
@@ -432,8 +433,8 @@ define([
                 mergedRanges = mergeCollection.getMergedRanges(checkRange);
                 expect(mergedRanges.length).to.equal(0);
 
-                var generator   = sheetModel.createOperationsGenerator({ applyImmediately: true });
-                var promise     = mergeCollection.generateMergeCellsOperations(generator, doMerge, 'merge');
+                var generator   = sheetModel.createOperationGenerator({ applyImmediately: true });
+                var promise     = mergeCollection.generateMergeCellsOperations(generator, doMerge, MergeMode.MERGE);
 
                 promise.always(function () {
                     expect(promise.state()).to.equal('resolved');
@@ -500,8 +501,8 @@ define([
                 mergedRanges = mergeCollection.getMergedRanges(checkRange);
                 expect(mergedRanges.length).to.equal(0);
 
-                var generator   = sheetModel.createOperationsGenerator({ applyImmediately: true });
-                var promise     = mergeCollection.generateMergeCellsOperations(generator, doMerge, 'merge');
+                var generator   = sheetModel.createOperationGenerator({ applyImmediately: true });
+                var promise     = mergeCollection.generateMergeCellsOperations(generator, doMerge, MergeMode.MERGE);
 
                 promise.always(function () {
                     expect(promise.state()).to.equal('resolved');
