@@ -35,6 +35,7 @@ define([
         // private helpers ----------------------------------------------------
 
         function testChartModel(chartModel, dataSeries1, dataSeries2) {
+            expect(chartModel).to.be.an('object');
             var count = 0;
             chartModel.iterateTokenArrays(function (seriesIndex, tokenArrays) {
 
@@ -82,16 +83,16 @@ define([
             // Named Ranges
             { name: 'insertName', sheet: 1, label: 'TestRangeSheet2', formula: 'Sheet2!$C$5:$C$6' },
             // Chart Drawing
-            { name: 'insertDrawing', start: [1, 0], type: 'chart', attrs: { drawing: { startCol: 8, startColOffset: 132, startRow: 0, startRowOffset: 0, endCol: 8, endColOffset: 4101, endRow: 4, endRowOffset: 370, anchorType: 'twoCell' }, chart: { type: 'column2d', chartStyleId: 2, stacking: 'clustered', chartColors: { id: 10, meth: 'cycle', schemeClr: [{ color: { type: 'scheme', value: 'accent1' } }, { color: { type: 'scheme', value: 'accent2' } }, { color: { type: 'scheme', value: 'accent3' } }, { color: { type: 'scheme', value: 'accent4' } }, { color: { type: 'scheme', value: 'accent5' } }, { color: { type: 'scheme', value: 'accent6' } }] }, varyColors: false }, line: { type: 'solid', width: 26, color: { type: 'scheme', value: 'text1', transformations: [{ type: 'lumMod', value: 15000 }, { type: 'lumOff', value: 85000 }] } }, fill: { type: 'solid', color: { type: 'scheme', value: 'background1' } } } },
-            { name: 'insertChartDataSeries', start: [1, 0], series: 0, attrs: { series: { title: 'Sheet1!$B$4', names: 'Sheet1!$A$5:$A$7', values: 'Sheet1!$B$5:$B$7' }, line: { type: 'none' }, fill: { type: 'solid', color: { type: 'scheme', value: 'accent1' } } } },
-            { name: 'insertChartDataSeries', start: [1, 0], series: 1, attrs: { series: { title: 'Sheet1!$C$4', names: 'Sheet1!$A$5:$A$7', values: 'Sheet1!$C$5:$C$7' }, line: { type: 'none' }, fill: { type: 'solid', color: { type: 'scheme', value: 'accent2' } } } },
+            { name: 'insertDrawing', start: [1, 0], type: 'chart', attrs: { drawing: { startCol: 8, startColOffset: 132, startRow: 0, startRowOffset: 0, endCol: 8, endColOffset: 4101, endRow: 4, endRowOffset: 370, anchorType: 'twoCell' }, chart: { chartStyleId: 2, stacking: 'clustered', chartColors: { id: 10, meth: 'cycle', schemeClr: [{ color: { type: 'scheme', value: 'accent1' } }, { color: { type: 'scheme', value: 'accent2' } }, { color: { type: 'scheme', value: 'accent3' } }, { color: { type: 'scheme', value: 'accent4' } }, { color: { type: 'scheme', value: 'accent5' } }, { color: { type: 'scheme', value: 'accent6' } }] }, varyColors: false }, line: { type: 'solid', width: 26, color: { type: 'scheme', value: 'text1', transformations: [{ type: 'lumMod', value: 15000 }, { type: 'lumOff', value: 85000 }] } }, fill: { type: 'solid', color: { type: 'scheme', value: 'background1' } } } },
+            { name: 'insertChartDataSeries', start: [1, 0], series: 0, attrs: { series: { type: 'column2d', title: 'Sheet1!$B$4', names: 'Sheet1!$A$5:$A$7', values: 'Sheet1!$B$5:$B$7' }, line: { type: 'none' }, fill: { type: 'solid', color: { type: 'scheme', value: 'accent1' } } } },
+            { name: 'insertChartDataSeries', start: [1, 0], series: 1, attrs: { series: { type: 'column2d', title: 'Sheet1!$C$4', names: 'Sheet1!$A$5:$A$7', values: 'Sheet1!$C$5:$C$7' }, line: { type: 'none' }, fill: { type: 'solid', color: { type: 'scheme', value: 'accent2' } } } },
             { name: 'setChartAxisAttributes', start: [1, 0], axis: 'x', attrs: { line: { type: 'solid', width: 26, color: { type: 'scheme', value: 'text1', transformations: [{ type: 'lumMod', value: 15000 }, { type: 'lumOff', value: 85000 }] } }, fill: { type: 'none' }, axis: { label: true }, character: { color: { type: 'scheme', value: 'text1', transformations: [{ type: 'lumMod', value: 65000 }, { type: 'lumOff', value: 35000 }] }, fontSize: 9 } } },
             { name: 'setChartAxisAttributes', start: [1, 0], axis: 'y', attrs: { line: { type: 'none', width: 18 }, fill: { type: 'none' }, axis: { label: true }, character: { color: { type: 'scheme', value: 'text1', transformations: [{ type: 'lumMod', value: 65000 }, { type: 'lumOff', value: 35000 }] }, fontSize: 9 } } },
             { name: 'setChartGridlineAttributes', start: [1, 0], axis: 'y', attrs: { line: { type: 'solid', width: 26, color: { type: 'scheme', value: 'text1', transformations: [{ type: 'lumMod', value: 15000 }, { type: 'lumOff', value: 85000 }] } }, fill: { type: 'none' } } },
             { name: 'setChartLegendAttributes', start: [1, 0], attrs: { legend: { pos: 'off' } } },
-            { name: 'insertDrawing', start: [1, 1], type: 'chart', attrs: { drawing: { startCol: 9, startColOffset: 1667, startRow: 0, startRowOffset: 0, endCol: 11, endColOffset: 79, endRow: 4, endRowOffset: 344, anchorType: 'twoCell' }, chart: { type: 'column2d', chartStyleId: 2, stacking: 'clustered', chartColors: { id: 10, meth: 'cycle', schemeClr: [{ color: { type: 'scheme', value: 'accent1' } }, { color: { type: 'scheme', value: 'accent2' } }, { color: { type: 'scheme', value: 'accent3' } }, { color: { type: 'scheme', value: 'accent4' } }, { color: { type: 'scheme', value: 'accent5' } }, { color: { type: 'scheme', value: 'accent6' } }] }, varyColors: false }, line: { type: 'solid', width: 26, color: { type: 'scheme', value: 'text1', transformations: [{ type: 'lumMod', value: 15000 }, { type: 'lumOff', value: 85000 }] } }, fill: { type: 'solid', color: { type: 'scheme', value: 'background1' } } } },
-            { name: 'insertChartDataSeries', start: [1, 1], series: 0, attrs: { series: { title: 'Sheet2!$O$2', names: 'Sheet2!$N$3:$N$5', values: 'Sheet2!$O$3:$O$5' }, line: { type: 'none' }, fill: { type: 'solid', color: { type: 'scheme', value: 'accent1' } } } },
-            { name: 'insertChartDataSeries', start: [1, 1], series: 1, attrs: { series: { title: 'Sheet2!$P$2', names: 'Sheet2!$N$3:$N$5', values: 'Sheet2!$P$3:$P$5' }, line: { type: 'none' }, fill: { type: 'solid', color: { type: 'scheme', value: 'accent2' } } } },
+            { name: 'insertDrawing', start: [1, 1], type: 'chart', attrs: { drawing: { startCol: 9, startColOffset: 1667, startRow: 0, startRowOffset: 0, endCol: 11, endColOffset: 79, endRow: 4, endRowOffset: 344, anchorType: 'twoCell' }, chart: { chartStyleId: 2, stacking: 'clustered', chartColors: { id: 10, meth: 'cycle', schemeClr: [{ color: { type: 'scheme', value: 'accent1' } }, { color: { type: 'scheme', value: 'accent2' } }, { color: { type: 'scheme', value: 'accent3' } }, { color: { type: 'scheme', value: 'accent4' } }, { color: { type: 'scheme', value: 'accent5' } }, { color: { type: 'scheme', value: 'accent6' } }] }, varyColors: false }, line: { type: 'solid', width: 26, color: { type: 'scheme', value: 'text1', transformations: [{ type: 'lumMod', value: 15000 }, { type: 'lumOff', value: 85000 }] } }, fill: { type: 'solid', color: { type: 'scheme', value: 'background1' } } } },
+            { name: 'insertChartDataSeries', start: [1, 1], series: 0, attrs: { series: { type: 'column2d', title: 'Sheet2!$O$2', names: 'Sheet2!$N$3:$N$5', values: 'Sheet2!$O$3:$O$5' }, line: { type: 'none' }, fill: { type: 'solid', color: { type: 'scheme', value: 'accent1' } } } },
+            { name: 'insertChartDataSeries', start: [1, 1], series: 1, attrs: { series: { type: 'column2d', title: 'Sheet2!$P$2', names: 'Sheet2!$N$3:$N$5', values: 'Sheet2!$P$3:$P$5' }, line: { type: 'none' }, fill: { type: 'solid', color: { type: 'scheme', value: 'accent2' } } } },
             { name: 'setChartAxisAttributes', start: [1, 1], axis: 'x', attrs: { line: { type: 'solid', width: 26, color: { type: 'scheme', value: 'text1', transformations: [{ type: 'lumMod', value: 15000 }, { type: 'lumOff', value: 85000 }] } }, fill: { type: 'none' }, axis: { label: true }, character: { color: { type: 'scheme', value: 'text1', transformations: [{ type: 'lumMod', value: 65000 }, { type: 'lumOff', value: 35000 }] }, fontSize: 9 } } },
             { name: 'setChartAxisAttributes', start: [1, 1], axis: 'y', attrs: { line: { type: 'none', width: 18 }, fill: { type: 'none' }, axis: { label: true }, character: { color: { type: 'scheme', value: 'text1', transformations: [{ type: 'lumMod', value: 65000 }, { type: 'lumOff', value: 35000 }] }, fontSize: 9 } } },
             { name: 'setChartGridlineAttributes', start: [1, 1], axis: 'y', attrs: { line: { type: 'solid', width: 26, color: { type: 'scheme', value: 'text1', transformations: [{ type: 'lumMod', value: 15000 }, { type: 'lumOff', value: 85000 }] } }, fill: { type: 'none' } } },
@@ -279,10 +280,10 @@ define([
 
                 // Chart Drawing
                 var drawingCollection = sheetModel.getDrawingCollection();
-                var chartModel = drawingCollection.findModel([0]);
+                var chartModel = drawingCollection.getModel([0], { type: 'chart' });
                 testChartModel(chartModel, { title: 'Sheet1!$B$4', names: 'Sheet1!$A$5:$A$7', values: 'Sheet1!$B$5:$B$7' }, { title: 'Sheet1!$C$4', names: 'Sheet1!$A$5:$A$7', values: 'Sheet1!$C$5:$C$7' });
 
-                chartModel = drawingCollection.findModel([1]);
+                chartModel = drawingCollection.getModel([1], { type: 'chart' });
                 testChartModel(chartModel, { title: 'Sheet2!$O$2', names: 'Sheet2!$N$3:$N$5', values: 'Sheet2!$O$3:$O$5' }, { title: 'Sheet2!$P$2', names: 'Sheet2!$N$3:$N$5', values: 'Sheet2!$P$3:$P$5' });
 
                 // Data validation
@@ -291,7 +292,7 @@ define([
                 expect(validationCollection.getValidationSettings(a('E6')).attributes.value1).to.equal('$E$3:$E$4');
 
                 //Delete Sheet1
-                var generator = sheetModel.createOperationsGenerator({ applyImmediately: true });
+                var generator = docModel.createSheetOperationGenerator({ applyImmediately: true });
                 var promise = docModel.generateDeleteSheetOperations(generator, 0);
                 expect(promise).to.respondTo('promise');
 
@@ -317,10 +318,10 @@ define([
 
                     // Chart Drawing
                     drawingCollection = sheetModel.getDrawingCollection();
-                    chartModel = drawingCollection.findModel([0]);
+                    chartModel = drawingCollection.getModel([0], { type: 'chart' });
                     testChartModel(chartModel, { title: '#REF!', names: '#REF!', values: '#REF!' }, { title: '#REF!', names: '#REF!', values: '#REF!' });
 
-                    chartModel = drawingCollection.findModel([1]);
+                    chartModel = drawingCollection.getModel([1], { type: 'chart' });
                     testChartModel(chartModel, { title: 'Sheet2!$O$2', names: 'Sheet2!$N$3:$N$5', values: 'Sheet2!$O$3:$O$5' }, { title: 'Sheet2!$P$2', names: 'Sheet2!$N$3:$N$5', values: 'Sheet2!$P$3:$P$5' });
 
                     // Data validation
