@@ -235,6 +235,22 @@ define([
             it('should exist', function () {
                 expect(AddressSet).to.respondTo('merge');
             });
+            it('should merge with an object', function () {
+                var set = new AddressSet();
+                set.insert(a('A2'));
+                set.insert(a('D5'));
+                set.insert(a('I10'));
+                var a1 = a('A2');
+                var map = { a: a1, b: a('G8') };
+                set.merge(map);
+                var values = set.values();
+                expect(values).to.satisfy(unorderedMatcher('A2 D5 I10 G8'));
+                expect(values.indexOf(a1)).to.equal(-1);
+                set.merge(map, true);
+                values = set.values();
+                expect(values).to.satisfy(unorderedMatcher('A2 D5 I10 G8'));
+                expect(values.indexOf(a1)).to.be.at.least(0);
+            });
             it('should merge two address sets', function () {
                 var set1 = new AddressSet();
                 set1.insert(a('A2'));
