@@ -37,7 +37,7 @@ define([
         // constants ----------------------------------------------------------
 
         describe('constant', function () {
-            checkOperationName('NOOP', 'noOp'); // include EditFramework operations
+            checkOperationName('INSERT_DRAWING', 'insertDrawing'); // include TextFramework operations
             checkOperationName('INSERT_NUMBER_FORMAT', 'insertNumberFormat');
             checkOperationName('DELETE_NUMBER_FORMAT', 'deleteNumberFormat');
             checkOperationName('INSERT_SHEET', 'insertSheet');
