@@ -67,25 +67,15 @@ define([
             });
         });
 
-        describe('constant "ZOOM_FACTORS"', function () {
+        describe('constant "MIN_ZOOM"', function () {
             it('should exist', function () {
-                expect(PaneUtils).to.have.a.property('ZOOM_FACTORS').that.is.an('array');
-                expect(PaneUtils.ZOOM_FACTORS).to.not.be.empty;
-            });
-            it('should be unique and sorted', function () {
-                var sorted = PaneUtils.ZOOM_FACTORS.every(function (f, i, a) { return !i || (a[i - 1] < f); });
-                expect(sorted).to.equal(true);
-            });
-            it('should be around the value 1', function () {
-                expect(_.first(PaneUtils.ZOOM_FACTORS)).to.be.at.most(1);
-                expect(_.last(PaneUtils.ZOOM_FACTORS)).to.be.at.least(1);
+                expect(PaneUtils.MIN_ZOOM).to.be.a('number').that.is.above(0).and.below(1);
             });
         });
 
-        describe('constant "DEFAULT_TRACKING_OPTIONS"', function () {
+        describe('constant "MAX_ZOOM"', function () {
             it('should exist', function () {
-                expect(PaneUtils).to.have.a.property('DEFAULT_TRACKING_OPTIONS').that.is.an('object');
-                expect(PaneUtils.DEFAULT_TRACKING_OPTIONS.autoScroll).to.equal(true);
+                expect(PaneUtils.MAX_ZOOM).to.be.a('number').that.is.above(1);
             });
         });
 
@@ -215,6 +205,44 @@ define([
             });
         });
 
+        describe('method "getValidZoom"', function () {
+            it('should exist', function () {
+                expect(PaneUtils).itself.to.respondTo('getValidZoom');
+            });
+            it('should return the correct zoom factor', function () {
+                var meanZoom = (PaneUtils.MIN_ZOOM + PaneUtils.MAX_ZOOM) / 2;
+                expect(PaneUtils.getValidZoom(0)).to.equal(PaneUtils.MIN_ZOOM);
+                expect(PaneUtils.getValidZoom(PaneUtils.MIN_ZOOM / 2)).to.equal(PaneUtils.MIN_ZOOM);
+                expect(PaneUtils.getValidZoom(PaneUtils.MIN_ZOOM)).to.equal(PaneUtils.MIN_ZOOM);
+                expect(PaneUtils.getValidZoom(meanZoom)).to.equal(meanZoom);
+                expect(PaneUtils.getValidZoom(PaneUtils.MAX_ZOOM)).to.equal(PaneUtils.MAX_ZOOM);
+                expect(PaneUtils.getValidZoom(PaneUtils.MAX_ZOOM + 1)).to.equal(PaneUtils.MAX_ZOOM);
+            });
+        });
+
+        describe('method "getPrevPresetZoom"', function () {
+            it('should exist', function () {
+                expect(PaneUtils).itself.to.respondTo('getPrevPresetZoom');
+            });
+            it('should return the correct zoom factor', function () {
+                expect(PaneUtils.getPrevPresetZoom(0)).to.equal(null);
+                expect(PaneUtils.getPrevPresetZoom(PaneUtils.MIN_ZOOM)).to.equal(null);
+                expect(PaneUtils.getPrevPresetZoom(1)).to.be.below(1);
+                expect(PaneUtils.getPrevPresetZoom(PaneUtils.MAX_ZOOM)).to.be.below(PaneUtils.MAX_ZOOM);
+            });
+        });
+
+        describe('method "getNextPresetZoom"', function () {
+            it('should exist', function () {
+                expect(PaneUtils).itself.to.respondTo('getNextPresetZoom');
+            });
+            it('should return the correct zoom factor', function () {
+                expect(PaneUtils.getNextPresetZoom(PaneUtils.MIN_ZOOM)).to.be.above(PaneUtils.MIN_ZOOM);
+                expect(PaneUtils.getNextPresetZoom(1)).to.be.above(1);
+                expect(PaneUtils.getNextPresetZoom(PaneUtils.MAX_ZOOM)).to.equal(null);
+            });
+        });
+
         describe('method "getRectangleStyleMarkup"', function () {
             it('should exist', function () {
                 expect(PaneUtils).itself.to.respondTo('getRectangleStyleMarkup');
@@ -262,13 +290,6 @@ define([
             });
         });
 
-        describe('method "processTrackingCycle"', function () {
-            it('should exist', function () {
-                expect(PaneUtils).itself.to.respondTo('processTrackingCycle');
-            });
-            // TODO
-        });
-
         describe('method "getSelectionMode"', function () {
             it('should exist', function () {
                 expect(PaneUtils).itself.to.respondTo('getSelectionMode');
@@ -292,9 +313,9 @@ define([
 
         // private helpers ----------------------------------------------------
 
-        var HeaderBoundary = PaneUtils.HeaderBoundary,
-            i = new Interval(1, 3),
-            p = { offset: 100, size: 10 };
+        var HeaderBoundary = PaneUtils.HeaderBoundary;
+        var i = new Interval(1, 3);
+        var p = { offset: 100, size: 10 };
 
         // constructor --------------------------------------------------------
 
