@@ -35,6 +35,7 @@ define([
         var i = SheetHelper.i;
         var a = SheetHelper.a;
         var r = SheetHelper.r;
+        var ra = SheetHelper.ra;
 
         // constructor --------------------------------------------------------
 
@@ -261,6 +262,27 @@ define([
             });
         });
 
+        describe('method "fitsIn"', function () {
+            it('should exist', function () {
+                expect(Range).to.respondTo('fitsIn');
+            });
+            var sourceRange     = r('A2:B3');                   // range:  2x2
+            var suitableRanges  = ra('B4:C5 D5:G6 G16:H19');    // ranges: 2x2 + 4x2 + 2x4
+            var inaptRanges     = ra('B4:C6 E5:G6 G16:H19');    // ranges: 2x3 + 3x2 + 2x4
+            it('should return false for equal ranges', function () {
+                expect(sourceRange.fitsIn(inaptRanges)).to.equal(false);
+                expect(sourceRange.fitsIn(inaptRanges)).to.equal(false);
+                expect(sourceRange.fitsIn(inaptRanges)).to.equal(false);
+                expect(sourceRange.fitsIn(inaptRanges)).to.equal(false);
+            });
+            it('should return true for suitable ranges', function () {
+                expect(sourceRange.fitsIn(suitableRanges)).to.equal(true);
+                expect(sourceRange.fitsIn(suitableRanges)).to.equal(true);
+                expect(sourceRange.fitsIn(suitableRanges)).to.equal(true);
+                expect(sourceRange.fitsIn(suitableRanges)).to.equal(true);
+            });
+        });
+
         describe('method "compareTo"', function () {
             var r1 = r('C3:E5');
             it('should exist', function () {
