@@ -200,24 +200,61 @@ define([
             });
         });
 
-        describe('constant "MIN_ZOOM"', function () {
-            it('should exist', function () {
-                expect(SheetUtils.MIN_ZOOM).to.be.a('number').that.is.above(0).and.below(1);
-            });
-        });
-
-        describe('constant "MAX_ZOOM"', function () {
-            it('should exist', function () {
-                expect(SheetUtils.MAX_ZOOM).to.be.a('number').that.is.above(1);
-            });
-        });
-
         describe('constant "MULTI_SELECTION"', function () {
             it('should exist', function () {
                 expect(SheetUtils.MULTI_SELECTION).to.be.a('boolean');
             });
         });
 
+        // enumerations -------------------------------------------------------
+
+        describe('enumeration "SheetType"', function () {
+            it('should exist', function () {
+                expect(SheetUtils.SheetType).to.be.a('function');
+            });
+            it('should contain all sheet types', function () {
+                expect(SheetUtils.SheetType).to.have.a.property('WORKSHEET');
+                expect(SheetUtils.SheetType).to.have.a.property('CHARTSHEET');
+                expect(SheetUtils.SheetType).to.have.a.property('MACROSHEET');
+                expect(SheetUtils.SheetType).to.have.a.property('DIALOGSHEET');
+            });
+        });
+
+        describe('enumeration "SplitMode"', function () {
+            it('should exist', function () {
+                expect(SheetUtils.SplitMode).to.be.a('function');
+            });
+            it('should contain all split modes', function () {
+                expect(SheetUtils.SplitMode).to.have.a.property('SPLIT');
+                expect(SheetUtils.SplitMode).to.have.a.property('FROZEN');
+                expect(SheetUtils.SplitMode).to.have.a.property('FROZEN_SPLIT');
+            });
+        });
+
+        describe('enumeration "MoveMode"', function () {
+            it('should exist', function () {
+                expect(SheetUtils.MoveMode).to.be.a('function');
+            });
+            it('should contain all move modes', function () {
+                expect(SheetUtils.MoveMode).to.have.a.property('LEFT');
+                expect(SheetUtils.MoveMode).to.have.a.property('RIGHT');
+                expect(SheetUtils.MoveMode).to.have.a.property('UP');
+                expect(SheetUtils.MoveMode).to.have.a.property('DOWN');
+            });
+        });
+
+        describe('enumeration "MergeMode"', function () {
+            it('should exist', function () {
+                expect(SheetUtils.MergeMode).to.be.a('function');
+            });
+            it('should contain all merge modes', function () {
+                expect(SheetUtils.MergeMode).to.have.a.property('MERGE');
+                expect(SheetUtils.MergeMode).to.have.a.property('HORIZONTAL');
+                expect(SheetUtils.MergeMode).to.have.a.property('VERTICAL');
+                expect(SheetUtils.MergeMode).to.have.a.property('UNMERGE');
+            });
+        });
+
         // static methods -----------------------------------------------------
 
         describe('method "getNameKey"', function () {
@@ -295,6 +332,7 @@ define([
                 expect(getTextAlignment(2, 'center', '2')).to.equal('center');
                 expect(getTextAlignment(2, 'right', '2')).to.equal('right');
                 expect(getTextAlignment(2, 'justify', '2')).to.equal('justify');
+                expect(getTextAlignment(2, 'distribute', '2')).to.equal('justify');
                 expect(getTextAlignment(2, 'auto', '2')).to.equal('right');
             });
             it('should return the correct cell text alignment for strings', function () {
@@ -302,6 +340,7 @@ define([
                 expect(getTextAlignment('a', 'center', 'a')).to.equal('center');
                 expect(getTextAlignment('a', 'right', 'a')).to.equal('right');
                 expect(getTextAlignment('a', 'justify', 'a')).to.equal('justify');
+                expect(getTextAlignment('a', 'distribute', 'a')).to.equal('justify');
                 expect(getTextAlignment('a', 'auto', 'a')).to.equal('left');
             });
             it('should return the correct cell text alignment for booleans', function () {
@@ -309,6 +348,7 @@ define([
                 expect(getTextAlignment(true, 'center', 'TRUE')).to.equal('center');
                 expect(getTextAlignment(true, 'right', 'TRUE')).to.equal('right');
                 expect(getTextAlignment(true, 'justify', 'TRUE')).to.equal('justify');
+                expect(getTextAlignment(true, 'distribute', 'TRUE')).to.equal('justify');
                 expect(getTextAlignment(true, 'auto', 'TRUE')).to.equal('center');
             });
             it('should return the correct cell text alignment for error codes', function () {
@@ -316,6 +356,7 @@ define([
                 expect(getTextAlignment(ErrorCode.NUM, 'center', '#NUM!')).to.equal('center');
                 expect(getTextAlignment(ErrorCode.NUM, 'right', '#NUM!')).to.equal('right');
                 expect(getTextAlignment(ErrorCode.NUM, 'justify', '#NUM!')).to.equal('justify');
+                expect(getTextAlignment(ErrorCode.NUM, 'distribute', '#NUM!')).to.equal('justify');
                 expect(getTextAlignment(ErrorCode.NUM, 'auto', '#NUM!')).to.equal('center');
             });
             it('should return the correct cell text alignment for blanks', function () {
@@ -323,6 +364,7 @@ define([
                 expect(getTextAlignment(null, 'center', '')).to.equal('center');
                 expect(getTextAlignment(null, 'right', '')).to.equal('right');
                 expect(getTextAlignment(null, 'justify', '')).to.equal('justify');
+                expect(getTextAlignment(null, 'distribute', '')).to.equal('justify');
                 expect(getTextAlignment(null, 'auto', '')).to.match(/^(left|right)$/);
             });
             it('should accept missing display parameter', function () {
@@ -398,9 +440,13 @@ define([
             it('should exist', function () {
                 expect(SheetUtils).itself.to.respondTo('getTextPadding');
             });
-            it('should return text padding according to zoom factor', function () {
-                expect(SheetUtils.getTextPadding(1)).to.equal(2);
-                expect(SheetUtils.getTextPadding(2)).to.be.above(2);
+            it('should return text padding according to digit width', function () {
+                expect(SheetUtils.getTextPadding(4)).to.equal(1);
+                expect(SheetUtils.getTextPadding(5)).to.equal(2);
+                expect(SheetUtils.getTextPadding(6)).to.equal(2);
+                expect(SheetUtils.getTextPadding(7)).to.equal(2);
+                expect(SheetUtils.getTextPadding(8)).to.equal(2);
+                expect(SheetUtils.getTextPadding(9)).to.equal(3);
             });
         });
 
@@ -409,30 +455,12 @@ define([
                 expect(SheetUtils).itself.to.respondTo('getTotalCellPadding');
             });
             it('should return text padding according to zoom factor', function () {
-                expect(SheetUtils.getTotalCellPadding(1)).to.equal(5);
-                expect(SheetUtils.getTotalCellPadding(2)).to.be.above(5);
-            });
-        });
-
-        describe('method "isDynamicSplit"', function () {
-            it('should exist', function () {
-                expect(SheetUtils).itself.to.respondTo('isDynamicSplit');
-            });
-            it('should recognize dynamic split modes', function () {
-                expect(SheetUtils.isDynamicSplit('split')).to.equal(true);
-                expect(SheetUtils.isDynamicSplit('frozen')).to.equal(false);
-                expect(SheetUtils.isDynamicSplit('frozenSplit')).to.equal(true);
-            });
-        });
-
-        describe('method "isFrozenSplit"', function () {
-            it('should exist', function () {
-                expect(SheetUtils).itself.to.respondTo('isFrozenSplit');
-            });
-            it('should recognize frozen split modes', function () {
-                expect(SheetUtils.isFrozenSplit('split')).to.equal(false);
-                expect(SheetUtils.isFrozenSplit('frozen')).to.equal(true);
-                expect(SheetUtils.isFrozenSplit('frozenSplit')).to.equal(true);
+                expect(SheetUtils.getTotalCellPadding(4)).to.equal(3);
+                expect(SheetUtils.getTotalCellPadding(5)).to.equal(5);
+                expect(SheetUtils.getTotalCellPadding(6)).to.equal(5);
+                expect(SheetUtils.getTotalCellPadding(7)).to.equal(5);
+                expect(SheetUtils.getTotalCellPadding(8)).to.equal(5);
+                expect(SheetUtils.getTotalCellPadding(9)).to.equal(7);
             });
         });
     });
