@@ -15,9 +15,10 @@
 define([
     'globals/apphelper',
     'io.ox/office/drawinglayer/view/drawingframe',
+    'io.ox/office/presentation/utils/presentationutils',
     'io.ox/office/textframework/utils/dom',
     'io.ox/office/textframework/selection/multiselectionmixin'
-], function (AppHelper, DrawingFrame, DOM, MultiSelectionMixin) {
+], function (AppHelper, DrawingFrame, PresentationUtils, DOM, MultiSelectionMixin) {
 
     'use strict';
 
@@ -201,7 +202,7 @@ define([
         });
 
         // setting character attributes to all selected drawings
-        describe('method "model.setAttribute"', function () {
+        describe('method "setAttribute"', function () {
 
             it('should exist', function () {
                 expect(model).to.respondTo('setAttribute');
@@ -241,7 +242,7 @@ define([
         });
 
         // delete all selected drawings
-        describe('method "model.deleteSelected"', function () {
+        describe('method "deleteSelected"', function () {
 
             it('should exist', function () {
                 expect(model).to.respondTo('deleteSelected');
@@ -341,7 +342,7 @@ define([
         });
 
         // moving all selected drawings
-        describe('method "model.handleDrawingOperations"', function () {
+        describe('method "handleDrawingOperations"', function () {
 
             it('should exist', function () {
                 expect(model).to.respondTo('handleDrawingOperations');
@@ -487,6 +488,160 @@ define([
 
         });
 
+        // getting and setting attributes to all selected drawings
+        describe('applying attributes to all selected drawings', function () {
+
+            it('should generate setAttributes operations for all affected drawings', function () {
+
+                var operationsCount = 0;
+
+                selection.setTextSelection([0, 0, 0, 0]);  // selecting the text position
+                activeSlide = model.getSlideById(model.getActiveSlideId());
+                drawingsOnSlide = activeSlide.children(DOM.ABSOLUTE_DRAWING_SELECTOR);
+
+                expect(drawingsOnSlide.length).to.equal(3);
+
+                expect(selection.isMultiSelection()).to.equal(false);
+                expect(selection.getMultiSelection().length).to.equal(0);
+
+                selection.selectAllDrawingsOnSlide();
+
+                expect(selection.isMultiSelection()).to.equal(true);
+                expect(selection.getMultiSelection().length).to.equal(3);
+
+                expect(drawingsOnSlide.length).to.equal(3);
+
+                // ctrTitle, subTitle and body -> all support background color
+                expect(model.isPlaceHolderDrawing(drawingsOnSlide[0])).to.equal(true);
+                expect(model.isPlaceHolderDrawing(drawingsOnSlide[1])).to.equal(true);
+                expect(model.isPlaceHolderDrawing(drawingsOnSlide[2])).to.equal(true);
+
+                expect(PresentationUtils.isTitleOrSubtitlePlaceHolderDrawing(drawingsOnSlide[0])).to.equal(true);
+                expect(PresentationUtils.isTitleOrSubtitlePlaceHolderDrawing(drawingsOnSlide[1])).to.equal(true);
+                expect(PresentationUtils.isBodyPlaceHolderDrawing(drawingsOnSlide[2])).to.equal(true);
+
+                // adding a line (not supporting background color)
+                model.insertShape('line', { left: 1000, top: 1000, width: 1000, height: 1000 });
+
+                drawingsOnSlide = activeSlide.children(DOM.ABSOLUTE_DRAWING_SELECTOR);
+
+                expect(drawingsOnSlide.length).to.equal(4);
+
+                selection.selectAllDrawingsOnSlide();
+
+                expect(selection.isMultiSelection()).to.equal(true);
+                expect(selection.getMultiSelection().length).to.equal(4);
+
+                operationsCount = model.getOperationsCount();
+
+                // setting background color (only three operations are generated, no operation for the line)
+                model.setDrawingFillColor({ type: 'rgb', color: 'FF0000' });
+                expect(model.getOperationsCount()).to.equal(operationsCount + 3); // check for 3 operations
+
+                operationsCount = model.getOperationsCount();
+
+                // setting border color (to all four drawings)
+                model.setDrawingBorderColor({ type: 'rgb', color: '0000FF' });
+                expect(model.getOperationsCount()).to.equal(operationsCount + 4); // check for 4 operations
+
+            });
+
+            // getting drawing attributes from all selected drawings
+            it('should get merged drawing attributes from selected drawings', function () {
+
+                var operationsCount = 0;
+                var allAttributes = null;
+
+                selection.setTextSelection([0, 0, 0, 0]);  // selecting the text position
+                activeSlide = model.getSlideById(model.getActiveSlideId());
+                drawingsOnSlide = activeSlide.children(DOM.ABSOLUTE_DRAWING_SELECTOR);
+
+                expect(drawingsOnSlide.length).to.equal(4);
+
+                // select three drawings
+                selection.setMultiDrawingSelectionByPosition([[0, 0], [0, 1], [0, 2]]);
+
+                expect(selection.isMultiSelection()).to.equal(true);
+                expect(selection.getMultiSelection().length).to.equal(3);
+
+                allAttributes = model.getAttributes('drawing');
+                expect(allAttributes.fill.type).to.equal('solid');
+                expect(allAttributes.fill.color.type).to.equal('rgb');
+                expect(allAttributes.fill.color.color).to.equal('FF0000'); // still red from previous test
+
+                // even if the line is part of the selection, the fill color shall be red (ignoring the value of the line)
+                selection.selectAllDrawingsOnSlide();
+
+                expect(selection.isMultiSelection()).to.equal(true);
+                expect(selection.getMultiSelection().length).to.equal(4);
+
+                allAttributes = model.getAttributes('drawing');
+                expect(allAttributes.fill.type).to.equal('solid');
+                expect(allAttributes.fill.color.type).to.equal('rgb');
+                expect(allAttributes.fill.color.color).to.equal('FF0000'); // still red from previous test
+
+                // modifying the color of two selected drawings
+                selection.setMultiDrawingSelectionByPosition([[0, 0], [0, 1]]);
+                expect(selection.getMultiSelection().length).to.equal(2);
+
+                operationsCount = model.getOperationsCount();
+
+                // setting a different background color to two drawings
+                model.setDrawingFillColor({ type: 'rgb', color: '00FF00' });
+                expect(model.getOperationsCount()).to.equal(operationsCount + 2); // check for 2 operations
+
+                // select the three drawings again
+                selection.setMultiDrawingSelectionByPosition([[0, 0], [0, 1], [0, 2]]);
+                expect(selection.getMultiSelection().length).to.equal(3);
+
+                allAttributes = model.getAttributes('drawing');
+                expect(allAttributes.fill.type).to.equal('solid');
+                expect(allAttributes.fill.color).to.be.null;
+            });
+
+            // getting character attributes from all selected drawings
+            it('should get merged character attributes from selected drawings', function () {
+
+                var operationsCount = 0;
+                var allAttributes = null;
+
+                selection.setTextSelection([0, 0, 0, 0]);  // selecting the text position
+                activeSlide = model.getSlideById(model.getActiveSlideId());
+                drawingsOnSlide = activeSlide.children(DOM.ABSOLUTE_DRAWING_SELECTOR);
+
+                expect(drawingsOnSlide.length).to.equal(4);
+
+                // select three drawings
+                selection.setMultiDrawingSelectionByPosition([[0, 0], [0, 1], [0, 2]]);
+
+                expect(selection.isMultiSelection()).to.equal(true);
+                expect(selection.getMultiSelection().length).to.equal(3);
+
+                allAttributes = model.getAttributes('character');
+
+                expect(allAttributes.character.italic).to.equal(false); // no text in italic
+
+                // setting italic to two selected drawings
+                selection.setMultiDrawingSelectionByPosition([[0, 0], [0, 1]]);
+                expect(selection.getMultiSelection().length).to.equal(2);
+
+                operationsCount = model.getOperationsCount();
+
+                // setting character attribute italic to only two drawings
+                model.setAttribute('character', 'italic', true);
+                expect(model.getOperationsCount()).to.equal(operationsCount + 3); // check for 3 operations in 2 drawings (3 paragraphs)
+
+                // select the three drawings again
+                selection.setMultiDrawingSelectionByPosition([[0, 0], [0, 1], [0, 2]]);
+                expect(selection.getMultiSelection().length).to.equal(3);
+
+                allAttributes = model.getAttributes('character');
+
+                expect(allAttributes.character.italic).to.be.null;  // italic is no longer the unique state
+            });
+
+        });
+
     });
 
     // ========================================================================
