@@ -32,11 +32,211 @@ define([
 
         var formatter = null;
 
+        // static methods -----------------------------------------------------
+
+        describe('method "formatDecimal"', function () {
+            it('should exist', function () {
+                expect(Formatter).itself.to.respondTo('formatDecimal');
+            });
+            it('should convert numbers to string using local decimal separator', function () {
+                expect(Formatter.formatDecimal(0)).to.equal('0');
+                expect(Formatter.formatDecimal(42)).to.equal('42');
+                expect(Formatter.formatDecimal(-1)).to.equal('-1');
+                expect(Formatter.formatDecimal(0.5)).to.equal('0,5');
+                expect(Formatter.formatDecimal(-12.5)).to.equal('-12,5');
+            });
+        });
+
+        describe('method "formatAlphabetic"', function () {
+            it('should exist', function () {
+                expect(Formatter).itself.to.respondTo('formatAlphabetic');
+            });
+            it('should convert decimal numbers for method "digit"', function () {
+                expect(Formatter.formatAlphabetic(1, 'digit')).to.equal('A');
+                expect(Formatter.formatAlphabetic(2, 'digit')).to.equal('B');
+                expect(Formatter.formatAlphabetic(3, 'digit')).to.equal('C');
+                expect(Formatter.formatAlphabetic(24, 'digit')).to.equal('X');
+                expect(Formatter.formatAlphabetic(25, 'digit')).to.equal('Y');
+                expect(Formatter.formatAlphabetic(26, 'digit')).to.equal('Z');
+                expect(Formatter.formatAlphabetic(27, 'digit')).to.equal('AA');
+                expect(Formatter.formatAlphabetic(28, 'digit')).to.equal('AB');
+                expect(Formatter.formatAlphabetic(51, 'digit')).to.equal('AY');
+                expect(Formatter.formatAlphabetic(52, 'digit')).to.equal('AZ');
+                expect(Formatter.formatAlphabetic(53, 'digit')).to.equal('BA');
+                expect(Formatter.formatAlphabetic(702, 'digit')).to.equal('ZZ');
+                expect(Formatter.formatAlphabetic(703, 'digit')).to.equal('AAA');
+                expect(Formatter.formatAlphabetic(704, 'digit')).to.equal('AAB');
+            });
+            it('should convert decimal numbers for method "repeat"', function () {
+                expect(Formatter.formatAlphabetic(1, 'repeat')).to.equal('A');
+                expect(Formatter.formatAlphabetic(2, 'repeat')).to.equal('B');
+                expect(Formatter.formatAlphabetic(3, 'repeat')).to.equal('C');
+                expect(Formatter.formatAlphabetic(24, 'repeat')).to.equal('X');
+                expect(Formatter.formatAlphabetic(25, 'repeat')).to.equal('Y');
+                expect(Formatter.formatAlphabetic(26, 'repeat')).to.equal('Z');
+                expect(Formatter.formatAlphabetic(27, 'repeat')).to.equal('AA');
+                expect(Formatter.formatAlphabetic(28, 'repeat')).to.equal('BB');
+                expect(Formatter.formatAlphabetic(51, 'repeat')).to.equal('YY');
+                expect(Formatter.formatAlphabetic(52, 'repeat')).to.equal('ZZ');
+                expect(Formatter.formatAlphabetic(53, 'repeat')).to.equal('AAA');
+                expect(Formatter.formatAlphabetic(54, 'repeat')).to.equal('BBB');
+                expect(Formatter.formatAlphabetic(77, 'repeat')).to.equal('YYY');
+                expect(Formatter.formatAlphabetic(78, 'repeat')).to.equal('ZZZ');
+                expect(Formatter.formatAlphabetic(79, 'repeat')).to.equal('AAAA');
+            });
+            it('should return empty string for invalid numbers or methods', function () {
+                expect(Formatter.formatAlphabetic(0, 'digit')).to.equal('');
+                expect(Formatter.formatAlphabetic(0, 'repeat')).to.equal('');
+                expect(Formatter.formatAlphabetic(-1, 'digit')).to.equal('');
+                expect(Formatter.formatAlphabetic(-1, 'repeat')).to.equal('');
+                expect(Formatter.formatAlphabetic(1, '__invalid__')).to.equal('');
+            });
+            it('should return lower-case numbers', function () {
+                expect(Formatter.formatAlphabetic(27, 'digit', { lower: true })).to.equal('aa');
+            });
+        });
+
+        describe('method "formatRoman"', function () {
+            it('should exist', function () {
+                expect(Formatter).itself.to.respondTo('formatRoman');
+            });
+            it('should return roman numbers for decimal numbers 1 to 9', function () {
+                expect(Formatter.formatRoman(1, -1)).to.equal('I');
+                expect(Formatter.formatRoman(1, 0)).to.equal('I');
+                expect(Formatter.formatRoman(1, 1)).to.equal('I');
+                expect(Formatter.formatRoman(1, 2)).to.equal('I');
+                expect(Formatter.formatRoman(1, 3)).to.equal('I');
+                expect(Formatter.formatRoman(1, 4)).to.equal('I');
+                expect(Formatter.formatRoman(2, 0)).to.equal('II');
+                expect(Formatter.formatRoman(3, 0)).to.equal('III');
+                expect(Formatter.formatRoman(3, 0)).to.equal('III');
+                expect(Formatter.formatRoman(4, -1)).to.equal('IIII');
+                expect(Formatter.formatRoman(4, 0)).to.equal('IV');
+                expect(Formatter.formatRoman(4, 1)).to.equal('IV');
+                expect(Formatter.formatRoman(4, 2)).to.equal('IV');
+                expect(Formatter.formatRoman(4, 3)).to.equal('IV');
+                expect(Formatter.formatRoman(4, 4)).to.equal('IV');
+                expect(Formatter.formatRoman(5, 0)).to.equal('V');
+                expect(Formatter.formatRoman(6, 0)).to.equal('VI');
+                expect(Formatter.formatRoman(7, 0)).to.equal('VII');
+                expect(Formatter.formatRoman(8, 0)).to.equal('VIII');
+                expect(Formatter.formatRoman(9, -1)).to.equal('VIIII');
+                expect(Formatter.formatRoman(9, 0)).to.equal('IX');
+                expect(Formatter.formatRoman(9, 1)).to.equal('IX');
+                expect(Formatter.formatRoman(9, 2)).to.equal('IX');
+                expect(Formatter.formatRoman(9, 3)).to.equal('IX');
+                expect(Formatter.formatRoman(9, 4)).to.equal('IX');
+            });
+            it('should return roman numbers for decimal numbers 10 to 99', function () {
+                expect(Formatter.formatRoman(10, 0)).to.equal('X');
+                expect(Formatter.formatRoman(19, -1)).to.equal('XVIIII');
+                expect(Formatter.formatRoman(19, 0)).to.equal('XIX');
+                expect(Formatter.formatRoman(19, 4)).to.equal('XIX');
+                expect(Formatter.formatRoman(20, 0)).to.equal('XX');
+                expect(Formatter.formatRoman(35, 0)).to.equal('XXXV');
+                expect(Formatter.formatRoman(35, 4)).to.equal('XXXV');
+                expect(Formatter.formatRoman(39, 0)).to.equal('XXXIX');
+                expect(Formatter.formatRoman(39, 4)).to.equal('XXXIX');
+                expect(Formatter.formatRoman(40, 0)).to.equal('XL');
+                expect(Formatter.formatRoman(40, 4)).to.equal('XL');
+                expect(Formatter.formatRoman(44, 0)).to.equal('XLIV');
+                expect(Formatter.formatRoman(44, 4)).to.equal('XLIV');
+                expect(Formatter.formatRoman(45, 0)).to.equal('XLV');
+                expect(Formatter.formatRoman(45, 1)).to.equal('VL');
+                expect(Formatter.formatRoman(45, 2)).to.equal('VL');
+                expect(Formatter.formatRoman(45, 3)).to.equal('VL');
+                expect(Formatter.formatRoman(45, 4)).to.equal('VL');
+                expect(Formatter.formatRoman(48, 0)).to.equal('XLVIII');
+                expect(Formatter.formatRoman(48, 1)).to.equal('VLIII');
+                expect(Formatter.formatRoman(49, 0)).to.equal('XLIX');
+                expect(Formatter.formatRoman(49, 1)).to.equal('VLIV');
+                expect(Formatter.formatRoman(49, 2)).to.equal('IL');
+                expect(Formatter.formatRoman(49, 3)).to.equal('IL');
+                expect(Formatter.formatRoman(49, 4)).to.equal('IL');
+                expect(Formatter.formatRoman(50, 0)).to.equal('L');
+                expect(Formatter.formatRoman(50, 4)).to.equal('L');
+                expect(Formatter.formatRoman(94, 0)).to.equal('XCIV');
+                expect(Formatter.formatRoman(94, 4)).to.equal('XCIV');
+                expect(Formatter.formatRoman(95, 0)).to.equal('XCV');
+                expect(Formatter.formatRoman(95, 1)).to.equal('VC');
+                expect(Formatter.formatRoman(95, 4)).to.equal('VC');
+                expect(Formatter.formatRoman(99, 0)).to.equal('XCIX');
+                expect(Formatter.formatRoman(99, 1)).to.equal('VCIV');
+                expect(Formatter.formatRoman(99, 2)).to.equal('IC');
+                expect(Formatter.formatRoman(99, 3)).to.equal('IC');
+                expect(Formatter.formatRoman(99, 4)).to.equal('IC');
+            });
+            it('should return roman numbers for decimal numbers 100 to 999', function () {
+                expect(Formatter.formatRoman(100, 0)).to.equal('C');
+                expect(Formatter.formatRoman(100, 4)).to.equal('C');
+                expect(Formatter.formatRoman(199, 0)).to.equal('CXCIX');
+                expect(Formatter.formatRoman(199, 1)).to.equal('CVCIV');
+                expect(Formatter.formatRoman(199, 2)).to.equal('CIC');
+                expect(Formatter.formatRoman(199, 3)).to.equal('CIC');
+                expect(Formatter.formatRoman(199, 4)).to.equal('CIC');
+                expect(Formatter.formatRoman(300, 0)).to.equal('CCC');
+                expect(Formatter.formatRoman(300, 4)).to.equal('CCC');
+                expect(Formatter.formatRoman(400, 0)).to.equal('CD');
+                expect(Formatter.formatRoman(400, 4)).to.equal('CD');
+                expect(Formatter.formatRoman(450, 0)).to.equal('CDL');
+                expect(Formatter.formatRoman(450, 1)).to.equal('LD');
+                expect(Formatter.formatRoman(450, 4)).to.equal('LD');
+                expect(Formatter.formatRoman(490, 0)).to.equal('CDXC');
+                expect(Formatter.formatRoman(490, 1)).to.equal('LDXL');
+                expect(Formatter.formatRoman(490, 2)).to.equal('XD');
+                expect(Formatter.formatRoman(490, 3)).to.equal('XD');
+                expect(Formatter.formatRoman(490, 4)).to.equal('XD');
+                expect(Formatter.formatRoman(495, 0)).to.equal('CDXCV');
+                expect(Formatter.formatRoman(495, 1)).to.equal('LDVL');
+                expect(Formatter.formatRoman(495, 2)).to.equal('XDV');
+                expect(Formatter.formatRoman(495, 3)).to.equal('VD');
+                expect(Formatter.formatRoman(495, 4)).to.equal('VD');
+                expect(Formatter.formatRoman(499, 0)).to.equal('CDXCIX');
+                expect(Formatter.formatRoman(499, 1)).to.equal('LDVLIV');
+                expect(Formatter.formatRoman(499, 2)).to.equal('XDIX');
+                expect(Formatter.formatRoman(499, 3)).to.equal('VDIV');
+                expect(Formatter.formatRoman(499, 4)).to.equal('ID');
+                expect(Formatter.formatRoman(500, 0)).to.equal('D');
+                expect(Formatter.formatRoman(500, 4)).to.equal('D');
+                expect(Formatter.formatRoman(888, 0)).to.equal('DCCCLXXXVIII');
+                expect(Formatter.formatRoman(888, 4)).to.equal('DCCCLXXXVIII');
+                expect(Formatter.formatRoman(999, 0)).to.equal('CMXCIX');
+                expect(Formatter.formatRoman(999, 1)).to.equal('LMVLIV');
+                expect(Formatter.formatRoman(999, 2)).to.equal('XMIX');
+                expect(Formatter.formatRoman(999, 3)).to.equal('VMIV');
+                expect(Formatter.formatRoman(999, 4)).to.equal('IM');
+            });
+            it('should return roman numbers for decimal numbers 1000 to 3999', function () {
+                expect(Formatter.formatRoman(1000, 0)).to.equal('M');
+                expect(Formatter.formatRoman(1000, 4)).to.equal('M');
+                expect(Formatter.formatRoman(3888, 0)).to.equal('MMMDCCCLXXXVIII');
+                expect(Formatter.formatRoman(3888, 4)).to.equal('MMMDCCCLXXXVIII');
+                expect(Formatter.formatRoman(3999, 0)).to.equal('MMMCMXCIX');
+                expect(Formatter.formatRoman(3999, 1)).to.equal('MMMLMVLIV');
+                expect(Formatter.formatRoman(3999, 2)).to.equal('MMMXMIX');
+                expect(Formatter.formatRoman(3999, 3)).to.equal('MMMVMIV');
+                expect(Formatter.formatRoman(3999, 4)).to.equal('MMMIM');
+            });
+            it('should return an empty string', function () {
+                expect(Formatter.formatRoman(0, -1)).to.equal('');
+                expect(Formatter.formatRoman(0, 0)).to.equal('');
+                expect(Formatter.formatRoman(0, 1)).to.equal('');
+                expect(Formatter.formatRoman(0, 2)).to.equal('');
+                expect(Formatter.formatRoman(0, 3)).to.equal('');
+                expect(Formatter.formatRoman(0, 4)).to.equal('');
+                expect(Formatter.formatRoman(-1, 0)).to.equal('');
+                expect(Formatter.formatRoman(4000, 0)).to.equal('');
+            });
+            it('should return lower-case numbers', function () {
+                expect(Formatter.formatRoman(1666, 0, { lower: true })).to.equal('mdclxvi');
+            });
+        });
+
         // constructor --------------------------------------------------------
 
         describe('constructor', function () {
             it('creates a new instance', function () {
-                formatter = new Formatter();
+                formatter = new Formatter('window-0');
                 expect(formatter).to.be.an('object');
             });
         });
@@ -79,186 +279,6 @@ define([
             });
         });
 
-        describe('method "formatRoman"', function () {
-            it('should exist', function () {
-                expect(formatter).to.respondTo('formatRoman');
-            });
-            it('should return an empty string for zero', function () {
-                expect(formatter.formatRoman(0, 0)).to.equal('');
-                expect(formatter.formatRoman(0, 1)).to.equal('');
-                expect(formatter.formatRoman(0, 2)).to.equal('');
-                expect(formatter.formatRoman(0, 3)).to.equal('');
-                expect(formatter.formatRoman(0, 4)).to.equal('');
-            });
-            it('should return roman numbers for decimal numbers 1 to 9', function () {
-                expect(formatter.formatRoman(1, 0)).to.equal('I');
-                expect(formatter.formatRoman(1, 1)).to.equal('I');
-                expect(formatter.formatRoman(1, 2)).to.equal('I');
-                expect(formatter.formatRoman(1, 3)).to.equal('I');
-                expect(formatter.formatRoman(1, 4)).to.equal('I');
-                expect(formatter.formatRoman(2, 0)).to.equal('II');
-                expect(formatter.formatRoman(3, 0)).to.equal('III');
-                expect(formatter.formatRoman(4, 0)).to.equal('IV');
-                expect(formatter.formatRoman(4, 1)).to.equal('IV');
-                expect(formatter.formatRoman(4, 2)).to.equal('IV');
-                expect(formatter.formatRoman(4, 3)).to.equal('IV');
-                expect(formatter.formatRoman(4, 4)).to.equal('IV');
-                expect(formatter.formatRoman(5, 0)).to.equal('V');
-                expect(formatter.formatRoman(6, 0)).to.equal('VI');
-                expect(formatter.formatRoman(7, 0)).to.equal('VII');
-                expect(formatter.formatRoman(8, 0)).to.equal('VIII');
-                expect(formatter.formatRoman(9, 0)).to.equal('IX');
-                expect(formatter.formatRoman(9, 1)).to.equal('IX');
-                expect(formatter.formatRoman(9, 2)).to.equal('IX');
-                expect(formatter.formatRoman(9, 3)).to.equal('IX');
-                expect(formatter.formatRoman(9, 4)).to.equal('IX');
-            });
-            it('should return roman numbers for decimal numbers 10 to 99', function () {
-                expect(formatter.formatRoman(10, 0)).to.equal('X');
-                expect(formatter.formatRoman(19, 0)).to.equal('XIX');
-                expect(formatter.formatRoman(19, 4)).to.equal('XIX');
-                expect(formatter.formatRoman(20, 0)).to.equal('XX');
-                expect(formatter.formatRoman(35, 0)).to.equal('XXXV');
-                expect(formatter.formatRoman(35, 4)).to.equal('XXXV');
-                expect(formatter.formatRoman(39, 0)).to.equal('XXXIX');
-                expect(formatter.formatRoman(39, 4)).to.equal('XXXIX');
-                expect(formatter.formatRoman(40, 0)).to.equal('XL');
-                expect(formatter.formatRoman(40, 4)).to.equal('XL');
-                expect(formatter.formatRoman(44, 0)).to.equal('XLIV');
-                expect(formatter.formatRoman(44, 4)).to.equal('XLIV');
-                expect(formatter.formatRoman(45, 0)).to.equal('XLV');
-                expect(formatter.formatRoman(45, 1)).to.equal('VL');
-                expect(formatter.formatRoman(45, 2)).to.equal('VL');
-                expect(formatter.formatRoman(45, 3)).to.equal('VL');
-                expect(formatter.formatRoman(45, 4)).to.equal('VL');
-                expect(formatter.formatRoman(48, 0)).to.equal('XLVIII');
-                expect(formatter.formatRoman(48, 1)).to.equal('VLIII');
-                expect(formatter.formatRoman(49, 0)).to.equal('XLIX');
-                expect(formatter.formatRoman(49, 1)).to.equal('VLIV');
-                expect(formatter.formatRoman(49, 2)).to.equal('IL');
-                expect(formatter.formatRoman(49, 3)).to.equal('IL');
-                expect(formatter.formatRoman(49, 4)).to.equal('IL');
-                expect(formatter.formatRoman(50, 0)).to.equal('L');
-                expect(formatter.formatRoman(50, 4)).to.equal('L');
-                expect(formatter.formatRoman(94, 0)).to.equal('XCIV');
-                expect(formatter.formatRoman(94, 4)).to.equal('XCIV');
-                expect(formatter.formatRoman(95, 0)).to.equal('XCV');
-                expect(formatter.formatRoman(95, 1)).to.equal('VC');
-                expect(formatter.formatRoman(95, 4)).to.equal('VC');
-                expect(formatter.formatRoman(99, 0)).to.equal('XCIX');
-                expect(formatter.formatRoman(99, 1)).to.equal('VCIV');
-                expect(formatter.formatRoman(99, 2)).to.equal('IC');
-                expect(formatter.formatRoman(99, 3)).to.equal('IC');
-                expect(formatter.formatRoman(99, 4)).to.equal('IC');
-            });
-            it('should return roman numbers for decimal numbers 100 to 999', function () {
-                expect(formatter.formatRoman(100, 0)).to.equal('C');
-                expect(formatter.formatRoman(100, 4)).to.equal('C');
-                expect(formatter.formatRoman(199, 0)).to.equal('CXCIX');
-                expect(formatter.formatRoman(199, 1)).to.equal('CVCIV');
-                expect(formatter.formatRoman(199, 2)).to.equal('CIC');
-                expect(formatter.formatRoman(199, 3)).to.equal('CIC');
-                expect(formatter.formatRoman(199, 4)).to.equal('CIC');
-                expect(formatter.formatRoman(300, 0)).to.equal('CCC');
-                expect(formatter.formatRoman(300, 4)).to.equal('CCC');
-                expect(formatter.formatRoman(400, 0)).to.equal('CD');
-                expect(formatter.formatRoman(400, 4)).to.equal('CD');
-                expect(formatter.formatRoman(450, 0)).to.equal('CDL');
-                expect(formatter.formatRoman(450, 1)).to.equal('LD');
-                expect(formatter.formatRoman(450, 4)).to.equal('LD');
-                expect(formatter.formatRoman(490, 0)).to.equal('CDXC');
-                expect(formatter.formatRoman(490, 1)).to.equal('LDXL');
-                expect(formatter.formatRoman(490, 2)).to.equal('XD');
-                expect(formatter.formatRoman(490, 3)).to.equal('XD');
-                expect(formatter.formatRoman(490, 4)).to.equal('XD');
-                expect(formatter.formatRoman(495, 0)).to.equal('CDXCV');
-                expect(formatter.formatRoman(495, 1)).to.equal('LDVL');
-                expect(formatter.formatRoman(495, 2)).to.equal('XDV');
-                expect(formatter.formatRoman(495, 3)).to.equal('VD');
-                expect(formatter.formatRoman(495, 4)).to.equal('VD');
-                expect(formatter.formatRoman(499, 0)).to.equal('CDXCIX');
-                expect(formatter.formatRoman(499, 1)).to.equal('LDVLIV');
-                expect(formatter.formatRoman(499, 2)).to.equal('XDIX');
-                expect(formatter.formatRoman(499, 3)).to.equal('VDIV');
-                expect(formatter.formatRoman(499, 4)).to.equal('ID');
-                expect(formatter.formatRoman(500, 0)).to.equal('D');
-                expect(formatter.formatRoman(500, 4)).to.equal('D');
-                expect(formatter.formatRoman(888, 0)).to.equal('DCCCLXXXVIII');
-                expect(formatter.formatRoman(888, 4)).to.equal('DCCCLXXXVIII');
-                expect(formatter.formatRoman(999, 0)).to.equal('CMXCIX');
-                expect(formatter.formatRoman(999, 1)).to.equal('LMVLIV');
-                expect(formatter.formatRoman(999, 2)).to.equal('XMIX');
-                expect(formatter.formatRoman(999, 3)).to.equal('VMIV');
-                expect(formatter.formatRoman(999, 4)).to.equal('IM');
-            });
-            it('should return roman numbers for decimal numbers 1000 to 3999', function () {
-                expect(formatter.formatRoman(1000, 0)).to.equal('M');
-                expect(formatter.formatRoman(1000, 4)).to.equal('M');
-                expect(formatter.formatRoman(3888, 0)).to.equal('MMMDCCCLXXXVIII');
-                expect(formatter.formatRoman(3888, 4)).to.equal('MMMDCCCLXXXVIII');
-                expect(formatter.formatRoman(3999, 0)).to.equal('MMMCMXCIX');
-                expect(formatter.formatRoman(3999, 1)).to.equal('MMMLMVLIV');
-                expect(formatter.formatRoman(3999, 2)).to.equal('MMMXMIX');
-                expect(formatter.formatRoman(3999, 3)).to.equal('MMMVMIV');
-                expect(formatter.formatRoman(3999, 4)).to.equal('MMMIM');
-            });
-            it('should return null for invalid numbers', function () {
-                expect(formatter.formatRoman(-1)).to.equal(null);
-                expect(formatter.formatRoman(4000)).to.equal(null);
-            });
-        });
-
-        describe('function "parseRoman"', function () {
-            it('should exist', function () {
-                expect(formatter).to.respondTo('parseRoman');
-            });
-            it('should convert roman to decimal', function () {
-                expect(formatter.parseRoman('')).to.equal(0);
-                expect(formatter.parseRoman('I')).to.equal(1);
-                expect(formatter.parseRoman('V')).to.equal(5);
-                expect(formatter.parseRoman('X')).to.equal(10);
-                expect(formatter.parseRoman('L')).to.equal(50);
-                expect(formatter.parseRoman('C')).to.equal(100);
-                expect(formatter.parseRoman('D')).to.equal(500);
-                expect(formatter.parseRoman('M')).to.equal(1000);
-                expect(formatter.parseRoman('II')).to.equal(2);
-                expect(formatter.parseRoman('III')).to.equal(3);
-                expect(formatter.parseRoman('IIII')).to.equal(4);
-                expect(formatter.parseRoman('IIIII')).to.equal(5);
-                expect(formatter.parseRoman('MMMDDDCCCLLLXXXVVVIII')).to.equal(4998);
-                expect(formatter.parseRoman('IV')).to.equal(4);
-                expect(formatter.parseRoman('IX')).to.equal(9);
-                expect(formatter.parseRoman('XXXIX')).to.equal(39);
-                expect(formatter.parseRoman('IM')).to.equal(999);
-                expect(formatter.parseRoman('VMIV')).to.equal(999);
-                expect(formatter.parseRoman('XMIX')).to.equal(999);
-                expect(formatter.parseRoman('LMVLIV')).to.equal(999);
-                expect(formatter.parseRoman('CMXCIX')).to.equal(999);
-                expect(formatter.parseRoman('DMCDLCXLVXIV')).to.equal(999);
-                expect(formatter.parseRoman('MIM')).to.equal(1999);
-                expect(formatter.parseRoman('MMMIM')).to.equal(3999);
-                expect(formatter.parseRoman('MMMIM')).to.equal(3999);
-                expect(formatter.parseRoman('IIV')).to.equal(3);
-                expect(formatter.parseRoman('IIIV')).to.equal(2);
-                expect(formatter.parseRoman('IIIIV')).to.equal(1);
-                expect(formatter.parseRoman('IIIIIV')).to.equal(0);
-                expect(formatter.parseRoman('IIIIIIV')).to.equal(-1);
-                expect(formatter.parseRoman('IMIVIX')).to.equal(1002);
-                expect(formatter.parseRoman('MDCLXVI')).to.equal(1666);
-                expect(formatter.parseRoman('IVXLCDM')).to.equal(334);
-            });
-            it('should accept lower-case strings', function () {
-                expect(formatter.parseRoman('mdclxvi')).to.equal(1666);
-                expect(formatter.parseRoman('mDcLxVi')).to.equal(1666);
-                expect(formatter.parseRoman('MdClXvI')).to.equal(1666);
-            });
-            it('should return null for invalid parameter', function () {
-                expect(formatter.parseRoman('abc')).to.equal(null);
-                expect(formatter.parseRoman('I I')).to.equal(null);
-                expect(formatter.parseRoman('42')).to.equal(null);
-            });
-        });
-
         describe('method "formatStandardNumber"', function () {
             it('should exist', function () {
                 expect(formatter).to.respondTo('formatStandardNumber');
