@@ -29,6 +29,16 @@ define([
         // constants ----------------------------------------------------------
 
         describe('constant', function () {
+            it('"ROMAN_DIGITS" should exist', function () {
+                expect(LocaleData).to.have.a.property('ROMAN_DIGITS').that.is.an('object');
+                expect(LocaleData.ROMAN_DIGITS).to.have.a.property('I', 1);
+                expect(LocaleData.ROMAN_DIGITS).to.have.a.property('V', 5);
+                expect(LocaleData.ROMAN_DIGITS).to.have.a.property('X', 10);
+                expect(LocaleData.ROMAN_DIGITS).to.have.a.property('L', 50);
+                expect(LocaleData.ROMAN_DIGITS).to.have.a.property('C', 100);
+                expect(LocaleData.ROMAN_DIGITS).to.have.a.property('D', 500);
+                expect(LocaleData.ROMAN_DIGITS).to.have.a.property('M', 1000);
+            });
             it('"LOCALE" should exist', function () {
                 expect(LocaleData).to.have.a.property('LOCALE').that.is.a('string');
             });
