@@ -49,33 +49,121 @@ define([
 
         // static methods -----------------------------------------------------
 
-        describe('method "numberToString"', function () {
+        describe('method "parseDecimal"', function () {
             it('should exist', function () {
-                expect(Parser).itself.to.respondTo('numberToString');
+                expect(Parser).itself.to.respondTo('parseDecimal');
             });
-            it('should convert numbers to string using local decimal separator', function () {
-                expect(Parser.numberToString(0)).to.equal('0');
-                expect(Parser.numberToString(42)).to.equal('42');
-                expect(Parser.numberToString(-1)).to.equal('-1');
-                expect(Parser.numberToString(0.5)).to.equal('0,5');
-                expect(Parser.numberToString(-12.5)).to.equal('-12,5');
+            it('should convert strings to number using local decimal separator', function () {
+                expect(Parser.parseDecimal('0')).to.equal(0);
+                expect(Parser.parseDecimal('42')).to.equal(42);
+                expect(Parser.parseDecimal('-1')).to.equal(-1);
+                expect(Parser.parseDecimal('0,5')).to.equal(0.5);
+                expect(Parser.parseDecimal('-12,5')).to.equal(-12.5);
+            });
+            it('should return NaN for invalid strings', function () {
+                expect(Parser.parseDecimal('')).to.be.nan;
+                expect(Parser.parseDecimal('a')).to.be.nan;
             });
         });
 
-        describe('method "stringToNumber"', function () {
+        describe('function "parseAlphabetic"', function () {
             it('should exist', function () {
-                expect(Parser).itself.to.respondTo('stringToNumber');
+                expect(Parser).itself.to.respondTo('parseAlphabetic');
             });
-            it('should convert strings to number using local decimal separator', function () {
-                expect(Parser.stringToNumber('0')).to.equal(0);
-                expect(Parser.stringToNumber('42')).to.equal(42);
-                expect(Parser.stringToNumber('-1')).to.equal(-1);
-                expect(Parser.stringToNumber('0,5')).to.equal(0.5);
-                expect(Parser.stringToNumber('-12,5')).to.equal(-12.5);
+            it('should convert "digit" method to decimal', function () {
+                expect(Parser.parseAlphabetic('', 'digit')).to.equal(0);
+                expect(Parser.parseAlphabetic('A', 'digit')).to.equal(1);
+                expect(Parser.parseAlphabetic('B', 'digit')).to.equal(2);
+                expect(Parser.parseAlphabetic('C', 'digit')).to.equal(3);
+                expect(Parser.parseAlphabetic('X', 'digit')).to.equal(24);
+                expect(Parser.parseAlphabetic('Y', 'digit')).to.equal(25);
+                expect(Parser.parseAlphabetic('Z', 'digit')).to.equal(26);
+                expect(Parser.parseAlphabetic('AA', 'digit')).to.equal(27);
+                expect(Parser.parseAlphabetic('AB', 'digit')).to.equal(28);
+                expect(Parser.parseAlphabetic('AY', 'digit')).to.equal(51);
+                expect(Parser.parseAlphabetic('AZ', 'digit')).to.equal(52);
+                expect(Parser.parseAlphabetic('BA', 'digit')).to.equal(53);
+                expect(Parser.parseAlphabetic('BB', 'digit')).to.equal(54);
+                expect(Parser.parseAlphabetic('ZY', 'digit')).to.equal(701);
+                expect(Parser.parseAlphabetic('ZZ', 'digit')).to.equal(702);
+                expect(Parser.parseAlphabetic('AAA', 'digit')).to.equal(703);
             });
-            it('should return NaN for invalid strings', function () {
-                expect(Parser.stringToNumber('')).to.be.nan;
-                expect(Parser.stringToNumber('a')).to.be.nan;
+            it('should convert "repeat" method to decimal', function () {
+                expect(Parser.parseAlphabetic('', 'repeat')).to.equal(0);
+                expect(Parser.parseAlphabetic('A', 'repeat')).to.equal(1);
+                expect(Parser.parseAlphabetic('B', 'repeat')).to.equal(2);
+                expect(Parser.parseAlphabetic('C', 'repeat')).to.equal(3);
+                expect(Parser.parseAlphabetic('X', 'repeat')).to.equal(24);
+                expect(Parser.parseAlphabetic('Y', 'repeat')).to.equal(25);
+                expect(Parser.parseAlphabetic('Z', 'repeat')).to.equal(26);
+                expect(Parser.parseAlphabetic('AA', 'repeat')).to.equal(27);
+                expect(Parser.parseAlphabetic('BB', 'repeat')).to.equal(28);
+                expect(Parser.parseAlphabetic('YY', 'repeat')).to.equal(51);
+                expect(Parser.parseAlphabetic('ZZ', 'repeat')).to.equal(52);
+                expect(Parser.parseAlphabetic('AAA', 'repeat')).to.equal(53);
+                expect(Parser.parseAlphabetic('ZZZ', 'repeat')).to.equal(78);
+            });
+            it('should accept lower-case strings', function () {
+                expect(Parser.parseAlphabetic('Aa', 'digit')).to.equal(27);
+                expect(Parser.parseAlphabetic('aA', 'repeat')).to.equal(27);
+            });
+            it('should return null for invalid parameter', function () {
+                expect(Parser.parseAlphabetic('I I', 'digit')).to.equal(null);
+                expect(Parser.parseAlphabetic('I I', 'repeat')).to.equal(null);
+                expect(Parser.parseAlphabetic('42', 'digit')).to.equal(null);
+                expect(Parser.parseAlphabetic('42', 'repeat')).to.equal(null);
+                expect(Parser.parseAlphabetic('abc', 'repeat')).to.equal(null);
+            });
+        });
+
+        describe('function "parseRoman"', function () {
+            it('should exist', function () {
+                expect(Parser).itself.to.respondTo('parseRoman');
+            });
+            it('should convert roman to decimal', function () {
+                expect(Parser.parseRoman('')).to.equal(0);
+                expect(Parser.parseRoman('I')).to.equal(1);
+                expect(Parser.parseRoman('V')).to.equal(5);
+                expect(Parser.parseRoman('X')).to.equal(10);
+                expect(Parser.parseRoman('L')).to.equal(50);
+                expect(Parser.parseRoman('C')).to.equal(100);
+                expect(Parser.parseRoman('D')).to.equal(500);
+                expect(Parser.parseRoman('M')).to.equal(1000);
+                expect(Parser.parseRoman('II')).to.equal(2);
+                expect(Parser.parseRoman('III')).to.equal(3);
+                expect(Parser.parseRoman('IIII')).to.equal(4);
+                expect(Parser.parseRoman('IIIII')).to.equal(5);
+                expect(Parser.parseRoman('MMMDDDCCCLLLXXXVVVIII')).to.equal(4998);
+                expect(Parser.parseRoman('IV')).to.equal(4);
+                expect(Parser.parseRoman('IX')).to.equal(9);
+                expect(Parser.parseRoman('XXXIX')).to.equal(39);
+                expect(Parser.parseRoman('IM')).to.equal(999);
+                expect(Parser.parseRoman('VMIV')).to.equal(999);
+                expect(Parser.parseRoman('XMIX')).to.equal(999);
+                expect(Parser.parseRoman('LMVLIV')).to.equal(999);
+                expect(Parser.parseRoman('CMXCIX')).to.equal(999);
+                expect(Parser.parseRoman('DMCDLCXLVXIV')).to.equal(999);
+                expect(Parser.parseRoman('MIM')).to.equal(1999);
+                expect(Parser.parseRoman('MMMIM')).to.equal(3999);
+                expect(Parser.parseRoman('MMMIM')).to.equal(3999);
+                expect(Parser.parseRoman('IIV')).to.equal(3);
+                expect(Parser.parseRoman('IIIV')).to.equal(2);
+                expect(Parser.parseRoman('IIIIV')).to.equal(1);
+                expect(Parser.parseRoman('IIIIIV')).to.equal(0);
+                expect(Parser.parseRoman('IIIIIIV')).to.equal(-1);
+                expect(Parser.parseRoman('IMIVIX')).to.equal(1002);
+                expect(Parser.parseRoman('MDCLXVI')).to.equal(1666);
+                expect(Parser.parseRoman('IVXLCDM')).to.equal(334);
+            });
+            it('should accept lower-case strings', function () {
+                expect(Parser.parseRoman('mdclxvi')).to.equal(1666);
+                expect(Parser.parseRoman('mDcLxVi')).to.equal(1666);
+                expect(Parser.parseRoman('MdClXvI')).to.equal(1666);
+            });
+            it('should return null for invalid parameter', function () {
+                expect(Parser.parseRoman('abc')).to.equal(null);
+                expect(Parser.parseRoman('I I')).to.equal(null);
+                expect(Parser.parseRoman('42')).to.equal(null);
             });
         });
 
