@@ -69,23 +69,23 @@ define([
         describe('constructor', function () {
             it('should take all parameters', function () {
                 var fontDesc = new Font('times', 10, false, true);
-                expect(fontDesc).to.have.property('family', 'times');
-                expect(fontDesc).to.have.property('size', 10);
-                expect(fontDesc).to.have.property('bold', false);
-                expect(fontDesc).to.have.property('italic', true);
+                expect(fontDesc).to.have.a.property('family', 'times');
+                expect(fontDesc).to.have.a.property('size', 10);
+                expect(fontDesc).to.have.a.property('bold', false);
+                expect(fontDesc).to.have.a.property('italic', true);
             });
             it('should convert font name to lower-case', function () {
                 var fontDesc = new Font('TiMeS', 10.25, false, true);
-                expect(fontDesc).to.have.property('family', 'times');
+                expect(fontDesc).to.have.a.property('family', 'times');
             });
             it('should round font size', function () {
                 var fontDesc = new Font('times', 10.25, false, true);
-                expect(fontDesc).to.have.property('size', 10.3);
+                expect(fontDesc).to.have.a.property('size', 10.3);
             });
             it('should accept missing flags', function () {
                 var fontDesc = new Font('times', 10);
-                expect(fontDesc).to.have.property('bold', false);
-                expect(fontDesc).to.have.property('italic', false);
+                expect(fontDesc).to.have.a.property('bold', false);
+                expect(fontDesc).to.have.a.property('italic', false);
             });
         });
 
@@ -95,7 +95,7 @@ define([
             it('should exist', function () {
                 expect(Font).to.respondTo('clone');
             });
-            it('should return a string', function () {
+            it('should return a clone', function () {
                 var fontDesc1 = new Font('times', 10, false, true);
                 var fontDesc2 = fontDesc1.clone();
                 expect(fontDesc2).to.not.equal(fontDesc1);
