@@ -338,7 +338,7 @@ define([
                 var it1 = IteratorUtils.createArrayIterator([2, 3]);
                 var it2 = IteratorUtils.ALWAYS_DONE_ITERATOR;
                 var it3 = IteratorUtils.createArrayIterator([4, 5]);
-                var combIt = IteratorUtils.createSerialIterator(it1, it2, it3);
+                var combIt = IteratorUtils.createSerialIterator(it1, it2, null, it3);
                 expect(combIt).to.respondTo('next');
                 expect(combIt.next()).to.deep.equal({ done: false, value: 2, index: 0 });
                 expect(combIt.next()).to.deep.equal({ done: false, value: 3, index: 1 });
@@ -346,6 +346,11 @@ define([
                 expect(combIt.next()).to.deep.equal({ done: false, value: 5, index: 1 });
                 expect(combIt.next()).to.deep.equal({ done: true });
             });
+            it('should create an empty iterator', function () {
+                var combIt = IteratorUtils.createSerialIterator(null);
+                expect(combIt).to.respondTo('next');
+                expect(combIt.next()).to.deep.equal({ done: true });
+            });
         });
 
         describe('method "createSynchronizedIterator"', function () {
